(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   4567754,      80597]
NotebookOptionsPosition[   4548585,      79930]
NotebookOutlinePosition[   4550813,      79994]
CellTagsIndexPosition[   4550632,      79988]
WindowTitle->Automatic
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Semi-Analytic Approach", "Title",
 Editable->True,
 CellOpen->True,
 CellChangeTimes->{{3.650670402973497*^9, 3.6506704076264763`*^9}},
 TextAlignment->Center,
 CellTags->{
  "DiaryDate[{2015, 9, 7, 23, 26, 54.229558}]", 
   "CellGUID[158075531113598598368791436607253277117]"},
 CellID->1490466418],

Cell[CellGroupData[{

Cell["Field functions for a ring", "Section",
 CellChangeTimes->{
  3.650659022905217*^9, {3.65065915429261*^9, 3.650659157746806*^9}, {
   3.6509031267815447`*^9, 3.650903129230991*^9}},
 CellID->53137184],

Cell[CellGroupData[{

Cell["Introduction", "Subsection",
 CellChangeTimes->{{3.650730432439126*^9, 3.6507304338146067`*^9}},
 CellID->839477994],

Cell["\<\
These definitions are based on the discussion given in the paper, cited here\
\>", "Text",
 CellChangeTimes->{{3.650729690067259*^9, 3.6507297176331377`*^9}, {
   3.650729778561084*^9, 3.6507297800697803`*^9}, 3.650969906208817*^9},
 CellID->1440129765],

Cell[TextData[ButtonBox["http://scitation.aip.org/content/aapt/journal/ajp/74/\
4/10.1119/1.2149869",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["http://scitation.aip.org/content/aapt/journal/ajp/74/4/10.1119/1.\
2149869"], None},
 ButtonNote->
  "http://scitation.aip.org/content/aapt/journal/ajp/74/4/10.1119/1.2149869"]]\
, "Text",
 CellChangeTimes->{{3.6507297834082127`*^9, 3.650729789241596*^9}},
 CellID->1242176565],

Cell["\<\
and which can be downloaded from several places on the Internet such as \
\>", "Text",
 CellChangeTimes->{{3.6507297926306953`*^9, 3.6507298073484097`*^9}, 
   3.6509730723245*^9},
 CellID->1811136106],

Cell[TextData[ButtonBox["https://wolfr.am/6T83BMIq",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://wolfr.am/6T83BMIq"], None},
 ButtonNote->"https://wolfr.am/6T83BMIq"]], "Text",
 CellChangeTimes->{{3.650729970623987*^9, 3.650729996733755*^9}},
 CellID->1331320964],

Cell[TextData[{
 "In that paper the electric field of a uniform ring of charge is computed. \
The result is presented in terms of Elliptic integrals.  Then that paper goes \
on to create estimates of those Elliptic expressions to help develop  \
intuitions for the computations by students.  However here we use the full, \
exact, analytic expressions that contain the Elliptic integrals themselves as \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " computes these efficiently.  The expressions from the above paper need to \
be modified slightly since they assume that the ring of charge is of a fixed \
radius.  However we will use the expressions for the ring of charge to then \
integrate over the radius with an appropriate radial symmetric charge \
distribution on a disk. "
}], "Text",
 CellChangeTimes->{{3.65073006006238*^9, 3.650730190716631*^9}, {
  3.6507302423097067`*^9, 3.650730423031921*^9}, {3.6509730950930157`*^9, 
  3.6509730975143633`*^9}},
 CellID->1665790189],

Cell[TextData[{
 "We will set the prefactor ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"4", "\[Pi]", " ", 
     SubscriptBox["\[Epsilon]", "0"]}]], TraditionalForm]]],
 " in all expressions to be 1\[LongDash]things can be scaled overall later \
on.  "
}], "Text",
 CellChangeTimes->{{3.650659225680077*^9, 3.6506592535989933`*^9}, {
  3.650970370213069*^9, 3.650970371995315*^9}, {3.650970455045982*^9, 
  3.650970470933374*^9}},
 CellID->746921763]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference for the expressions from the paper", "Subsection",
 CellChangeTimes->{{3.650731256602261*^9, 3.650731267201847*^9}, {
  3.6507313996618633`*^9, 3.650731399964464*^9}},
 CellID->1859160167],

Cell["\<\
The boxed equations here are screen captures from the reference.\
\>", "Text",
 CellChangeTimes->{{3.650925700422077*^9, 3.650925719853364*^9}},
 CellID->1584707174],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs3ftfVIeh9/t9znN+OP/FDMzIRTTBaILVGLd4eTRKQXIUo9ZYlbwiplVs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    "], {{0, 360}, {954, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJydlndUVNcWxs+9d3qhzTACUoZehyZlAOm9Sa+iMswMMJQBhxkQ7IqoYEQR
kaYIEhUwYDQCEiuiWAgKFuwZJAgoMRhFVCy5o2slvry89/Ly/XHW756z97nn
fHvfta52UlZ4MgwAyCGgQzgnz10k4uRHYNAHj3wxPwlCwY+CDoDiFyQQZsEK
AGQKxaJwXw9mbFw8E98PYEAEOGAFAIebkx0c4RMpi/b39mTmoEHgX/TqFpBt
CK6z/EKZTPD/SZGbLRIDAIWiPI/Hz+GiXIhyRp44WzY/hTI9KV3GsOz8dBF6
QJRVZJzymc0+xXxmNxnzMoU8lGVnzuZl8mTcg/KmXAkfZSQI5aJcAT8P5Rso
62VIMgUov5blZvI5OQBgZO7oifncVJQtZUaJIsM9UZ4PAIGS8gUnfcFi/jKx
7FKeWdn5IkFKqphpxDVmWjk4sJl+/LwMvljMCuVw0zkiHtMzKzObI8wH4POd
P0lJ5i0TNdnOysHOjmVtbvWFUf918W9KVtvP9CLsU80gRt8fc38Vl9UAAHsa
9WbbH3NJVQB0bABA5e4fc3p7AZBH69Z+9Yv7MGT9kioWZztaWOTl5ZkL+Fxz
maG/638G/A198T5z2Xa/28P04idzJBlipsw3blZGlkTEzMnmcPlM1p+b+B8n
/vU5zML5yXwRX4hmRKNdJhCmoOUW8gRiQZaQKRD+pyL+w7Q/6XNfo6I1fgD0
JeZA4SodID/3AQyNDJCEPegK9HvdgojRQPblxWiNfe77T4L+fVe4VDbkCFI+
5XmGRzK5ElHu5zXZZwmwgATkAR2oAk2gC4wAC1gDe+AE3IA3CAAhIBLEgcWA
C1JBJhCBPLACrAVFoARsAztBNagDjaAJtIIjoAOcAGfBBXAFXAM3wT0gBaPg
KZgCr8AsBEF4iArRIFVIC9KHTCFriA25QN5QEBQOxUGJUAokhCTQCmg9VAKV
QdVQPdQEfQsdh85Cl6AB6A40DE1Av0JvYQSmwHRYAzaALWA27A4HwpHwIjgF
XgoXwIXwVrgSboAPwe3wWfgKfBOWwk/haQQgZISBaCMshI14IiFIPJKMiJBV
SDFSgTQgrUgX0otcR6TIJPIGg8PQMEwMC+OE8cNEYbiYpZhVmC2YasxBTDum
B3MdM4yZwnzAUrHqWFOsI9YfG4tNweZhi7AV2P3YY9jz2JvYUewrHA7HwBni
7HF+uDhcGm45bgtuN64NdwY3gBvBTePxeFW8Kd4ZH4Ln4MX4InwV/hD+NH4Q
P4p/TSATtAjWBB9CPEFIWEeoIDQTThEGCWOEWaICUZ/oSAwh8oj5xFJiI7GL
eJU4SpwlKZIMSc6kSFIaaS2pktRKOk+6T3pBJpN1yA7kMLKAvIZcST5Mvkge
Jr+hKFFMKJ6UBIqEspVygHKGcofygkqlGlDdqPFUMXUrtYl6jvqQ+lqOJmcu
5y/Hk1stVyPXLjco90yeKK8v7y6/WL5AvkL+qPxV+UkFooKBgqcCR2GVQo3C
cYUhhWlFmqKVYohipuIWxWbFS4rjSnglAyVvJZ5SodI+pXNKIzSEpkvzpHFp
62mNtPO0UTqObkj3p6fRS+jf0PvpU8pKyjbK0crLlGuUTypLGQjDgOHPyGCU
Mo4wbjHeztGY4z6HP2fznNY5g3NmVOaquKnwVYpV2lRuqrxVZap6q6arblft
UH2ghlEzUQtTy1Pbo3ZebXIufa7TXO7c4rlH5t5Vh9VN1MPVl6vvU+9Tn9bQ
1PDVyNao0jinManJ0HTTTNMs1zylOaFF03LREmiVa53WesJUZrozM5iVzB7m
lLa6tp+2RLteu197VsdQJ0pnnU6bzgNdki5bN1m3XLdbd0pPSy9Yb4Vei95d
faI+Wz9Vf5d+r/6MgaFBjMFGgw6DcUMVQ3/DAsMWw/tGVCNXo6VGDUY3jHHG
bON0493G10xgE1uTVJMak6umsKmdqcB0t+mAGdbMwUxo1mA2xKKw3Fm5rBbW
sDnDPMh8nXmH+TMLPYt4i+0WvRYfLG0tMywbLe9ZKVkFWK2z6rL61drEmmtd
Y31jHnWez7zV8zrnPbcxteHb7LG5bUuzDbbdaNtt+97O3k5k12o3Ya9nn2hf
az/EprND2VvYFx2wDh4Oqx1OOLxxtHMUOx5x/MWJ5ZTu1Ow0Pt9wPn9+4/wR
Zx1njnO9s9SF6ZLostdF6qrtynFtcH3kpuvGc9vvNuZu7J7mfsj9mYelh8jj
mMeMp6PnSs8zXoiXr1exV7+3kneUd7X3Qx8dnxSfFp8pX1vf5b5n/LB+gX7b
/Yb8Nfy5/k3+UwH2ASsDegIpgRGB1YGPgkyCREFdwXBwQPCO4PsL9BcIF3SE
gBD/kB0hD0INQ5eGfh+GCwsNqwl7HG4VviK8N4IWsSSiOeJVpEdkaeS9KKMo
SVR3tHx0QnRT9EyMV0xZjDTWInZl7JU4tThBXGc8Pj46fn/89ELvhTsXjibY
JhQl3FpkuGjZokuL1RZnLD65RH4JZ8nRRGxiTGJz4jtOCKeBM53kn1SbNMX1
5O7iPuW58cp5E3xnfhl/LNk5uSx5PMU5ZUfKRKprakXqpMBTUC14nuaXVpc2
kx6SfiD9Y0ZMRlsmITMx87hQSZgu7MnSzFqWNZBtml2ULV3quHTn0ilRoGh/
DpSzKKdTTEd/pvokRpINkuFcl9ya3Nd50XlHlykuEy7ryzfJ35w/VuBT8PVy
zHLu8u4V2ivWrhhe6b6yfhW0KmlV92rd1YWrR9f4rjm4lrQ2fe0P6yzXla17
uT5mfVehRuGawpENvhtaiuSKREVDG5021m3CbBJs6t88b3PV5g/FvOLLJZYl
FSXvtnC3XP7K6qvKrz5uTd7aX2pXumcbbptw263trtsPlimWFZSN7Aje0V7O
LC8uf7lzyc5LFTYVdbtIuyS7pJVBlZ1VelXbqt5Vp1bfrPGoaatVr91cO7Ob
t3twj9ue1jqNupK6t3sFe2/X+9a3Nxg0VOzD7cvd97gxurH3a/bXTfvV9pfs
f39AeEB6MPxgT5N9U1OzenNpC9wiaZk4lHDo2jde33S2slrr2xhtJYfBYcnh
J98mfnvrSOCR7qPso63f6X9Xe4x2rLgdas9vn+pI7ZB2xnUOHA843t3l1HXs
e/PvD5zQPlFzUvlk6SnSqcJTH08XnJ4+k31m8mzK2ZHuJd33zsWeu9ET1tN/
PvD8xQs+F871uveevuh88cQlx0vHL7Mvd1yxu9LeZ9t37AfbH4712/W3X7W/
2nnN4VrXwPyBU4Oug2eve12/cMP/xpWbC24O3Iq6dXsoYUh6m3d7/E7Gned3
c+/O3ltzH3u/+IHCg4qH6g8bfjT+sU1qJz057DXc9yji0b0R7sjTn3J+ejda
+Jj6uGJMa6xp3Hr8xITPxLUnC5+MPs1+OjtZ9LPiz7XPjJ5994vbL31TsVOj
z0XPP/665YXqiwMvbV52T4dOP3yV+Wp2pvi16uuDb9hvet/GvB2bzXuHf1f5
3vh914fAD/c/Zn78+BtCu/vt
      "], "RGB", "XYZ"], Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{450.1578125, Automatic},
  ImageSizeRaw->{954, 360},
  PlotRange->{{0, 954}, {0, 360}}]], "Text",
 Editable->True,
 Deletable->True,
 CellFrame->True,
 CellChangeTimes->{3.650925453996668*^9},
 TextAlignment->Center,
 CellID->1879126508],

Cell["\<\
Corresponding to the above, but not given in the reference, is an expression \
for the potential. Using the reference\[CloseCurlyQuote]s notation this is,\
\>", "Text",
 CellChangeTimes->{{3.650925722765225*^9, 3.6509257789319153`*^9}, {
  3.6509705168258247`*^9, 3.650970522669788*^9}},
 CellID->707936593],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"4", " ", "\[Pi]", " ", 
    SubscriptBox["\[Epsilon]", "0"]}]], 
  FractionBox["Q", 
   RowBox[{"2", "\[Pi]", " ", "a"}]], 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", 
    RowBox[{"2", "\[Pi]"}]], 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[Xi]", "2"], "-", 
        RowBox[{"2", "\[Xi]", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}], 
         RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ")"}], 
      FractionBox["1", "2"]]], 
    RowBox[{"\[DifferentialD]", "\[Alpha]"}]}]}]}]], "DisplayFormula",
 Editable->True,
 Deletable->True,
 CellChangeTimes->{{3.650925747700405*^9, 3.650925878657222*^9}},
 TextAlignment->Center,
 CellID->805650956],

Cell["\<\
The reference gives the electric field in the x-z plane.  Because of the \
symmetry of the charge distribution, the field is rotationally symmetric \
about the z-axis.\
\>", "Text",
 CellChangeTimes->{{3.650970532509089*^9, 3.6509705808666*^9}, 
   3.650973110236718*^9},
 CellID->614425537],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzs3f9bVIeB9/297uf54f4vZoBRREmC0YirSVzxy2qUiOQRjVpj/ZI7SFIk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    "], {{0, 828}, {970, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJydlndUVNcWxs+9d3qhzTACUoZehyZlAOm9Sa+iMswMMJQBhxkQ7IqoYEQR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      "], "RGB", "XYZ"], Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{448.54453125, Automatic},
  ImageSizeRaw->{970, 828},
  PlotRange->{{0, 970}, {0, 828}}]], "Text",
 Editable->True,
 Deletable->True,
 CellFrame->True,
 CellChangeTimes->{3.6507313947935753`*^9},
 TextAlignment->Center,
 CellID->901763965],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3VuOJEtSANDL44NtsBRYAvzwO0jwiwRIaNbIomBKrVZnZWdmuHv4y9zO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    "], {{0, 459}, {600, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->{267.23046875, Automatic},
  ImageSizeRaw->{600, 459},
  PlotRange->{{0, 600}, {0, 459}}]], "Text",
 Editable->True,
 Deletable->True,
 CellFrame->True,
 CellChangeTimes->{3.6509706090053988`*^9},
 TextAlignment->Center,
 CellID->1937722837]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computation and function set up", "Subsection",
 CellChangeTimes->{{3.65073044072691*^9, 3.650730443718623*^9}, {
  3.6507320578839912`*^9, 3.650732061073113*^9}},
 CellID->139084368],

Cell[TextData[{
 "In the following the parameter ",
 StyleBox["a", "MB"],
 " will generally be the (variable) radius on the disk: this parameter will \
ultimately be integrated over. The parameters r and \[Theta] are the radial \
distance from the origin and the angle with respect to the z-axis of the \
observation point (\[Theta] varies from 0 to \[Pi]).  r0 is the radius of the \
disk.  The expressions below will allow for an arbitrary value of ",
 StyleBox["r0", "MB"],
 ", however generally for plots we will set ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r0", "=", "1"}], TraditionalForm]]],
 " since the visualizations will have no reference value to compare with."
}], "Text",
 CellChangeTimes->{{3.650730586023522*^9, 3.650730609943201*^9}, {
   3.6507306679107847`*^9, 3.650730680476594*^9}, {3.650731074156352*^9, 
   3.650731132249301*^9}, {3.650731868384287*^9, 3.65073188078389*^9}, {
   3.650733028449141*^9, 3.650733080783083*^9}, {3.650733117709383*^9, 
   3.650733126133284*^9}, 3.650973112220869*^9},
 CellID->307386776],

Cell[TextData[{
 "The standard overall factor in front of the electric field vector (and in \
front of the potential which is discussed later on) is ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"4", "\[Pi]", " ", 
     SubscriptBox["\[Epsilon]", "0"]}]], TraditionalForm]]],
 ".  We will set this to 1 since, as above, we will be visualizing scaled \
versions of the field vector and the potential.  All results for the field \
and the potential can be rescaled by this factor if desired."
}], "Text",
 CellChangeTimes->{{3.650730451254155*^9, 3.650730498548543*^9}, {
  3.6507330885263042`*^9, 3.6507331127339563`*^9}, {3.650804904599464*^9, 
  3.650804912157681*^9}, {3.650897780173183*^9, 3.650897798482728*^9}, {
  3.650897965488595*^9, 3.650897980876114*^9}, {3.6509703869153023`*^9, 
  3.6509704467906637`*^9}},
 CellID->1128765040],

Cell[TextData[{
 "In the following \[Rho] represents the surface charge density on the disk \
which will generally be a function only of ",
 StyleBox["a", "MB"],
 ".  The expression for ",
 StyleBox["radialChargeFactor", "MB"],
 " below, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"radialChargeFactor", "[", 
      RowBox[{"a", ",", "\[Rho]"}], "]"}], " ", 
     RowBox[{"\[DifferentialD]", "a"}]}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"2", "\[Pi]", " ", "a", " ", "\[Rho]", " "}], 
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox["a", "2"]}]], 
     RowBox[{"\[DifferentialD]", "a"}]}]}], TraditionalForm]]],
 ", replaces the factor of ",
 Cell[BoxData[
  FormBox[
   FractionBox["Q", 
    RowBox[{"\[Pi]", " ", 
     SuperscriptBox["a", "2"]}]], TraditionalForm]]],
 " in the referenced paper\[CloseCurlyQuote]s expressions. "
}], "Text",
 CellChangeTimes->{{3.650658829015503*^9, 3.650658850206933*^9}, {
  3.650729636044036*^9, 3.650729665830701*^9}, {3.650730521618579*^9, 
  3.650730579481642*^9}, {3.650730708917347*^9, 3.6507307094511967`*^9}, {
  3.6507307697983522`*^9, 3.650730784083737*^9}, {3.6507308173593283`*^9, 
  3.650730975220066*^9}, {3.650897914215942*^9, 3.650897945189732*^9}, {
  3.650898697468663*^9, 3.6508987024228487`*^9}, {3.6508988091015263`*^9, 
  3.650898833663931*^9}, {3.650925988029862*^9, 3.650925989644349*^9}, {
  3.650926033590508*^9, 3.650926052281906*^9}, {3.650970662176229*^9, 
  3.6509707222180243`*^9}},
 CellID->632671142],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    StyleBox["radialChargeFactor", "MB"], "[", 
    RowBox[{"a_", ",", "\[Rho]_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"2", " ", "\[Rho]"}], "a"]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506577639376783`*^9, 3.650657778425453*^9}, {
   3.650658214296318*^9, 3.650658248414599*^9}, {3.6506588042440023`*^9, 
   3.650658822225803*^9}, {3.650730786908121*^9, 3.650730787836318*^9}, 
   3.650730826216053*^9, 3.650898706160748*^9},
 CellID->858673513],

Cell[TextData[{
 "The functions ",
 StyleBox["f1", "MB"],
 " and ",
 StyleBox["f2", "MB"],
 " from the paper are expressible in terms of elliptic integrals and are \
respectively (using ",
 StyleBox["m", "MB"],
 " instead of ",
 StyleBox["\[Mu]", "MB"],
 " here to avoid confusion later on)."
}], "Text",
 CellChangeTimes->{{3.6507309868593903`*^9, 3.650731005621999*^9}, {
   3.6507316230548677`*^9, 3.650731639644744*^9}, {3.650925577148633*^9, 
   3.650925588906554*^9}, 3.650926107953541*^9, 3.650973116998304*^9},
 CellID->732743175],

Cell[TextData[{
 "For ",
 StyleBox["f1", "MB"],
 ":"
}], "Text",
 CellChangeTimes->{{3.650926111615847*^9, 3.65092611392802*^9}},
 CellID->1577158026],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"m", " ", 
        RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "\[Element]", "Reals"}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "<", "m", "\[LessEqual]", "1"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellID->1543310327],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"EllipticE", "[", 
     FractionBox[
      RowBox[{"2", " ", "m"}], 
      RowBox[{"1", "+", "m"}]], "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "+", "m"}]]}]]}]], "Output",
 CellChangeTimes->{3.650731020249058*^9, 3.650732086573826*^9, 
  3.650736432352112*^9, 3.650748935521942*^9, 3.6507518402688093`*^9, 
  3.6508044856372423`*^9},
 CellID->1099153206]
}, Open  ]],

Cell[TextData[{
 "and for ",
 StyleBox["f2", "MB"],
 ":"
}], "Text",
 CellChangeTimes->{{3.650731017247027*^9, 3.650731017429492*^9}, {
  3.650926120073105*^9, 3.650926123039338*^9}},
 CellID->1786892401],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"Cos", "[", "\[Alpha]", "]"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"m", " ", 
        RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "\[Element]", "Reals"}], ",", 
      RowBox[{
       RowBox[{"-", "1"}], "<", "m", "\[LessEqual]", "1"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellID->1109177423],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"EllipticE", "[", 
       FractionBox[
        RowBox[{"2", " ", "m"}], 
        RowBox[{"1", "+", "m"}]], "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
       RowBox[{"EllipticK", "[", 
        FractionBox[
         RowBox[{"2", " ", "m"}], 
         RowBox[{"1", "+", "m"}]], "]"}]}]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", "m", " ", 
    SqrtBox[
     RowBox[{"1", "+", "m"}]]}]]}]], "Output",
 CellChangeTimes->{3.650731023869132*^9, 3.650732087067842*^9, 
  3.6507364333611403`*^9, 3.650748936610238*^9, 3.650751841289955*^9, 
  3.6508044866374598`*^9},
 CellID->813601748]
}, Open  ]],

Cell[TextData[{
 "and hence define ",
 StyleBox["f1", "MB"],
 " and ",
 StyleBox["f2", "MB"],
 " as,"
}], "Text",
 CellChangeTimes->{{3.650731028700996*^9, 3.650731035764563*^9}},
 CellID->72086914],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f1", "[", "m_", "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"EllipticE", "[", 
       FractionBox[
        RowBox[{"2", " ", "m"}], 
        RowBox[{"1", "+", "m"}]], "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
      SqrtBox[
       RowBox[{"1", "+", "m"}]]}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506578098725557`*^9, 3.650657896189987*^9}, {
   3.650658021035164*^9, 3.650658031127488*^9}, {3.650658312174068*^9, 
   3.65065832020749*^9}, 3.650731039628167*^9},
 CellID->259879548],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f2", "[", "m_", "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"EllipticE", "[", 
         FractionBox[
          RowBox[{"2", " ", "m"}], 
          RowBox[{"1", "+", "m"}]], "]"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", 
         RowBox[{"EllipticK", "[", 
          FractionBox[
           RowBox[{"2", " ", "m"}], 
           RowBox[{"1", "+", "m"}]], "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "m"}], ")"}], " ", "m", " ", 
      SqrtBox[
       RowBox[{"1", "+", "m"}]]}]]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506578098725557`*^9, 3.650657909252202*^9}, {
   3.6506580496960773`*^9, 3.6506580705776653`*^9}, {3.650658321279385*^9, 
   3.6506583246551332`*^9}, 3.650731042790305*^9},
 CellID->312793153],

Cell[TextData[{
 "The parameter \[Mu] from the paper needs to be re-expressed back in terms \
of ",
 StyleBox["r",
  FontWeight->"Bold"],
 " and ",
 StyleBox["a",
  FontWeight->"Bold"],
 " since ",
 StyleBox["a",
  FontWeight->"Bold"],
 " varies and is the ultimate integration variable when we integrate over the \
disk."
}], "Text",
 CellChangeTimes->{{3.650658624457007*^9, 3.6506586284556103`*^9}, {
   3.650731045876569*^9, 3.650731061083624*^9}, {3.650731147328781*^9, 
   3.650731195267861*^9}, 3.65097312064214*^9},
 CellID->1986570322],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"2", "\[Xi]", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
    RowBox[{"1", "+", 
     SuperscriptBox["\[Xi]", "2"]}]], "/.", 
   RowBox[{"\[Xi]", "\[Rule]", 
    RowBox[{"r", "/", "a"}]}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.650632590625018*^9, 3.650632613379101*^9}, 
   3.650658355310178*^9, 3.6506583860491447`*^9, 3.65065849603909*^9},
 CellID->2052067146],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "a", " ", "r", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   SuperscriptBox["r", "2"]}]]], "Output",
 CellChangeTimes->{
  3.650632623917178*^9, 3.650633033766444*^9, {3.650658360146106*^9, 
   3.650658387762933*^9}, 3.6506584975980463`*^9, 3.650659078337325*^9, 
   3.650659480142517*^9, 3.650670891375195*^9, 3.6507320871359873`*^9, 
   3.650736433609048*^9, 3.650748936792832*^9, 3.650751841488967*^9, 
   3.650804486873782*^9},
 CellID->1176198187]
}, Open  ]],

Cell["\<\
Similarly we need to re-express additional expressions from the paper that \
depend on its \[Xi] as follows.\
\>", "Text",
 CellChangeTimes->{{3.650731224835313*^9, 3.650731249050557*^9}, 
   3.6509731256058283`*^9},
 CellID->1153083017],

Cell["\<\
This is the coefficient of f1 from the paper for the x component of the \
electric field of the ring is \
\>", "Text",
 CellChangeTimes->{{3.650658636503091*^9, 3.6506586662699223`*^9}, {
  3.650731210052073*^9, 3.650731220051446*^9}, {3.650731445906631*^9, 
  3.650731447914897*^9}},
 CellID->467938630],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"\[Xi]", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Xi]", "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], "/.", 
   RowBox[{"\[Xi]", "\[Rule]", 
    RowBox[{"r", "/", "a"}]}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.650658546828668*^9, 3.650658554802763*^9}},
 CellID->97972188],

Cell[BoxData[
 FractionBox[
  RowBox[{"r", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
  RowBox[{"a", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["r", "2"], 
       SuperscriptBox["a", "2"]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.650658577588464*^9, 3.6506587283459272`*^9, 
  3.650659078433989*^9, 3.6506594802936153`*^9, 3.650670891460907*^9, 
  3.650732087223549*^9, 3.6507364337011023`*^9, 3.650748936881721*^9, 
  3.650751841612639*^9, 3.650804486970351*^9},
 CellID->775958274]
}, Open  ]],

Cell[TextData[{
 "This is the coefficient of ",
 StyleBox["f2", "MB"],
 " from the paper for the ",
 StyleBox["x", "MB"],
 " component of the electric field of the ring is "
}], "Text",
 CellChangeTimes->{{3.650658649558632*^9, 3.6506586699098063`*^9}, {
   3.6507314618262663`*^9, 3.650731463642185*^9}, 3.65073150807625*^9},
 CellID->394138863],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["\[Xi]", "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]]}], "/.", 
   RowBox[{"\[Xi]", "\[Rule]", 
    RowBox[{"r", "/", "a"}]}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.650658546828668*^9, 3.650658554802763*^9}, 
   3.650658646672307*^9, {3.6506586802073603`*^9, 3.65065869167906*^9}},
 CellID->819432782],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["r", "2"], 
       SuperscriptBox["a", "2"]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]]}]], "Output",
 CellChangeTimes->{3.650658730599057*^9, 3.6506590784577227`*^9, 
  3.650659480394561*^9, 3.650670891484131*^9, 3.650732087282836*^9, 
  3.650736433755694*^9, 3.650748936906705*^9, 3.6507518417313337`*^9, 
  3.6508044870380163`*^9},
 CellID->2010006534]
}, Open  ]],

Cell[TextData[{
 "This is the coefficient of ",
 StyleBox["f1", "MB"],
 " from the paper for the ",
 StyleBox["z", "MB"],
 " component of the electric field of the ring is "
}], "Text",
 CellChangeTimes->{{3.650658694972774*^9, 3.6506587046206017`*^9}, 
   3.6507314686856747`*^9, {3.6507315142679033`*^9, 3.650731516450004*^9}},
 CellID->558952249],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"\[Xi]", " ", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Xi]", "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], "/.", 
   RowBox[{"\[Xi]", "\[Rule]", 
    RowBox[{"r", "/", "a"}]}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.650658715854011*^9, 3.650658716460438*^9}},
 CellID->1097596727],

Cell[BoxData[
 FractionBox[
  RowBox[{"r", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
  RowBox[{"a", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["r", "2"], 
       SuperscriptBox["a", "2"]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.650658733857813*^9, 3.6506590785094843`*^9, 
  3.6506594804450083`*^9, 3.65067089153047*^9, 3.650732087406478*^9, 
  3.650736433829776*^9, 3.650748936955505*^9, 3.65075184184447*^9, 
  3.650804487105335*^9},
 CellID->114565981]
}, Open  ]],

Cell["And the expression for \[Mu] from the paper becomes", "Text",
 CellChangeTimes->{{3.650731668228652*^9, 3.6507317070898027`*^9}},
 CellID->1394744027],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"2", "\[Xi]", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["\[Xi]", "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], "/.", 
   RowBox[{"\[Xi]", "\[Rule]", 
    RowBox[{"r", "/", "a"}]}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.650731716867485*^9, 3.650731721433939*^9}},
 CellID->1415107266],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "r", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
  RowBox[{"a", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["r", "2"], 
       SuperscriptBox["a", "2"]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{3.650731723746194*^9, 3.650732087466177*^9, 
  3.6507364338913813`*^9, 3.650748937022273*^9, 3.650751841961351*^9, 
  3.6508044872194357`*^9},
 CellID->1365094955]
}, Open  ]],

Cell[TextData[{
 "Hence define the function ",
 StyleBox["\[Mu]", "MB"],
 " as:"
}], "Text",
 CellChangeTimes->{{3.650731727442341*^9, 3.65073173820866*^9}, {
  3.650894803868978*^9, 3.65089480517181*^9}},
 CellID->1431217511],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[Mu]", "[", 
    RowBox[{"a_", ",", "r_", ",", "\[Theta]_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{"2", " ", "a", " ", "r", " ", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["r", "2"]}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506583309067793`*^9, 3.6506583364912786`*^9}, {
   3.650658381109253*^9, 3.6506584187520447`*^9}, {3.6506585015769043`*^9, 
   3.650658504502246*^9}, 3.650970831406592*^9},
 CellID->1171745599],

Cell[TextData[{
 "Then functions for the x and z components of the electric field can be \
defined as the functions ",
 StyleBox["ExRing", "MB"],
 " and ",
 StyleBox["EzRing", "MB"],
 " as follows:"
}], "Text",
 CellChangeTimes->{{3.650731748569953*^9, 3.650731799870522*^9}, {
  3.650731894786027*^9, 3.6507318965271883`*^9}},
 CellID->1012304277],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExRing", "[", 
   RowBox[{"a_", ",", "r_", ",", "\[Theta]_", ",", "\[Rho]_"}], "]"}], ":=", 
  " ", 
  RowBox[{
   RowBox[{"radialChargeFactor", "[", 
    RowBox[{"a", ",", "\[Rho]"}], "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       FractionBox[
        RowBox[{"r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{"a", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             SuperscriptBox["r", "2"], 
             SuperscriptBox["a", "2"]]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]], ")"}], 
      RowBox[{"f1", "[", 
       RowBox[{"\[Mu]", "[", 
        RowBox[{"a", ",", "r", ",", "\[Theta]"}], "]"}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          FractionBox[
           SuperscriptBox["r", "2"], 
           SuperscriptBox["a", "2"]]}], ")"}], 
        RowBox[{"3", "/", "2"}]]], 
      RowBox[{"f2", "[", 
       RowBox[{"\[Mu]", "[", 
        RowBox[{"a", ",", "r", ",", "\[Theta]"}], "]"}], "]"}]}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.650658121579467*^9, 3.650658127075223*^9}, {
   3.650658275586061*^9, 3.650658277495064*^9}, {3.65065858260315*^9, 
   3.6506586134442453`*^9}, {3.650658762119834*^9, 3.650658790459303*^9}, {
   3.650658867089611*^9, 3.6506588749823103`*^9}, {3.650658988427607*^9, 
   3.6506589980096197`*^9}, 3.6507307953839903`*^9, {3.650731538288946*^9, 
   3.65073153871275*^9}, {3.650804924089272*^9, 3.6508049246711617`*^9}, {
   3.6508948468126383`*^9, 3.650894846962665*^9}, 3.6508987075297823`*^9, 
   3.650970483830285*^9},
 CellID->17249391],

Cell[BoxData[
 RowBox[{
  RowBox[{"EzRing", "[", 
   RowBox[{"a_", ",", "r_", ",", "\[Theta]_", ",", "\[Rho]_"}], "]"}], ":=", 
  " ", 
  RowBox[{
   RowBox[{"radialChargeFactor", "[", 
    RowBox[{"a", ",", "\[Rho]"}], "]"}], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"r", " ", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}], 
       RowBox[{"a", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            SuperscriptBox["r", "2"], 
            SuperscriptBox["a", "2"]]}], ")"}], 
         RowBox[{"3", "/", "2"}]]}]], ")"}], 
     RowBox[{"f1", "[", 
      RowBox[{"\[Mu]", "[", 
       RowBox[{"a", ",", "r", ",", "\[Theta]"}], "]"}], "]"}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.650658927974042*^9, 3.650658961163094*^9}, {
   3.650659004746805*^9, 3.650659012818315*^9}, 3.650730797135723*^9, {
   3.6507315659931*^9, 3.650731566639855*^9}, {3.6508049265351477`*^9, 
   3.650804926775066*^9}, 3.650898708385182*^9, 3.650970485069113*^9},
 CellID->1455839901],

Cell[TextData[{
 "Note that these expressions are appropriate for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "0"}], TraditionalForm]]],
 ".  For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", "0"}], TraditionalForm]]],
 " the y component of the electric field is 0. Since the problem is radially \
symmetric we can get the value of the electric field for any other location \
by appropriately applying a rotation transformation to the results from the \
x-z plane discussed here.  That will be done later on."
}], "Text",
 CellChangeTimes->{{3.650731904462525*^9, 3.650732028522736*^9}, {
  3.650973132469708*^9, 3.650973134309555*^9}},
 CellID->1775296751]
}, Open  ]],

Cell[CellGroupData[{

Cell["Confirm that Ex is 0 on the z axis for this ring of charge", \
"Subsection",
 CellChangeTimes->{{3.6506594962788897`*^9, 3.650659507989134*^9}, {
  3.650732068544949*^9, 3.650732076200338*^9}},
 CellID->350418199],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"testRingOnAxis", "=", 
  RowBox[{
   RowBox[{"ExRing", "[", 
    RowBox[{"a", ",", "r", ",", "\[Theta]", ",", "\[Rho]"}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.650659515888452*^9, 3.650659543955948*^9}, 
   3.650731549811801*^9, {3.6507321250328074`*^9, 3.650732129566914*^9}},
 CellID->428911551],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", "\[Rho]", " ", 
    RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}]}], " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], "+", 
      RowBox[{
       RowBox[{"EllipticK", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ")"}]}], 
   ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"r", " ", 
    SqrtBox[
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["r", "2"], 
       SuperscriptBox["a", "2"]]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["r", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "r", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["r", "2"]}]]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.650659539821278*^9, 3.650659544320319*^9}, 
   3.6507320891781807`*^9, 3.6507321314143877`*^9, 3.650736435675318*^9},
 CellID->143693563]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"testRingOnAxis", ",", 
   RowBox[{"\[Theta]", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6506595482209263`*^9, 3.6506595706586*^9}, {
  3.6507318483468513`*^9, 3.650731850312893*^9}, {3.6507321157694273`*^9, 
  3.6507321329703836`*^9}},
 CellID->1176127223],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.650659558431761*^9, 3.6506595724462547`*^9}, 
   3.650732089429503*^9, 3.650732134306026*^9, 3.6507364364065228`*^9},
 CellID->1286094113]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{"testRingOnAxis", ",", 
   RowBox[{"\[Theta]", "\[Rule]", "\[Pi]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6506595482209263`*^9, 3.650659576018498*^9}, 
   3.6507318548250628`*^9, {3.650732118303453*^9, 3.650732134994451*^9}},
 CellID->1239296472],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.650659576630412*^9, 3.650732089486116*^9, 
  3.650732135969714*^9, 3.6507364369362507`*^9},
 CellID->960850136]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discussion", "Section",
 CellChangeTimes->{{3.6507321589586906`*^9, 3.650732162213264*^9}},
 CellID->1184817857],

Cell["\<\
The analytical expressions for the field of the ring can be used to then \
compute the field based on a charge distribution of a radially symmetric \
charge distribution in the x-y plane. \
\>", "Text",
 CellChangeTimes->{{3.650732166812887*^9, 3.6507322741061563`*^9}, 
   3.650973136427182*^9},
 CellID->1765347615],

Cell["\<\
Below we first do this for the standard uniformly charged disk.  Then \
following that we do it for the radian charge distribution of interest.\
\>", "Text",
 CellChangeTimes->{{3.650732278882188*^9, 3.650732323808638*^9}},
 CellID->1149328518],

Cell["\<\
Computing for the uniformly charged disk allows us to confirm the expressions \
by comparing to the easily calculated analytical expressions for the field on \
the z-axis.\
\>", "Text",
 CellChangeTimes->{{3.650926250460186*^9, 3.650926295801445*^9}},
 CellID->833680192]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field evaluation for a uniform disk", "Section",
 CellChangeTimes->{{3.650659168026176*^9, 3.650659176114109*^9}, {
  3.650903118179484*^9, 3.650903119295313*^9}},
 CellID->1007106498],

Cell[CellGroupData[{

Cell["General", "Subsection",
 CellChangeTimes->{{3.65065964796058*^9, 3.650659648799752*^9}},
 CellID->1499011559],

Cell[TextData[{
 "The uniform charge distribution corresponds to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Rho]", "[", "a", "]"}], "=", 
    FractionBox["1", 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox["r0", "2"]}]]}], TraditionalForm]]],
 ", hence we have the following analytic expressions for the x and z \
components of the field of a charged ring of radius a:"
}], "Text",
 CellChangeTimes->{{3.650732374430563*^9, 3.650732429612691*^9}, {
   3.650896716360997*^9, 3.6508967163610497`*^9}, {3.650926328856216*^9, 
   3.650926367070606*^9}, {3.6509710131565647`*^9, 3.6509710134088717`*^9}, 
   3.6509731380692*^9},
 CellID->1242625867],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ExRing", "[", 
   RowBox[{"a", ",", "r", ",", "\[Theta]", ",", 
    FractionBox["1", 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox["r0", "2"]}]]}], "]"}], "//", "FullSimplify"}]], "Input",\

 CellChangeTimes->{{3.650659192879286*^9, 3.650659194073555*^9}, {
   3.65065942866774*^9, 3.6506594542327414`*^9}, 3.650660178571718*^9, 
   3.6507315514596233`*^9, 3.6509276023483686`*^9, 3.65092763300288*^9, {
   3.6509276756980124`*^9, 3.650927680095895*^9}},
 CellID->1945623591],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}]}], " ", 
      RowBox[{"EllipticE", "[", 
       FractionBox[
        RowBox[{"4", " ", "a", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "+", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], "+", 
     RowBox[{
      RowBox[{"EllipticK", "[", 
       FractionBox[
        RowBox[{"4", " ", "a", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "+", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"\[Pi]", " ", "r", " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]], " ", 
   SuperscriptBox["r0", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["r", "2"]}]]}]]}]]], "Output",
 CellChangeTimes->{{3.6506594686195993`*^9, 3.650659483914063*^9}, 
   3.650660186915718*^9, 3.650670913715756*^9, 3.6508064297779016`*^9, {
   3.6509276030045958`*^9, 3.650927634318892*^9}, {3.650927676220504*^9, 
   3.65092769855317*^9}},
 CellID->557359578]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"EzRing", "[", 
   RowBox[{"a", ",", "r", ",", "\[Theta]", ",", 
    FractionBox["1", 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox["r0", "2"]}]]}], "]"}], "//", "FullSimplify"}]], "Input",\

 CellChangeTimes->{{3.650659192879286*^9, 3.650659194073555*^9}, {
   3.65065942866774*^9, 3.6506594542327414`*^9}, 3.6506601735565367`*^9, 
   3.6507315725309067`*^9},
 CellID->1070117033],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "r", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"EllipticE", "[", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["r", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
  RowBox[{"\[Pi]", " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]], " ", 
   SuperscriptBox["r0", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["r", "2"]}]]}]]}]]], "Output",
 CellChangeTimes->{3.6506601830962877`*^9, 3.6506709141759987`*^9, 
  3.650806430281209*^9},
 CellID->2010485893]
}, Open  ]],

Cell["\<\
Then we define functions for the x and z components of the uniform disk in \
terms of numerical integrations since these integrations are generally not \
analytically computable:\
\>", "Text",
 CellChangeTimes->{{3.650732438740183*^9, 3.650732490002308*^9}},
 CellID->204579048],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}]}], " ", 
           RowBox[{"EllipticE", "[", 
            FractionBox[
             RowBox[{"4", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["r", "2"], "+", 
              RowBox[{"2", " ", "a", " ", "r", " ", 
               RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], "+", 
          RowBox[{
           RowBox[{"EllipticK", "[", 
            FractionBox[
             RowBox[{"4", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["r", "2"], "+", 
              RowBox[{"2", " ", "a", " ", "r", " ", 
               RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["r", "2"], "-", 
             RowBox[{"2", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Pi]", " ", "r", " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          FractionBox[
           SuperscriptBox["r", "2"], 
           SuperscriptBox["a", "2"]]}]], " ", 
        SuperscriptBox["r0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "-", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          FractionBox[
           RowBox[{"2", " ", "a", " ", "r", " ", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["r", "2"]}]]}]]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, {
   3.650660199036735*^9, 3.6506602057557383`*^9}, {3.6508079857330017`*^9, 
   3.650807986014132*^9}, 3.65080815859853*^9, 3.650971550932289*^9},
 CellID->805446546],

Cell[BoxData[
 RowBox[{
  RowBox[{"EzUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", "r", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, 
   3.65066019498035*^9, {3.650807989702139*^9, 3.6508079900381527`*^9}, 
   3.650808159676626*^9, 3.650971552147904*^9},
 CellID->814147825],

Cell["\<\
We also add the following special definition since the integration above \
fails for \[Theta] = 0 and \[Theta] = \[Pi] but the limit of the integrand in \
those cases is both 0.\
\>", "Text",
 CellChangeTimes->{{3.650927813275943*^9, 3.6509278582252274`*^9}, {
   3.650928027731102*^9, 3.65092804143471*^9}, 3.650973149292527*^9},
 CellID->154342588],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"0", "|", "0.0"}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}},
 CellID->1323435006],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"\[Pi]", "|", 
     RowBox[{"N", "[", "\[Pi]", "]"}]}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}, 
   3.650927980592544*^9, {3.650928012437546*^9, 3.650928019059594*^9}},
 CellID->1704025153]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check analytically on the z axis", "Subsection",
 CellChangeTimes->{{3.650659735269438*^9, 3.650659743291773*^9}},
 CellID->502867073],

Cell["\<\
To confirm that we are using the correct expressions let\[CloseCurlyQuote]s \
check the value of the field on the z axis since that is the standard \
undergraduate electrostatics problem:\
\>", "Text",
 CellChangeTimes->{{3.650732499553722*^9, 3.650732537920348*^9}, 
   3.650973152090371*^9},
 CellID->1715162838],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EzRing", "[", 
  RowBox[{"a", ",", "z", ",", "0", ",", 
   FractionBox["1", 
    RowBox[{"\[Pi]", " ", 
     SuperscriptBox["r0", "2"]}]]}], "]"}]], "Input",
 CellChangeTimes->{{3.650659760573246*^9, 3.650659794730489*^9}, 
   3.650662441981062*^9, 3.650731573602623*^9},
 CellID->1338744966],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "z"}], 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["r0", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       SuperscriptBox["a", "2"]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{{3.650659777896194*^9, 3.650659790158773*^9}, 
   3.6506624447950287`*^9},
 CellID->1600530724]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "z"}], 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["r0", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         SuperscriptBox["a", "2"]]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0", ",", "r0"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r0", ">", "0"}], ",", 
      RowBox[{"z", "\[Element]", "Reals"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6506598475832357`*^9, 3.650659936228998*^9}, 
   3.650662451871788*^9},
 CellID->680055749],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["r0", "2"], "+", 
           SuperscriptBox["z", "2"]}]]]}], "+", 
       FractionBox["1", 
        RowBox[{"Abs", "[", "z", "]"}]]}], ")"}]}], 
    SuperscriptBox["r0", "2"]], ",", 
   RowBox[{"z", "\[NotEqual]", "0"}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.650659860245924*^9, {3.650659913552411*^9, 3.6506599381036053`*^9}, 
   3.650662459323532*^9},
 CellID->623071939]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"ConditionalExpression", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["r0", "2"], "+", 
             SuperscriptBox["z", "2"]}]]]}], "+", 
         FractionBox["1", 
          RowBox[{"Abs", "[", "z", "]"}]]}], ")"}]}], 
      SuperscriptBox["r0", "2"]], ",", 
     RowBox[{"z", "\[NotEqual]", "0"}]}], "]"}], ",", 
   RowBox[{"z", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650660015454708*^9, 3.650660032416836*^9}, 
   3.650662464096493*^9},
 CellID->685184104],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", "-", 
   FractionBox[
    RowBox[{"2", " ", "z"}], 
    SqrtBox[
     RowBox[{
      SuperscriptBox["r0", "2"], "+", 
      SuperscriptBox["z", "2"]}]]]}], 
  SuperscriptBox["r0", "2"]]], "Output",
 CellChangeTimes->{3.650660033000345*^9, 3.650662468817395*^9},
 CellID->1525000723]
}, Open  ]],

Cell[TextData[{
 "Which agrees with the standard on-axis expression.  Also the field varies \
as ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    SuperscriptBox["z", "2"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " for large z as expected:"
}], "Text",
 CellChangeTimes->{{3.6506601133425407`*^9, 3.650660124260962*^9}, {
  3.650732615028801*^9, 3.65073261601271*^9}, {3.650732646453465*^9, 
  3.650732666260664*^9}},
 CellID->1642036448],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"2", "-", 
     FractionBox[
      RowBox[{"2", " ", "z"}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["r0", "2"], "+", 
        SuperscriptBox["z", "2"]}]]]}], 
    SuperscriptBox["r0", "2"]], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "\[Infinity]", ",", "4"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650732619881044*^9, 3.650732641574044*^9}},
 CellID->1952844528],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox["1", "z"], ")"}], "2"], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     SuperscriptBox["r0", "2"]}], 
    RowBox[{"4", " ", 
     SuperscriptBox["z", "4"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "z"], "]"}], "5"],
    SeriesData[$CellContext`z, 
     DirectedInfinity[1], {}, 2, 5, 1],
    Editable->False]}],
  SeriesData[$CellContext`z, 
   DirectedInfinity[1], {1, 0, Rational[-3, 4] $CellContext`r0^2}, 2, 5, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.65073264229256*^9},
 CellID->1756564992]
}, Open  ]],

Cell[TextData[{
 "The field off axis can also be expanded for large r and any value of \
\[Theta] to see that the ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    SuperscriptBox["r", "2"]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " behavior is as expected off of the z-axis."
}], "Text",
 CellChangeTimes->{{3.65073267321231*^9, 3.650732765920741*^9}},
 CellID->1942274173]
}, Open  ]],

Cell[CellGroupData[{

Cell["Look at the behavior everywhere", "Subsection",
 CellChangeTimes->{{3.65066022697818*^9, 3.650660255056013*^9}, {
  3.650732577129916*^9, 3.6507325786789837`*^9}},
 CellID->262142437],

Cell["\<\
Let\[CloseCurlyQuote]s plot the field behavior in the x-z plane, scaling r0 \
to be 1\
\>", "Text",
 CellChangeTimes->{{3.650732582558752*^9, 3.650732591662331*^9}, {
  3.650732998284449*^9, 3.650733015441204*^9}, {3.650733153914247*^9, 
  3.6507331628483686`*^9}},
 CellID->1760371544],

Cell["\<\
First look at the field vectors on a uniform array, the disk is located on \
the x-axis between -1 and 1:\
\>", "Text",
 CellChangeTimes->{{3.650660293807664*^9, 3.650660302406025*^9}, {
   3.650733181900217*^9, 3.6507332357701893`*^9}, 3.6509731540122337`*^9},
 CellID->671699585],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ExUniformDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
     RowBox[{"EzUniformDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.650660779207404*^9, {3.650660809613495*^9, 3.6506608184941177`*^9}, {
   3.650660910432844*^9, 3.650660923478569*^9}, {3.650661606141987*^9, 
   3.6506616166633863`*^9}, {3.6507357534570312`*^9, 3.650735758519354*^9}},
 CellID->160957774],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.0012771583698610745`, 1.}}], 
     ArrowBox[{{-2.9941594429168275`, -2.9939113806778193`}, \
{-3.0058405570831725`, -3.0060886193221807`}}]}, 
    {Arrowheads[{{0.0014779291576124862`, 1.}}], 
     ArrowBox[{{-2.992741007221255, -2.5648994260228073`}, \
{-3.007258992778745, -2.5779577168343355`}}]}, 
    {Arrowheads[{{0.0017077538436409952`, 1.}}], 
     ArrowBox[{{-2.990997389407272, -2.136058098136514}, \
{-3.0090026105927277`, -2.149656187577773}}]}, 
    {Arrowheads[{{0.00196106422354382, 1.}}], 
     ArrowBox[{{-2.9889365632929374`, -1.7075454168541515`}, \
{-3.0110634367070626`, -1.7210260117172778`}}]}, 
    {Arrowheads[{{0.0022222289338737467`, 1.}}], 
     ArrowBox[{{-2.986667572253526, -1.2795696910315995`}, \
{-3.0133324277464744`, -1.2918588803969726`}}]}, 
    {Arrowheads[{{0.00246118812456134, 1.}}], 
     ArrowBox[{{-2.9844688369273746`, -0.8523332150407432}, \
{-3.0155311630726254`, -0.8619524992449716}}]}, 
    {Arrowheads[{{0.002634370164857432, 1.}}], 
     ArrowBox[{{-2.982804355401518, -0.4258936679465384}, \
{-3.0171956445984827`, -0.4312491891963194}}]}, 
    {Arrowheads[{{0.0026983989483408384`, 1.}}], 
     ArrowBox[{{-2.9821741295716246`, -3.2993552797625713`*^-16}, \
{-3.017825870428375, -3.361982867988368*^-16}}]}, 
    {Arrowheads[{{0.002634370164857432, 1.}}], 
     ArrowBox[{{-2.982804355401518, 
      0.4258936679465377}, {-3.0171956445984827`, 0.4312491891963187}}]}, 
    {Arrowheads[{{0.00246118812456134, 1.}}], 
     ArrowBox[{{-2.9844688369273746`, 
      0.8523332150407426}, {-3.0155311630726254`, 0.861952499244971}}]}, 
    {Arrowheads[{{0.0022222289338737467`, 1.}}], 
     ArrowBox[{{-2.986667572253526, 
      1.2795696910315988`}, {-3.0133324277464744`, 1.291858880396972}}]}, 
    {Arrowheads[{{0.00196106422354382, 1.}}], 
     ArrowBox[{{-2.9889365632929374`, 
      1.7075454168541508`}, {-3.0110634367070626`, 1.721026011717277}}]}, 
    {Arrowheads[{{0.001707753843641022, 1.}}], 
     ArrowBox[{{-2.990997389407272, 2.136058098136513}, {-3.009002610592728, 
      2.149656187577772}}]}, 
    {Arrowheads[{{0.0014779291576124862`, 1.}}], 
     ArrowBox[{{-2.992741007221255, 2.5648994260228064`}, {-3.007258992778745,
       2.5779577168343346`}}]}, 
    {Arrowheads[{{0.0012771583698610745`, 1.}}], 
     ArrowBox[{{-2.9941594429168275`, 
      2.9939113806778184`}, {-3.0058405570831725`, 3.00608861932218}}]}, 
    {Arrowheads[{{0.001461937620733608, 1.}}], 
     ArrowBox[{{-2.5653172712442416`, -2.992521827882498}, \
{-2.577539871612901, -3.0074781721175015`}}]}, 
    {Arrowheads[{{0.0017309273443527017`, 1.}}], 
     ArrowBox[{{-2.5635747995863696`, -2.563117746004457}, \
{-2.579282343270773, -2.5797393968526863`}}]}, 
    {Arrowheads[{{0.0020553471264462457`, 1.}}], 
     ArrowBox[{{-2.561292698996496, -2.1338227060725434`}, \
{-2.5815644438606475`, -2.1518915796417435`}}]}, 
    {Arrowheads[{{0.002436241535732508, 1.}}], 
     ArrowBox[{{-2.558380816396414, -1.704863716767077}, {-2.584476326460729, \
-1.7237077118043522`}}]}, 
    {Arrowheads[{{0.0028592922698599445`, 1.}}], 
     ArrowBox[{{-2.554872629050643, -1.2766211281814925`}, {-2.5879845138065, \
-1.2948074432470795`}}]}, 
    {Arrowheads[{{0.003279399448681085, 1.}}], 
     ArrowBox[{{-2.551119308924244, -0.8496020805299832}, \
{-2.591737833932899, -0.8646836337557317}}]}, 
    {Arrowheads[{{0.003608178532496202, 1.}}], 
     ArrowBox[{{-2.5480016493566775`, -0.4241745889793647}, \
{-2.5948554935004657`, -0.43296826816349304`}}]}, 
    {Arrowheads[{{0.003735842627013546, 1.}}], 
     ArrowBox[{{-2.5467492531050557`, -3.285787786693303*^-16}, \
{-2.5961078897520875`, -3.3755503610576365`*^-16}}]}, 
    {Arrowheads[{{0.003608178532496202, 1.}}], 
     ArrowBox[{{-2.5480016493566775`, 
      0.42417458897936405`}, {-2.5948554935004657`, 0.4329682681634924}}]}, 
    {Arrowheads[{{0.003279399448681085, 1.}}], 
     ArrowBox[{{-2.551119308924244, 0.8496020805299825}, {-2.591737833932899, 
      0.864683633755731}}]}, 
    {Arrowheads[{{0.0028592922698599445`, 1.}}], 
     ArrowBox[{{-2.554872629050643, 1.2766211281814919`}, {-2.5879845138065, 
      1.2948074432470789`}}]}, 
    {Arrowheads[{{0.002436241535732508, 1.}}], 
     ArrowBox[{{-2.558380816396414, 1.7048637167670764`}, {-2.584476326460729,
       1.7237077118043516`}}]}, 
    {Arrowheads[{{0.0020553471264462457`, 1.}}], 
     ArrowBox[{{-2.561292698996496, 
      2.1338227060725425`}, {-2.5815644438606475`, 2.1518915796417426`}}]}, 
    {Arrowheads[{{0.0017309273443527017`, 1.}}], 
     ArrowBox[{{-2.5635747995863696`, 2.563117746004456}, {-2.579282343270773,
       2.5797393968526854`}}]}, 
    {Arrowheads[{{0.001461937620733608, 1.}}], 
     ArrowBox[{{-2.5653172712442416`, 2.992521827882497}, {-2.577539871612901,
       3.0074781721175006`}}]}, 
    {Arrowheads[{{0.0016631798672512462`, 1.}}], 
     ArrowBox[{{-2.136700884852401, -2.9908996011768463`}, \
{-2.149013400861886, -3.0091003988231537`}}]}, 
    {Arrowheads[{{0.0020191693753136937`, 1.}}], 
     ArrowBox[{{-2.13465351250045, -2.5609107528981383`}, \
{-2.1510607732138367`, -2.581946389959005}}]}, 
    {Arrowheads[{{0.002474059287005173, 1.}}], 
     ArrowBox[{{-2.1317789966425336`, -2.1308406331914}, {-2.153935289071753, \
-2.1548736525228867`}}]}, 
    {Arrowheads[{{0.0030494251158718552`, 1.}}], 
     ArrowBox[{{-2.1277687112505848`, -1.7009383755963687`}, \
{-2.1579455744637017`, -1.7276330529750605`}}]}, 
    {Arrowheads[{{0.0037528465275942823`, 1.}}], 
     ArrowBox[{{-2.1223495477420817`, -1.2717835881132014`}, \
{-2.1633647379722047`, -1.2996449833153705`}}]}, 
    {Arrowheads[{{0.0045401492965471265`, 1.}}], 
     ArrowBox[{{-2.115661045181475, -0.8444964808539926}, \
{-2.1700532405328112`, -0.8697892334317221}}]}, 
    {Arrowheads[{{0.005242389338532468, 1.}}], 
     ArrowBox[{{-2.109166892136871, -0.4205513341990666}, \
{-2.176547393577415, -0.4365915229437912}}]}, 
    {Arrowheads[{{0.005542467523030282, 1.}}], 
     ArrowBox[{{-2.1062430951160693`, -3.2598774529122724`*^-16}, \
{-2.179471190598217, -3.401460694838667*^-16}}]}, 
    {Arrowheads[{{0.005242389338532466, 1.}}], 
     ArrowBox[{{-2.109166892136871, 
      0.42055133419906593`}, {-2.176547393577415, 0.4365915229437905}}]}, 
    {Arrowheads[{{0.0045401492965471265`, 1.}}], 
     ArrowBox[{{-2.115661045181475, 0.844496480853992}, {-2.1700532405328112`,
       0.8697892334317214}}]}, 
    {Arrowheads[{{0.0037528465275942823`, 1.}}], 
     ArrowBox[{{-2.1223495477420817`, 
      1.2717835881132007`}, {-2.1633647379722047`, 1.2996449833153698`}}]}, 
    {Arrowheads[{{0.0030494251158718552`, 1.}}], 
     ArrowBox[{{-2.1277687112505848`, 
      1.700938375596368}, {-2.1579455744637017`, 1.7276330529750599`}}]}, 
    {Arrowheads[{{0.002474059287005173, 1.}}], 
     ArrowBox[{{-2.1317789966425336`, 2.130840633191399}, {-2.153935289071753,
       2.1548736525228858`}}]}, 
    {Arrowheads[{{0.0020191693753136937`, 1.}}], 
     ArrowBox[{{-2.13465351250045, 
      2.5609107528981374`}, {-2.1510607732138367`, 2.581946389959004}}]}, 
    {Arrowheads[{{0.0016631798672512462`, 1.}}], 
     ArrowBox[{{-2.136700884852401, 2.9908996011768454`}, {-2.149013400861886,
       3.009100398823153}}]}, 
    {Arrowheads[{{0.0018709140462428865`, 1.}}], 
     ArrowBox[{{-1.7084346742986174`, -2.989113272904208}, \
{-1.7201367542728117`, -3.0108867270957926`}}]}, 
    {Arrowheads[{{0.0023306964471982833`, 1.}}], 
     ArrowBox[{{-1.7061963537845422`, -2.558328055647209}, \
{-1.722375074786887, -2.5845290872099347`}}]}, 
    {Arrowheads[{{0.002954127119825161, 1.}}], 
     ArrowBox[{{-1.7028243112729446`, -2.1270621878293774`}, \
{-1.7257471172984846`, -2.158652097884909}}]}, 
    {Arrowheads[{{0.0038090652094623176`, 1.}}], 
     ArrowBox[{{-1.6976497654750295`, -1.6954065337603523`}, \
{-1.7309216630963997`, -1.7331648948110767`}}]}, 
    {Arrowheads[{{0.004980741248993108, 1.}}], 
     ArrowBox[{{-1.689656767841313, -1.2638959972833468`}, \
{-1.738914660730116, -1.3075325741452253`}}]}, 
    {Arrowheads[{{0.00652990583637025, 1.}}], 
     ArrowBox[{{-1.6776716447441764`, -0.8343344353156835}, \
{-1.750899783827253, -0.8799512789700313}}]}, 
    {Arrowheads[{{0.008274449613191693, 1.}}], 
     ArrowBox[{{-1.662389748600584, -0.4114040756383581}, \
{-1.766181679970845, -0.4457387815044997}}]}, 
    {Arrowheads[{{0.009206473150227656, 1.}}], 
     ArrowBox[{{-1.6534669100169164`, -3.1970411921145054`*^-16}, \
{-1.7751045185545131`, -3.464296955636434*^-16}}]}, 
    {Arrowheads[{{0.008274449613191692, 1.}}], 
     ArrowBox[{{-1.662389748600584, 
      0.41140407563835746`}, {-1.766181679970845, 0.44573878150449897`}}]}, 
    {Arrowheads[{{0.00652990583637025, 1.}}], 
     ArrowBox[{{-1.6776716447441764`, 
      0.8343344353156829}, {-1.750899783827253, 0.8799512789700307}}]}, 
    {Arrowheads[{{0.004980741248993108, 1.}}], 
     ArrowBox[{{-1.689656767841313, 1.2638959972833461`}, {-1.738914660730116,
       1.3075325741452246`}}]}, 
    {Arrowheads[{{0.0038090652094623176`, 1.}}], 
     ArrowBox[{{-1.6976497654750295`, 
      1.6954065337603517`}, {-1.7309216630963997`, 1.733164894811076}}]}, 
    {Arrowheads[{{0.002954127119825161, 1.}}], 
     ArrowBox[{{-1.7028243112729446`, 
      2.1270621878293765`}, {-1.7257471172984846`, 2.158652097884908}}]}, 
    {Arrowheads[{{0.0023306964471982833`, 1.}}], 
     ArrowBox[{{-1.7061963537845422`, 2.558328055647208}, {-1.722375074786887,
       2.584529087209934}}]}, 
    {Arrowheads[{{0.0018709140462428865`, 1.}}], 
     ArrowBox[{{-1.7084346742986174`, 
      2.989113272904207}, {-1.7201367542728117`, 3.0108867270957917`}}]}, 
    {Arrowheads[{{0.0020686792684911056`, 1.}}], 
     ArrowBox[{{-1.2806343297537743`, -2.987313375193248}, \
{-1.290794241674798, -3.0126866248067525`}}]}, 
    {Arrowheads[{{0.002640238120928706, 1.}}], 
     ArrowBox[{{-1.2784478301839584`, -2.5555726595350556`}, \
{-1.2929807412446135`, -2.587284483322087}}]}, 
    {Arrowheads[{{0.003458622281051903, 1.}}], 
     ArrowBox[{{-1.2749379528358993`, -2.1227101672265207`}, \
{-1.2964906185926726`, -2.1630041184877657`}}]}, 
    {Arrowheads[{{0.004670052112326001, 1.}}], 
     ArrowBox[{{-1.2690597863842992`, -1.6883165210005404`}, \
{-1.3023687850442731`, -1.7402549075708889`}}]}, 
    {Arrowheads[{{0.006531051369324182, 1.}}], 
     ArrowBox[{{-1.2587406472599343`, -1.2520410031165745`}, \
{-1.3126879241686376`, -1.3193875683119973`}}]}, 
    {Arrowheads[{{0.009509167878198103, 1.}}], 
     ArrowBox[{{-1.2396330441879473`, -0.8144500621126521}, \
{-1.331795527240625, -0.8998356521730626}}]}, 
    {Arrowheads[{{0.014412324462740631`, 1.}}], 
     ArrowBox[{{-1.2024771981098752`, -0.3823505832524057}, \
{-1.3689513733186969`, -0.47479227389045203`}}]}, 
    {Arrowheads[{{0.01950891841763194, 1.}}], 
     ArrowBox[{{-1.156836585059875, -2.9141176157394496`*^-16}, \
{-1.414591986368697, -3.7472205320114897`*^-16}}]}, 
    {Arrowheads[{{0.014412324462740631`, 1.}}], 
     ArrowBox[{{-1.2024771981098752`, 
      0.382350583252405}, {-1.3689513733186969`, 0.47479227389045137`}}]}, 
    {Arrowheads[{{0.00950916787819811, 1.}}], 
     ArrowBox[{{-1.239633044187947, 
      0.8144500621126515}, {-1.3317955272406248`, 0.899835652173062}}]}, 
    {Arrowheads[{{0.006531051369324196, 1.}}], 
     ArrowBox[{{-1.2587406472599343`, 
      1.2520410031165738`}, {-1.3126879241686376`, 1.3193875683119969`}}]}, 
    {Arrowheads[{{0.004670052112326001, 1.}}], 
     ArrowBox[{{-1.2690597863842992`, 
      1.6883165210005397`}, {-1.3023687850442731`, 1.7402549075708882`}}]}, 
    {Arrowheads[{{0.003458622281051903, 1.}}], 
     ArrowBox[{{-1.2749379528358993`, 
      2.12271016722652}, {-1.2964906185926726`, 2.163004118487765}}]}, 
    {Arrowheads[{{0.002640238120928706, 1.}}], 
     ArrowBox[{{-1.2784478301839584`, 
      2.5555726595350547`}, {-1.2929807412446135`, 2.5872844833220863`}}]}, 
    {Arrowheads[{{0.0020686792684911056`, 1.}}], 
     ArrowBox[{{-1.2806343297537743`, 2.987313375193247}, {-1.290794241674798,
       3.0126866248067516`}}]}, 
    {Arrowheads[{{0.002234723176453573, 1.}}], 
     ArrowBox[{{-0.8533552046791204, -2.9857313793733176`}, \
{-0.8609305096065945, -3.0142686206266824`}}]}, 
    {Arrowheads[{{0.002909456697377387, 1.}}], 
     ArrowBox[{{-0.8515740902412994, -2.5530328515306078`}, \
{-0.8627116240444155, -2.5898242913265355`}}]}, 
    {Arrowheads[{{0.0039177854696890385`, 1.}}], 
     ArrowBox[{{-0.8485726844273632, -2.1184360206498054`}, \
{-0.8657130298583516, -2.1672782650644815`}}]}, 
    {Arrowheads[{{0.005500953560028696, 1.}}], 
     ArrowBox[{{-0.8432134511258956, -1.6807215532143596`}, \
{-0.8710722631598192, -1.74784987535707}}]}, 
    {Arrowheads[{{0.008145733118202656, 1.}}], 
     ArrowBox[{{-0.8329737760195958, -1.2376359268934052`}, \
{-0.8813119382661191, -1.333792644535167}}]}, 
    {Arrowheads[{{0.012962809606057961`, 1.}}], 
     ArrowBox[{{-0.811706244182687, -0.7845576542936953}, \
{-0.9025794701030277, -0.9297280599920196}}]}, 
    {Arrowheads[{{0.023266062866074307`, 1.}}], 
     ArrowBox[{{-0.7615295784279656, -0.30823400110969557`}, \
{-0.9527561358577492, -0.5489088560331622}}]}, 
    {Arrowheads[{{0.029995593344474096`, 1.}}], 
     ArrowBox[{{-1.0552964921750663`, 
      4.454357516359771*^-12}, {-0.6589892221106485, \
-4.455023650174546*^-12}}]}, 
    {Arrowheads[{{0.023266062866074327`, 1.}}], 
     ArrowBox[{{-0.7615295784279655, 
      0.3082340011096948}, {-0.9527561358577493, 0.5489088560331616}}]}, 
    {Arrowheads[{{0.012962809606057966`, 1.}}], 
     ArrowBox[{{-0.811706244182687, 0.7845576542936946}, {-0.9025794701030279,
       0.9297280599920189}}]}, 
    {Arrowheads[{{0.008145733118202656, 1.}}], 
     ArrowBox[{{-0.8329737760195958, 
      1.2376359268934043`}, {-0.8813119382661191, 1.3337926445351662`}}]}, 
    {Arrowheads[{{0.0055009535600287, 1.}}], 
     ArrowBox[{{-0.8432134511258956, 1.680721553214359}, {-0.8710722631598193,
       1.7478498753570693`}}]}, 
    {Arrowheads[{{0.0039177854696890385`, 1.}}], 
     ArrowBox[{{-0.8485726844273632, 
      2.1184360206498045`}, {-0.8657130298583516, 2.1672782650644806`}}]}, 
    {Arrowheads[{{0.002909456697377387, 1.}}], 
     ArrowBox[{{-0.8515740902412994, 2.553032851530607}, {-0.8627116240444155,
       2.5898242913265346`}}]}, 
    {Arrowheads[{{0.002234723176453573, 1.}}], 
     ArrowBox[{{-0.8533552046791204, 
      2.9857313793733167`}, {-0.8609305096065945, 3.0142686206266815`}}]}, 
    {Arrowheads[{{0.002346222541180885, 1.}}], 
     ArrowBox[{{-0.42653969864753094`, -2.9846343805771585`}, \
{-0.4306031584953269, -3.0153656194228415`}}]}, 
    {Arrowheads[{{0.0030947165913376294`, 1.}}], 
     ArrowBox[{{-0.4255309020734353, -2.5512119554937507`}, \
{-0.43161195506942246`, -2.5916451873633926`}}]}, 
    {Arrowheads[{{0.004243316920240459, 1.}}], 
     ArrowBox[{{-0.4237805330521658, -2.1152378422711022`}, \
{-0.43336232409069203`, -2.1704764434431842`}}]}, 
    {Arrowheads[{{0.006109484188900942, 1.}}], 
     ArrowBox[{{-0.4205452497646652, -1.6747320184168724`}, \
{-0.43659760737819253`, -1.7538394101545567`}}]}, 
    {Arrowheads[{{0.009353595266389094, 1.}}], 
     ArrowBox[{{-0.41417043511441526`, -1.2256251619976346`}, \
{-0.44297242202844256`, -1.3458034094309377`}}]}, 
    {Arrowheads[{{0.01542246424804209, 1.}}], 
     ArrowBox[{{-0.4011289873447941, -0.7590261041720339}, \
{-0.45601386979806363`, -0.955259610113681}}]}, 
    {Arrowheads[{{0.027336325018442267`, 1.}}], 
     ArrowBox[{{-0.3770365897294582, -0.25549468397602804`}, \
{-0.4801062674133995, -0.6016481731668297}}]}, 
    {Arrowheads[{{0.011662527103758837`, 1.}}], 
     ArrowBox[{{-0.35152770709101316`, 
      1.248633936147021*^-12}, {-0.5056151500518445, \
-1.2493000699617961`*^-12}}]}, 
    {Arrowheads[{{0.02733632501844229, 1.}}], 
     ArrowBox[{{-0.3770365897294582, 
      0.2554946839760272}, {-0.4801062674133996, 0.6016481731668292}}]}, 
    {Arrowheads[{{0.01542246424804211, 1.}}], 
     ArrowBox[{{-0.4011289873447941, 
      0.7590261041720331}, {-0.45601386979806374`, 0.9552596101136804}}]}, 
    {Arrowheads[{{0.009353595266389094, 1.}}], 
     ArrowBox[{{-0.4141704351144152, 1.225625161997634}, {-0.4429724220284425,
       1.345803409430937}}]}, 
    {Arrowheads[{{0.006109484188900943, 1.}}], 
     ArrowBox[{{-0.4205452497646652, 
      1.6747320184168717`}, {-0.4365976073781926, 1.753839410154556}}]}, 
    {Arrowheads[{{0.004243316920240459, 1.}}], 
     ArrowBox[{{-0.4237805330521658, 
      2.1152378422711013`}, {-0.43336232409069203`, 2.1704764434431834`}}]}, 
    {Arrowheads[{{0.0030947165913376294`, 1.}}], 
     ArrowBox[{{-0.4255309020734353, 
      2.55121195549375}, {-0.43161195506942246`, 2.5916451873633917`}}]}, 
    {Arrowheads[{{0.002346222541180885, 1.}}], 
     ArrowBox[{{-0.42653969864753094`, 
      2.9846343805771576`}, {-0.4306031584953269, 3.0153656194228406`}}]}, 
    {Arrowheads[{{0.0023855970345504594`, 1.}}], 
     ArrowBox[{{-3.3306690738754696`*^-16, -2.984240527643861}, \
{-3.3306690738754696`*^-16, -3.015759472356139}}]}, 
    {Arrowheads[{{0.0032514813903970156`, 1.}}], 
     ArrowBox[{{
      0.0050333717551113415`, -2.5505470560839894`}, {-0.005033371755112008, \
-2.5923100867731534`}}]}, 
    {Arrowheads[{{0.0044470207213304904`, 1.}}], 
     ArrowBox[{{
      0.005739200353305618, -2.1140457782211275`}, {-0.005739200353306284, \
-2.171668507493159}}]}, 
    {Arrowheads[{{0.006832518782122861, 1.}}], 
     ArrowBox[{{
      0.016947381500148396`, -1.672451914293517}, {-0.016947381500149062`, \
-1.7561195142779122`}}]}, 
    {Arrowheads[{{0.01058770480757326, 1.}}], 
     ArrowBox[{{
      0.026593685582269416`, -1.2210238870521215`}, {-0.02659368558227008, \
-1.3504046843764508`}}]}, 
    {Arrowheads[{{0.016345272461943394`, 1.}}], 
     ArrowBox[{{
      0.01258262058264279, -0.7499001176939505}, {-0.012582620582643455`, \
-0.9643855965917644}}]}, 
    {Arrowheads[{{0.02867777239487808, 1.}}], 
     ArrowBox[{{
      0.03530779136438216, -0.24244270835411913`}, {-0.03530779136438283, \
-0.6147001487887386}}]}, 
    {Arrowheads[{{0.04587368524026632, 1.}}], 
     ArrowBox[{{0.012827980272658255`, 
      0.3027741363062599}, {-0.01282798027265892, -0.30277413630626054`}}]}, 
    {Arrowheads[{{0.02846936499398311, 1.}}], 
     ArrowBox[{{0.02696084914787793, 
      0.2424427083541183}, {-0.026960849147878597`, 0.6147001487887382}}]}, 
    {Arrowheads[{{0.016436439026781033`, 1.}}], 
     ArrowBox[{{-0.016992527828403266`, 0.7499001176939497}, {
      0.0169925278284026, 0.9643855965917638}}]}, 
    {Arrowheads[{{0.010134215714807467`, 1.}}], 
     ArrowBox[{{-0.01723739106634993, 1.2210238870521206`}, {
      0.017237391066349264`, 1.35040468437645}}]}, 
    {Arrowheads[{{0.0065979814557068335`, 1.}}], 
     ArrowBox[{{0.012237171293478646`, 
      1.6724519142935164`}, {-0.012237171293479312`, 
      1.7561195142779116`}}]}, 
    {Arrowheads[{{0.004606224396387825, 1.}}], 
     ArrowBox[{{0.009789679577173513, 
      2.1140457782211266`}, {-0.009789679577174179, 2.171668507493158}}]}, 
    {Arrowheads[{{0.0032795526762778257`, 1.}}], 
     ArrowBox[{{0.0057737017155956175`, 
      2.5505470560839885`}, {-0.005773701715596284, 2.5923100867731526`}}]}, 
    {Arrowheads[{{0.0023855970345504594`, 1.}}], 
     ArrowBox[{{-3.3306690738754696`*^-16, 
      2.98424052764386}, {-3.3306690738754696`*^-16, 
      3.0157594723561383`}}]}, 
    {Arrowheads[{{0.002346222541180885, 1.}}], 
     ArrowBox[{{0.4265396986475303, -2.9846343805771585`}, {
      0.4306031584953262, -3.0153656194228415`}}]}, 
    {Arrowheads[{{0.0030947165913376294`, 1.}}], 
     ArrowBox[{{0.42553090207343464`, -2.5512119554937507`}, {
      0.4316119550694218, -2.5916451873633926`}}]}, 
    {Arrowheads[{{0.004243316920240459, 1.}}], 
     ArrowBox[{{0.4237805330521651, -2.1152378422711022`}, {
      0.4333623240906913, -2.1704764434431842`}}]}, 
    {Arrowheads[{{0.006109484188900942, 1.}}], 
     ArrowBox[{{0.4205452497646645, -1.6747320184168724`}, {
      0.43659760737819187`, -1.7538394101545567`}}]}, 
    {Arrowheads[{{0.009353595266389077, 1.}}], 
     ArrowBox[{{0.4141704351144146, -1.2256251619976346`}, {
      0.44297242202844184`, -1.3458034094309375`}}]}, 
    {Arrowheads[{{0.01542246424804209, 1.}}], 
     ArrowBox[{{0.40112898734479346`, -0.7590261041720339}, {
      0.45601386979806297`, -0.955259610113681}}]}, 
    {Arrowheads[{{0.027336325018442277`, 1.}}], 
     ArrowBox[{{0.37703658972945764`, -0.2554946839760279}, {
      0.48010626741339885`, -0.6016481731668298}}]}, 
    {Arrowheads[{{0.011662527106001411`, 1.}}], 
     ArrowBox[{{0.3515277070761979, 1.2486339362370868`*^-12}, {
      0.5056151500666586, -1.249300070051862*^-12}}]}, 
    {Arrowheads[{{0.027336325018442287`, 1.}}], 
     ArrowBox[{{0.3770365897294576, 0.2554946839760272}, {0.4801062674133988, 
      0.6016481731668292}}]}, 
    {Arrowheads[{{0.015422464248042108`, 1.}}], 
     ArrowBox[{{0.40112898734479346`, 0.7590261041720331}, {0.456013869798063,
       0.9552596101136804}}]}, 
    {Arrowheads[{{0.009353595266389078, 1.}}], 
     ArrowBox[{{0.4141704351144146, 1.225625161997634}, {0.4429724220284419, 
      1.3458034094309368`}}]}, 
    {Arrowheads[{{0.006109484188900958, 1.}}], 
     ArrowBox[{{0.42054524976466456`, 1.6747320184168717`}, {
      0.4365976073781919, 1.7538394101545562`}}]}, 
    {Arrowheads[{{0.004243316920240459, 1.}}], 
     ArrowBox[{{0.42378053305216506`, 2.1152378422711013`}, {
      0.4333623240906913, 2.1704764434431834`}}]}, 
    {Arrowheads[{{0.0030947165913376294`, 1.}}], 
     ArrowBox[{{0.42553090207343464`, 2.55121195549375}, {0.4316119550694218, 
      2.5916451873633917`}}]}, 
    {Arrowheads[{{0.0023462225411808846`, 1.}}], 
     ArrowBox[{{0.4265396986475303, 2.9846343805771576`}, {
      0.43060315849532615`, 3.0153656194228406`}}]}, 
    {Arrowheads[{{0.002234723176453573, 1.}}], 
     ArrowBox[{{0.8533552046791197, -2.9857313793733176`}, {
      0.8609305096065938, -3.0142686206266824`}}]}, 
    {Arrowheads[{{0.002909456697377387, 1.}}], 
     ArrowBox[{{0.8515740902412987, -2.5530328515306078`}, {
      0.8627116240444148, -2.5898242913265355`}}]}, 
    {Arrowheads[{{0.003917785469689035, 1.}}], 
     ArrowBox[{{0.8485726844273626, -2.1184360206498054`}, {
      0.8657130298583509, -2.1672782650644815`}}]}, 
    {Arrowheads[{{0.005500953560028696, 1.}}], 
     ArrowBox[{{0.843213451125895, -1.6807215532143596`}, {
      0.8710722631598186, -1.74784987535707}}]}, 
    {Arrowheads[{{0.008145733118202653, 1.}}], 
     ArrowBox[{{0.8329737760195951, -1.237635926893405}, {
      0.8813119382661183, -1.3337926445351669`}}]}, 
    {Arrowheads[{{0.012962809606057961`, 1.}}], 
     ArrowBox[{{0.8117062441826863, -0.7845576542936953}, {
      0.9025794701030271, -0.9297280599920196}}]}, 
    {Arrowheads[{{0.023266062866074307`, 1.}}], 
     ArrowBox[{{0.7615295784279651, -0.30823400110969545`}, {
      0.9527561358577484, -0.5489088560331623}}]}, 
    {Arrowheads[{{0.029995590831845026`, 1.}}], 
     ArrowBox[{{1.055296475576408, 4.45435737557932*^-12}, {
      0.6589892387093055, -4.455023509394095*^-12}}]}, 
    {Arrowheads[{{0.02326606286607434, 1.}}], 
     ArrowBox[{{0.761529578427965, 0.3082340011096947}, {0.9527561358577485, 
      0.5489088560331619}}]}, 
    {Arrowheads[{{0.012962809606057966`, 1.}}], 
     ArrowBox[{{0.8117062441826863, 0.7845576542936946}, {0.9025794701030272, 
      0.9297280599920189}}]}, 
    {Arrowheads[{{0.008145733118202656, 1.}}], 
     ArrowBox[{{0.8329737760195951, 1.2376359268934043`}, {0.8813119382661184,
       1.3337926445351662`}}]}, 
    {Arrowheads[{{0.005500953560028696, 1.}}], 
     ArrowBox[{{0.843213451125895, 1.680721553214359}, {0.8710722631598186, 
      1.7478498753570693`}}]}, 
    {Arrowheads[{{0.0039177854696890385`, 1.}}], 
     ArrowBox[{{0.8485726844273626, 2.1184360206498045`}, {0.865713029858351, 
      2.1672782650644806`}}]}, 
    {Arrowheads[{{0.002909456697377387, 1.}}], 
     ArrowBox[{{0.8515740902412987, 2.553032851530607}, {0.8627116240444148, 
      2.5898242913265346`}}]}, 
    {Arrowheads[{{0.002234723176453573, 1.}}], 
     ArrowBox[{{0.8533552046791197, 2.9857313793733167`}, {0.8609305096065938,
       3.0142686206266815`}}]}, 
    {Arrowheads[{{0.0020686792684911056`, 1.}}], 
     ArrowBox[{{1.2806343297537737`, -2.987313375193248}, {
      1.2907942416747973`, -3.0126866248067525`}}]}, 
    {Arrowheads[{{0.002640238120928706, 1.}}], 
     ArrowBox[{{1.2784478301839577`, -2.5555726595350556`}, {
      1.2929807412446128`, -2.587284483322087}}]}, 
    {Arrowheads[{{0.003458622281051903, 1.}}], 
     ArrowBox[{{1.2749379528358986`, -2.1227101672265207`}, {
      1.296490618592672, -2.1630041184877657`}}]}, 
    {Arrowheads[{{0.004670052112325992, 1.}}], 
     ArrowBox[{{1.2690597863842985`, -1.6883165210005404`}, {
      1.3023687850442722`, -1.7402549075708889`}}]}, 
    {Arrowheads[{{0.006531051369324196, 1.}}], 
     ArrowBox[{{1.2587406472599338`, -1.2520410031165745`}, {
      1.312687924168637, -1.3193875683119975`}}]}, 
    {Arrowheads[{{0.00950916787819811, 1.}}], 
     ArrowBox[{{1.2396330441879466`, -0.8144500621126521}, {
      1.3317955272406243`, -0.8998356521730627}}]}, 
    {Arrowheads[{{0.014412324462740635`, 1.}}], 
     ArrowBox[{{1.2024771981098745`, -0.3823505832524056}, {
      1.3689513733186962`, -0.4747922738904521}}]}, 
    {Arrowheads[{{0.019508918417631957`, 1.}}], 
     ArrowBox[{{1.156836585059874, -2.9141176157394486`*^-16}, {
      1.4145919863686964`, -3.7472205320114907`*^-16}}]}, 
    {Arrowheads[{{0.014412324462740654`, 1.}}], 
     ArrowBox[{{1.2024771981098745`, 0.38235058325240495`}, {
      1.3689513733186964`, 0.47479227389045153`}}]}, 
    {Arrowheads[{{0.00950916787819811, 1.}}], 
     ArrowBox[{{1.2396330441879464`, 0.8144500621126515}, {1.331795527240624, 
      0.899835652173062}}]}, 
    {Arrowheads[{{0.006531051369324196, 1.}}], 
     ArrowBox[{{1.2587406472599336`, 1.2520410031165738`}, {
      1.3126879241686369`, 1.3193875683119969`}}]}, 
    {Arrowheads[{{0.004670052112326001, 1.}}], 
     ArrowBox[{{1.2690597863842985`, 1.6883165210005397`}, {
      1.3023687850442724`, 1.7402549075708882`}}]}, 
    {Arrowheads[{{0.003458622281051903, 1.}}], 
     ArrowBox[{{1.2749379528358986`, 2.12271016722652}, {1.296490618592672, 
      2.163004118487765}}]}, 
    {Arrowheads[{{0.002640238120928706, 1.}}], 
     ArrowBox[{{1.2784478301839577`, 2.5555726595350547`}, {
      1.2929807412446128`, 2.5872844833220863`}}]}, 
    {Arrowheads[{{0.0020686792684911056`, 1.}}], 
     ArrowBox[{{1.2806343297537737`, 2.987313375193247}, {1.2907942416747973`,
       3.0126866248067516`}}]}, 
    {Arrowheads[{{0.0018709140462428865`, 1.}}], 
     ArrowBox[{{1.7084346742986167`, -2.989113272904208}, {
      1.720136754272811, -3.0108867270957926`}}]}, 
    {Arrowheads[{{0.0023306964471982833`, 1.}}], 
     ArrowBox[{{1.7061963537845415`, -2.558328055647209}, {
      1.7223750747868862`, -2.5845290872099347`}}]}, 
    {Arrowheads[{{0.002954127119825161, 1.}}], 
     ArrowBox[{{1.702824311272944, -2.1270621878293774`}, {
      1.725747117298484, -2.158652097884909}}]}, 
    {Arrowheads[{{0.0038090652094623176`, 1.}}], 
     ArrowBox[{{1.6976497654750289`, -1.6954065337603523`}, {
      1.730921663096399, -1.7331648948110767`}}]}, 
    {Arrowheads[{{0.004980741248993108, 1.}}], 
     ArrowBox[{{1.6896567678413124`, -1.2638959972833468`}, {
      1.7389146607301154`, -1.3075325741452253`}}]}, 
    {Arrowheads[{{0.00652990583637025, 1.}}], 
     ArrowBox[{{1.6776716447441757`, -0.8343344353156835}, {
      1.7508997838272524`, -0.8799512789700313}}]}, 
    {Arrowheads[{{0.008274449613191693, 1.}}], 
     ArrowBox[{{1.6623897486005834`, -0.41140407563835807`}, {
      1.7661816799708443`, -0.44573878150449964`}}]}, 
    {Arrowheads[{{0.009206473150227656, 1.}}], 
     ArrowBox[{{1.6534669100169155`, -3.197041192114505*^-16}, {
      1.7751045185545122`, -3.464296955636434*^-16}}]}, 
    {Arrowheads[{{0.008274449613191709, 1.}}], 
     ArrowBox[{{1.6623897486005834`, 0.41140407563835746`}, {
      1.7661816799708445`, 0.445738781504499}}]}, 
    {Arrowheads[{{0.00652990583637025, 1.}}], 
     ArrowBox[{{1.6776716447441757`, 0.8343344353156829}, {
      1.7508997838272524`, 0.8799512789700307}}]}, 
    {Arrowheads[{{0.00498074124899312, 1.}}], 
     ArrowBox[{{1.6896567678413124`, 1.2638959972833461`}, {
      1.7389146607301156`, 1.3075325741452246`}}]}, 
    {Arrowheads[{{0.0038090652094623176`, 1.}}], 
     ArrowBox[{{1.6976497654750289`, 1.6954065337603517`}, {1.730921663096399,
       1.733164894811076}}]}, 
    {Arrowheads[{{0.002954127119825161, 1.}}], 
     ArrowBox[{{1.702824311272944, 2.1270621878293765`}, {1.725747117298484, 
      2.158652097884908}}]}, 
    {Arrowheads[{{0.0023306964471982833`, 1.}}], 
     ArrowBox[{{1.7061963537845415`, 2.558328055647208}, {1.7223750747868862`,
       2.584529087209934}}]}, 
    {Arrowheads[{{0.0018709140462428865`, 1.}}], 
     ArrowBox[{{1.7084346742986167`, 2.989113272904207}, {1.720136754272811, 
      3.0108867270957917`}}]}, 
    {Arrowheads[{{0.0016631798672512462`, 1.}}], 
     ArrowBox[{{2.1367008848524, -2.9908996011768463`}, {
      2.149013400861885, -3.0091003988231537`}}]}, 
    {Arrowheads[{{0.0020191693753136937`, 1.}}], 
     ArrowBox[{{2.1346535125004493`, -2.5609107528981383`}, {
      2.151060773213836, -2.581946389959005}}]}, 
    {Arrowheads[{{0.002474059287005173, 1.}}], 
     ArrowBox[{{2.1317789966425327`, -2.1308406331914}, {
      2.153935289071752, -2.1548736525228867`}}]}, 
    {Arrowheads[{{0.0030494251158718552`, 1.}}], 
     ArrowBox[{{2.127768711250584, -1.7009383755963687`}, {
      2.157945574463701, -1.7276330529750605`}}]}, 
    {Arrowheads[{{0.0037528465275942823`, 1.}}], 
     ArrowBox[{{2.122349547742081, -1.2717835881132014`}, {
      2.163364737972204, -1.2996449833153705`}}]}, 
    {Arrowheads[{{0.00454014929654713, 1.}}], 
     ArrowBox[{{2.115661045181474, -0.8444964808539926}, {
      2.1700532405328103`, -0.8697892334317222}}]}, 
    {Arrowheads[{{0.005242389338532468, 1.}}], 
     ArrowBox[{{2.1091668921368703`, -0.42055133419906654`}, {
      2.176547393577414, -0.43659152294379117`}}]}, 
    {Arrowheads[{{0.005542467523030282, 1.}}], 
     ArrowBox[{{2.1062430951160684`, -3.2598774529122724`*^-16}, {
      2.1794711905982163`, -3.401460694838667*^-16}}]}, 
    {Arrowheads[{{0.005242389338532468, 1.}}], 
     ArrowBox[{{2.1091668921368703`, 0.42055133419906593`}, {
      2.176547393577414, 0.43659152294379056`}}]}, 
    {Arrowheads[{{0.00454014929654713, 1.}}], 
     ArrowBox[{{2.115661045181474, 0.844496480853992}, {2.1700532405328103`, 
      0.8697892334317215}}]}, 
    {Arrowheads[{{0.0037528465275942823`, 1.}}], 
     ArrowBox[{{2.122349547742081, 1.2717835881132007`}, {2.163364737972204, 
      1.2996449833153698`}}]}, 
    {Arrowheads[{{0.0030494251158718552`, 1.}}], 
     ArrowBox[{{2.127768711250584, 1.700938375596368}, {2.157945574463701, 
      1.7276330529750599`}}]}, 
    {Arrowheads[{{0.002474059287005173, 1.}}], 
     ArrowBox[{{2.1317789966425327`, 2.130840633191399}, {2.153935289071752, 
      2.1548736525228858`}}]}, 
    {Arrowheads[{{0.0020191693753136937`, 1.}}], 
     ArrowBox[{{2.1346535125004493`, 2.5609107528981374`}, {2.151060773213836,
       2.581946389959004}}]}, 
    {Arrowheads[{{0.0016631798672512462`, 1.}}], 
     ArrowBox[{{2.1367008848524, 2.9908996011768454`}, {2.149013400861885, 
      3.009100398823153}}]}, 
    {Arrowheads[{{0.001461937620733608, 1.}}], 
     ArrowBox[{{2.5653172712442407`, -2.992521827882498}, {
      2.5775398716129003`, -3.0074781721175015`}}]}, 
    {Arrowheads[{{0.0017309273443527017`, 1.}}], 
     ArrowBox[{{2.5635747995863687`, -2.563117746004457}, {
      2.5792823432707723`, -2.5797393968526863`}}]}, 
    {Arrowheads[{{0.0020553471264462457`, 1.}}], 
     ArrowBox[{{2.5612926989964953`, -2.1338227060725434`}, {
      2.5815644438606467`, -2.1518915796417435`}}]}, 
    {Arrowheads[{{0.002436241535732508, 1.}}], 
     ArrowBox[{{2.5583808163964132`, -1.704863716767077}, {
      2.5844763264607282`, -1.7237077118043522`}}]}, 
    {Arrowheads[{{0.0028592922698599445`, 1.}}], 
     ArrowBox[{{2.5548726290506423`, -1.2766211281814925`}, {
      2.587984513806499, -1.2948074432470795`}}]}, 
    {Arrowheads[{{0.003279399448681085, 1.}}], 
     ArrowBox[{{2.551119308924243, -0.8496020805299832}, {
      2.591737833932898, -0.8646836337557317}}]}, 
    {Arrowheads[{{0.0036081785324962026`, 1.}}], 
     ArrowBox[{{2.5480016493566766`, -0.4241745889793647}, {
      2.594855493500465, -0.4329682681634931}}]}, 
    {Arrowheads[{{0.003735842627013546, 1.}}], 
     ArrowBox[{{2.546749253105055, -3.2857877866933027`*^-16}, {
      2.5961078897520866`, -3.375550361057636*^-16}}]}, 
    {Arrowheads[{{0.003608178532496202, 1.}}], 
     ArrowBox[{{2.5480016493566766`, 0.42417458897936405`}, {
      2.594855493500465, 0.4329682681634924}}]}, 
    {Arrowheads[{{0.003279399448681085, 1.}}], 
     ArrowBox[{{2.551119308924243, 0.8496020805299825}, {2.591737833932898, 
      0.864683633755731}}]}, 
    {Arrowheads[{{0.0028592922698599445`, 1.}}], 
     ArrowBox[{{2.5548726290506423`, 1.2766211281814919`}, {2.587984513806499,
       1.2948074432470789`}}]}, 
    {Arrowheads[{{0.002436241535732508, 1.}}], 
     ArrowBox[{{2.5583808163964132`, 1.7048637167670764`}, {
      2.5844763264607282`, 1.7237077118043516`}}]}, 
    {Arrowheads[{{0.0020553471264462457`, 1.}}], 
     ArrowBox[{{2.5612926989964953`, 2.1338227060725425`}, {
      2.5815644438606467`, 2.1518915796417426`}}]}, 
    {Arrowheads[{{0.0017309273443527017`, 1.}}], 
     ArrowBox[{{2.5635747995863687`, 2.563117746004456}, {2.5792823432707723`,
       2.5797393968526854`}}]}, 
    {Arrowheads[{{0.001461937620733608, 1.}}], 
     ArrowBox[{{2.5653172712442407`, 2.992521827882497}, {2.5775398716129003`,
       3.0074781721175006`}}]}, 
    {Arrowheads[{{0.0012771583698610745`, 1.}}], 
     ArrowBox[{{2.9941594429168266`, -2.9939113806778193`}, {
      3.0058405570831717`, -3.0060886193221807`}}]}, 
    {Arrowheads[{{0.0014779291576124862`, 1.}}], 
     ArrowBox[{{2.992741007221254, -2.5648994260228073`}, {
      3.0072589927787443`, -2.5779577168343355`}}]}, 
    {Arrowheads[{{0.0017077538436409952`, 1.}}], 
     ArrowBox[{{2.990997389407271, -2.136058098136514}, {
      3.009002610592727, -2.149656187577773}}]}, 
    {Arrowheads[{{0.00196106422354382, 1.}}], 
     ArrowBox[{{2.9889365632929366`, -1.7075454168541515`}, {
      3.0110634367070617`, -1.7210260117172778`}}]}, 
    {Arrowheads[{{0.0022222289338737467`, 1.}}], 
     ArrowBox[{{2.986667572253525, -1.2795696910315995`}, {
      3.0133324277464735`, -1.2918588803969726`}}]}, 
    {Arrowheads[{{0.0024611881245613426`, 1.}}], 
     ArrowBox[{{2.9844688369273737`, -0.8523332150407432}, {
      3.0155311630726245`, -0.8619524992449717}}]}, 
    {Arrowheads[{{0.002634370164857432, 1.}}], 
     ArrowBox[{{2.982804355401517, -0.4258936679465384}, {
      3.0171956445984818`, -0.4312491891963194}}]}, 
    {Arrowheads[{{0.0026983989483408384`, 1.}}], 
     ArrowBox[{{2.9821741295716238`, -3.2993552797625713`*^-16}, {
      3.017825870428374, -3.361982867988368*^-16}}]}, 
    {Arrowheads[{{0.002634370164857432, 1.}}], 
     ArrowBox[{{2.982804355401517, 0.4258936679465377}, {3.0171956445984818`, 
      0.4312491891963187}}]}, 
    {Arrowheads[{{0.00246118812456134, 1.}}], 
     ArrowBox[{{2.9844688369273737`, 0.8523332150407426}, {
      3.0155311630726245`, 0.861952499244971}}]}, 
    {Arrowheads[{{0.0022222289338737467`, 1.}}], 
     ArrowBox[{{2.986667572253525, 1.2795696910315988`}, {3.0133324277464735`,
       1.291858880396972}}]}, 
    {Arrowheads[{{0.00196106422354382, 1.}}], 
     ArrowBox[{{2.9889365632929366`, 1.7075454168541508`}, {
      3.0110634367070617`, 1.721026011717277}}]}, 
    {Arrowheads[{{0.001707753843641022, 1.}}], 
     ArrowBox[{{2.990997389407271, 2.136058098136513}, {3.0090026105927272`, 
      2.149656187577772}}]}, 
    {Arrowheads[{{0.0014779291576124862`, 1.}}], 
     ArrowBox[{{2.992741007221254, 2.5648994260228064`}, {3.0072589927787443`,
       2.5779577168343346`}}]}, 
    {Arrowheads[{{0.0012771583698610745`, 1.}}], 
     ArrowBox[{{2.9941594429168266`, 2.9939113806778184`}, {
      3.0058405570831717`, 3.00608861932218}}]}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-3.303045763365663, 3.303045763365663}, {-3.303045763365663, 
   3.303045763365663}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650660789674789*^9, 3.6506608589819098`*^9, 
  3.65066162396356*^9, 3.6507357635966053`*^9, 3.650928053122463*^9},
 CellID->134014425]
}, Open  ]],

Cell["\<\
And here is a plot of field lines for the disk of radius 1 plotted out to a \
distance of 4. Note that the field lines are set to be equally spaced out at \
the radius 4.  It is good to take the number of stream starting points to be \
divisible by 4 so that  \
\>", "Text",
 CellChangeTimes->{{3.650733326336039*^9, 3.650733331662566*^9}, {
  3.6509267946249733`*^9, 3.6509268914837418`*^9}, {3.650927174169146*^9, 
  3.650927212279825*^9}},
 CellID->1427656527],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"uniformStreamPlot", "=", "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"range", "=", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"StreamPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ExUniformDisk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
        RowBox[{"EzUniformDisk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "range"}], ",", "range"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "range"}], ",", "range"}], "}"}], ",", 
      RowBox[{"StreamPoints", "\[Rule]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", "=", "32"}], "}"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RotationMatrix", "[", " ", 
             RowBox[{"2", "\[Pi]", " ", 
              FractionBox["i", "n"]}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"range", ",", "0"}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"First", "@", 
         RowBox[{"Plot", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", 
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y"}], "}"}], ",", 
              RowBox[{"Blend", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"Darker", "@", "Blue"}], "}"}], ",", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SuperscriptBox["x", "2"]}], ")"}], 
                 RowBox[{"1", "/", "2"}]]}], "]"}]}], "]"}]}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", " ", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"AbsoluteThickness", "[", "6", "]"}], "}"}]}]}], "]"}]}],
         "}"}]}], ",", 
      RowBox[{"StreamStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Line\>\"", ",", 
         RowBox[{"Directive", "[", 
          RowBox[{
           RowBox[{"Darker", "@", "Green"}], ",", "Thick"}], "]"}]}], "}"}]}],
       ",", 
      RowBox[{"Frame", "\[Rule]", "False"}], ",", 
      RowBox[{"RegionFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "z", ",", "vx", ",", "vz", ",", "n"}], "}"}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}], "<", 
          SuperscriptBox["range", "2"]}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.65080637315687*^9, 3.650806387311253*^9}, {
   3.6508065056804934`*^9, 3.650806506270322*^9}, {3.650806611228487*^9, 
   3.650806613186453*^9}, 3.6508066524493637`*^9, {3.6508085374404488`*^9, 
   3.650808544097351*^9}, {3.650808719264966*^9, 3.650808727185721*^9}, {
   3.6508087833325033`*^9, 3.650808821159395*^9}, {3.650808958792677*^9, 
   3.650808975974661*^9}, {3.650809087384323*^9, 3.650809091958276*^9}, {
   3.6508091632451468`*^9, 3.650809164275715*^9}, 3.650926768435526*^9, 
   3.650927167220886*^9, {3.650928138368949*^9, 3.650928170943906*^9}, 
   3.650983784093615*^9},
 CellID->1907003143],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJx1XXVclcn3pkUEcc117cTurhnXBgNRMbFFxU7EWLuwwO4OcBUVC/HqjJ2o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    
    "], {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, 
      {RGBColor[0, 
        NCache[
         Rational[2, 3], 0.6666666666666666], 0], Thickness[Large], 
       LineBox[{34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
        49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 
        66, 67}], 
       LineBox[{92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 
        106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116}], 
       LineBox[{148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 
        160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
        174, 175, 176, 177, 178, 179}], 
       LineBox[{208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 
        220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 
        234, 235}], 
       LineBox[{268, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 279, 
        280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 290, 291, 292, 293, 
        294, 295, 296, 297, 298, 299, 300}], 
       LineBox[{332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 342, 343, 
        344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 
        358, 359, 360, 361, 362}], 
       LineBox[{400, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410, 411, 
        412, 413, 414, 415, 416, 417, 418, 419, 420, 421, 422, 423, 424, 425, 
        426, 427, 428, 429, 430, 431, 432, 433, 434, 435, 436, 437}], 
       LineBox[{442, 443, 472, 473, 474, 475, 476, 477, 478, 479, 480, 481, 
        482, 483, 484, 485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 
        496, 497, 498, 499, 500, 501, 502}], 
       LineBox[{545, 546, 547, 548, 549, 550, 551, 552, 553, 554, 555, 556, 
        557, 558, 559, 560, 561, 562, 563, 564, 565, 566, 567, 568, 569, 570, 
        571, 572, 573, 574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 
        585, 586, 587}], 
       LineBox[{592, 593, 622, 623, 624, 625, 626, 627, 628, 629, 630, 631, 
        632, 633, 634, 635, 636, 637, 638, 639, 640, 641, 642, 643, 644, 645, 
        646, 647, 648, 649, 650, 651, 652}], 
       LineBox[{691, 692, 693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 
        703, 704, 705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 
        717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728}], 
       LineBox[{760, 761, 762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 
        772, 773, 774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 
        786, 787, 788, 789, 790}], 
       LineBox[{824, 825, 826, 827, 828, 829, 830, 831, 832, 833, 834, 835, 
        836, 837, 838, 839, 840, 841, 842, 843, 844, 845, 846, 847, 848, 849, 
        850, 851, 852, 853, 854, 855, 856}], 
       LineBox[{886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
        898, 899, 900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 
        912, 913, 914}], 
       LineBox[{942, 943, 944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 
        954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 
        968}], LineBox[{994, 995, 996, 997, 998, 999, 1000, 1001, 1002, 1003, 
        1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 
        1015, 1016, 1017, 1018, 1019}], 
       LineBox[{1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 
        1055, 1056, 1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 
        1066, 1067, 1068, 1069, 1070}], 
       LineBox[{1096, 1097, 1098, 1099, 1100, 1101, 1102, 1103, 1104, 1105, 
        1106, 1107, 1108, 1109, 1110, 1111, 1112, 1113, 1114, 1115, 1116, 
        1117, 1118, 1119, 1120, 1121}], 
       LineBox[{1154, 1155, 1156, 1157, 1158, 1159, 1160, 1161, 1162, 1163, 
        1164, 1165, 1166, 1167, 1168, 1169, 1170, 1171, 1172, 1173, 1174, 
        1175, 1176, 1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184, 1185}], 
       LineBox[{1213, 1214, 1215, 1216, 1217, 1218, 1219, 1220, 1221, 1222, 
        1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232, 1233, 
        1234, 1235, 1236, 1237, 1238, 1239, 1240}], 
       LineBox[{1272, 1273, 1274, 1275, 1276, 1277, 1278, 1279, 1280, 1281, 
        1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 1292, 
        1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302}], 
       LineBox[{1334, 1335, 1336, 1337, 1338, 1339, 1340, 1341, 1342, 1343, 
        1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353, 1354, 
        1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364}], 
       LineBox[{1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 
        1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 
        1421, 1422, 1423, 1424, 1425, 1426, 1427, 1428, 1429, 1430, 1431, 
        1432, 1433, 1434, 1435}], 
       LineBox[{1440, 1441, 1470, 1471, 1472, 1473, 1474, 1475, 1476, 1477, 
        1478, 1479, 1480, 1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 
        1489, 1490, 1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 
        1500}], LineBox[{1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551,
         1552, 1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 
        1563, 1564, 1565, 1566, 1567, 1568, 1569, 1570, 1571, 1572, 1573, 
        1574, 1575, 1576, 1577, 1578, 1579, 1580, 1581, 1582, 1583, 1584, 
        1585}], LineBox[{1590, 1591, 1620, 1621, 1622, 1623, 1624, 1625, 1626,
         1627, 1628, 1629, 1630, 1631, 1632, 1633, 1634, 1635, 1636, 1637, 
        1638, 1639, 1640, 1641, 1642, 1643, 1644, 1645, 1646, 1647, 1648, 
        1649, 1650}], 
       LineBox[{1687, 1688, 1689, 1690, 1691, 1692, 1693, 1694, 1695, 1696, 
        1697, 1698, 1699, 1700, 1701, 1702, 1703, 1704, 1705, 1706, 1707, 
        1708, 1709, 1710, 1711, 1712, 1713, 1714, 1715, 1716, 1717, 1718, 
        1719, 1720, 1721, 1722}], 
       LineBox[{1753, 1754, 1755, 1756, 1757, 1758, 1759, 1760, 1761, 1762, 
        1763, 1764, 1765, 1766, 1767, 1768, 1769, 1770, 1771, 1772, 1773, 
        1774, 1775, 1776, 1777, 1778, 1779, 1780, 1781, 1782, 1783}], 
       LineBox[{1815, 1816, 1817, 1818, 1819, 1820, 1821, 1822, 1823, 1824, 
        1825, 1826, 1827, 1828, 1829, 1830, 1831, 1832, 1833, 1834, 1835, 
        1836, 1837, 1838, 1839, 1840, 1841, 1842, 1843, 1844, 1845}], 
       LineBox[{1875, 1876, 1877, 1878, 1879, 1880, 1881, 1882, 1883, 1884, 
        1885, 1886, 1887, 1888, 1889, 1890, 1891, 1892, 1893, 1894, 1895, 
        1896, 1897, 1898, 1899, 1900, 1901, 1902, 1903}], 
       LineBox[{1931, 1932, 1933, 1934, 1935, 1936, 1937, 1938, 1939, 1940, 
        1941, 1942, 1943, 1944, 1945, 1946, 1947, 1948, 1949, 1950, 1951, 
        1952, 1953, 1954, 1955, 1956, 1957}], 
       LineBox[{1982, 1983, 1984, 1985, 1986, 1987, 1988, 1989, 1990, 1991, 
        1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 
        2003, 2004, 2005, 2006}]}}}]},
  AspectRatio->1,
  DisplayFunction->Identity,
  Epilog->{
    GraphicsComplexBox[CompressedData["
1:eJxF03lI02EYB/BpmqVRUKlJimc2LUcYHvNg4VGu1JlZqavpZnlSmV0qlDMP
DCwZmujmspozjzkTLHNsTScy0UXpbM7UNeeB2y81c0VaYAX2vC+8vHx4vu/3
v8eZcS32sikOh4v6e/+9BJKNYWNjWYrbPKJt9Ktpb5fABe9UWC99Eazn29n6
2X8Be36O2L5rygBu2MMzjt/Xg/uogw+lpAWwfb29U830PPhUKDVP+WAO7Pgr
lelBngV7CbnMnEUdWHvzGUHVNA3OqGPx6jK14Ph7Ca4CFw0Yj3lQ455MgLOi
Y0p0M2pw4g1KsK+vClwpXYiRvlaCSabqcwSTYXCmWpbNX1WAg2oL94ly5eD0
qZWJBFsZmKI93DbgJgL7SjljhmIhmPj1YoompQp8qGjZsudWJem/2+VLzQXx
7WAJedA/QNYNxlqeZ0THy8DcNgLH+EoOFtNLrY90KcD5e2s/UnYPgxUfRsNG
2Erw9SE/9wobFbjhfZh16oAaXC7oarKInACbVI6S+8w1YNvmVnlDhBasesF0
NS+bBlNbPUtzdDpwEMcisP/ALHimovuHW/EcuNO1AHOenAdreXe8zRwWwCP4
cOZqrh7syA53GpAYwNUtCWvE3xhYKQ0Zf3N2EZzVS7NyqFkCb+4D2MgLFBxN
QvsRyRTl74xEc9YKfqi2Hc0nn+7os/6G+iRJ6d4WjSifXFP/STGG8m4dPml2
/Shvls1SWeah/G0K6dEWJbIcS2TMY+h/BPEkkSNE//E/+U3lDJRnj51JLhEj
x8o9xYV65PzH/u6r31Ff4t04lws81BcQ9JIVdR7lBftp5OMdyJesfPghGuRj
RU7KHiNyXObBsrV11M+oH68Wc1F/KM1nq/A0yncGz0gaW5GveInseGpkMp9/
wnkZ2Y/OoSWvI/8BvPBPPg==
     "], {{{}, {}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[6]], 
        LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
         12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
         29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
         46, 47, 48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 
         63, 59, 75, 69, 64, 76, 70, 77, 50}, VertexColors -> Automatic]}}}, 
     VertexColors -> {
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.0002857142828357789], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.27744099258219684`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.39615583738176013`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.47784487131161285`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.5433833117604547], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.6036848322784806], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.6525080762147237], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.6990852198584507], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.7395747128039711], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.7733896726405063], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8063158088352537], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8339368104687275], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8583801533431665], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8822046177495451], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9020944402327128], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9212761799021476], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9378433602801247], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9513769641563284], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9640565646946965], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9740842481626342], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9830436334517096], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9899614528891321], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9947716994553699], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9982218724969131], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9998017321147395], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9998194101801232], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9981241699238359], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9949249371779421], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9896764157400462], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9826932461747339], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.974510832675839], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.963767788268366], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9519271361170829], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9385560297090676], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9219825737393734], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.9044802540801411], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8831441338353901], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8608447765582377], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8365739540788304], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.8072990955859816], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.7769108258857161], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.740205320145062], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.69976650080207], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.6573997211201691], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.605277489759211], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.5492368694454814], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.4849545367404146], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.3995437692093681], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.2931432288874855], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.0002857142828357789], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.19716002765968152`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.20844426018086942`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.13975836270754877`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.25458123308415476`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.14780111208541072`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.09894605100214668], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.27459503677171687`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.18076848438558926`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.10465553479015588`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.07000872356783124], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.2840338577984708], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.1951170577357807], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.12808791431165623`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.0740538334064749], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.04951925401121532], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.2886277485714457], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.20189532596645082`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.13830302237980016`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.09066565137026299], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.05238235078357036], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.03502135532307443], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.2908950603362815], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.20519706944489305`], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.1431325209398042], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.09791318519153286], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.06414367967267814], 
       Blend[{
         RGBColor[0, 0, 
          Rational[2, 3]]}, 0.03704682627675106]}]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-4.174050091548382, 4.174050091548382}, {-4.174050091548382, 
   4.174050091548382}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650808714949293*^9, 3.650808773482143*^9, 
  3.650808866600458*^9, 3.650809027554111*^9, 3.650809140661948*^9, 
  3.650809270323045*^9, 3.65092721530663*^9, 3.65092796047086*^9, 
  3.6509284615506897`*^9},
 CellID->693348500]
}, Open  ]],

Cell[TextData[{
 "It is worth noting that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox["StreamPlot", "MB"],
 " function\[CloseCurlyQuote]s algorithm limits the degree to which it\
\[CloseCurlyQuote]s lines can get close to one another.  This accounts for \
the lines not completely terminating on the disk in the image. Unfortunately \
there is no way to adjust this behavior as far as I know short of engaging in \
a development process to design a custom function for this particular \
problem. One can edit the graphic in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " by hand to drag the stream lines which do not terminate on the disk to a \
point interpolated between their nearest streamlines. Since the streamlines \
do come very close to the disk this should be a pretty accurate rendition."
}], "Text",
 CellChangeTimes->{{3.650983794864203*^9, 3.650983863724794*^9}, {
  3.6509840992608643`*^9, 3.6509841687814503`*^9}, {3.650984233323874*^9, 
  3.650984345332592*^9}},
 CellID->1476542942]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Field evaluation for a disk varying as ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["r", "r0"], ")"}], "2"]}]], TraditionalForm]]]
}], "Section",
 CellChangeTimes->{{3.650659168026176*^9, 3.650659176114109*^9}, {
   3.650661891160697*^9, 3.650661914052271*^9}, 3.650903122870521*^9},
 CellID->252724095],

Cell[CellGroupData[{

Cell["General", "Subsection",
 CellChangeTimes->{{3.65065964796058*^9, 3.650659648799752*^9}},
 CellID->1977060651],

Cell[TextData[{
 "Similarly to the constant charge density approach above the radial charge \
density ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Rho]", "=", 
    RowBox[{
     FractionBox["3", 
      RowBox[{"2", "\[Pi]", " ", 
       SuperscriptBox["r0", "2"]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["a", "r0"], ")"}], "2"]}]]}]}], TraditionalForm]]],
 " can be used in our functions to define two functions ",
 StyleBox["ExSqrtDisk", "MB"],
 " and ",
 StyleBox["EzSqrtDisk", "MB"],
 " as follows."
}], "Text",
 CellChangeTimes->{{3.6507354670898867`*^9, 3.650735521230867*^9}, {
   3.65073555780482*^9, 3.650735571330597*^9}, 3.650973155930285*^9},
 CellID->867775769],

Cell["\<\
First compute the ring x and z components of the field for this expression \
for the radial charge density\
\>", "Text",
 CellChangeTimes->{{3.650735577067527*^9, 3.650735615257031*^9}, 
   3.650973159998116*^9},
 CellID->993769986],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ExRing", "[", 
   RowBox[{"a", ",", "r", ",", "\[Theta]", ",", 
    RowBox[{
     FractionBox["3", 
      RowBox[{"2", "\[Pi]", " ", 
       SuperscriptBox["r0", "2"]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["a", "r0"], ")"}], "2"]}]]}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.650659192879286*^9, 3.650659194073555*^9}, {
   3.65065942866774*^9, 3.6506594542327414`*^9}, 3.650660178571718*^9, 
   3.650661983881125*^9, 3.650662922531926*^9, 3.6507315534997473`*^9},
 CellID->443891326],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3", " ", 
    SqrtBox[
     RowBox[{"1", "-", 
      FractionBox[
       SuperscriptBox["a", "2"], 
       SuperscriptBox["r0", "2"]]}]], " ", 
    RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], "-", 
      RowBox[{
       RowBox[{"EllipticK", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{"\[Pi]", " ", "r", " ", 
    SqrtBox[
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["r", "2"], 
       SuperscriptBox["a", "2"]]}]], " ", 
    SuperscriptBox["r0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["r", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
    SqrtBox[
     RowBox[{"1", "+", 
      FractionBox[
       RowBox[{"2", " ", "a", " ", "r", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["r", "2"]}]]}]]}]]}]], "Output",
 CellChangeTimes->{{3.6506594686195993`*^9, 3.650659483914063*^9}, 
   3.650660186915718*^9, 3.650661991370586*^9, 3.650662933818042*^9, 
   3.650735731114748*^9, 3.650736446859209*^9, 3.650748985897647*^9, 
   3.650751852454097*^9, 3.650804947791771*^9},
 CellID->1304341000]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"EzRing", "[", 
   RowBox[{"a", ",", "r", ",", "\[Theta]", ",", 
    RowBox[{
     FractionBox["3", 
      RowBox[{"2", "\[Pi]", " ", 
       SuperscriptBox["r0", "2"]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["a", "r0"], ")"}], "2"]}]]}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.650659192879286*^9, 3.650659194073555*^9}, {
   3.65065942866774*^9, 3.6506594542327414`*^9}, 3.6506601735565367`*^9, 
   3.650661996224491*^9, 3.650662926056033*^9, 3.650731574722869*^9},
 CellID->425152673],

Cell[BoxData[
 FractionBox[
  RowBox[{"6", " ", "r", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox[
      SuperscriptBox["a", "2"], 
      SuperscriptBox["r0", "2"]]}]], " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   RowBox[{"EllipticE", "[", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["r", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
  RowBox[{"\[Pi]", " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]], " ", 
   SuperscriptBox["r0", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"2", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["r", "2"]}]]}]]}]]], "Output",
 CellChangeTimes->{3.6506601830962877`*^9, 3.650661998735875*^9, 
  3.6506629491063623`*^9, 3.650735731704954*^9, 3.65073644762537*^9, 
  3.650748986452467*^9, 3.650751853025607*^9, 3.650804948337202*^9},
 CellID->546118424]
}, Open  ]],

Cell[TextData[{
 "And then use these to define ",
 StyleBox["ExSqrtDisk", "MB"],
 " and ",
 StyleBox["EzSqrtDisk", "MB"],
 ":"
}], "Text",
 CellChangeTimes->{{3.6507356196087723`*^9, 3.650735636744067*^9}},
 CellID->665150686],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", " ", 
          SqrtBox[
           RowBox[{"1", "-", 
            FractionBox[
             SuperscriptBox["a", "2"], 
             SuperscriptBox["r0", "2"]]}]], " ", 
          RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"EllipticE", "[", 
              FractionBox[
               RowBox[{"4", " ", "a", " ", "r", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["r", "2"], "+", 
                RowBox[{"2", " ", "a", " ", "r", " ", 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], "-", 
            RowBox[{
             RowBox[{"EllipticK", "[", 
              FractionBox[
               RowBox[{"4", " ", "a", " ", "r", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
               RowBox[{
                SuperscriptBox["a", "2"], "+", 
                SuperscriptBox["r", "2"], "+", 
                RowBox[{"2", " ", "a", " ", "r", " ", 
                 RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["r", "2"], "-", 
               RowBox[{"2", " ", "a", " ", "r", " ", 
                RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}]}]}], ")"}]}],
          ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Pi]", " ", "r", " ", 
          SqrtBox[
           RowBox[{"1", "+", 
            FractionBox[
             SuperscriptBox["r", "2"], 
             SuperscriptBox["a", "2"]]}]], " ", 
          SuperscriptBox["r0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["r", "2"], "-", 
            RowBox[{"2", " ", "a", " ", "r", " ", 
             RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
          SqrtBox[
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"2", " ", "a", " ", "r", " ", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["r", "2"]}]]}]]}], ")"}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, {
   3.650660199036735*^9, 3.6506602057557383`*^9}, {3.6506620057514353`*^9, 
   3.650662023850267*^9}, 3.650662943717815*^9, {3.650807997190048*^9, 
   3.650808004261982*^9}, 3.650808160732793*^9, 3.650971553236285*^9},
 CellID->493008203],

Cell[BoxData[
 RowBox[{
  RowBox[{"EzSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"6", " ", "r", " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["a", "2"], 
          SuperscriptBox["r0", "2"]]}]], " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"], "-", 
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650659607726983*^9, 3.650659720983036*^9}, 
   3.65066019498035*^9, {3.65066201470468*^9, 3.650662038759881*^9}, 
   3.6506629552286386`*^9, {3.650808007549223*^9, 3.650808008853302*^9}, 
   3.65080816157265*^9, 3.650971554325108*^9},
 CellID->996957695],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"0", "|", "0.0"}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}, 
   3.6509285036865063`*^9},
 CellID->861970878],

Cell[BoxData[
 RowBox[{
  RowBox[{"ExSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", 
    RowBox[{"\[Pi]", "|", 
     RowBox[{"N", "[", "\[Pi]", "]"}]}]}], "]"}], ":=", "0"}]], "Input",
 CellChangeTimes->{{3.650927785069584*^9, 3.6509277902197943`*^9}, 
   3.650927980592544*^9, {3.650928012437546*^9, 3.650928019059594*^9}, 
   3.650928505054163*^9},
 CellID->219863884]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check analytically on the z axis", "Subsection",
 CellChangeTimes->{{3.650659735269438*^9, 3.650659743291773*^9}},
 CellID->307849756],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EzRing", "[", 
  RowBox[{"a", ",", "z", ",", "0", ",", 
   RowBox[{
    FractionBox["3", 
     RowBox[{"2", "\[Pi]", " ", 
      SuperscriptBox["r0", "2"]}]], 
    SqrtBox[
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["a", "r0"], ")"}], "2"]}]]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650659760573246*^9, 3.650659794730489*^9}, 
   3.650662080373152*^9, 3.6506624813157597`*^9, {3.6506629721289186`*^9, 
   3.6506629904717216`*^9}, 3.650731575762704*^9},
 CellID->742743469],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox[
      SuperscriptBox["a", "2"], 
      SuperscriptBox["r0", "2"]]}]], " ", "z"}], 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   SuperscriptBox["r0", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["z", "2"], 
       SuperscriptBox["a", "2"]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{{3.650659777896194*^9, 3.650659790158773*^9}, 
   3.6506620877872877`*^9, 3.6506624836172113`*^9, 3.6506629911947927`*^9, 
   3.650751853152869*^9},
 CellID->310263991]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"3", " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["a", "2"], 
        SuperscriptBox["r0", "2"]]}]], " ", "z"}], 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["r0", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        FractionBox[
         SuperscriptBox["z", "2"], 
         SuperscriptBox["a", "2"]]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0", ",", "r0"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"r0", ">", "0"}], ",", 
      RowBox[{"z", "\[Element]", "Reals"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6506598475832357`*^9, 3.650659936228998*^9}, {
   3.650662096727861*^9, 3.650662099642292*^9}, 3.650662491549912*^9, 
   3.650662998226872*^9},
 CellID->150414830],

Cell[BoxData[
 RowBox[{"ConditionalExpression", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"3", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], "+", 
       FractionBox["r0", 
        RowBox[{"Abs", "[", "z", "]"}]], "+", 
       RowBox[{"ArcTan", "[", 
        FractionBox[
         RowBox[{"Abs", "[", "z", "]"}], "r0"], "]"}]}], ")"}]}], 
    SuperscriptBox["r0", "3"]], ",", 
   RowBox[{"z", "\[NotEqual]", "0"}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.650659860245924*^9, {3.650659913552411*^9, 3.6506599381036053`*^9}, 
   3.650662107233263*^9, 3.6506624939307137`*^9, 3.6506630177897*^9, 
   3.650751871089522*^9},
 CellID->1900677409]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{"ConditionalExpression", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"3", " ", "z", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "+", 
         FractionBox["r0", 
          RowBox[{"Abs", "[", "z", "]"}]], "+", 
         RowBox[{"ArcTan", "[", 
          FractionBox[
           RowBox[{"Abs", "[", "z", "]"}], "r0"], "]"}]}], ")"}]}], 
      SuperscriptBox["r0", "3"]], ",", 
     RowBox[{"z", "\[NotEqual]", "0"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", ">", "0"}], ",", 
     RowBox[{"r0", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650660015454708*^9, 3.650660032416836*^9}, {
   3.6506621149756947`*^9, 3.650662121604257*^9}, {3.650662378679714*^9, 
   3.650662388141632*^9}, 3.650662498745957*^9, 3.650663022454584*^9},
 CellID->90474272],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"6", " ", "r0"}], "-", 
   RowBox[{"3", " ", "\[Pi]", " ", "z"}], "+", 
   RowBox[{"6", " ", "z", " ", 
    RowBox[{"ArcTan", "[", 
     FractionBox["z", "r0"], "]"}]}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["r0", "3"]}]]], "Output",
 CellChangeTimes->{3.650660033000345*^9, 3.65066212242974*^9, 
  3.650662388715272*^9, 3.650662499737296*^9, 3.6506630241523027`*^9, 
  3.650751871397091*^9},
 CellID->865963938]
}, Open  ]],

Cell["A hand calculation shows that this is correct.", "Text",
 CellChangeTimes->{{3.650735657917452*^9, 3.650735666925161*^9}},
 CellID->951398009]
}, Open  ]],

Cell[CellGroupData[{

Cell["Look at Behavior everywhere", "Subsection",
 CellChangeTimes->{{3.65066022697818*^9, 3.650660255056013*^9}},
 CellID->652444475],

Cell["Scale r0 to be 1 as before", "Text",
 CellChangeTimes->{{3.650660293807664*^9, 3.650660302406025*^9}, {
  3.650735669972913*^9, 3.650735671700733*^9}},
 CellID->582789743],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ExSqrtDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
     RowBox[{"EzSqrtDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.650660779207404*^9, {3.650660809613495*^9, 3.6506608184941177`*^9}, {
   3.650660910432844*^9, 3.650660923478569*^9}, {3.650661606141987*^9, 
   3.6506616166633863`*^9}, {3.650662178193193*^9, 3.650662179169054*^9}},
 CellID->274296634],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.001880767422840142, 1.}}], 
     ArrowBox[{{-1.9943651268165778`, -1.9939290418172353`}, \
{-2.005634873183422, -2.0060709581827645`}}]}, 
    {Arrowheads[{{0.002181884181584564, 1.}}], 
     ArrowBox[{{-1.992980472118557, -1.7077235490486578`}, \
{-2.007019527881443, -1.720847879522771}}]}, 
    {Arrowheads[{{0.002532164920691602, 1.}}], 
     ArrowBox[{{-1.9912507228512462`, -1.4216567348482378`}, \
{-2.008749277148754, -1.43548612229462}}]}, 
    {Arrowheads[{{0.002927650629414116, 1.}}], 
     ArrowBox[{{-1.9891536018853633`, -1.1358858207878333`}, \
{-2.0108463981146367`, -1.1498284649264532`}}]}, 
    {Arrowheads[{{0.003349520958467606, 1.}}], 
     ArrowBox[{{-1.9867570202011025`, -0.8506443895245555}, \
{-2.0132429797988975`, -0.8636413247611596}}]}, 
    {Arrowheads[{{0.0037526890420342693`, 1.}}], 
     ArrowBox[{{-1.984318794766212, -0.5662090029109638}, \
{-2.015681205233788, -0.57664813994618}}]}, 
    {Arrowheads[{{0.004058553372820616, 1.}}], 
     ArrowBox[{{-1.9823748250166717`, -0.28274153369969757`}, \
{-2.017625174983328, -0.28868703772887466`}}]}, 
    {Arrowheads[{{0.004175239517375117, 1.}}], 
     ArrowBox[{{-1.9816119904014629`, -4.405799705336537*^-16}, \
{-2.018388009598537, -4.475984491664715*^-16}}]}, 
    {Arrowheads[{{0.004058553372820616, 1.}}], 
     ArrowBox[{{-1.9823748250166717`, 
      0.28274153369969673`}, {-2.017625174983328, 0.28868703772887383`}}]}, 
    {Arrowheads[{{0.0037526890420342693`, 1.}}], 
     ArrowBox[{{-1.984318794766212, 0.5662090029109629}, {-2.015681205233788, 
      0.5766481399461791}}]}, 
    {Arrowheads[{{0.003349520958467606, 1.}}], 
     ArrowBox[{{-1.9867570202011025`, 
      0.8506443895245546}, {-2.0132429797988975`, 0.8636413247611587}}]}, 
    {Arrowheads[{{0.002927650629414116, 1.}}], 
     ArrowBox[{{-1.9891536018853633`, 
      1.1358858207878324`}, {-2.0108463981146367`, 1.1498284649264523`}}]}, 
    {Arrowheads[{{0.002532164920691602, 1.}}], 
     ArrowBox[{{-1.9912507228512462`, 1.421656734848237}, {-2.008749277148754,
       1.4354861222946191`}}]}, 
    {Arrowheads[{{0.002181884181584564, 1.}}], 
     ArrowBox[{{-1.992980472118557, 1.7077235490486569`}, {-2.007019527881443,
       1.7208478795227702`}}]}, 
    {Arrowheads[{{0.001880767422840142, 1.}}], 
     ArrowBox[{{-1.9943651268165778`, 
      1.9939290418172344`}, {-2.005634873183422, 2.0060709581827636`}}]}, 
    {Arrowheads[{{0.0021403718392650085`, 1.}}], 
     ArrowBox[{{-1.7084543696228307`, -1.9925938483408991`}, \
{-1.7201170589485983`, -2.007406151659101}}]}, 
    {Arrowheads[{{0.002538129293067883, 1.}}], 
     ArrowBox[{{-1.7067904330074304`, -1.7059929374388743`}, \
{-1.7217809955639984`, -1.7225784911325543`}}]}, 
    {Arrowheads[{{0.0030252752071000364`, 1.}}], 
     ArrowBox[{{-1.7045812534404114`, -1.4194424088234372`}, \
{-1.7239901751310172`, -1.4377004483194207`}}]}, 
    {Arrowheads[{{0.0036125235031166584`, 1.}}], 
     ArrowBox[{{-1.7016879641340739`, -1.1331402710450489`}, \
{-1.7268834644373547`, -1.1525740146692374`}}]}, 
    {Arrowheads[{{0.004293706453292537, 1.}}], 
     ArrowBox[{{-1.6980394840399602`, -0.8474661600400661}, \
{-1.7305319445314689`, -0.8668195542456489}}]}, 
    {Arrowheads[{{0.005016386590780677, 1.}}], 
     ArrowBox[{{-1.693844160544599, -0.5630488203721596}, {-1.73472726802683, \
-0.579808322484984}}]}, 
    {Arrowheads[{{0.005631699745768355, 1.}}], 
     ArrowBox[{{-1.690016613298682, -0.2805988904416559}, \
{-1.7385548152727468`, -0.29082968098691636`}}]}, 
    {Arrowheads[{{0.005887482444701832, 1.}}], 
     ArrowBox[{{-1.6883568823578983`, -4.3875298669545934`*^-16}, \
{-1.7402145462135306`, -4.494254330046659*^-16}}]}, 
    {Arrowheads[{{0.005631699745768354, 1.}}], 
     ArrowBox[{{-1.690016613298682, 
      0.28059889044165504`}, {-1.7385548152727468`, 0.2908296809869154}}]}, 
    {Arrowheads[{{0.005016386590780677, 1.}}], 
     ArrowBox[{{-1.6938441605445989`, 
      0.5630488203721588}, {-1.7347272680268297`, 0.5798083224849832}}]}, 
    {Arrowheads[{{0.004293706453292537, 1.}}], 
     ArrowBox[{{-1.69803948403996, 0.8474661600400653}, {-1.7305319445314686`,
       0.866819554245648}}]}, 
    {Arrowheads[{{0.0036125235031166584`, 1.}}], 
     ArrowBox[{{-1.7016879641340739`, 
      1.133140271045048}, {-1.7268834644373547`, 1.1525740146692365`}}]}, 
    {Arrowheads[{{0.0030252752071000364`, 1.}}], 
     ArrowBox[{{-1.7045812534404114`, 
      1.4194424088234363`}, {-1.7239901751310172`, 1.4377004483194198`}}]}, 
    {Arrowheads[{{0.002538129293067883, 1.}}], 
     ArrowBox[{{-1.7067904330074304`, 
      1.7059929374388734`}, {-1.7217809955639984`, 1.7225784911325535`}}]}, 
    {Arrowheads[{{0.0021403718392650085`, 1.}}], 
     ArrowBox[{{-1.7084543696228307`, 
      1.9925938483408983`}, {-1.7201170589485983`, 2.0074061516591}}]}, 
    {Arrowheads[{{0.0024169717183109333`, 1.}}], 
     ArrowBox[{{-1.4227770095294583`, -1.9910708401831276`}, \
{-1.4343658476133994`, -2.0089291598168724`}}]}, 
    {Arrowheads[{{0.0029329540166056767`, 1.}}], 
     ArrowBox[{{-1.4208790383630154`, -1.7039091225124792`}, \
{-1.4362638187798424`, -1.7246623060589494`}}]}, 
    {Arrowheads[{{0.0035995159695871247`, 1.}}], 
     ArrowBox[{{-1.418197893655124, -1.416584304312016}, \
{-1.4389449634877338`, -1.4405585528308418`}}]}, 
    {Arrowheads[{{0.004462510991202184, 1.}}], 
     ArrowBox[{{-1.4143850877942532`, -1.1292558615264512`}, \
{-1.4427577693486044`, -1.1564584241878355`}}]}, 
    {Arrowheads[{{0.005568452933907629, 1.}}], 
     ArrowBox[{{-1.4089952808861774`, -0.8423715495890788}, \
{-1.4481475762566802`, -0.8719141646966363}}]}, 
    {Arrowheads[{{0.006924949252397214, 1.}}], 
     ArrowBox[{{-1.4016813065498368`, -0.5570395761786257}, \
{-1.4554615505930206`, -0.585817566678518}}]}, 
    {Arrowheads[{{0.008344773279125717, 1.}}], 
     ArrowBox[{{-1.3932424912080585`, -0.27559034615979444`}, \
{-1.463900365934799, -0.2958382252687778}}]}, 
    {Arrowheads[{{0.009070048199052282, 1.}}], 
     ArrowBox[{{-1.3886263828682262`, -4.213519254952592*^-16}, \
{-1.4685164742746315`, -4.66826494204866*^-16}}]}, 
    {Arrowheads[{{0.008344773279125717, 1.}}], 
     ArrowBox[{{-1.3932424912080585`, 
      0.2755903461597936}, {-1.463900365934799, 0.29583822526877696`}}]}, 
    {Arrowheads[{{0.006924949252397214, 1.}}], 
     ArrowBox[{{-1.4016813065498368`, 
      0.5570395761786248}, {-1.4554615505930206`, 0.5858175666785171}}]}, 
    {Arrowheads[{{0.005568452933907648, 1.}}], 
     ArrowBox[{{-1.4089952808861774`, 
      0.8423715495890779}, {-1.4481475762566804`, 0.8719141646966354}}]}, 
    {Arrowheads[{{0.004462510991202184, 1.}}], 
     ArrowBox[{{-1.4143850877942532`, 
      1.1292558615264503`}, {-1.4427577693486044`, 1.1564584241878346`}}]}, 
    {Arrowheads[{{0.0035995159695871247`, 1.}}], 
     ArrowBox[{{-1.418197893655124, 
      1.4165843043120152`}, {-1.4389449634877338`, 1.4405585528308409`}}]}, 
    {Arrowheads[{{0.0029329540166056767`, 1.}}], 
     ArrowBox[{{-1.4208790383630154`, 
      1.7039091225124783`}, {-1.4362638187798424`, 1.7246623060589485`}}]}, 
    {Arrowheads[{{0.0024169717183109333`, 1.}}], 
     ArrowBox[{{-1.4227770095294583`, 
      1.9910708401831267`}, {-1.4343658476133994`, 2.0089291598168715`}}]}, 
    {Arrowheads[{{0.0026952276761843673`, 1.}}], 
     ArrowBox[{{-1.13743567334394, -1.9894404870618423`}, \
{-1.1482786123703463`, -2.0105595129381575`}}]}, 
    {Arrowheads[{{0.0033450975609575135`, 1.}}], 
     ArrowBox[{{-1.135434254378219, -1.7015604262213888`}, \
{-1.1502800313360677`, -1.72701100235004}}]}, 
    {Arrowheads[{{0.004227686744131671, 1.}}], 
     ArrowBox[{{-1.132441992276255, -1.4131379765483523`}, \
{-1.1532722934380317`, -1.4440048805945054`}}]}, 
    {Arrowheads[{{0.005451296529682465, 1.}}], 
     ArrowBox[{{-1.127849846029578, -1.1241179447553897`}, \
{-1.1578644396847082`, -1.1615963409588967`}}]}, 
    {Arrowheads[{{0.007184741761303215, 1.}}], 
     ArrowBox[{{-1.1206055179845378`, -0.8346465473033962}, \
{-1.1651087677297485`, -0.8796391669823189}}]}, 
    {Arrowheads[{{0.00969391259101261, 1.}}], 
     ArrowBox[{{-1.1088465610616123`, -0.5456228175951829}, \
{-1.1768677246526742`, -0.5972343252619609}}]}, 
    {Arrowheads[{{0.013351598549787005`, 1.}}], 
     ArrowBox[{{-1.0894567816201628`, -0.26109744241741584`}, \
{-1.1962575040941235`, -0.31033112901115645`}}]}, 
    {Arrowheads[{{0.016904438381818536`, 1.}}], 
     ArrowBox[{{-1.068408964751621, -3.781900209878704*^-16}, \
{-1.2173053209626654`, -5.099883987122549*^-16}}]}, 
    {Arrowheads[{{0.013351598549787026`, 1.}}], 
     ArrowBox[{{-1.0894567816201628`, 
      0.26109744241741495`}, {-1.1962575040941237`, 0.3103311290111555}}]}, 
    {Arrowheads[{{0.00969391259101261, 1.}}], 
     ArrowBox[{{-1.1088465610616123`, 
      0.5456228175951819}, {-1.1768677246526742`, 0.5972343252619599}}]}, 
    {Arrowheads[{{0.007184741761303215, 1.}}], 
     ArrowBox[{{-1.1206055179845378`, 
      0.8346465473033953}, {-1.1651087677297485`, 0.879639166982318}}]}, 
    {Arrowheads[{{0.005451296529682465, 1.}}], 
     ArrowBox[{{-1.127849846029578, 
      1.1241179447553888`}, {-1.1578644396847082`, 1.1615963409588959`}}]}, 
    {Arrowheads[{{0.004227686744131671, 1.}}], 
     ArrowBox[{{-1.132441992276255, 
      1.4131379765483514`}, {-1.1532722934380317`, 1.4440048805945045`}}]}, 
    {Arrowheads[{{0.0033450975609575135`, 1.}}], 
     ArrowBox[{{-1.135434254378219, 1.701560426221388}, {-1.1502800313360677`,
       1.7270110023500391`}}]}, 
    {Arrowheads[{{0.0026952276761843673`, 1.}}], 
     ArrowBox[{{-1.13743567334394, 
      1.9894404870618414`}, {-1.1482786123703463`, 2.0105595129381566`}}]}, 
    {Arrowheads[{{0.0029529428105732306`, 1.}}], 
     ArrowBox[{{-0.8525111621694166, -1.9878478037212541`}, \
{-0.8617745521162986, -2.0121521962787456`}}]}, 
    {Arrowheads[{{0.0037388914442127523`, 1.}}], 
     ArrowBox[{{-0.8506299980988723, -1.6991621597328843`}, \
{-0.8636557161868428, -1.7294092688385443`}}]}, 
    {Arrowheads[{{0.004851254389419558, 1.}}], 
     ArrowBox[{{-0.8476877836911462, -1.4094122473162356`}, \
{-0.8665979305945689, -1.4477306098266223`}}]}, 
    {Arrowheads[{{0.006480302005259709, 1.}}], 
     ArrowBox[{{-0.842905431038949, -1.11812240897812}, {-0.871380283246766, \
-1.1675918767361664`}}]}, 
    {Arrowheads[{{0.00897099449688626, 1.}}], 
     ArrowBox[{{-0.834770029795106, -0.8245790361252827}, \
{-0.879515684490609, -0.8897066781604325}}]}, 
    {Arrowheads[{{0.013024690015806051`, 1.}}], 
     ArrowBox[{{-0.8200673767425397, -0.527659246240209}, \
{-0.8942183375431754, -0.6151978966169347}}]}, 
    {Arrowheads[{{0.02046933016250423, 1.}}], 
     ArrowBox[{{-0.7905954800870337, -0.2249019449491006}, \
{-0.9236902341986813, -0.3465266264794717}}]}, 
    {Arrowheads[{{0.0003240082765921462, 1.}}], 
     ArrowBox[{{-0.8585698093632483, 
      2.395554851797089*^-12}, {-0.8557159049224667, \
-2.396443030216789*^-12}}]}, 
    {Arrowheads[{{0.02046933016250426, 1.}}], 
     ArrowBox[{{-0.7905954800870336, 
      0.22490194494909968`}, {-0.9236902341986816, 0.3465266264794708}}]}, 
    {Arrowheads[{{0.013024690015806068`, 1.}}], 
     ArrowBox[{{-0.8200673767425397, 
      0.5276592462402081}, {-0.8942183375431755, 0.6151978966169339}}]}, 
    {Arrowheads[{{0.008970994496886266, 1.}}], 
     ArrowBox[{{-0.834770029795106, 0.8245790361252817}, {-0.8795156844906091,
       0.8897066781604315}}]}, 
    {Arrowheads[{{0.006480302005259715, 1.}}], 
     ArrowBox[{{-0.842905431038949, 
      1.1181224089781192`}, {-0.8713802832467661, 1.1675918767361655`}}]}, 
    {Arrowheads[{{0.004851254389419564, 1.}}], 
     ArrowBox[{{-0.8476877836911462, 
      1.4094122473162345`}, {-0.866597930594569, 1.4477306098266212`}}]}, 
    {Arrowheads[{{0.0037388914442127523`, 1.}}], 
     ArrowBox[{{-0.8506299980988723, 
      1.6991621597328834`}, {-0.8636557161868428, 1.7294092688385434`}}]}, 
    {Arrowheads[{{0.0029529428105732306`, 1.}}], 
     ArrowBox[{{-0.8525111621694166, 
      1.9878478037212532`}, {-0.8617745521162986, 2.0121521962787448`}}]}, 
    {Arrowheads[{{0.003163810685525903, 1.}}], 
     ArrowBox[{{-0.56802401349222, -1.9864887224583947`}, \
{-0.5748331293649236, -2.013511277541605}}]}, 
    {Arrowheads[{{0.004068615395705963, 1.}}], 
     ArrowBox[{{-0.5665437630609816, -1.6970459695837736`}, \
{-0.5763133797961622, -1.7315254589876554`}}]}, 
    {Arrowheads[{{0.005387049271177564, 1.}}], 
     ArrowBox[{{-0.5641573091931489, -1.4059882639038452`}, \
{-0.5786998336639948, -1.4511545932390122`}}]}, 
    {Arrowheads[{{0.007387597288200467, 1.}}], 
     ArrowBox[{{-0.560145824991951, -1.1123406917499385`}, \
{-0.5827113178651927, -1.173373593964348}}]}, 
    {Arrowheads[{{0.010572150061157982`, 1.}}], 
     ArrowBox[{{-0.5531092221809131, -0.8143378138798244}, \
{-0.5897479206762307, -0.8999479004058907}}]}, 
    {Arrowheads[{{0.015939946959106593`, 1.}}], 
     ArrowBox[{{-0.5403096499824611, -0.5085022431397382}, \
{-0.6025474928746826, -0.6343548997174054}}]}, 
    {Arrowheads[{{0.02557535051854146, 1.}}], 
     ArrowBox[{{-0.5169861513971119, -0.1871102432592061}, \
{-0.6258709914600318, -0.3843183281693662}}]}, 
    {Arrowheads[{{0.019929462774819263`, 1.}}], 
     ArrowBox[{{-0.4836580013158779, 
      9.028134492467216*^-13}, {-0.6591991415412658, \
-9.037016276664218*^-13}}]}, 
    {Arrowheads[{{0.025575350518541498`, 1.}}], 
     ArrowBox[{{-0.5169861513971118, 0.1871102432592051}, {-0.625870991460032,
       0.3843183281693654}}]}, 
    {Arrowheads[{{0.015939946959106607`, 1.}}], 
     ArrowBox[{{-0.5403096499824611, 
      0.5085022431397374}, {-0.6025474928746826, 0.6343548997174047}}]}, 
    {Arrowheads[{{0.010572150061158005`, 1.}}], 
     ArrowBox[{{-0.553109222180913, 0.8143378138798234}, {-0.5897479206762306,
       0.8999479004058899}}]}, 
    {Arrowheads[{{0.007387597288200467, 1.}}], 
     ArrowBox[{{-0.560145824991951, 
      1.1123406917499377`}, {-0.5827113178651927, 1.173373593964347}}]}, 
    {Arrowheads[{{0.0053870492711775905`, 1.}}], 
     ArrowBox[{{-0.5641573091931488, 
      1.4059882639038443`}, {-0.5786998336639948, 1.4511545932390115`}}]}, 
    {Arrowheads[{{0.004068615395705963, 1.}}], 
     ArrowBox[{{-0.5665437630609816, 
      1.6970459695837727`}, {-0.5763133797961622, 1.7315254589876545`}}]}, 
    {Arrowheads[{{0.003163810685525906, 1.}}], 
     ArrowBox[{{-0.56802401349222, 1.9864887224583938`}, {-0.5748331293649237,
       2.013511277541604}}]}, 
    {Arrowheads[{{0.003302592672164705, 1.}}], 
     ArrowBox[{{-0.2839059566419866, -1.9855680311641726`}, \
{-0.28752261478658564`, -2.0144319688358276`}}]}, 
    {Arrowheads[{{0.004288790865682509, 1.}}], 
     ArrowBox[{{-0.28308742720020946`, -1.6955811744630231`}, \
{-0.2883411442283629, -1.7329902541084057`}}]}, 
    {Arrowheads[{{0.005749910883923254, 1.}}], 
     ArrowBox[{{-0.28174597664243467`, -1.4035613357244023`}, \
{-0.28968259478613756`, -1.4535815214184553`}}]}, 
    {Arrowheads[{{0.008007157281231136, 1.}}], 
     ArrowBox[{{-0.27945780233385015`, -1.1081525788374014`}, \
{-0.29197076909472214`, -1.177561706876885}}]}, 
    {Arrowheads[{{0.011652514607818094`, 1.}}], 
     ArrowBox[{{-0.27542804916359725`, -0.8068659239435638}, \
{-0.2960005222649751, -0.9074197903421511}}]}, 
    {Arrowheads[{{0.017777936864451435`, 1.}}], 
     ArrowBox[{{-0.2682981275089624, -0.4950950725629952}, \
{-0.30313044391960986`, -0.6477620702941486}}]}, 
    {Arrowheads[{{0.02823875574263374, 1.}}], 
     ArrowBox[{{-0.2564535340551818, -0.16484033393560155`}, \
{-0.31497503737339055`, -0.40658823749297074`}}]}, 
    {Arrowheads[{{0.01877540945769047, 1.}}], 
     ArrowBox[{{-0.203026236828046, 
      1.0725466032566942`*^-12}, {-0.3684023346005263, \
-1.0734347816763944`*^-12}}]}, 
    {Arrowheads[{{0.028238755742633764`, 1.}}], 
     ArrowBox[{{-0.25645353405518173`, 
      0.16484033393560052`}, {-0.31497503737339055`, 0.4065882374929699}}]}, 
    {Arrowheads[{{0.017777936864451446`, 1.}}], 
     ArrowBox[{{-0.26829812750896237`, 
      0.49509507256299423`}, {-0.3031304439196099, 0.6477620702941477}}]}, 
    {Arrowheads[{{0.011652514607818104`, 1.}}], 
     ArrowBox[{{-0.27542804916359725`, 
      0.8068659239435629}, {-0.29600052226497503`, 0.9074197903421504}}]}, 
    {Arrowheads[{{0.008007157281231136, 1.}}], 
     ArrowBox[{{-0.2794578023338501, 
      1.1081525788374005`}, {-0.29197076909472214`, 1.1775617068768842`}}]}, 
    {Arrowheads[{{0.0057499108839232545`, 1.}}], 
     ArrowBox[{{-0.28174597664243467`, 
      1.4035613357244014`}, {-0.2896825947861376, 1.4535815214184544`}}]}, 
    {Arrowheads[{{0.004288790865682509, 1.}}], 
     ArrowBox[{{-0.2830874272002094, 
      1.6955811744630223`}, {-0.2883411442283628, 1.7329902541084048`}}]}, 
    {Arrowheads[{{0.003302592672164705, 1.}}], 
     ArrowBox[{{-0.2839059566419866, 
      1.9855680311641717`}, {-0.28752261478658564`, 2.0144319688358268`}}]}, 
    {Arrowheads[{{0.0033567641843441527`, 1.}}], 
     ArrowBox[{{
      0.000861046047758646, -1.9852417024543567`}, {-0.0008610460477595341, \
-2.0147582975456433`}}]}, 
    {Arrowheads[{{0.004646775763964458, 1.}}], 
     ArrowBox[{{
      0.007003256371127799, -1.6950566297665304`}, {-0.007003256371128687, \
-1.7335147988048984`}}]}, 
    {Arrowheads[{{0.006210107662064079, 1.}}], 
     ArrowBox[{{
      0.00882106927957263, -1.402683314545083}, {-0.008821069279573518, \
-1.4544595425977747`}}]}, 
    {Arrowheads[{{0.008227061430702922, 1.}}], 
     ArrowBox[{{
      0.00046144674706761357`, -1.106627600866539}, \
{-0.00046144674706850175`, -1.1790866848477475`}}]}, 
    {Arrowheads[{{0.01205399154544864, 1.}}], 
     ArrowBox[{{
      0.0033669407714252723`, -0.8041632223040499}, {-0.0033669407714261605`, \
-0.9101224919816652}}]}, 
    {Arrowheads[{{0.018594741743842992`, 1.}}], 
     ArrowBox[{{
      0.01202745762537263, -0.4904242399714887}, {-0.012027457625373519`, \
-0.652432902885655}}]}, 
    {Arrowheads[{{0.029104340298872034`, 1.}}], 
     ArrowBox[{{
      0.0061745164313606596`, -0.15768579996969384`}, {-0.006174516431361548, \
-0.41374277145887844`}}]}, 
    {Arrowheads[{{0.04587368524026631, 1.}}], 
     ArrowBox[{{0.0016518143430915603`, 
      0.20202375612780799`}, {-0.0016518143430924485`, \
-0.20202375612780887`}}]}, 
    {Arrowheads[{{0.02915483522982471, 1.}}], 
     ArrowBox[{{0.009756174751008175, 
      0.15768579996969284`}, {-0.009756174751009063, 0.41374277145887767`}}]}, 
    {Arrowheads[{{0.018409027846664, 1.}}], 
     ArrowBox[{{0.003371928684478212, 
      0.49042423997148776`}, {-0.0033719286844791003`, 0.6524329028856541}}]}, 
    {Arrowheads[{{0.012032495715042267`, 1.}}], 
     ArrowBox[{{0.0011375251078734718`, 
      0.804163222304049}, {-0.00113752510787436, 0.9101224919816644}}]}, 
    {Arrowheads[{{0.00831203325372364, 1.}}], 
     ArrowBox[{{-0.005241268118762128, 1.106627600866538}, {
      0.00524126811876124, 1.1790866848477466`}}]}, 
    {Arrowheads[{{0.005990842651404195, 1.}}], 
     ArrowBox[{{-0.005091457421484672, 1.402683314545082}, {
      0.005091457421483783, 1.4544595425977738`}}]}, 
    {Arrowheads[{{0.004384658195100306, 1.}}], 
     ArrowBox[{{-0.001769203465852629, 1.6950566297665295`}, {
      0.0017692034658517409`, 1.7335147988048976`}}]}, 
    {Arrowheads[{{0.003399055547532024, 1.}}], 
     ArrowBox[{{0.002506594467577022, 
      1.9852417024543558`}, {-0.00250659446757791, 2.0147582975456424`}}]}, 
    {Arrowheads[{{0.003302592672164705, 1.}}], 
     ArrowBox[{{0.2839059566419857, -1.9855680311641726`}, {
      0.28752261478658475`, -2.0144319688358276`}}]}, 
    {Arrowheads[{{0.004288790865682509, 1.}}], 
     ArrowBox[{{0.2830874272002086, -1.6955811744630231`}, {
      0.288341144228362, -1.7329902541084057`}}]}, 
    {Arrowheads[{{0.005749910883923254, 1.}}], 
     ArrowBox[{{0.28174597664243384`, -1.4035613357244023`}, {
      0.2896825947861367, -1.4535815214184553`}}]}, 
    {Arrowheads[{{0.008007157281231136, 1.}}], 
     ArrowBox[{{0.27945780233384926`, -1.1081525788374014`}, {
      0.29197076909472125`, -1.177561706876885}}]}, 
    {Arrowheads[{{0.011652514607818092`, 1.}}], 
     ArrowBox[{{0.27542804916359637`, -0.8068659239435638}, {
      0.2960005222649741, -0.9074197903421511}}]}, 
    {Arrowheads[{{0.017777936864451435`, 1.}}], 
     ArrowBox[{{0.26829812750896154`, -0.4950950725629952}, {
      0.3031304439196089, -0.6477620702941486}}]}, 
    {Arrowheads[{{0.028238755742633723`, 1.}}], 
     ArrowBox[{{0.256453534055181, -0.1648403339356016}, {
      0.31497503737338955`, -0.4065882374929707}}]}, 
    {Arrowheads[{{0.018775409433252475`, 1.}}], 
     ArrowBox[{{0.2030262369356715, 1.0725466029216467`*^-12}, {
      0.368402334492899, -1.0734347813413468`*^-12}}]}, 
    {Arrowheads[{{0.028238755742633778`, 1.}}], 
     ArrowBox[{{0.2564535340551809, 0.1648403339356005}, {0.3149750373733896, 
      0.40658823749297}}]}, 
    {Arrowheads[{{0.01777793686445146, 1.}}], 
     ArrowBox[{{0.26829812750896154`, 0.4950950725629942}, {
      0.30313044391960897`, 0.6477620702941478}}]}, 
    {Arrowheads[{{0.011652514607818116`, 1.}}], 
     ArrowBox[{{0.27542804916359637`, 0.8068659239435629}, {
      0.29600052226497414`, 0.9074197903421505}}]}, 
    {Arrowheads[{{0.008007157281231136, 1.}}], 
     ArrowBox[{{0.27945780233384926`, 1.1081525788374005`}, {
      0.29197076909472125`, 1.1775617068768842`}}]}, 
    {Arrowheads[{{0.005749910883923254, 1.}}], 
     ArrowBox[{{0.2817459766424338, 1.4035613357244014`}, {
      0.28968259478613667`, 1.4535815214184544`}}]}, 
    {Arrowheads[{{0.004288790865682509, 1.}}], 
     ArrowBox[{{0.2830874272002086, 1.6955811744630223`}, {0.288341144228362, 
      1.7329902541084048`}}]}, 
    {Arrowheads[{{0.003302592672164705, 1.}}], 
     ArrowBox[{{0.2839059566419857, 1.9855680311641717`}, {
      0.28752261478658475`, 2.0144319688358268`}}]}, 
    {Arrowheads[{{0.003163810685525903, 1.}}], 
     ArrowBox[{{0.5680240134922191, -1.9864887224583947`}, {
      0.5748331293649227, -2.013511277541605}}]}, 
    {Arrowheads[{{0.0040686153957059604`, 1.}}], 
     ArrowBox[{{0.5665437630609808, -1.6970459695837736`}, {
      0.5763133797961612, -1.7315254589876554`}}]}, 
    {Arrowheads[{{0.005387049271177567, 1.}}], 
     ArrowBox[{{0.564157309193148, -1.4059882639038452`}, {
      0.578699833663994, -1.4511545932390122`}}]}, 
    {Arrowheads[{{0.007387597288200467, 1.}}], 
     ArrowBox[{{0.5601458249919501, -1.1123406917499385`}, {
      0.5827113178651918, -1.173373593964348}}]}, 
    {Arrowheads[{{0.010572150061157987`, 1.}}], 
     ArrowBox[{{0.5531092221809122, -0.8143378138798244}, {
      0.5897479206762297, -0.8999479004058908}}]}, 
    {Arrowheads[{{0.01593994695910659, 1.}}], 
     ArrowBox[{{0.5403096499824603, -0.5085022431397382}, {
      0.6025474928746817, -0.6343548997174054}}]}, 
    {Arrowheads[{{0.025575350518541477`, 1.}}], 
     ArrowBox[{{0.516986151397111, -0.187110243259206}, {
      0.6258709914600308, -0.3843183281693663}}]}, 
    {Arrowheads[{{0.019929462802760572`, 1.}}], 
     ArrowBox[{{0.48365800119282176`, 9.028134480189919*^-13}, {
      0.6591991416643201, -9.037016264386921*^-13}}]}, 
    {Arrowheads[{{0.025575350518541505`, 1.}}], 
     ArrowBox[{{0.516986151397111, 0.187110243259205}, {0.6258709914600309, 
      0.3843183281693655}}]}, 
    {Arrowheads[{{0.015939946959106614`, 1.}}], 
     ArrowBox[{{0.5403096499824602, 0.5085022431397372}, {0.6025474928746816, 
      0.6343548997174047}}]}, 
    {Arrowheads[{{0.010572150061158005`, 1.}}], 
     ArrowBox[{{0.5531092221809122, 0.8143378138798234}, {0.5897479206762298, 
      0.8999479004058899}}]}, 
    {Arrowheads[{{0.007387597288200467, 1.}}], 
     ArrowBox[{{0.5601458249919501, 1.1123406917499377`}, {0.5827113178651918,
       1.173373593964347}}]}, 
    {Arrowheads[{{0.0053870492711775905`, 1.}}], 
     ArrowBox[{{0.564157309193148, 1.4059882639038443`}, {0.578699833663994, 
      1.4511545932390115`}}]}, 
    {Arrowheads[{{0.004068615395705963, 1.}}], 
     ArrowBox[{{0.5665437630609808, 1.6970459695837727`}, {0.5763133797961613,
       1.7315254589876545`}}]}, 
    {Arrowheads[{{0.003163810685525906, 1.}}], 
     ArrowBox[{{0.5680240134922191, 1.9864887224583938`}, {0.5748331293649228,
       2.013511277541604}}]}, 
    {Arrowheads[{{0.0029529428105732306`, 1.}}], 
     ArrowBox[{{0.8525111621694157, -1.9878478037212541`}, {
      0.8617745521162977, -2.0121521962787456`}}]}, 
    {Arrowheads[{{0.0037388914442127523`, 1.}}], 
     ArrowBox[{{0.8506299980988714, -1.6991621597328843`}, {
      0.8636557161868419, -1.7294092688385443`}}]}, 
    {Arrowheads[{{0.004851254389419558, 1.}}], 
     ArrowBox[{{0.8476877836911453, -1.4094122473162354`}, {
      0.866597930594568, -1.447730609826622}}]}, 
    {Arrowheads[{{0.006480302005259709, 1.}}], 
     ArrowBox[{{0.8429054310389481, -1.11812240897812}, {
      0.8713802832467651, -1.1675918767361664`}}]}, 
    {Arrowheads[{{0.00897099449688626, 1.}}], 
     ArrowBox[{{0.8347700297951051, -0.8245790361252826}, {
      0.8795156844906081, -0.8897066781604324}}]}, 
    {Arrowheads[{{0.013024690015806053`, 1.}}], 
     ArrowBox[{{0.8200673767425388, -0.527659246240209}, {
      0.8942183375431744, -0.6151978966169348}}]}, 
    {Arrowheads[{{0.020469330162504264`, 1.}}], 
     ArrowBox[{{0.7905954800870328, -0.22490194494910037`}, {
      0.9236902341986805, -0.3465266264794719}}]}, 
    {Arrowheads[{{0.00032400700353637775`, 1.}}], 
     ArrowBox[{{0.8585698037566322, 2.3955547762150865`*^-12}, {
      0.8557159105290811, -2.3964429546347866`*^-12}}]}, 
    {Arrowheads[{{0.020469330162504296`, 1.}}], 
     ArrowBox[{{0.7905954800870327, 0.22490194494909946`}, {
      0.9236902341986807, 0.346526626479471}}]}, 
    {Arrowheads[{{0.01302469001580606, 1.}}], 
     ArrowBox[{{0.8200673767425388, 0.527659246240208}, {0.8942183375431745, 
      0.6151978966169338}}]}, 
    {Arrowheads[{{0.008970994496886278, 1.}}], 
     ArrowBox[{{0.8347700297951051, 0.8245790361252817}, {0.8795156844906082, 
      0.8897066781604316}}]}, 
    {Arrowheads[{{0.006480302005259715, 1.}}], 
     ArrowBox[{{0.8429054310389481, 1.1181224089781192`}, {0.8713802832467652,
       1.1675918767361655`}}]}, 
    {Arrowheads[{{0.004851254389419564, 1.}}], 
     ArrowBox[{{0.8476877836911453, 1.4094122473162345`}, {0.8665979305945681,
       1.4477306098266212`}}]}, 
    {Arrowheads[{{0.0037388914442127523`, 1.}}], 
     ArrowBox[{{0.8506299980988714, 1.6991621597328834`}, {0.8636557161868419,
       1.7294092688385434`}}]}, 
    {Arrowheads[{{0.0029529428105732306`, 1.}}], 
     ArrowBox[{{0.8525111621694157, 1.9878478037212532`}, {0.8617745521162977,
       2.0121521962787448`}}]}, 
    {Arrowheads[{{0.0026952276761843673`, 1.}}], 
     ArrowBox[{{1.137435673343939, -1.9894404870618423`}, {
      1.1482786123703455`, -2.0105595129381575`}}]}, 
    {Arrowheads[{{0.0033450975609575135`, 1.}}], 
     ArrowBox[{{1.135434254378218, -1.7015604262213888`}, {
      1.1502800313360668`, -1.72701100235004}}]}, 
    {Arrowheads[{{0.004227686744131671, 1.}}], 
     ArrowBox[{{1.132441992276254, -1.4131379765483523`}, {
      1.1532722934380308`, -1.4440048805945054`}}]}, 
    {Arrowheads[{{0.005451296529682465, 1.}}], 
     ArrowBox[{{1.1278498460295774`, -1.1241179447553897`}, {
      1.1578644396847075`, -1.1615963409588967`}}]}, 
    {Arrowheads[{{0.007184741761303215, 1.}}], 
     ArrowBox[{{1.120605517984537, -0.8346465473033962}, {
      1.1651087677297476`, -0.8796391669823189}}]}, 
    {Arrowheads[{{0.009693912591012618, 1.}}], 
     ArrowBox[{{1.1088465610616114`, -0.5456228175951828}, {
      1.1768677246526733`, -0.5972343252619609}}]}, 
    {Arrowheads[{{0.013351598549787036`, 1.}}], 
     ArrowBox[{{1.089456781620162, -0.2610974424174157}, {
      1.1962575040941228`, -0.3103311290111565}}]}, 
    {Arrowheads[{{0.016904438381818588`, 1.}}], 
     ArrowBox[{{1.06840896475162, -3.7819002098787004`*^-16}, {
      1.2173053209626647`, -5.099883987122552*^-16}}]}, 
    {Arrowheads[{{0.013351598549787059`, 1.}}], 
     ArrowBox[{{1.0894567816201617`, 0.2610974424174149}, {
      1.1962575040941228`, 0.31033112901115567`}}]}, 
    {Arrowheads[{{0.009693912591012618, 1.}}], 
     ArrowBox[{{1.1088465610616114`, 0.5456228175951819}, {
      1.1768677246526733`, 0.59723432526196}}]}, 
    {Arrowheads[{{0.007184741761303215, 1.}}], 
     ArrowBox[{{1.120605517984537, 0.8346465473033953}, {1.1651087677297476`, 
      0.879639166982318}}]}, 
    {Arrowheads[{{0.005451296529682465, 1.}}], 
     ArrowBox[{{1.1278498460295772`, 1.1241179447553888`}, {
      1.1578644396847073`, 1.1615963409588959`}}]}, 
    {Arrowheads[{{0.004227686744131671, 1.}}], 
     ArrowBox[{{1.132441992276254, 1.4131379765483514`}, {1.1532722934380308`,
       1.4440048805945045`}}]}, 
    {Arrowheads[{{0.0033450975609575135`, 1.}}], 
     ArrowBox[{{1.135434254378218, 1.701560426221388}, {1.1502800313360668`, 
      1.7270110023500391`}}]}, 
    {Arrowheads[{{0.0026952276761844345`, 1.}}], 
     ArrowBox[{{1.137435673343939, 1.9894404870618412`}, {1.1482786123703455`,
       2.010559512938157}}]}, 
    {Arrowheads[{{0.0024169717183109333`, 1.}}], 
     ArrowBox[{{1.4227770095294574`, -1.9910708401831276`}, {
      1.4343658476133985`, -2.0089291598168724`}}]}, 
    {Arrowheads[{{0.0029329540166056767`, 1.}}], 
     ArrowBox[{{1.4208790383630145`, -1.7039091225124792`}, {
      1.4362638187798416`, -1.7246623060589494`}}]}, 
    {Arrowheads[{{0.0035995159695871247`, 1.}}], 
     ArrowBox[{{1.4181978936551232`, -1.4165843043120159`}, {
      1.438944963487733, -1.4405585528308416`}}]}, 
    {Arrowheads[{{0.004462510991202184, 1.}}], 
     ArrowBox[{{1.4143850877942523`, -1.1292558615264512`}, {
      1.4427577693486036`, -1.1564584241878355`}}]}, 
    {Arrowheads[{{0.005568452933907636, 1.}}], 
     ArrowBox[{{1.4089952808861765`, -0.8423715495890788}, {
      1.4481475762566793`, -0.8719141646966364}}]}, 
    {Arrowheads[{{0.00692494925239722, 1.}}], 
     ArrowBox[{{1.401681306549836, -0.5570395761786257}, {
      1.4554615505930197`, -0.5858175666785181}}]}, 
    {Arrowheads[{{0.008344773279125719, 1.}}], 
     ArrowBox[{{1.3932424912080577`, -0.27559034615979444`}, {
      1.4639003659347982`, -0.29583822526877784`}}]}, 
    {Arrowheads[{{0.009070048199052307, 1.}}], 
     ArrowBox[{{1.3886263828682253`, -4.2135192549525914`*^-16}, {
      1.4685164742746308`, -4.66826494204866*^-16}}]}, 
    {Arrowheads[{{0.008344773279125715, 1.}}], 
     ArrowBox[{{1.3932424912080577`, 0.2755903461597936}, {
      1.4639003659347982`, 0.2958382252687769}}]}, 
    {Arrowheads[{{0.0069249492523972426`, 1.}}], 
     ArrowBox[{{1.401681306549836, 0.5570395761786248}, {1.45546155059302, 
      0.5858175666785173}}]}, 
    {Arrowheads[{{0.005568452933907656, 1.}}], 
     ArrowBox[{{1.4089952808861765`, 0.8423715495890779}, {
      1.4481475762566796`, 0.8719141646966355}}]}, 
    {Arrowheads[{{0.004462510991202184, 1.}}], 
     ArrowBox[{{1.4143850877942523`, 1.1292558615264503`}, {
      1.4427577693486036`, 1.1564584241878346`}}]}, 
    {Arrowheads[{{0.0035995159695871247`, 1.}}], 
     ArrowBox[{{1.4181978936551232`, 1.416584304312015}, {1.438944963487733, 
      1.4405585528308407`}}]}, 
    {Arrowheads[{{0.0029329540166056767`, 1.}}], 
     ArrowBox[{{1.4208790383630145`, 1.7039091225124783`}, {
      1.4362638187798416`, 1.7246623060589485`}}]}, 
    {Arrowheads[{{0.0024169717183109333`, 1.}}], 
     ArrowBox[{{1.4227770095294574`, 1.9910708401831267`}, {
      1.4343658476133985`, 2.0089291598168715`}}]}, 
    {Arrowheads[{{0.0021403718392650085`, 1.}}], 
     ArrowBox[{{1.7084543696228298`, -1.9925938483408991`}, {
      1.7201170589485975`, -2.007406151659101}}]}, 
    {Arrowheads[{{0.002538129293067902, 1.}}], 
     ArrowBox[{{1.7067904330074295`, -1.7059929374388743`}, {
      1.7217809955639976`, -1.7225784911325546`}}]}, 
    {Arrowheads[{{0.0030252752071000364`, 1.}}], 
     ArrowBox[{{1.7045812534404106`, -1.4194424088234372`}, {
      1.7239901751310163`, -1.4377004483194207`}}]}, 
    {Arrowheads[{{0.0036125235031166584`, 1.}}], 
     ArrowBox[{{1.701687964134073, -1.1331402710450489`}, {
      1.7268834644373539`, -1.1525740146692374`}}]}, 
    {Arrowheads[{{0.004293706453292537, 1.}}], 
     ArrowBox[{{1.698039484039959, -0.8474661600400661}, {
      1.7305319445314677`, -0.8668195542456489}}]}, 
    {Arrowheads[{{0.005016386590780677, 1.}}], 
     ArrowBox[{{1.693844160544598, -0.5630488203721596}, {
      1.7347272680268289`, -0.579808322484984}}]}, 
    {Arrowheads[{{0.005631699745768379, 1.}}], 
     ArrowBox[{{1.6900166132986811`, -0.2805988904416559}, {
      1.7385548152727461`, -0.29082968098691636`}}]}, 
    {Arrowheads[{{0.005887482444701832, 1.}}], 
     ArrowBox[{{1.6883568823578974`, -4.3875298669545934`*^-16}, {
      1.7402145462135297`, -4.494254330046659*^-16}}]}, 
    {Arrowheads[{{0.005631699745768379, 1.}}], 
     ArrowBox[{{1.6900166132986811`, 0.28059889044165504`}, {
      1.7385548152727461`, 0.2908296809869155}}]}, 
    {Arrowheads[{{0.005016386590780677, 1.}}], 
     ArrowBox[{{1.693844160544598, 0.5630488203721588}, {1.7347272680268289`, 
      0.5798083224849832}}]}, 
    {Arrowheads[{{0.004293706453292537, 1.}}], 
     ArrowBox[{{1.698039484039959, 0.8474661600400653}, {1.7305319445314677`, 
      0.866819554245648}}]}, 
    {Arrowheads[{{0.0036125235031166584`, 1.}}], 
     ArrowBox[{{1.701687964134073, 1.133140271045048}, {1.7268834644373539`, 
      1.1525740146692365`}}]}, 
    {Arrowheads[{{0.0030252752071000364`, 1.}}], 
     ArrowBox[{{1.7045812534404106`, 1.419442408823436}, {1.7239901751310163`,
       1.4377004483194196`}}]}, 
    {Arrowheads[{{0.002538129293067902, 1.}}], 
     ArrowBox[{{1.7067904330074295`, 1.7059929374388734`}, {
      1.7217809955639976`, 1.7225784911325537`}}]}, 
    {Arrowheads[{{0.0021403718392650085`, 1.}}], 
     ArrowBox[{{1.7084543696228298`, 1.9925938483408983`}, {
      1.7201170589485975`, 2.0074061516591}}]}, 
    {Arrowheads[{{0.001880767422840142, 1.}}], 
     ArrowBox[{{1.994365126816577, -1.9939290418172353`}, {
      2.0056348731834213`, -2.0060709581827645`}}]}, 
    {Arrowheads[{{0.0021818841815845814`, 1.}}], 
     ArrowBox[{{1.992980472118556, -1.7077235490486578`}, {
      2.0070195278814422`, -1.7208478795227713`}}]}, 
    {Arrowheads[{{0.002532164920691602, 1.}}], 
     ArrowBox[{{1.9912507228512453`, -1.4216567348482378`}, {
      2.008749277148753, -1.43548612229462}}]}, 
    {Arrowheads[{{0.002927650629414116, 1.}}], 
     ArrowBox[{{1.9891536018853624`, -1.1358858207878333`}, {
      2.010846398114636, -1.1498284649264532`}}]}, 
    {Arrowheads[{{0.0033495209584676116`, 1.}}], 
     ArrowBox[{{1.9867570202011016`, -0.8506443895245555}, {
      2.0132429797988967`, -0.8636413247611597}}]}, 
    {Arrowheads[{{0.0037526890420342693`, 1.}}], 
     ArrowBox[{{1.984318794766211, -0.5662090029109638}, {
      2.015681205233787, -0.57664813994618}}]}, 
    {Arrowheads[{{0.004058553372820616, 1.}}], 
     ArrowBox[{{1.9823748250166708`, -0.28274153369969757`}, {
      2.017625174983327, -0.28868703772887466`}}]}, 
    {Arrowheads[{{0.004175239517375117, 1.}}], 
     ArrowBox[{{1.981611990401462, -4.405799705336537*^-16}, {
      2.018388009598536, -4.475984491664715*^-16}}]}, 
    {Arrowheads[{{0.004058553372820616, 1.}}], 
     ArrowBox[{{1.9823748250166708`, 0.2827415336996967}, {2.017625174983327, 
      0.2886870377288738}}]}, 
    {Arrowheads[{{0.0037526890420342693`, 1.}}], 
     ArrowBox[{{1.984318794766211, 0.5662090029109629}, {2.015681205233787, 
      0.5766481399461791}}]}, 
    {Arrowheads[{{0.0033495209584676116`, 1.}}], 
     ArrowBox[{{1.9867570202011016`, 0.8506443895245546}, {
      2.0132429797988967`, 0.8636413247611588}}]}, 
    {Arrowheads[{{0.002927650629414116, 1.}}], 
     ArrowBox[{{1.9891536018853624`, 1.1358858207878324`}, {2.010846398114636,
       1.1498284649264523`}}]}, 
    {Arrowheads[{{0.002532164920691602, 1.}}], 
     ArrowBox[{{1.9912507228512453`, 1.421656734848237}, {2.008749277148753, 
      1.4354861222946191`}}]}, 
    {Arrowheads[{{0.0021818841815845814`, 1.}}], 
     ArrowBox[{{1.992980472118556, 1.7077235490486569`}, {2.0070195278814422`,
       1.7208478795227704`}}]}, 
    {Arrowheads[{{0.001880767422840142, 1.}}], 
     ArrowBox[{{1.994365126816577, 1.9939290418172344`}, {2.0056348731834213`,
       2.0060709581827636`}}]}}},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-2.2020305089104424`, 
   2.2020305089104424`}, {-2.2020305089104424`, 2.2020305089104424`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650660789674789*^9, 3.6506608589819098`*^9, 
  3.65066162396356*^9, 3.650662183530579*^9, 3.650663037718487*^9, 
  3.650751876872239*^9, 3.6508081444771023`*^9, 3.6508081844630632`*^9, 
  3.650928525036599*^9},
 CellID->308322049]
}, Open  ]],

Cell["A two dimensional field line plot:", "Text",
 CellChangeTimes->{{3.650749068427232*^9, 3.650749076530199*^9}},
 CellID->1516498751],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sqrtDiskStreamPlot", "=", "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"range", "=", "4"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"StreamPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ExSqrtDisk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
        RowBox[{"EzSqrtDisk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            SqrtBox[
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
          RowBox[{"ArcTan", "[", 
           RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "range"}], ",", "range"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "range"}], ",", "range"}], "}"}], ",", 
      RowBox[{"StreamPoints", "\[Rule]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", "=", "32"}], "}"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RotationMatrix", "[", " ", 
             RowBox[{"2", "\[Pi]", " ", 
              FractionBox["i", "n"]}], "]"}], ".", 
            RowBox[{"{", 
             RowBox[{"4", ",", "0"}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ",", 
      RowBox[{"Epilog", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"First", "@", 
         RowBox[{"Plot", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", 
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"ColorFunction", "\[Rule]", 
            RowBox[{"Function", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y"}], "}"}], ",", 
              RowBox[{"Blend", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"White", ",", 
                  RowBox[{"Darker", "@", "Blue"}]}], "}"}], ",", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   SuperscriptBox["x", "2"]}], ")"}], 
                 RowBox[{"1", "/", "2"}]]}], "]"}]}], "]"}]}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", " ", 
           RowBox[{"Axes", "\[Rule]", "False"}], ",", 
           RowBox[{"Frame", "\[Rule]", "False"}], ",", 
           RowBox[{"PlotStyle", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"AbsoluteThickness", "[", "6", "]"}], "}"}]}]}], "]"}]}],
         "}"}]}], ",", 
      RowBox[{"StreamStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<Line\>\"", ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Red", ",", "Thick"}], "]"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "False"}], ",", 
      RowBox[{"RegionFunction", "\[Rule]", 
       RowBox[{"Function", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "z", ",", "vx", ",", "vz", ",", "n"}], "}"}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}], "<", 
          SuperscriptBox["range", "2"]}]}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{
  3.650660779207404*^9, {3.650660809613495*^9, 3.6506608184941177`*^9}, {
   3.650660910432844*^9, 3.650660923478569*^9}, {3.650661606141987*^9, 
   3.6506616166633863`*^9}, {3.650662178193193*^9, 3.650662179169054*^9}, {
   3.6506723872506533`*^9, 3.650672391363111*^9}, {3.650672672709649*^9, 
   3.650672672908963*^9}, {3.650672865078529*^9, 3.6506728748201838`*^9}, {
   3.650735855789771*^9, 3.650735866113501*^9}, {3.650735929217368*^9, 
   3.6507359310079308`*^9}, {3.650749001311715*^9, 3.650749028901394*^9}, {
   3.650751308787128*^9, 3.650751331751278*^9}, {3.650751437004649*^9, 
   3.6507514383717537`*^9}, {3.650805979308152*^9, 3.650805979874177*^9}, {
   3.65080607457237*^9, 3.650806077562846*^9}, 3.6508063135240393`*^9, {
   3.6508064098614388`*^9, 3.65080641069937*^9}, {3.6508091156806*^9, 
   3.650809134019904*^9}, {3.6509285334994907`*^9, 3.650928575104718*^9}, 
   3.650928658002185*^9, 3.650972926340344*^9},
 CellID->1943859137],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJx1XXdUFcnTBSQLgjnnHNectceEOSfMiWAWdVdBxYAYMYBZFMWsiBFRV9Fu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    
    "], {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, 
      {RGBColor[1, 0, 0], Thickness[Large], 
       LineBox[{33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 
        48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 
        65}], LineBox[{89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 
        102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112}], 
       LineBox[{148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 
        160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 
        174, 175, 176, 177, 178, 179, 180, 181, 182, 183}], 
       LineBox[{212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 
        224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 
        238, 239}], 
       LineBox[{278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 289, 
        290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 301, 302, 303, 
        304, 305, 306, 307, 308, 309, 310, 311, 312, 313, 314, 315, 316}], 
       LineBox[{348, 349, 350, 351, 352, 353, 354, 355, 356, 357, 358, 359, 
        360, 361, 362, 363, 364, 365, 366, 367, 368, 369, 370, 371, 372, 373, 
        374, 375, 376, 377, 378}], 
       LineBox[{416, 417, 418, 419, 420, 421, 422, 423, 424, 425, 426, 427, 
        428, 429, 430, 431, 432, 433, 434, 435, 436, 437, 438, 439, 440, 441, 
        442, 443, 444, 445, 446, 447, 448, 449, 450, 451, 452, 453}], 
       LineBox[{485, 486, 487, 488, 489, 490, 491, 492, 493, 494, 495, 496, 
        497, 498, 499, 500, 501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 
        511, 512, 513, 514, 515, 516}], 
       LineBox[{554, 555, 556, 557, 558, 559, 560, 561, 562, 563, 564, 565, 
        566, 567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 577, 578, 579, 
        580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 590, 591}], 
       LineBox[{623, 624, 625, 626, 627, 628, 629, 630, 631, 632, 633, 634, 
        635, 636, 637, 638, 639, 640, 641, 642, 643, 644, 645, 646, 647, 648, 
        649, 650, 651, 652, 653, 654}], 
       LineBox[{693, 694, 695, 696, 697, 698, 699, 700, 701, 702, 703, 704, 
        705, 706, 707, 708, 709, 710, 711, 712, 713, 714, 715, 716, 717, 718, 
        719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 729, 730}], 
       LineBox[{762, 763, 764, 765, 766, 767, 768, 769, 770, 771, 772, 773, 
        774, 775, 776, 777, 778, 779, 780, 781, 782, 783, 784, 785, 786, 787, 
        788, 789, 790, 791, 792}], 
       LineBox[{831, 832, 833, 834, 835, 836, 837, 838, 839, 840, 841, 842, 
        843, 844, 845, 846, 847, 848, 849, 850, 851, 852, 853, 854, 855, 856, 
        857, 858, 859, 860, 861, 862, 863, 864, 865, 866, 867, 868, 869}], 
       LineBox[{900, 901, 902, 903, 904, 905, 906, 907, 908, 909, 910, 911, 
        912, 913, 914, 915, 916, 917, 918, 919, 920, 921, 922, 923, 924, 925, 
        926, 927, 928, 929}], 
       LineBox[{956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 
        968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 981, 
        982}], LineBox[{1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 
        1016, 1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026, 
        1027, 1028, 1029, 1030, 1031}], 
       LineBox[{1057, 1058, 1059, 1060, 1061, 1062, 1063, 1064, 1065, 1066, 
        1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075, 1076, 1077, 
        1078, 1079, 1080, 1081, 1082}], 
       LineBox[{1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121, 1122, 
        1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133, 
        1134, 1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142, 1143}], 
       LineBox[{1169, 1170, 1171, 1172, 1173, 1174, 1175, 1176, 1177, 1178, 
        1179, 1180, 1181, 1182, 1183, 1184, 1185, 1186, 1187, 1188, 1189, 
        1190, 1191, 1192, 1193}], 
       LineBox[{1223, 1224, 1225, 1226, 1227, 1228, 1229, 1230, 1231, 1232, 
        1233, 1234, 1235, 1236, 1237, 1238, 1239, 1240, 1241, 1242, 1243, 
        1244, 1245, 1246, 1247, 1248, 1249, 1250, 1251, 1252}], 
       LineBox[{1282, 1283, 1284, 1285, 1286, 1287, 1288, 1289, 1290, 1291, 
        1292, 1293, 1294, 1295, 1296, 1297, 1298, 1299, 1300, 1301, 1302, 
        1303, 1304, 1305, 1306, 1307, 1308, 1309, 1310, 1311}], 
       LineBox[{1344, 1345, 1346, 1347, 1348, 1349, 1350, 1351, 1352, 1353, 
        1354, 1355, 1356, 1357, 1358, 1359, 1360, 1361, 1362, 1363, 1364, 
        1365, 1366, 1367, 1368, 1369, 1370, 1371, 1372, 1373, 1374, 1375}], 
       LineBox[{1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416, 
        1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1425, 1426, 1427, 
        1428, 1429, 1430, 1431, 1432, 1433, 1434, 1435, 1436, 1437}], 
       LineBox[{1470, 1471, 1472, 1473, 1474, 1475, 1476, 1477, 1478, 1479, 
        1480, 1481, 1482, 1483, 1484, 1485, 1486, 1487, 1488, 1489, 1490, 
        1491, 1492, 1493, 1494, 1495, 1496, 1497, 1498, 1499, 1500, 1501, 
        1502}], LineBox[{1533, 1534, 1535, 1536, 1537, 1538, 1539, 1540, 1541,
         1542, 1543, 1544, 1545, 1546, 1547, 1548, 1549, 1550, 1551, 1552, 
        1553, 1554, 1555, 1556, 1557, 1558, 1559, 1560, 1561, 1562, 1563}], 
       LineBox[{1596, 1597, 1598, 1599, 1600, 1601, 1602, 1603, 1604, 1605, 
        1606, 1607, 1608, 1609, 1610, 1611, 1612, 1613, 1614, 1615, 1616, 
        1617, 1618, 1619, 1620, 1621, 1622, 1623, 1624, 1625, 1626, 1627, 
        1628}], LineBox[{1660, 1661, 1662, 1663, 1664, 1665, 1666, 1667, 1668,
         1669, 1670, 1671, 1672, 1673, 1674, 1675, 1676, 1677, 1678, 1679, 
        1680, 1681, 1682, 1683, 1684, 1685, 1686, 1687, 1688, 1689, 1690}], 
       LineBox[{1723, 1724, 1725, 1726, 1727, 1728, 1729, 1730, 1731, 1732, 
        1733, 1734, 1735, 1736, 1737, 1738, 1739, 1740, 1741, 1742, 1743, 
        1744, 1745, 1746, 1747, 1748, 1749, 1750, 1751, 1752, 1753, 1754}], 
       LineBox[{1785, 1786, 1787, 1788, 1789, 1790, 1791, 1792, 1793, 1794, 
        1795, 1796, 1797, 1798, 1799, 1800, 1801, 1802, 1803, 1804, 1805, 
        1806, 1807, 1808, 1809, 1810, 1811, 1812, 1813, 1814}], 
       LineBox[{1845, 1846, 1847, 1848, 1849, 1850, 1851, 1852, 1853, 1854, 
        1855, 1856, 1857, 1858, 1859, 1860, 1861, 1862, 1863, 1864, 1865, 
        1866, 1867, 1868, 1869, 1870, 1871, 1872, 1873, 1874}], 
       LineBox[{1902, 1903, 1904, 1905, 1906, 1907, 1908, 1909, 1910, 1911, 
        1912, 1913, 1914, 1915, 1916, 1917, 1918, 1919, 1920, 1921, 1922, 
        1923, 1924, 1925, 1926, 1927, 1928}], 
       LineBox[{1952, 1953, 1954, 1955, 1956, 1957, 1958, 1959, 1960, 1961, 
        1962, 1963, 1964, 1965, 1966, 1967, 1968, 1969, 1970, 1971, 1972, 
        1973, 1974, 1975}]}}}]},
  AspectRatio->1,
  DisplayFunction->Identity,
  Epilog->{
    GraphicsComplexBox[CompressedData["
1:eJxF03lI02EYB/BpmqVRUKlJimc2LUcYHvNg4VGu1JlZqavpZnlSmV0qlDMP
DCwZmujmspozjzkTLHNsTScy0UXpbM7UNeeB2y81c0VaYAX2vC+8vHx4vu/3
v8eZcS32sikOh4v6e/+9BJKNYWNjWYrbPKJt9Ktpb5fABe9UWC99Eazn29n6
2X8Be36O2L5rygBu2MMzjt/Xg/uogw+lpAWwfb29U830PPhUKDVP+WAO7Pgr
lelBngV7CbnMnEUdWHvzGUHVNA3OqGPx6jK14Ph7Ca4CFw0Yj3lQ455MgLOi
Y0p0M2pw4g1KsK+vClwpXYiRvlaCSabqcwSTYXCmWpbNX1WAg2oL94ly5eD0
qZWJBFsZmKI93DbgJgL7SjljhmIhmPj1YoompQp8qGjZsudWJem/2+VLzQXx
7WAJedA/QNYNxlqeZ0THy8DcNgLH+EoOFtNLrY90KcD5e2s/UnYPgxUfRsNG
2Erw9SE/9wobFbjhfZh16oAaXC7oarKInACbVI6S+8w1YNvmVnlDhBasesF0
NS+bBlNbPUtzdDpwEMcisP/ALHimovuHW/EcuNO1AHOenAdreXe8zRwWwCP4
cOZqrh7syA53GpAYwNUtCWvE3xhYKQ0Zf3N2EZzVS7NyqFkCb+4D2MgLFBxN
QvsRyRTl74xEc9YKfqi2Hc0nn+7os/6G+iRJ6d4WjSifXFP/STGG8m4dPml2
/Shvls1SWeah/G0K6dEWJbIcS2TMY+h/BPEkkSNE//E/+U3lDJRnj51JLhEj
x8o9xYV65PzH/u6r31Ff4t04lws81BcQ9JIVdR7lBftp5OMdyJesfPghGuRj
RU7KHiNyXObBsrV11M+oH68Wc1F/KM1nq/A0yncGz0gaW5GveInseGpkMp9/
wnkZ2Y/OoSWvI/8BvPBPPg==
     "], {{{}, {}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[6]], 
        LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 
         12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 
         29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 
         46, 47, 48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 55, 74, 68, 
         63, 59, 75, 69, 64, 76, 70, 77, 50}, VertexColors -> Automatic]}}}, 
     VertexColors -> CompressedData["
1:eJx11H8w1HkYB/CNi9opu+gHqu0qJXuEWD+a9Kizd+ooIcXhKqQfGyoO19VV
qFUTofNjj8LQsEw2xHaHcHIk2ShhEsd89/d3N9XUqrXd9sc999f98cxr5v3H
85l5nmc+qw7GBUQbUCgUP30Z6qt4ZpeoclYN/zo+G8d2/6SG5eztpi4rJWhD
+3HBISoJQcd36AQBU+gJ69hPm7oUYKexrjl7dwI1qTzgwZTIQaitc2Z5jKE9
T4u5zi5y4J0y/W5T+AjqnWvflJElAw7VrHOn5xBqtndfrxtVBoIBgu64bRA9
qREZzLsihXnNUwOP+SI0+KaoL2m5FETTyS7Zc/rQdYuocavaJFBkGNNe/rAb
9fU6Fe1+SAIWvIWUrK0P0OePquW9VhKITyf3F37ZgTJ6zbsXDIuh5M7BnCGb
VtT0pOU3ujwxSBf43gum30MvnxN+e3u/GCa4zdwtNg1oQ3od289ODPSZWy26
gVp0tN9nhvaJAMGDrBAGUYkygri+y0YJuPbQJ9M+pgx1TystPt1EQNu7CH5l
Bg/NCehqtywi4Nzd1b8YhGejHsaBd8pSCaAYBmqXZKWht2P9e1rj9fnWCk/2
0UR0yMJ2Q1GkPtcFvpyzOvw/TSr2OIbqc/80ZqfWFu2YbFON79HnlJKWvGob
dM+bNbmDn/MwBqvvjwiUlu5clvC5Tyu3L68nAT0rcKY5fX53vZMR1zodZSnr
qBdPELD/flPeC2E2qpNll+anETCh2Ux/ZslDC8rOXVXz9HN4TfgYXy1DFyY6
/MwWEuCVHlM+p7gS7Rrg1POG9X1cxtN/TaxFrXav7F4xS4Bj007XN5p69H1R
QdIPTP0eLUYOfzwlRIMb61OYoWKwGExf5i1vQX/MXXv++HV9rhu/MdTfjl7g
50zufqK/nyn2/LWKTrTyTPyxAnP9fS52COHwu9Gl+bHGGZES6HyUUOqQ+Qil
m67UpDZKwKvxyFhKiQilbt/8odVKCkYUk2wjt0G0hv+846sMKTAV+4S25DN0
o03U9hdaKcRXM1xWfz2C5iyfG+F4RQYTIbpCv5EXqH8Uv9DNWg5W4us3vU5P
oPPLnFhtg3Kw+81Tq3adQqNeHqn60KwAul/Y0pwbYnRuXI/xxXEl/N+/9P30
moQxgQztqWhcd5MgQXtWXc8JkqFBzArx4y4S+KmhyZaXFGjmUPdA+AUVxPq5
JSaPStB+y5YnAz4k3P+4nufKVqDyQCE3hqMCpXnY0rhnSrTcKKGuf1oFh8/Y
J6e5StA+W9p6OzMSXANJg7VuctTsRHn1ATMVJETmx1XdUqJPei/95D6pgi3k
7/QzHSR6f0Ya+tRLDaxr9wadZGK0edRzOlqjBPtt3uOF7TKUtoSzw1lBwraC
ErsGsQJt3zhhsrlMBa5GytGQUhJtqdl5o5ulhi+06oLgoyq0RreL+1eyGg6H
Rbdk/SlG+xhJ10cVSojwcReZXZahDzvMXgmGSVi4bMvlubkKtLZ+0Ya9F1UQ
IqKFeFuSKONV7QrOPDVYS7JgMkCFNr13WPwuXg1tHsaE1d8qVNGy1zeiRA1U
VtVzrUCMGsa4F1cRStBqHDKN4mRo1SxttKafhCiP1/sSjynQVea3VtikqCCK
qWESY0o0KXJWWPpWBeXTTm+5r0nU7WP07mF/NaTQ8+1SRSp0MHRj1BBPDf8A
TlOcKA==
      "]]},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-4.174050091548382, 4.174050091548382}, {-4.174050091548382, 
   4.174050091548382}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6509286448476143`*^9, 3.650928730152315*^9},
 CellID->1356066043]
}, Open  ]],

Cell[TextData[{
 "Now take an approach of trying to plot this in 3-dimensions.  Note that \
there is no 3-dimensional  stream plotting routine in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " so we need to take another approach. However the stream lines in the \
following will only be artificially distributed over the spherical 3-D region \
and therefore the representation of field line density will not be physical."
}], "Text",
 CellChangeTimes->{{3.6508094689080143`*^9, 3.650809521016828*^9}, {
  3.650928601089933*^9, 3.650928652012967*^9}, {3.65097316336415*^9, 
  3.650973165529736*^9}},
 CellID->1389638980],

Cell["\<\
Start with fewer stream lines so that the resulting 3-D version is not too \
crowded\
\>", "Text",
 CellChangeTimes->{{3.650809527944416*^9, 3.650809548671693*^9}},
 CellID->1366025182],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sqrtStreamPlot", "=", "\[IndentingNewLine]", 
  RowBox[{"StreamPlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ExSqrtDisk", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
      RowBox[{"EzSqrtDisk", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", 
      RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
    RowBox[{"StreamPoints", "\[Rule]", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"n", "=", "12"}], "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"RotationMatrix", "[", " ", 
           RowBox[{"2", "\[Pi]", " ", 
            FractionBox["i", "n"]}], "]"}], ".", 
          RowBox[{"{", 
           RowBox[{"2", ",", "0"}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ",", 
    RowBox[{"StreamStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Line\>\"", ",", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", "Thick"}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.650660779207404*^9, {3.650660809613495*^9, 3.6506608184941177`*^9}, {
   3.650660910432844*^9, 3.650660923478569*^9}, {3.650661606141987*^9, 
   3.6506616166633863`*^9}, {3.650662178193193*^9, 3.650662179169054*^9}, {
   3.6506723872506533`*^9, 3.650672391363111*^9}, {3.650672672709649*^9, 
   3.650672672908963*^9}, {3.650672865078529*^9, 3.6506728748201838`*^9}, {
   3.650735855789771*^9, 3.650735866113501*^9}, {3.650735929217368*^9, 
   3.6507359310079308`*^9}, {3.650749001311715*^9, 3.650749049212633*^9}, {
   3.65075206415805*^9, 3.6507520642038097`*^9}, {3.650752224399819*^9, 
   3.650752266668524*^9}, {3.650752359802537*^9, 3.6507523601769047`*^9}, 
   3.65075239883963*^9, 3.650752447733348*^9, {3.6508109741053057`*^9, 
   3.650810978580113*^9}, 3.6509287455555687`*^9, 3.650972930546611*^9},
 CellID->1193845310],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJzVWnlcTdv7blCRhHSlXEMhmSmilLWFiEyZCxVFuJkK6aJ0G68hU/caUskY
rjJmOLW2OaGuUmggJSU0p06Dfmedtc72Pa/P79Mf7v3j9k/elnPOPut9nv2s
/Tyv/pI1dq5KCgoKP7dSUCC/Q1zzJ85r24b/f35z4Pd3f08etbk9+fsvO/wd
Djqq8Zc6RQwgf99gEHaW1Cum5HUi6+8cIie+uqzCh0a0rpsrWXe4uuUmqe/G
+PUm6/cslHz1Wrfic3WKtMjrP5tcziX15HePhpP1jnYzMxwWKvGxGWbdyboB
Vq8gdaejGd3I+h+BbonhcQq8165VI8n6HR2VMUcl9dqijdL1S5kPE261+Yrd
zO8bkvUS+x5bRZL618dfFcj6eo+12mMu1ePcW9O6kHWXpXwcqcfjK8pk3cZX
MYC3r8Uvxt0m35fzrw53uC2pO4zIViPr4fd/VxunXI0brZMbyPfrkLchntR/
Wu+Url88NW3m/XPluH9MDPk+XICexpAHkjqWe8aR9eDPgW93nynBFW9edSTr
o8aWbt4jqQdXvtIg67OfLp65X1yAjdX0pfs37vKKA2GS2jEySHp97ydeyRwS
loVT0iLGktf3Tc0YOFxSr2jrUC/5/7zVkJA+61cn4yzdBHOyvnTGpdTNktp6
9V4L8vrnPZzG3168FK14O7kzWdd3Fft8WbgUnT20CJF1J0f1Q65tHqPcoUFK
ZP2sj/OApZL65tOyVmS9aZvC6pj8LLRTcaolWR/nvmw4qcu5VY3k8xPzOprM
6PkOvbsYTj6Pm5Qu/nO6pH5QeUGRvP63Dh2H2aaWoL8vH60l3883QH/rZEk9
9k/1tmR9Se3Z/F64HF23TDIirw99MmMcqQeYzP5K3j+q3zGPY52r0e1g76Fk
XT1gWlaUpP6UOoHUvPGEsfY9Vteior9MB0nxe/GDS3dJ/WZl/jCyPjF3z4Pw
+/Vo44Qa6fUNWiZeSmqfVfbS/ft1335bvW5f0a+a5lJ8pLu/StSV1J1nnSH7
xVcFD9KxvanAtQ9qaCLXv+W06MMUSV0bki/9/gYfxj1TX6bE1ZQe7Elef+is
815SD9q2RJ28/twZ9/RHHVtxfVI9+krxl6C1htRqBeusyPrg59MSgxNUOIdc
Q2n/jjSWO5B6VspSA7LeaGnpNHGFGvei9/xm8vkahxw5Uu/e/7wn4eG56J79
yP8bctPuKKknf9QkuOGC72uvIzz02tSF4Ip/GWkZIeWlzzPpPvZymupPeHjN
JFrKw4hdI6S87HTqog5Zfx105znh4XQdNymPDjgbfiL1Ej0/ggsud0S1mPCy
oOo82XfePanTcMLLaR3rh5D1P/NVrAkPZ6POqmTdZfGDCFKPWrCD4J5rYxU4
kfDQp07bWMqDMx16IEldmc9LcR5+c/MDwsuUGxnS14/smupKePlHkbn0PqCB
CtKsJDy86O0i5dGkSR+iCC/T9YzNyPpse0UPwssgz9ljyPqr4eekvFwXbWQq
xbnBlZWhEh56FgwcSNY3/r7kIuGl4dO/xGSfx8f+4UB4mX5ElVwP/3l7cTvC
y6AjS6U4EuusGT1MwsMBtQ80yTofoepuLKljrXqNJus/mYxM8JDw8KnCkAlk
PS7AfgXhpa2otfTzb90+GOEq4WW4Rjfp+zsFnxpksmgpMnFcS74v52hhX+Mi
4eEtvSZy3+HjA5tnO0lq01/e9yDrO1YeOUZ4+Op6HMEdr3j41rUzkjqzYrm0
//GO2rGEl5d7WI0g66dnFmdMk9RJbdWk97H2dSvDpkh4ePLjEun+5Hl29SO8
bBxe1pq8/nTRhTTCw1/8P5Ga/7CxS5GBpJ6/xkd6n0rfV+VPeHlFN0aXrPes
GZNKeNm/uav0+w+cn1xOeDiz+07pfdrF9YwJqS3iz2qT9dLe0+4THjb9FC3l
oavzgV6kbni5UPr9064VXCG8XJamMUr6+dknupPaeJwd0RXuQqCrAuFleLWN
ubR/qm/TCS8nf10u7U/oha7NhIczxTvGSe/DL68eIbV99pnBZL2y/8cYwsOa
zIvS17taNP5C6g2V+lJ8jxybHEZ4mGWwRqqPZec1bUhtslisR9bbmRaEER72
0D4ovU+Upd01JLVbXLD09Qr0R/Zb4V7CFO+QnGaUu+2ThzPXV5S8zKXjrevN
aM+033O2LhkpCvQ2TbBPEaPPz5+UWP28XTTwmM8kt7/rkJ9CuH65lr9o113n
rZxHFSqJddgw03e/6GRe4poRx78i77UKDsEvF4pKG5c+672xCRlpLXA5qLdK
dP3PjsFK/RvR+srw47XXPEVddgUUToyvR/mLo15vKN0icu53xD3rXCWa+7du
isOlvSLTSh1VpfsVqDgy9PjZ14Giy0UNz4Ou1KIZZherxCFBoog5X7sM9vyC
bEzON6Sf2CFy6vVr/+3ONWha3dSbj9xDRR91cid06VONnjeebz+i0z7Rzh2d
b46cXIG4Dz4dtPUDRGPVJ40cKcHPbrHSvfULQ0RqtjUzsjuWo4iBp3VtBuwX
BXbYUj7ldBnSnBiVtc50QYJjac3Tj0FlqN1fBpFlASsT1aatQxrhCpzp6/A5
7oMXWESeE2v0GaTI1ds2zvvQz83CbIqCc/QQZY6ba3stycDXIuhA8gBf9VZc
iMoUi8R5/hbw/bR/29Mj44Yit8XoWuXCc+ssrKaNF122VOKOzojTLcjeaAGv
B16v+6L2AY6lrbh2q27cz78QbLFm4fUwH6zCzQ0zDOkVvdPiXnlB8idfVS7/
yYGTs/X3WBzbHLf38gg1Lu/BQLeUv/da7E5StQ16o8ZNyey+Q99lvwVFSWvO
z/uwcVncfgu4X3A/Yb9gPyFeYH9g/2B/Yf8hHiFeIb4g/iA+IX4hHyBfIJ9a
wkNL/W0JL/92f8/azi/2vtaA6N/LUcFZm+HDjjSglMn7tXWyy5DvTUWbWJ8G
pHdBa1/21TJkNmaA4bhkMdLi01wKnT+jqDZezyZp1iJxL6/2qWEf0MTIZdO9
uS8ofI/puuPri5FT1KG2Z2aVoL6tcbc+nunIU0lXNS6zDindu2XvpvUJjbe7
Ot0kpRaNXuEU+iS6BCWllj8THy9CIp2pw/y7PUanA7w2rjYuRAfPRXQ9/VaE
ROe9Qu841aDeS3TelA8rQiV6/bRm/VKNPPoXif1TClFs/t+zf1pYhQqtyx7V
mL1DRY1JzyuNKlGG9uZ5r1zz0eeB9y0O2lag4K3x0TVt36LWmyxCu84rRw/F
h4qONb5Gcau0dqf9VIbKM64q9LPNQb62B/7Sm/4ZBYavVhk94BXatmbx27Eh
71D9xeFfw8yuIpPNMUldsguQeYFK7oBrMShr9UyfEUYFaNJ75UsfvXehjCf9
Kn3L8pFLcbsXXZ1cUapyK1+ld/lII/r05ZNuRmi0eob/vOONKK7kJ5NhkeXI
vmfrEF2/JpSy2vOo8fAK1M7GcXlno2akVXk5yWNqJTrtMtrZ3E6Bi/AxTrW0
qUI1zcFreykochcUi1WsB1d/9/7w8+H1eZa4GunHK3LDt6LJ1t1r0DN+kN9g
JyXuj36TP/ZuqEHjt5xbsrJJiftl67EZbx9+QRqdz16o2qPMzS57/dY7qBZ5
HfDsovZzKy5IL2Ds2dF16GXTHLu3ka24sYc7axm9r0O7IxcfeuGhwp06XLL8
ZK0YeRrMGOM6SpXDyVouJ6rrUUr08dePy1S57p/bHh6e14DeWqTpTA1X4+bd
szvqmtCIZHi1XKmjrm7Z9N1+w35AvEA8QTzC/sL+Q3xA/EB8QfxBfEL8Qr5A
PkF+QP5APkK+Qj5Dvv/T+Puv4Um2D7J92dRhfOnawjIU9OC6omp4Awq83aF9
fHIZ6n3/yayl2xuQZtZvF9T6laL6ObE1rm/EqGe5Z8D7uZ9QYKfcGQdbS/ry
+NDOias+ol171tXEdqlFJ5vG/MyvKUEXgu9ez+78BSVp56ywnvQcrTK855o5
BKOIW3FFM3ano5qtwX3NDa8gh85LllWnpKGkooervF2jUEqU9RcTpw/ohMvH
Y+KmanTxQnXTU7NipOmuHL0puQrNXZF4q6bmPbpiNPr4Vo9K9FBL97rW7kK0
tPudUJPycsSLffJGub5Da9+5dhLPLkN7jqXFW3ctQGvPpYdtWvcJDQkZUzu4
Uz4K07XyD9AqQb6BVxY1l+ahfQ9cy/Y6FaGZ0fY5WDkPvZn2wqbJoBDVf9gw
d6yShAdl4ttmf+Qjc1XTqESnHGQe1m/1oXV5KHS9ycrHh7KQXQ/bh7OUclDE
4Pxu0UavUP3jfdkVL1+gVaK1KR8Ov0B/X7GeiLulo+KSiksaczPRliWJj9ar
pKAXDbz6/cbnSHPG4t69r91DnerfmUxwT0Nn7i23+cl/KzKsuGx+cnYa6qVf
v++L6RSkn5Vgmv675HzicVgj9lEjWjrKMvdOO8n55M8empZPmlCdp9HI4UWV
KP2SuXPBNQXus6VfW8erVehkg5r3PR9FDr7fO7vFWxfvqkAdKjTuvnr4FRUW
3ulgp1qJesYnv95/tfm764H98htkqlccWo0sQiO+VMxS4pyLcvKV7GvQquOZ
K/11lLm8E9cG95HgYJF72rg2T5W5BZHKD+89+IIsDa6UttvUirs4yaf7HPda
9LLPmgBNHRXuqVbhaZu2dUic/UU/6IIKp2i+9tIir3oBxxA/L2MN7bx21KF2
/onnrPupcpP7+yV0VxOj37zUl++NVOV6+9V+sNgmRotuZM1a3lGNc40PfJFW
LkYHrYesT9qmxkF8wn7AfsF+wn5DPEC8QDxBvEE8QrxCPEO8Qz5AvkA+Qb5B
/kJ+Q/7D+wO8f8D7C7z/tITnlvDZEt7/bXz+KP4gvhXkf4R6aG8/3aMFzUhW
t5n7PrDdw2/1DLyjcuLneqFu7H2gfEGcWKj/EB96nXbSV6gnT93iu1D1q1Cf
ELfJDurUKNRDq1Q3/NZ3rlDfVtwVfu/ct+vxtfj9ecOcOmF9yo7MQ56vvgh1
Tt+/YkWDa4Q61sgq4IlEP2V159D5MdqZFUJtWNIx4uuwcqHWvKuV1/PYZ6Ee
GSOOmelTItTmTqftNpQVffu8TVmXO7QuFGo7/9a6H4/mC3XdmvKnJ+6+Eeo1
+6YqnzXKFuqt2ruz9lZlCLWX4+83dvk8E+ov16IHn6lKEupBpc7FViP5b/vn
MiSh+WCMUD9X9Wt/xFZR2K/8LpNK1H9rJdRwf2F/PFNssj8Wf3v9sK7x84dt
URLqZSuL1barKQu1h1mjW/mObzW8nuy5dl1iglSE9b6mG38ZvUlVqCcpJOzR
mqMm1PTnGx7h94X7AfcL7ifcb9gP2C/YT9hviAeIF4gniDeIR4hXiGeId8gv
yD/IJ8g3yF/Ib/bDyf4B+Qfx9aN4gfj8MbyUY3C+xOB8iWX60J7qB5bphwHV
FyzTFxWqP3g305+zVJ9wHNOnVKrf+CjT7+P0fIANttHzgSM9r+DOxfS8kkH1
DscwvbtB9RBrMz10onqJRUwv06me4tVMTx9TvcX+TG8PUz3GvkyPR1K9xtFM
r4OpnuMopucLqN7jT0zvVUuk5wH8hZ0HJtHzAp7AzguH6XkCu7DzxBl63sAa
T+h5YyM9j+ACdh4pp+cVvJudV97Q8wzuz84zOvQ8hx3YeU6Pngfxgm7V/3u+
xKHyeoytmB6Lqd7iTKa3pVRv8Rmmt/D9mH5jbXn9xr2YfsPrgf0KpPqNrZh+
L6P6jdcz/X5P9Ru7Mv1eQvUbT2T6fYvqN85n+v2S6jdWyaH63Wwm1V8swy/E
TyHVd9yV6bs91Xd8gOn7SKrveB3Td2+q7/gC03eIT9gP2C/YT9hviAeIF4gn
iDeIR4hXiGeId8gHyBfIJ8g3yF/Ib8h/eH+A9w94f4H3n5bw3BI+W8L7v43P
H8UfxDfbF1YL/icG/icG/ifuJO9/4gZ5/xMfZX6OI/WbsJG8/4lbyfuf2FLe
/8SJzK86Rf0sfEDe/8R95P1P7Cnvf+L38v4nzmT+1CfqX2Hgf+Jkef8TV8r7
nziE+WNbqN+GK5jfNpT6cdiY+XEZ1F/EboXUX0yi/iM+lUP9R15F6k/iK4+H
Xfof/xMD/wkD/wl3lPef+KPy/hP/F/Of4PvDz4fXx/wq3pj5VanUr+L3Mb/K
ivpVvBvzq9pQv4qfxvwqT+pX8b7Mr0qnfhVvxvyqQOpX8YeZX7WK+lX8ReZX
3aN+Fd+e+VUZ1K/ireX9Kn4086vgfsN+QLxAPEE8wv7C/kN8QPxAfEH8QXxC
/EK+QD5BfkD+QD5CvkI+Q77/0/j7r+GJHVR52YmV5V04Rz4fxrI8LIjmbfgT
y9sG0TwOy/K4PTTvw8Us7ztF8zXsxfK1Mpq/YUOWv92g+Rxey/I5XZrf4dcs
v3OleSKW5Ymjad6IW0XRvPESzQfxTJYPRtL8EE9m+aEzzRexLF/8TPNHnM7y
xz00z8SLWZ45nuad+BjLO9Vp3opHsbx18rOhFVNOl+Frtg7Na0wXJHTWOthG
NaQMX1kcY9zQf4ksH+ZHy+eB/FeWB5rTvI+3YnlfMM37+J0s74Pvx/JD3pfl
h+NofshHsfwQXg+83tU0P+Q15fNDHuSHPMgPeZAf8iA/5GX5IdwvuJ+wX7Cf
EC+wP7B/sL+w/xCPEK8QXxB/EJ8Qv5APkC+QTy3hoaX+toSXf7u/4H6Jwf0U
g/stNpe/H+Nj7H5eT+/neJL8/R4vYnrUjeoR3sDu78r0/o4nsPu/Bb3/48dM
z+5QPcMXmd4pnpfqHU6Q1xf8UV5/cJy8PuFipl8sv8Ol8vqGZfr3gOoflukj
ywfxdqafLD/EQE/wAnk9wTI9YXkaPsP0JJLqCa5lehJL9eS77we/P9y/jfL6
g1n+xu+n+oNZ/savoPqD2zL9mU71B29k+rOd6g/OYPpjTvUHBzP9OUL1B7vL
6w9+wPRHk+oPzmT6M57qj+zczY+i+vPd/sH9hfsP+wP7B/sL+w/xAfEI8Qrx
B/EJ8Q75APkC+fRP4+W/1n/wfIrB8ysGz7cYPP9i8HyMZc/PLJ/BMez5OpY+
X+MnzH9wof4DjmL+RjbNz7Ds+ZjlLziNPa+fos/rOJ49z3ekz/N4IXvev06f
93Eq8wNWUD9AglvqF2ymfgEOY37CJuon4OHMbwinfgMOYH7EYepH4LnMr3hP
/QqsxPyMSupn4PHM77Cifgc+yPyQxdQPwaeYX6JK/RLsyfyUXOqn4Ermt4RT
vwXnMD9Gi/oxWOYPsPwJs3wJs3yJZ/kSZvkSD/dT5iewvArL/ASWV33XD/j5
vsxPMKd+Au/I/IQV1E/gXzM/wZ76Cfxc5ieYUT+BP8/8hDTqJ/BJzE+oonkV
r2Qu5wfwcD8ymN/QhvoNPMuz8HbqN/Asz8L21G/glzO/4RD1G3i437AfsF+w
n7DfEA8QLxBPEG8QjxCvEM8Q75APkF+Qf5CfkL+Q35D/8P4A+Qnx2RLeWsLv
v423H8UTxKt83vDt3MnyEyyrWb4i1CyfEWqW3wh1XYM0fxNqltcINctzhJpT
VSP5nVDfofmMcD0sLxLWbWmeJNS5NG8S6ks0jxLqLjSvEur+NM8Sam2adwm1
Jc3DhNqK5mVCXUjzNKG2p3mbUGuuleZxQh1K8zqh3k3zPKEOoXmfUHeNl+aB
Qm1H80KhtnCV5pFCnUHzK2G/Cmj+JNRwf2F/NtK8S/j/xjTvEmo3mncJtSfN
u4QaXs8bmncJ6wNp3iXU02neJdT05xse4feF+wH3C+4n3G/YD9gv2E/Yb4gH
iBeIJ4g3iEeIV4hniHfIL8g/yCfIN8hfyG/2w8v+AfkH8fWjeIH4/DG8CPMv
GMzHYDA/I9MP2XwN1pefv8HK8vM5+JT8/A5OZvNNXuy8Ecnmp5S2yZ3/EMtH
cKr8PBC+zOaF2jM9nM/mia4yvXzE5o1cmJ7ekZ9Hwvvk55XwUDbPtJ/ptR+b
d9rP9HwWm4fKY3rfyOalPrHzwBg2T2XBzgv72LzVLHaekM1jVdN5LLyazWs9
Y+eREjbP5cvOO6/YvJe2/PkPjWX6Ws/mizKYfpax+aLTTD/hfhayeSUtpsfv
2bySAdNj2A/4+cFsXonlSbwbm1fyYHpcwuaVljM9dmXzSjZMjxPZvFIh0+Mc
Nq/UmuZJvIL8vBEP96OYzTN1Y3rN8ibE8iZ+BJtnWs302ovNM51jeg33G/YD
9gv2E/Yb4gHiBeIJ4g3iEeIV4hniHfIB8gvyD/IT8hfyG/If3h8gPyE+W8Jb
S/j9t/H2o3iCeAXz3BjMe2MwD45l8+Iyv0I2by7zO2Tz6DI/xJnNy7O8CHvI
z59j2Xy6zB95wubtnzB/KpHN40cw/0o2/24o78+hDfL+HCpm/s0HNl//Ut6f
QzuY/9OGzec/Zf7QJTa/X8P8I382379L3p+TzbtjMO+Owby7zG/hgN/CyfwW
+P3g94f758Xm402ZP5MuPx+PreXn47Gm/Hw89mbz8YHMn8li8/Ec82f2sPn4
E8yf2cDm40XMn0ll8/FdmT8jm4+fJe/PcGbMn4H7B/cX7j/sD+wf7C/sP8QH
xCPEK8QfxCfEO+QD5Avk0z+Nl/9a//8PeQpuAg==
    
    "], {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, 
      {RGBColor[1, 0, 0], Thickness[Large], 
       LineBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165, 
        166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 
        180, 181, 182, 183, 184, 185, 186}], 
       LineBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238, 
        239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 
        253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 
        266}], LineBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322,
         323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336,
         337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350,
         351, 352, 353, 354, 355, 356}], 
       LineBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406, 
        407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420, 
        421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
       LineBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489, 
        490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 
        504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 
        518, 519, 520, 521, 522}], 
       LineBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574, 
        575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 
        589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601, 
        602}], LineBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646,
         647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 660,
         661, 662, 663, 664, 665, 666, 667, 668}], 
       LineBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715, 
        716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 729, 
        730, 731, 732, 733, 734, 735, 736, 737, 738}], 
       LineBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792, 
        793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 
        807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820, 
        821, 822}], 
       LineBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872, 
        873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 886, 
        887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
       LineBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952, 
        953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 
        967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 
        981, 982}], 
       LineBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 
        1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
        1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
        1050, 1051, 1052}]}}}]},
  AspectRatio->1,
  DisplayFunction->Identity,
  Frame->True,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-3.130537568661286, 3.130537568661286}, {-3.130537568661286, 
   3.130537568661286}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.05], 
     Scaled[0.05]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6507491090075483`*^9, 3.650751958511614*^9, 
  3.650752089916502*^9, 3.650752385217863*^9, 3.650752473906156*^9, 
  3.650807919612281*^9, 3.650808042761189*^9, 3.650808210259221*^9, 
  3.650811032058681*^9, 3.6509287726570168`*^9},
 CellID->1114243051]
}, Open  ]],

Cell["\<\
Extract the lines from the result in 2-D and then adjust the lines so that \
they are comprised of 3 dimensional points.\
\>", "Text",
 CellChangeTimes->{{3.65080955207157*^9, 3.650809586854369*^9}},
 CellID->2122027608],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphicsComplex", "=", 
   RowBox[{"Cases", "[", 
    RowBox[{"sqrtStreamPlot", ",", "_GraphicsComplex", ",", "\[Infinity]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.650749121708294*^9, 3.6507491824951057`*^9}},
 CellID->768198854],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphicsComplex", "=", 
   RowBox[{"First", "[", "graphicsComplex", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.650749200431837*^9, 3.650749204541976*^9}},
 CellID->174626081],

Cell[BoxData[
 RowBox[{
  RowBox[{"graphicsComplex3D", "=", 
   RowBox[{"graphicsComplex", "/.", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x_", "?", "NumberQ"}], ",", 
       RowBox[{"z_", "?", "NumberQ"}]}], "}"}], "\[RuleDelayed]", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "z"}], "}"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.650749231510235*^9, 3.650749234820866*^9}, {
  3.650749285628489*^9, 3.650749360607522*^9}},
 CellID->1819804432],

Cell["Test that this is indeed a 3-dimensional set of lines:", "Text",
 CellChangeTimes->{{3.6508095906057577`*^9, 3.650809606621619*^9}},
 CellID->430491815],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graphics3D", "[", "graphicsComplex3D", "]"}]], "Input",
 CellChangeTimes->{{3.650749214313375*^9, 3.6507492259252787`*^9}, {
  3.650749330137291*^9, 3.650749330696022*^9}},
 CellID->1304431384],

Cell[BoxData[
 Graphics3DBox[
  GraphicsComplex3DBox[{{-3.130537568661286, 
     0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
    3.130537568661286, 0, -3.130537568661286}, {
    3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
     0, -2.921677317602578}, {
    3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
     0, -2.7128167720324985`}, {
    3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
     0, -2.5039567948038854`}, {
    3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
     0, -2.295097033065993}, {
    3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
     0, -2.086236465039131}, {
    3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
     0, -1.8773763097100695`}, {
    3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
     0, -1.6685162351998}, {
    3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
     0, -1.4596562572042038`}, {
    3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
     0, -1.2507963461506284`}, {
    3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
     0, -1.041936223608371}, {
    3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
     0, -0.8330759434533528}, {
    3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
     0, -0.6242157544387887}, {
    3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
     0, -0.41535564391335666`}, {
    3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
     0, -0.20649554093176375`}, {
    3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
     0.002364518618382031}, {
    3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0, 
     0.21122426960641416`}, {
    3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
     0.420084340499656}, {
    3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
     0.6289444920976377}, {
    3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
     0.8378048857052963}, {
    3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
     1.0466650823795693`}, {
    3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
     1.2555250660685502`}, {
    3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
     1.4643853688797432`}, {
    3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
     1.6732452160338924`}, {
    3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
     1.8821051589267472`}, {
    3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
     2.090965443684689}, {
    3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
     2.2998253201341337`}, {
    3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
     2.508685733589194}, {
    3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
     2.7175459735685967`}, {
    3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
     2.9264056700410475`}, {
    3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
     0, -3.130537339504675}, {-2.921677807891022, 0, 
     3.1305370558669994`}, {-2.712817080923461, 
     0, -3.130536974188484}, {-2.7128174173885604`, 0, 
     3.1305373968061487`}, {-2.5039568267930163`, 
     0, -3.130537425231945}, {-2.503957489201368, 0, 
     3.130537209614667}, {-2.295097028910262, 
     0, -3.130537036110503}, {-2.2950972031796457`, 0, 
     3.1305370666698744`}, {-2.0862369086887456`, 
     0, -3.130537373390767}, {-2.086237341741301, 0, 
     3.1305373905362677`}, {-1.877376817252445, 
     0, -3.130537078432022}, {-1.8773771478789962`, 0, 
     3.1305371265435973`}, {-1.6685164255069387`, 
     0, -3.130537406220412}, {-1.6685172284583318`, 0, 
     3.1305375229825296`}, {-1.4596565010976184`, 
     0, -3.1305370840047777`}, {-1.45965709466118, 0, 
     3.130537444577338}, {-1.250796149997714, 
     0, -3.1305371254123533`}, {-1.250796917495352, 0, 
     3.13053745922239}, {-1.0419363491434028`, 
     0, -3.130537497475021}, {-1.041937051969674, 0, 
     3.1305374365950276`}, {-0.8330761989646664, 
     0, -3.130537362213028}, {-0.8330768074559518, 0, 
     3.130536985985276}, {-0.6242157734718394, 
     0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
     3.130537483014851}, {-0.4153559761438142, 
     0, -3.130537143179841}, {-0.41535626074844956`, 0, 
     3.130537473691525}, {-0.20649573077243902`, 
     0, -3.130537548539087}, {-0.20649640697687976`, 0, 
     3.1305374356666444`}, {0.0023643479114740774`, 0, -3.130537518214238}, {
    0.0023637771202667385`, 0, 3.13053708105499}, {
    0.21122419338323348`, 0, -3.1305370031944597`}, {
    0.2112236418752695, 0, 3.1305372707552364`}, {
    0.42008438856070346`, 0, -3.1305372766429227`}, {
    0.4200841698169882, 0, 3.1305370584579846`}, {
    0.6289447230837969, 0, -3.130537429886283}, {
    0.6289438417320995, 0, 3.130536996033218}, {
    0.8378045957867942, 0, -3.1305374978960168`}, {
    0.8378040829808491, 0, 3.1305370996475386`}, {
    1.046665022832238, 0, -3.130537099569258}, {
    1.046664145199822, 0, 3.1305369771852547`}, {
    1.2555251305977222`, 0, -3.130537224267039}, {
    1.2555244536918693`, 0, 3.130537473480122}, {
    1.4643849759936627`, 0, -3.130537253225875}, {
    1.4643842714197826`, 0, 3.130537187061149}, {
    1.6732452113376968`, 0, -3.1305369930948914`}, {
    1.6732446088627395`, 0, 3.1305370804867585`}, {
    1.8821055475231572`, 0, -3.1305374506867336`}, {
    1.88210498781495, 0, 3.1305373036961095`}, {
    2.090965273950892, 0, -3.130537467367118}, {
    2.0909649422690633`, 0, 3.1305374831424944`}, {
    2.2998256616900288`, 0, -3.130537536343731}, {
    2.2998249211187307`, 0, 3.130537380722143}, {
    2.5086854243175987`, 0, -3.130537470390545}, {
    2.508684970328931, 0, 3.1305370638713677`}, {
    2.7175456716869593`, 0, -3.1305375653067644`}, {
    2.71754509998356, 0, 3.130537234053713}, {
    2.926406069752153, 0, -3.1305372014198976`}, {
    2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
    1.9913420464689446`, 0, -6.302328183019255*^-19}, {
    1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
    1.612879504311111, 0, -2.9681805755008195`*^-17}, {
    1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
    1.2156376741151889`, 0, -6.765852793648817*^-17}, {
    1.9148458828986261`, 0, -6.254942444948598*^-18}, {
    1.84134370606608, 0, -1.1754437621658815`*^-17}, {
    1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
    1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
    1.166956356190518, 0, -6.139780813753298*^-17}, {
    1.1105976331738368`, 0, -3.967276376016019*^-17}, {
    1.4815748519599594`, 0, -4.083360422996936*^-17}, {
    1.403364274626575, 0, -4.795445222401027*^-17}, {
    1.3363048228659054`, 0, -5.452038017442776*^-17}, {
    1.2590563515709572`, 0, -6.271035218943372*^-17}, {
    1.0806195515694723`, 0, -3.665334079520424*^-17}, {
    1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
    1.0043595468930577`, 0, -6.650612064757262*^-17}, {
    0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
    0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
    2.076195235867775, 0, 5.460336135267355*^-18}, {
    2.147043324822746, 0, 1.0479341696570644`*^-17}, {
    2.3982589319433854`, 0, 2.799128138239359*^-17}, {
    2.505127279395825, 0, 3.5289039943105043`*^-17}, {
    0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
    2.215738531682641, 0, 1.532575023947979*^-17}, {
    2.280127974352383, 0, 1.9826964745600654`*^-17}, {
    0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
    1.0043595468930577`, 0, -6.650612064757262*^-17}, {
    2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
    2.7185050675284894`, 0, 4.967095265032991*^-17}, {
    2.8129516459285657`, 0, 5.59628657917814*^-17}, {
    2.9012214071255618`, 0, 6.181045092373603*^-17}, {
    2.9841447772569785`, 0, 6.727652057761554*^-17}, {
    3., 0, 6.831739988578082*^-17}, {
    1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
    1.0806195515694723`, 0, -3.665334079520424*^-17}, {
    1.1105976331738368`, 0, -3.967276376016019*^-17}, {
    1.166956356190518, 0, -6.139780813753298*^-17}, {
    1.2156376741151889`, 0, -6.765852793648817*^-17}, {
    1.2590563515709572`, 0, -6.271035218943372*^-17}, {
    1.3363048228659054`, 0, -5.452038017442776*^-17}, {
    1.403364274626575, 0, -4.795445222401027*^-17}, {
    1.4815748519599594`, 0, -4.083360422996936*^-17}, {
    1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
    1.612879504311111, 0, -2.9681805755008195`*^-17}, {
    1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
    1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
    1.84134370606608, 0, -1.1754437621658815`*^-17}, {
    1.9148458828986261`, 0, -6.254942444948598*^-18}, {
    1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
    1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
    2.076195235867775, 0, 5.460336135267355*^-18}, {
    2.147043324822746, 0, 1.0479341696570644`*^-17}, {
    2.215738531682641, 0, 1.532575023947979*^-17}, {
    2.280127974352383, 0, 1.9826964745600654`*^-17}, {
    2.3982589319433854`, 0, 2.799128138239359*^-17}, {
    2.505127279395825, 0, 3.5289039943105043`*^-17}, {
    2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
    2.7185050675284894`, 0, 4.967095265032991*^-17}, {
    2.8129516459285657`, 0, 5.59628657917814*^-17}, {
    2.9012214071255618`, 0, 6.181045092373603*^-17}, {
    2.9841447772569785`, 0, 6.727652057761554*^-17}, {
    3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
    1.725388721703603, 0, 0.9954944040167335}, {
    1.718673024351716, 0, 0.9909494259822538}, {
    1.6118804446194999`, 0, 0.9182002038196535}, {
    1.4409874136332306`, 0, 0.7995372106680626}, {
    1.3907416440578844`, 0, 0.7639939509577007}, {
    0.8227119661869544, 0, 0.3039639273157512}, {
    1.5524139631453666`, 0, 0.8772470256936915}, {
    1.4878419030766432`, 0, 0.8323729324650125}, {
    0.7387665844348641, 0, 0.2118382683494796}, {
    0.6624061883814435, 0, 0.11281818794547716`}, {
    1.3361230472899441`, 0, 0.7248463017704734}, {
    1.2764464101216455`, 0, 0.6814598923604777}, {
    1.2099812806247134`, 0, 0.6320752090489036}, {
    1.1349972068708725`, 0, 0.574932738156941}, {
    1.0811998723827927`, 0, 0.532709901624842}, {
    1.0212665171779367`, 0, 0.4841694604619104}, {
    0.9714138769953617, 0, 0.44214844769825756`}, {
    0.9159062757702401, 0, 0.39326358347393187`}, {
    0.6417550470100506, 0, 0.08290994125554355}, {
    0.6204952162914082, 0, 0.05021798203501367}, {
    0.5986583220178219, 0, 0.01439460885056855}, {
    0.591736290908012, 0, 0.002609304785832699}, {
    0.5903332233721076, 0, 0.00018622420050397358`}, {
    1.7898783863789862`, 0, 1.0388652797252398`}, {
    1.8442626335909353`, 0, 1.0752435827807179`}, {
    1.947286990926446, 0, 1.1439092483479993`}, {
    2.04015041315559, 0, 1.2053812116282425`}, {
    2.125067595654395, 0, 1.2612972479547397`}, {
    0.5903332233721076, 0, 0.00018622420050397358`}, {
    0.591736290908012, 0, 0.002609304785832699}, {
    0.5986583220178219, 0, 0.01439460885056855}, {
    2.214418712244248, 0, 1.3198912525475182`}, {
    2.29696370794418, 0, 1.3738145056728164`}, {
    2.373738070352859, 0, 1.423798861469403}, {
    2.445777287068955, 0, 1.4705761740760481`}, {
    2.5136854086472873`, 0, 1.514566665589571}, {
    2.578066485642676, 0, 1.556190558106792}, {
    2.6815635663987853`, 0, 1.6229604777560467`}, {
    2.7775368564801344`, 0, 1.6847270878903797`}, {
    2.8670880693137866`, 0, 1.7422376649327087`}, {
    2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
    0.6204952162914082, 0, 0.05021798203501367}, {
    0.6417550470100506, 0, 0.08290994125554355}, {
    0.6624061883814435, 0, 0.11281818794547716`}, {
    0.7387665844348641, 0, 0.2118382683494796}, {
    0.8227119661869544, 0, 0.3039639273157512}, {
    0.9159062757702401, 0, 0.39326358347393187`}, {
    0.9714138769953617, 0, 0.44214844769825756`}, {
    1.0212665171779367`, 0, 0.4841694604619104}, {
    1.0811998723827927`, 0, 0.532709901624842}, {
    1.1349972068708725`, 0, 0.574932738156941}, {
    1.2099812806247134`, 0, 0.6320752090489036}, {
    1.2764464101216455`, 0, 0.6814598923604777}, {
    1.3361230472899441`, 0, 0.7248463017704734}, {
    1.3907416440578844`, 0, 0.7639939509577007}, {
    1.4409874136332306`, 0, 0.7995372106680626}, {
    1.4878419030766432`, 0, 0.8323729324650125}, {
    1.5524139631453666`, 0, 0.8772470256936915}, {
    1.6118804446194999`, 0, 0.9182002038196535}, {
    1.718673024351716, 0, 0.9909494259822538}, {
    1.725388721703603, 0, 0.9954944040167335}, {1.7320508075688772`, 0, 1.}, {
    1.7898783863789862`, 0, 1.0388652797252398`}, {
    1.8442626335909353`, 0, 1.0752435827807179`}, {
    1.947286990926446, 0, 1.1439092483479993`}, {
    2.04015041315559, 0, 1.2053812116282425`}, {
    2.125067595654395, 0, 1.2612972479547397`}, {
    2.214418712244248, 0, 1.3198912525475182`}, {
    2.29696370794418, 0, 1.3738145056728164`}, {
    2.373738070352859, 0, 1.423798861469403}, {
    2.445777287068955, 0, 1.4705761740760481`}, {
    2.5136854086472873`, 0, 1.514566665589571}, {
    2.578066485642676, 0, 1.556190558106792}, {
    2.6815635663987853`, 0, 1.6229604777560467`}, {
    2.7775368564801344`, 0, 1.6847270878903797`}, {
    2.8670880693137866`, 0, 1.7422376649327087`}, {
    2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
    1., 0, 1.7320508075688772`}, {0.9967579511289973, 0, 1.725591665960026}, {
    0.993495492386544, 0, 1.7190888665612158`}, {
    0.9425085457322113, 0, 1.6170405957285525`}, {
    0.8856079680040274, 0, 1.5020983847364007`}, {
    0.8568456407650447, 0, 1.4435271823540774`}, {
    0.8261414100342576, 0, 1.3805806367241007`}, {
    0.3169113191400581, 0, 0.12182369217421189`}, {
    0.30556128145229333`, 0, 0.07870830025830584}, {
    0.293881511672543, 0, 0.03202421727833343}, {
    0.7929935274196624, 0, 1.312005646226944}, {
    0.7570562324594531, 0, 1.2369304970405355`}, {
    0.7175244013663284, 0, 1.1531959892477461`}, {
    0.6735929103529877, 0, 1.0586429229314482`}, {
    0.6373562226070177, 0, 0.9791226748340147}, {
    0.5970796194351795, 0, 0.888850968008553}, {
    0.5648417309751376, 0, 0.814760931317141}, {
    0.5291745023898358, 0, 0.7305383373006455}, {
    0.5004576972760991, 0, 0.6605211679656938}, {
    0.46888764804285155`, 0, 0.5808380879020639}, {
    0.4434048237381806, 0, 0.513867106591227}, {
    0.4156368767851654, 0, 0.43764204466468926`}, {
    0.3931050578910148, 0, 0.3726162571212509}, {
    0.36883015785401224`, 0, 0.2986906238609892}, {
    0.3490020511159586, 0, 0.2345412716938603}, {
    0.32792783785037954`, 0, 0.161808507688534}, {
    0.28791933124367225`, 0, 0.007206042434050243}, {
    0.2864163468618862, 0, 0.0008305267310371494}, {
    1.033892835459149, 0, 1.7992392055814181`}, {
    1.0658596651224108`, 0, 1.862362914247072}, {
    1.181446280919145, 0, 2.0893008800543185`}, {
    1.231780095058521, 0, 2.1873864682851996`}, {
    0.2864163468618862, 0, 0.0008305267310371494}, {
    1.0970139405446213`, 0, 1.9237916583215942`}, {
    1.1265431074847296`, 0, 1.9818304732138543`}, {
    0.28791933124367225`, 0, 0.007206042434050243}, {
    0.293881511672543, 0, 0.03202421727833343}, {
    1.2851334594623443`, 0, 2.2909888522280237`}, {
    1.334475408728814, 0, 2.3864830347778727`}, {
    1.3804065537208814`, 0, 2.475115327700833}, {
    1.4235275053014986`, 0, 2.5581320427629906`}, {
    1.4641925040528287`, 0, 2.6362581657929063`}, {
    1.5027557905570348`, 0, 2.7102186826191397`}, {
    1.6543862314462106`, 0, 3.}, {
    0.30556128145229333`, 0, 0.07870830025830584}, {
    1.5340502938297416`, 0, 2.770154325248319}, {
    1.5642383005785114`, 0, 2.827914052016298}, {
    1.5933198108033446`, 0, 2.8834978629230776`}, {
    1.621294824504241, 0, 2.936905757968656}, {
    0.3169113191400581, 0, 0.12182369217421189`}, {
    0.32792783785037954`, 0, 0.161808507688534}, {
    0.3490020511159586, 0, 0.2345412716938603}, {
    0.36883015785401224`, 0, 0.2986906238609892}, {
    0.3931050578910148, 0, 0.3726162571212509}, {
    0.4156368767851654, 0, 0.43764204466468926`}, {
    0.4434048237381806, 0, 0.513867106591227}, {
    0.46888764804285155`, 0, 0.5808380879020639}, {
    0.5004576972760991, 0, 0.6605211679656938}, {
    0.5291745023898358, 0, 0.7305383373006455}, {
    0.5648417309751376, 0, 0.814760931317141}, {
    0.5970796194351795, 0, 0.888850968008553}, {
    0.6373562226070177, 0, 0.9791226748340147}, {
    0.6735929103529877, 0, 1.0586429229314482`}, {
    0.7175244013663284, 0, 1.1531959892477461`}, {
    0.7570562324594531, 0, 1.2369304970405355`}, {
    0.7929935274196624, 0, 1.312005646226944}, {
    0.8261414100342576, 0, 1.3805806367241007`}, {
    0.8568456407650447, 0, 1.4435271823540774`}, {
    0.8856079680040274, 0, 1.5020983847364007`}, {
    0.9425085457322113, 0, 1.6170405957285525`}, {
    0.993495492386544, 0, 1.7190888665612158`}, {
    0.9967579511289973, 0, 1.725591665960026}, {1., 0, 1.7320508075688772`}, {
    1.033892835459149, 0, 1.7992392055814181`}, {
    1.0658596651224108`, 0, 1.862362914247072}, {
    1.0970139405446213`, 0, 1.9237916583215942`}, {
    1.1265431074847296`, 0, 1.9818304732138543`}, {
    1.181446280919145, 0, 2.0893008800543185`}, {
    1.231780095058521, 0, 2.1873864682851996`}, {
    1.2851334594623443`, 0, 2.2909888522280237`}, {
    1.334475408728814, 0, 2.3864830347778727`}, {
    1.3804065537208814`, 0, 2.475115327700833}, {
    1.4235275053014986`, 0, 2.5581320427629906`}, {
    1.4641925040528287`, 0, 2.6362581657929063`}, {
    1.5027557905570348`, 0, 2.7102186826191397`}, {
    1.5340502938297416`, 0, 2.770154325248319}, {
    1.5642383005785114`, 0, 2.827914052016298}, {
    1.5933198108033446`, 0, 2.8834978629230776`}, {
    1.621294824504241, 0, 2.936905757968656}, {1.6543862314462106`, 0, 3.}, {
    0., 0, 2.}, {0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
    0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
    0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
    0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
    0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
    0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
    0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
    0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
    0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
    0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
    0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
    0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
    0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
    0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
    0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
    0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
    0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
    0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
    0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
    0., 0, 2.9165393169096525`}, {0., 0, 3.}, {0., 0, 0.12668644282153832`}, {
    0., 0, 0.19493582036141505`}, {0., 0, 0.2734102546614774}, {
    0., 0, 0.34299131720792514`}, {0., 0, 0.4243569404846203}, {
    0., 0, 0.49631614791155654`}, {0., 0, 0.5817771424227749}, {
    0., 0, 0.6572345268975783}, {0., 0, 0.7479807485897318}, {
    0., 0, 0.8280418701008675}, {0., 0, 0.925918996470587}, {
    0., 0, 1.0122057127579267`}, {0., 0, 1.1147657980990906`}, {
    0., 0, 1.2055173116118956`}, {0., 0, 1.3239104139670337`}, {
    0., 0, 1.4280897149371465`}, {0., 0, 1.5209921171515646`}, {
    0., 0, 1.6055545232396176`}, {0., 0, 1.6829299425553081`}, {
    0., 0, 1.7547682338914479`}, {0., 0, 1.8765530604330984`}, {
    0., 0, 1.9860968846818443`}, {0., 0, 1.9930697437687392`}, {0., 0, 2.}, {
    0., 0, 2.083871100476444}, {0., 0, 2.162405129581069}, {
    0., 0, 2.2387311107539123`}, {0., 0, 2.3106409960631926`}, {
    0., 0, 2.3786640756418818`}, {0., 0, 2.4433296396229536`}, {
    0., 0, 2.5639856627704924`}, {0., 0, 2.691240491879268}, {
    0., 0, 2.808218810422449}, {0., 0, 2.9165393169096525`}, {
    0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
     1.725591665960026}, {-0.993495492386544, 0, 
     1.7190888665612158`}, {-0.9425085457322114, 0, 
     1.6170405957285525`}, {-0.8856079680040276, 0, 
     1.5020983847364007`}, {-0.856845640765045, 0, 
     1.4435271823540776`}, {-0.8261414100342581, 0, 
     1.3805806367241011`}, {-0.3169113191400585, 0, 
     0.12182369217421259`}, {-0.3055612814522936, 0, 
     0.07870830025830647}, {-0.2938815116725432, 0, 
     0.032024217278333975`}, {-0.7929935274196632, 0, 
     1.3120056462269452`}, {-0.757056232459454, 0, 
     1.2369304970405368`}, {-0.7175244013663296, 0, 
     1.153195989247748}, {-0.6735929103529891, 0, 
     1.0586429229314507`}, {-0.637356222607019, 0, 
     0.9791226748340169}, {-0.5970796194351806, 0, 
     0.8888509680085548}, {-0.5648417309751385, 0, 
     0.8147609313171424}, {-0.5291745023898367, 0, 
     0.7305383373006471}, {-0.5004576972761, 0, 
     0.6605211679656953}, {-0.4688876480428522, 0, 
     0.5808380879020649}, {-0.44340482373818135`, 0, 
     0.5138671065912283}, {-0.41563687678516603`, 0, 
     0.43764204466469026`}, {-0.39310505789101535`, 0, 
     0.3726162571212519}, {-0.36883015785401285`, 0, 
     0.29869062386099027`}, {-0.34900205111595906`, 0, 
     0.2345412716938608}, {-0.32792783785038, 0, 
     0.16180850768853478`}, {-0.28791933124367247`, 0, 
     0.007206042434050176}, {-0.28641634686188555`, 0, 
     0.0008305267309944116}, {-1.033892835459149, 0, 
     1.7992392055814184`}, {-1.0658596651224108`, 0, 
     1.8623629142470723`}, {-1.1814462809191453`, 0, 
     2.08930088005432}, {-1.2317800950585212`, 0, 
     2.187386468285201}, {-0.28641634686188555`, 0, 
     0.0008305267309944116}, {-1.0970139405446213`, 0, 
     1.923791658321595}, {-1.1265431074847296`, 0, 
     1.981830473213855}, {-0.28791933124367247`, 0, 
     0.007206042434050176}, {-0.2938815116725432, 0, 
     0.032024217278333975`}, {-1.2851334594623451`, 0, 
     2.2909888522280264`}, {-1.334475408728815, 0, 
     2.386483034777876}, {-1.3804065537208827`, 0, 
     2.4751153277008364`}, {-1.4235275053015006`, 0, 
     2.558132042762995}, {-1.464192504052831, 0, 
     2.6362581657929107`}, {-1.5027557905570372`, 0, 
     2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 0, 
     0.07870830025830647}, {-1.5340502938297444`, 0, 
     2.7701543252483254`}, {-1.564238300578515, 0, 
     2.8279140520163057`}, {-1.5933198108033488`, 0, 
     2.8834978629230865`}, {-1.6212948245042456`, 0, 
     2.936905757968666}, {-0.3169113191400585, 0, 
     0.12182369217421259`}, {-0.32792783785038, 0, 
     0.16180850768853478`}, {-0.34900205111595906`, 0, 
     0.2345412716938608}, {-0.36883015785401285`, 0, 
     0.29869062386099027`}, {-0.39310505789101535`, 0, 
     0.3726162571212519}, {-0.41563687678516603`, 0, 
     0.43764204466469026`}, {-0.44340482373818135`, 0, 
     0.5138671065912283}, {-0.4688876480428522, 0, 
     0.5808380879020649}, {-0.5004576972761, 0, 
     0.6605211679656953}, {-0.5291745023898367, 0, 
     0.7305383373006471}, {-0.5648417309751385, 0, 
     0.8147609313171424}, {-0.5970796194351806, 0, 
     0.8888509680085548}, {-0.637356222607019, 0, 
     0.9791226748340169}, {-0.6735929103529891, 0, 
     1.0586429229314507`}, {-0.7175244013663296, 0, 
     1.153195989247748}, {-0.757056232459454, 0, 
     1.2369304970405368`}, {-0.7929935274196632, 0, 
     1.3120056462269452`}, {-0.8261414100342581, 0, 
     1.3805806367241011`}, {-0.856845640765045, 0, 
     1.4435271823540776`}, {-0.8856079680040276, 0, 
     1.5020983847364007`}, {-0.9425085457322114, 0, 
     1.6170405957285525`}, {-0.993495492386544, 0, 
     1.7190888665612158`}, {-0.9967579511289973, 0, 1.725591665960026}, {-1., 
     0, 1.7320508075688772`}, {-1.033892835459149, 0, 
     1.7992392055814184`}, {-1.0658596651224108`, 0, 
     1.8623629142470723`}, {-1.0970139405446213`, 0, 
     1.923791658321595}, {-1.1265431074847296`, 0, 
     1.981830473213855}, {-1.1814462809191453`, 0, 
     2.08930088005432}, {-1.2317800950585212`, 0, 
     2.187386468285201}, {-1.2851334594623451`, 0, 
     2.2909888522280264`}, {-1.334475408728815, 0, 
     2.386483034777876}, {-1.3804065537208827`, 0, 
     2.4751153277008364`}, {-1.4235275053015006`, 0, 
     2.558132042762995}, {-1.464192504052831, 0, 
     2.6362581657929107`}, {-1.5027557905570372`, 0, 
     2.710218682619145}, {-1.5340502938297444`, 0, 
     2.7701543252483254`}, {-1.564238300578515, 0, 
     2.8279140520163057`}, {-1.5933198108033488`, 0, 
     2.8834978629230865`}, {-1.6212948245042456`, 0, 
     2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 0,
      1.}, {-1.725388721703603, 0, 0.9954944040167335}, {-1.718673024351716, 
     0, 0.9909494259822538}, {-1.6118804446194999`, 0, 
     0.9182002038196536}, {-1.4409874136332306`, 0, 
     0.7995372106680628}, {-1.3907416440578844`, 0, 
     0.7639939509577008}, {-0.8227119661869543, 0, 
     0.3039639273157513}, {-1.5524139631453666`, 0, 
     0.8772470256936917}, {-1.4878419030766432`, 0, 
     0.8323729324650128}, {-0.7387665844348641, 0, 
     0.21183826834947966`}, {-0.6624061883814434, 0, 
     0.1128181879454771}, {-1.3361230472899441`, 0, 
     0.7248463017704735}, {-1.2764464101216455`, 0, 
     0.6814598923604778}, {-1.2099812806247134`, 0, 
     0.6320752090489037}, {-1.1349972068708725`, 0, 
     0.5749327381569411}, {-1.0811998723827925`, 0, 
     0.532709901624842}, {-1.0212665171779367`, 0, 
     0.48416946046191056`}, {-0.9714138769953617, 0, 
     0.4421484476982577}, {-0.9159062757702401, 0, 
     0.39326358347393203`}, {-0.6417550470100504, 0, 
     0.08290994125554342}, {-0.6204952162914079, 0, 
     0.05021798203501361}, {-0.5986583220178213, 0, 
     0.01439460885056816}, {-0.5917362909080106, 0, 
     0.0026093047858313954`}, {-0.5903332233721628, 0, 
     0.00018622419983990517`}, {-1.7898783863789862`, 0, 
     1.0388652797252398`}, {-1.8442626335909353`, 0, 
     1.0752435827807179`}, {-1.947286990926446, 0, 
     1.1439092483479991`}, {-2.04015041315559, 0, 
     1.2053812116282423`}, {-2.125067595654395, 0, 
     1.2612972479547395`}, {-0.5903332233721628, 0, 
     0.00018622419983990517`}, {-0.5917362909080106, 0, 
     0.0026093047858313954`}, {-0.5986583220178213, 0, 
     0.01439460885056816}, {-2.214418712244248, 0, 
     1.3198912525475177`}, {-2.296963707944179, 0, 
     1.3738145056728155`}, {-2.373738070352858, 0, 
     1.4237988614694022`}, {-2.4457772870689536`, 0, 
     1.4705761740760468`}, {-2.5136854086472855`, 0, 
     1.5145666655895695`}, {-2.578066485642674, 0, 
     1.5561905581067903`}, {-2.681563566398782, 0, 
     1.622960477756044}, {-2.7775368564801304`, 0, 
     1.6847270878903766`}, {-2.867088069313782, 0, 
     1.7422376649327054`}, {-2.9513189183268005`, 0, 
     1.7962394853059478`}, {-3., 0, 
     1.8274021524617996`}, {-0.6204952162914079, 0, 
     0.05021798203501361}, {-0.6417550470100504, 0, 
     0.08290994125554342}, {-0.6624061883814434, 0, 
     0.1128181879454771}, {-0.7387665844348641, 0, 
     0.21183826834947966`}, {-0.8227119661869543, 0, 
     0.3039639273157513}, {-0.9159062757702401, 0, 
     0.39326358347393203`}, {-0.9714138769953617, 0, 
     0.4421484476982577}, {-1.0212665171779367`, 0, 
     0.48416946046191056`}, {-1.0811998723827925`, 0, 
     0.532709901624842}, {-1.1349972068708725`, 0, 
     0.5749327381569411}, {-1.2099812806247134`, 0, 
     0.6320752090489037}, {-1.2764464101216455`, 0, 
     0.6814598923604778}, {-1.3361230472899441`, 0, 
     0.7248463017704735}, {-1.3907416440578844`, 0, 
     0.7639939509577008}, {-1.4409874136332306`, 0, 
     0.7995372106680628}, {-1.4878419030766432`, 0, 
     0.8323729324650128}, {-1.5524139631453666`, 0, 
     0.8772470256936917}, {-1.6118804446194999`, 0, 
     0.9182002038196536}, {-1.718673024351716, 0, 
     0.9909494259822538}, {-1.725388721703603, 0, 
     0.9954944040167335}, {-1.7320508075688772`, 0, 
     1.}, {-1.7898783863789862`, 0, 
     1.0388652797252398`}, {-1.8442626335909353`, 0, 
     1.0752435827807179`}, {-1.947286990926446, 0, 
     1.1439092483479991`}, {-2.04015041315559, 0, 
     1.2053812116282423`}, {-2.125067595654395, 0, 
     1.2612972479547395`}, {-2.214418712244248, 0, 
     1.3198912525475177`}, {-2.296963707944179, 0, 
     1.3738145056728155`}, {-2.373738070352858, 0, 
     1.4237988614694022`}, {-2.4457772870689536`, 0, 
     1.4705761740760468`}, {-2.5136854086472855`, 0, 
     1.5145666655895695`}, {-2.578066485642674, 0, 
     1.5561905581067903`}, {-2.681563566398782, 0, 
     1.622960477756044}, {-2.7775368564801304`, 0, 
     1.6847270878903766`}, {-2.867088069313782, 0, 
     1.7422376649327054`}, {-2.9513189183268005`, 0, 
     1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
     0.}, {-1.9913420464689446`, 
     0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
     0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
     0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
     0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
     0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
     0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
     0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
     0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
     0, -2.509406402108567*^-17}, {-1.166956356190519, 
     0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
     0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
     0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
     0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
     0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
     0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
     0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
     0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
     0, -6.650612064757136*^-17}, {-0.9891719542270405, 
     0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
     0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
     5.460336135267359*^-18}, {-2.147043324822746, 0, 
     1.047934169657065*^-17}, {-2.398258931943386, 0, 
     2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
     3.528903994310506*^-17}, {-0.9854765117057152, 
     0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
     1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
     1.9826964745600664`*^-17}, {-0.9891719542270405, 
     0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
     0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
     4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
     4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
     5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
     6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
     6.727652057761554*^-17}, {-3., 0, 
     6.831739988578082*^-17}, {-1.0466835174016902`, 
     0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
     0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
     0, -3.967276376016036*^-17}, {-1.166956356190519, 
     0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
     0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
     0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
     0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
     0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
     0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
     0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
     0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
     0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
     0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
     0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
     0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
     0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
     0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
     5.460336135267359*^-18}, {-2.147043324822746, 0, 
     1.047934169657065*^-17}, {-2.215738531682641, 0, 
     1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
     1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
     2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
     3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
     4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
     4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
     5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
     6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
     6.727652057761554*^-17}, {-3., 0, 
     6.831739988578082*^-17}, {-1.7320508075688772`, 
     0, -1.}, {-1.725388721703603, 
     0, -0.9954944040167335}, {-1.718673024351716, 
     0, -0.9909494259822538}, {-1.6118804446195, 
     0, -0.9182002038196536}, {-1.4409874136332308`, 
     0, -0.7995372106680627}, {-1.3907416440578846`, 
     0, -0.7639939509577008}, {-0.8227119661869541, 
     0, -0.30396392731575067`}, {-1.5524139631453668`, 
     0, -0.8772470256936916}, {-1.4878419030766434`, 
     0, -0.8323729324650126}, {-0.7387665844348644, 
     0, -0.21183826834947977`}, {-0.6624061883814446, 
     0, -0.11281818794547861`}, {-1.3361230472899444`, 
     0, -0.7248463017704735}, {-1.2764464101216457`, 
     0, -0.6814598923604778}, {-1.2099812806247137`, 
     0, -0.6320752090489037}, {-1.1349972068708727`, 
     0, -0.574932738156941}, {-1.081199872382793, 
     0, -0.532709901624842}, {-1.0212665171779367`, 
     0, -0.48416946046191034`}, {-0.9714138769953617, 
     0, -0.44214844769825756`}, {-0.9159062757702402, 
     0, -0.39326358347393187`}, {-1.7898783863789862`, 
     0, -1.0388652797252398`}, {-1.8442626335909351`, 
     0, -1.0752435827807179`}, {-1.947286990926446, 
     0, -1.1439092483479993`}, {-2.0401504131555903`, 
     0, -1.2053812116282427`}, {-2.125067595654396, 
     0, -1.26129724795474}, {-0.6624061883814446, 
     0, -0.11281818794547861`}, {-0.7387665844348644, 
     0, -0.21183826834947977`}, {-0.8227119661869541, 
     0, -0.30396392731575067`}, {-2.2144187122442487`, 
     0, -1.3198912525475177`}, {-2.29696370794418, 
     0, -1.3738145056728157`}, {-2.373738070352859, 
     0, -1.4237988614694024`}, {-2.4457772870689545`, 
     0, -1.470576174076047}, {-2.5136854086472864`, 
     0, -1.5145666655895698`}, {-2.5780664856426747`, 
     0, -1.5561905581067905`}, {-2.6815635663987827`, 
     0, -1.6229604777560442`}, {-2.7775368564801313`, 
     0, -1.6847270878903766`}, {-2.867088069313783, 
     0, -1.7422376649327052`}, {-2.951318918326801, 
     0, -1.7962394853059473`}, {-3., 
     0, -1.827402152461799}, {-0.9159062757702402, 
     0, -0.39326358347393187`}, {-0.9714138769953617, 
     0, -0.44214844769825756`}, {-1.0212665171779367`, 
     0, -0.48416946046191034`}, {-1.081199872382793, 
     0, -0.532709901624842}, {-1.1349972068708727`, 
     0, -0.574932738156941}, {-1.2099812806247137`, 
     0, -0.6320752090489037}, {-1.2764464101216457`, 
     0, -0.6814598923604778}, {-1.3361230472899444`, 
     0, -0.7248463017704735}, {-1.3907416440578846`, 
     0, -0.7639939509577008}, {-1.4409874136332308`, 
     0, -0.7995372106680627}, {-1.4878419030766434`, 
     0, -0.8323729324650126}, {-1.5524139631453668`, 
     0, -0.8772470256936916}, {-1.6118804446195, 
     0, -0.9182002038196536}, {-1.718673024351716, 
     0, -0.9909494259822538}, {-1.725388721703603, 
     0, -0.9954944040167335}, {-1.7320508075688772`, 
     0, -1.}, {-1.7898783863789862`, 
     0, -1.0388652797252398`}, {-1.8442626335909351`, 
     0, -1.0752435827807179`}, {-1.947286990926446, 
     0, -1.1439092483479993`}, {-2.0401504131555903`, 
     0, -1.2053812116282427`}, {-2.125067595654396, 
     0, -1.26129724795474}, {-2.2144187122442487`, 
     0, -1.3198912525475177`}, {-2.29696370794418, 
     0, -1.3738145056728157`}, {-2.373738070352859, 
     0, -1.4237988614694024`}, {-2.4457772870689545`, 
     0, -1.470576174076047}, {-2.5136854086472864`, 
     0, -1.5145666655895698`}, {-2.5780664856426747`, 
     0, -1.5561905581067905`}, {-2.6815635663987827`, 
     0, -1.6229604777560442`}, {-2.7775368564801313`, 
     0, -1.6847270878903766`}, {-2.867088069313783, 
     0, -1.7422376649327052`}, {-2.951318918326801, 
     0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
     0, -1.7320508075688772`}, {-0.9967579511289973, 
     0, -1.725591665960026}, {-0.993495492386544, 
     0, -1.7190888665612158`}, {-0.9425085457322114, 
     0, -1.6170405957285525`}, {-0.8856079680040276, 
     0, -1.5020983847364007`}, {-0.856845640765045, 
     0, -1.4435271823540774`}, {-0.826141410034258, 
     0, -1.380580636724101}, {-0.3169113191400583, 
     0, -0.1218236921742118}, {-0.30556128145229344`, 
     0, -0.07870830025830548}, {-1.033892835459149, 
     0, -1.7992392055814181`}, {-0.7929935274196629, 
     0, -1.3120056462269445`}, {-0.7570562324594537, 
     0, -1.2369304970405361`}, {-0.7175244013663291, 
     0, -1.153195989247747}, {-0.6735929103529886, 
     0, -1.0586429229314496`}, {-0.6373562226070184, 
     0, -0.9791226748340157}, {-0.5970796194351801, 
     0, -0.8888509680085538}, {-0.5648417309751381, 
     0, -0.8147609313171418}, {-0.5291745023898363, 
     0, -0.7305383373006464}, {-0.5004576972760997, 
     0, -0.6605211679656946}, {-0.468887648042852, 
     0, -0.5808380879020645}, {-0.44340482373818113`, 
     0, -0.5138671065912279}, {-0.4156368767851659, 
     0, -0.4376420446646899}, {-0.39310505789101524`, 
     0, -0.37261625712125157`}, {-0.36883015785401274`, 
     0, -0.29869062386098993`}, {-0.34900205111595917`, 
     0, -0.2345412716938612}, {-0.3279278378503798, 
     0, -0.1618085076885341}, {-1.0658596651224108`, 
     0, -1.862362914247072}, {-1.181446280919145, 
     0, -2.0893008800543185`}, {-1.231780095058521, 
     0, -2.1873864682851996`}, {-0.30556128145229344`, 
     0, -0.07870830025830548}, {-1.0970139405446213`, 
     0, -1.9237916583215942`}, {-1.1265431074847296`, 
     0, -1.9818304732138543`}, {-0.3169113191400583, 
     0, -0.1218236921742118}, {-0.3279278378503798, 
     0, -0.1618085076885341}, {-1.2851334594623438`, 
     0, -2.290988852228023}, {-1.3344754087288135`, 
     0, -2.386483034777872}, {-1.380406553720881, 
     0, -2.4751153277008315`}, {-1.423527505301498, 
     0, -2.558132042762989}, {-1.4641925040528276`, 
     0, -2.6362581657929036`}, {-1.5027557905570337`, 
     0, -2.710218682619137}, {-1.6543862314462108`, 
     0, -3.}, {-0.34900205111595917`, 
     0, -0.2345412716938612}, {-1.534050293829741, 
     0, -2.7701543252483174`}, {-1.5642383005785114`, 
     0, -2.8279140520162973`}, {-1.5933198108033446`, 
     0, -2.8834978629230763`}, {-1.6212948245042413`, 
     0, -2.9369057579686566`}, {-0.36883015785401274`, 
     0, -0.29869062386098993`}, {-0.39310505789101524`, 
     0, -0.37261625712125157`}, {-0.4156368767851659, 
     0, -0.4376420446646899}, {-0.44340482373818113`, 
     0, -0.5138671065912279}, {-0.468887648042852, 
     0, -0.5808380879020645}, {-0.5004576972760997, 
     0, -0.6605211679656946}, {-0.5291745023898363, 
     0, -0.7305383373006464}, {-0.5648417309751381, 
     0, -0.8147609313171418}, {-0.5970796194351801, 
     0, -0.8888509680085538}, {-0.6373562226070184, 
     0, -0.9791226748340157}, {-0.6735929103529886, 
     0, -1.0586429229314496`}, {-0.7175244013663291, 
     0, -1.153195989247747}, {-0.7570562324594537, 
     0, -1.2369304970405361`}, {-0.7929935274196629, 
     0, -1.3120056462269445`}, {-0.826141410034258, 
     0, -1.380580636724101}, {-0.856845640765045, 
     0, -1.4435271823540774`}, {-0.8856079680040276, 
     0, -1.5020983847364007`}, {-0.9425085457322114, 
     0, -1.6170405957285525`}, {-0.993495492386544, 
     0, -1.7190888665612158`}, {-0.9967579511289973, 
     0, -1.725591665960026}, {-1., 
     0, -1.7320508075688772`}, {-1.033892835459149, 
     0, -1.7992392055814181`}, {-1.0658596651224108`, 
     0, -1.862362914247072}, {-1.0970139405446213`, 
     0, -1.9237916583215942`}, {-1.1265431074847296`, 
     0, -1.9818304732138543`}, {-1.181446280919145, 
     0, -2.0893008800543185`}, {-1.231780095058521, 
     0, -2.1873864682851996`}, {-1.2851334594623438`, 
     0, -2.290988852228023}, {-1.3344754087288135`, 
     0, -2.386483034777872}, {-1.380406553720881, 
     0, -2.4751153277008315`}, {-1.423527505301498, 
     0, -2.558132042762989}, {-1.4641925040528276`, 
     0, -2.6362581657929036`}, {-1.5027557905570337`, 
     0, -2.710218682619137}, {-1.534050293829741, 
     0, -2.7701543252483174`}, {-1.5642383005785114`, 
     0, -2.8279140520162973`}, {-1.5933198108033446`, 
     0, -2.8834978629230763`}, {-1.6212948245042413`, 
     0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {0., 0, -2.}, {
    0., 0, -1.9930697437687392`}, {0., 0, -1.9860968846818443`}, {
    0., 0, -1.6829299425553081`}, {0., 0, -1.6055545232396176`}, {
    0., 0, -0.00812878362489576}, {0., 0, -1.8765530604330984`}, {
    0., 0, -1.7547682338914479`}, {0., 0, -0.001352194191085579}, {
    0., 0, -2.0838711004764443`}, {0., 0, -1.5209921171515646`}, {
    0., 0, -1.4280897149371468`}, {0., 0, -1.323910413967034}, {
    0., 0, -1.2055173116118962`}, {0., 0, -1.114765798099091}, {
    0., 0, -1.0122057127579276`}, {0., 0, -0.9259189964705876}, {
    0., 0, -0.8280418701008682}, {0., 0, -0.7479807485897327}, {
    0., 0, -0.6572345268975793}, {0., 0, -0.5817771424227758}, {
    0., 0, -0.49631614791155776`}, {0., 0, -0.4243569404846221}, {
    0., 0, -0.3429913172079261}, {0., 0, -0.27341025466147834`}, {
    0., 0, -0.19493582036141607`}, {0., 0, -0.12668644282153935`}, {
    0., 0, -0.04999541458500764}, {0., 0, -2.1624051295810696`}, {
    0., 0, -2.563985662770493}, {0., 0, -0.001352194191085579}, {
    0., 0, -0.00812878362489576}, {0., 0, -2.238731110753913}, {
    0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
    0., 0, -2.443329639622954}, {0., 0, -0.04999541458500764}, {
    0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
    0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
    0., 0, -0.12668644282153935`}, {0., 0, -0.19493582036141607`}, {
    0., 0, -0.27341025466147834`}, {0., 0, -0.3429913172079261}, {
    0., 0, -0.4243569404846221}, {0., 0, -0.49631614791155776`}, {
    0., 0, -0.5817771424227758}, {0., 0, -0.6572345268975793}, {
    0., 0, -0.7479807485897327}, {0., 0, -0.8280418701008682}, {
    0., 0, -0.9259189964705876}, {0., 0, -1.0122057127579276`}, {
    0., 0, -1.114765798099091}, {0., 0, -1.2055173116118962`}, {
    0., 0, -1.323910413967034}, {0., 0, -1.4280897149371468`}, {
    0., 0, -1.5209921171515646`}, {0., 0, -1.6055545232396176`}, {
    0., 0, -1.6829299425553081`}, {0., 0, -1.7547682338914479`}, {
    0., 0, -1.8765530604330984`}, {0., 0, -1.9860968846818443`}, {
    0., 0, -1.9930697437687392`}, {0., 0, -2.}, {
    0., 0, -2.0838711004764443`}, {0., 0, -2.1624051295810696`}, {
    0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
    0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
    0., 0, -2.563985662770493}, {0., 0, -2.69124049187927}, {
    0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
    1., 0, -1.7320508075688772`}, {
    0.9967579511289973, 0, -1.725591665960026}, {
    0.993495492386544, 0, -1.7190888665612158`}, {
    0.9425085457322114, 0, -1.6170405957285525`}, {
    0.8856079680040275, 0, -1.5020983847364007`}, {
    0.8568456407650448, 0, -1.4435271823540774`}, {
    0.8261414100342577, 0, -1.3805806367241007`}, {
    0.3169113191400582, 0, -0.12182369217421207`}, {
    0.3055612814522934, 0, -0.07870830025830602}, {
    1.033892835459149, 0, -1.7992392055814184`}, {
    0.7929935274196626, 0, -1.312005646226944}, {
    0.7570562324594533, 0, -1.2369304970405357`}, {
    0.7175244013663287, 0, -1.1531959892477464`}, {
    0.673592910352988, 0, -1.0586429229314485`}, {
    0.637356222607018, 0, -0.9791226748340147}, {
    0.5970796194351797, 0, -0.888850968008553}, {
    0.5648417309751377, 0, -0.8147609313171408}, {
    0.529174502389836, 0, -0.7305383373006457}, {
    0.5004576972760993, 0, -0.6605211679656939}, {
    0.46888764804285166`, 0, -0.5808380879020638}, {
    0.4434048237381808, 0, -0.5138671065912273}, {
    0.4156368767851656, 0, -0.4376420446646893}, {
    0.3931050578910148, 0, -0.37261625712125057`}, {
    0.3688301578540124, 0, -0.29869062386098927`}, {
    0.3490020511159587, 0, -0.2345412716938604}, {
    0.32792783785037966`, 0, -0.16180850768853416`}, {
    1.0658596651224108`, 0, -1.8623629142470721`}, {
    1.1814462809191455`, 0, -2.0893008800543194`}, {
    1.2317800950585214`, 0, -2.1873864682852004`}, {
    0.3055612814522934, 0, -0.07870830025830602}, {
    1.0970139405446215`, 0, -1.9237916583215946`}, {
    1.1265431074847299`, 0, -1.9818304732138547`}, {
    0.3169113191400582, 0, -0.12182369217421207`}, {
    0.32792783785037966`, 0, -0.16180850768853416`}, {
    1.2851334594623456`, 0, -2.2909888522280264`}, {
    1.3344754087288155`, 0, -2.3864830347778763`}, {
    1.3804065537208836`, 0, -2.4751153277008373`}, {
    1.4235275053015013`, 0, -2.558132042762996}, {
    1.4641925040528316`, 0, -2.636258165792912}, {
    1.5027557905570381`, 0, -2.7102186826191463`}, {
    1.6543862314462103`, 0, -3.}, {
    0.3490020511159587, 0, -0.2345412716938604}, {
    1.5340502938297451`, 0, -2.7701543252483263`}, {
    1.564238300578515, 0, -2.8279140520163057`}, {
    1.5933198108033484`, 0, -2.883497862923085}, {
    1.6212948245042451`, 0, -2.9369057579686646`}, {
    0.3688301578540124, 0, -0.29869062386098927`}, {
    0.3931050578910148, 0, -0.37261625712125057`}, {
    0.4156368767851656, 0, -0.4376420446646893}, {
    0.4434048237381808, 0, -0.5138671065912273}, {
    0.46888764804285166`, 0, -0.5808380879020638}, {
    0.5004576972760993, 0, -0.6605211679656939}, {
    0.529174502389836, 0, -0.7305383373006457}, {
    0.5648417309751377, 0, -0.8147609313171408}, {
    0.5970796194351797, 0, -0.888850968008553}, {
    0.637356222607018, 0, -0.9791226748340147}, {
    0.673592910352988, 0, -1.0586429229314485`}, {
    0.7175244013663287, 0, -1.1531959892477464`}, {
    0.7570562324594533, 0, -1.2369304970405357`}, {
    0.7929935274196626, 0, -1.312005646226944}, {
    0.8261414100342577, 0, -1.3805806367241007`}, {
    0.8568456407650448, 0, -1.4435271823540774`}, {
    0.8856079680040275, 0, -1.5020983847364007`}, {
    0.9425085457322114, 0, -1.6170405957285525`}, {
    0.993495492386544, 0, -1.7190888665612158`}, {
    0.9967579511289973, 0, -1.725591665960026}, {
    1., 0, -1.7320508075688772`}, {
    1.033892835459149, 0, -1.7992392055814184`}, {
    1.0658596651224108`, 0, -1.8623629142470721`}, {
    1.0970139405446215`, 0, -1.9237916583215946`}, {
    1.1265431074847299`, 0, -1.9818304732138547`}, {
    1.1814462809191455`, 0, -2.0893008800543194`}, {
    1.2317800950585214`, 0, -2.1873864682852004`}, {
    1.2851334594623456`, 0, -2.2909888522280264`}, {
    1.3344754087288155`, 0, -2.3864830347778763`}, {
    1.3804065537208836`, 0, -2.4751153277008373`}, {
    1.4235275053015013`, 0, -2.558132042762996}, {
    1.4641925040528316`, 0, -2.636258165792912}, {
    1.5027557905570381`, 0, -2.7102186826191463`}, {
    1.5340502938297451`, 0, -2.7701543252483263`}, {
    1.564238300578515, 0, -2.8279140520163057`}, {
    1.5933198108033484`, 0, -2.883497862923085}, {
    1.6212948245042451`, 0, -2.9369057579686646`}, {
    1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
    1.725388721703603, 0, -0.9954944040167335}, {
    1.718673024351716, 0, -0.9909494259822538}, {
    1.6118804446194999`, 0, -0.9182002038196536}, {
    1.4409874136332306`, 0, -0.7995372106680627}, {
    1.3907416440578844`, 0, -0.7639939509577008}, {
    0.8227119661869545, 0, -0.3039639273157513}, {
    1.5524139631453664`, 0, -0.8772470256936915}, {
    1.4878419030766432`, 0, -0.8323729324650126}, {
    0.7387665844348645, 0, -0.21183826834948005`}, {
    0.662406188381446, 0, -0.11281818794548079`}, {
    1.3361230472899441`, 0, -0.7248463017704736}, {
    1.2764464101216457`, 0, -0.6814598923604779}, {
    1.2099812806247137`, 0, -0.6320752090489039}, {
    1.134997206870873, 0, -0.5749327381569413}, {
    1.081199872382793, 0, -0.5327099016248423}, {
    1.021266517177937, 0, -0.48416946046191073`}, {
    0.971413876995362, 0, -0.44214844769825784`}, {
    0.9159062757702405, 0, -0.39326358347393225`}, {
    1.7898783863789862`, 0, -1.0388652797252398`}, {
    1.8442626335909353`, 0, -1.0752435827807179`}, {
    1.947286990926446, 0, -1.1439092483479993`}, {
    2.0401504131555903`, 0, -1.2053812116282427`}, {
    2.125067595654396, 0, -1.26129724795474}, {
    0.662406188381446, 0, -0.11281818794548079`}, {
    0.7387665844348645, 0, -0.21183826834948005`}, {
    0.8227119661869545, 0, -0.3039639273157513}, {
    2.2144187122442496`, 0, -1.3198912525475186`}, {
    2.296963707944181, 0, -1.3738145056728164`}, {
    2.37373807035286, 0, -1.423798861469403}, {
    2.445777287068956, 0, -1.4705761740760481`}, {
    2.513685408647288, 0, -1.5145666655895709`}, {
    2.578066485642677, 0, -1.5561905581067919`}, {
    2.6815635663987862`, 0, -1.6229604777560462`}, {
    2.777536856480135, 0, -1.684727087890379}, {
    2.867088069313787, 0, -1.742237664932708}, {
    2.951318918326806, 0, -1.7962394853059507`}, {
    3., 0, -1.8274021524617992`}, {
    0.9159062757702405, 0, -0.39326358347393225`}, {
    0.971413876995362, 0, -0.44214844769825784`}, {
    1.021266517177937, 0, -0.48416946046191073`}, {
    1.081199872382793, 0, -0.5327099016248423}, {
    1.134997206870873, 0, -0.5749327381569413}, {
    1.2099812806247137`, 0, -0.6320752090489039}, {
    1.2764464101216457`, 0, -0.6814598923604779}, {
    1.3361230472899441`, 0, -0.7248463017704736}, {
    1.3907416440578844`, 0, -0.7639939509577008}, {
    1.4409874136332306`, 0, -0.7995372106680627}, {
    1.4878419030766432`, 0, -0.8323729324650126}, {
    1.5524139631453664`, 0, -0.8772470256936915}, {
    1.6118804446194999`, 0, -0.9182002038196536}, {
    1.718673024351716, 0, -0.9909494259822538}, {
    1.725388721703603, 0, -0.9954944040167335}, {
    1.7320508075688772`, 0, -1.}, {
    1.7898783863789862`, 0, -1.0388652797252398`}, {
    1.8442626335909353`, 0, -1.0752435827807179`}, {
    1.947286990926446, 0, -1.1439092483479993`}, {
    2.0401504131555903`, 0, -1.2053812116282427`}, {
    2.125067595654396, 0, -1.26129724795474}, {
    2.2144187122442496`, 0, -1.3198912525475186`}, {
    2.296963707944181, 0, -1.3738145056728164`}, {
    2.37373807035286, 0, -1.423798861469403}, {
    2.445777287068956, 0, -1.4705761740760481`}, {
    2.513685408647288, 0, -1.5145666655895709`}, {
    2.578066485642677, 0, -1.5561905581067919`}, {
    2.6815635663987862`, 0, -1.6229604777560462`}, {
    2.777536856480135, 0, -1.684727087890379}, {
    2.867088069313787, 0, -1.742237664932708}, {
    2.951318918326806, 0, -1.7962394853059507`}, {
    3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {RGBColor[1, 0, 0], Thickness[Large], 
      Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165, 
       166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 
       180, 181, 182, 183, 184, 185, 186}], 
      Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238, 
       239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 
       253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266}],
       Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 323, 
       324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 
       338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 
       352, 353, 354, 355, 356}], 
      Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406, 
       407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 420, 
       421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
      Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489, 
       490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 
       504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 
       518, 519, 520, 521, 522}], 
      Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574, 
       575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 
       589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601, 602}],
       Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 647, 
       648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 660, 661, 
       662, 663, 664, 665, 666, 667, 668}], 
      Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715, 
       716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 729, 
       730, 731, 732, 733, 734, 735, 736, 737, 738}], 
      Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792, 
       793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 
       807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820, 
       821, 822}], 
      Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872, 
       873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 886, 
       887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
      Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952, 
       953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 
       967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979, 980, 
       981, 982}], 
      Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027, 
       1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039,
        1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 
       1051, 1052}]}}}],
  ImageSize->{360., 398.91509415194486`},
  ViewAngle->0.369323000539599,
  ViewPoint->{-0.6817129872895182, -3.238505135453937, 0.705231799197455},
  ViewVertical->{-0.07927548879441128, -1.2067832741193865`, 
   0.9120862959411826}]], "Output",
 CellChangeTimes->{3.650749219113619*^9, 3.650749331989985*^9, 
  3.650749363742737*^9, 3.650752171118525*^9, 3.6507525564149942`*^9, 
  3.65092877291286*^9},
 CellID->1025556317]
}, Open  ]],

Cell["\<\
Now create versions of these lines rotated by a set of fixed angles around \
the z-axis:\
\>", "Text",
 CellChangeTimes->{{3.6508096111173477`*^9, 3.650809631620977*^9}},
 CellID->472774026],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fieldLines", "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"n", "=", "10"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"GeometricTransformation", "[", 
        RowBox[{"graphicsComplex3D", ",", 
         RowBox[{"RotationTransform", "[", " ", 
          RowBox[{
           RowBox[{"i", " ", 
            FractionBox[
             RowBox[{"2", "\[Pi]"}], "n"]}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", 
         RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.65074957908152*^9, 3.6507496438940477`*^9}, {
   3.650749687678155*^9, 3.650749691996298*^9}, {3.650749791176577*^9, 
   3.6507498034160357`*^9}, {3.6507521216829977`*^9, 3.6507521510165787`*^9}, 
   3.650752182371057*^9, {3.650752296931576*^9, 3.650752308242537*^9}, 
   3.6507523518083763`*^9},
 CellID->1838132122],

Cell[BoxData[
 Graphics3DBox[{
   GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 
     0}}], GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
         Rational[1, 2], 0}, {
       Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2], 
        Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
      0}}, {{{0.8090169943749475, -0.5877852522924731, 0}, {
       0.5877852522924731, 0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 0}}]], 
   GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
         Rational[1, 2], 0}, {
       Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2], 
        Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
      0}}, {{{0.30901699437494745`, -0.9510565162951535, 0}, {
       0.9510565162951535, 0.30901699437494745`, 0}, {0, 0, 1}}, {0, 0, 0}}]],
    GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 0.01439460885056816},
       {-2.214418712244248, 0, 1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
         Rational[1, 2], 0}, {
       Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2], 
        Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
      0}}, {{{-0.30901699437494745`, -0.9510565162951535, 0}, {
       0.9510565162951535, -0.30901699437494745`, 0}, {0, 0, 1}}, {0, 0, 
      0}}]], GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
         Rational[1, 2], 0}, {
       Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2], 
        Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
      0}}, {{{-0.8090169943749475, -0.5877852522924731, 0}, {
       0.5877852522924731, -0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 0}}]], 
   GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], {{{-1, 0, 0}, {0, -1, 0}, {0, 0, 1}}, {0, 0, 
     0}}], GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (-1 - 5^Rational[1, 2]), 
        Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2],
         0}, {Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
         Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {0, 0, 
       1}}, {0, 0, 
      0}}, {{{-0.8090169943749475, 0.5877852522924731, 
        0}, {-0.5877852522924731, -0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 
      0}}]], GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (1 - 5^Rational[1, 2]), 
        Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2],
         0}, {Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
         Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {0, 0, 
       1}}, {0, 0, 
      0}}, {{{-0.30901699437494745`, 0.9510565162951535, 
        0}, {-0.9510565162951535, -0.30901699437494745`, 0}, {0, 0, 1}}, {0, 
      0, 0}}]], 
   GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (-1 + 5^Rational[1, 2]), 
        Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2],
         0}, {Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
         Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {0, 0, 
       1}}, {0, 0, 
      0}}, {{{0.30901699437494745`, 0.9510565162951535, 
        0}, {-0.9510565162951535, 0.30901699437494745`, 0}, {0, 0, 1}}, {0, 0,
       0}}]], GeometricTransformation3DBox[
    GraphicsComplex3DBox[{{-3.130537568661286, 
       0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
      3.130537568661286, 0, -3.130537568661286}, {
      3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
       0, -2.921677317602578}, {
      3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
       0, -2.7128167720324985`}, {
      3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
       0, -2.5039567948038854`}, {
      3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
       0, -2.295097033065993}, {
      3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
       0, -2.086236465039131}, {
      3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
       0, -1.8773763097100695`}, {
      3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
       0, -1.6685162351998}, {
      3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
       0, -1.4596562572042038`}, {
      3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
       0, -1.2507963461506284`}, {
      3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
       0, -1.041936223608371}, {
      3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
       0, -0.8330759434533528}, {
      3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
       0, -0.6242157544387887}, {
      3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
       0, -0.41535564391335666`}, {
      3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
       0, -0.20649554093176375`}, {
      3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0, 
       0.002364518618382031}, {
      3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 0,
        0.21122426960641416`}, {
      3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
       0.420084340499656}, {
      3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
       0.6289444920976377}, {
      3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
       0.8378048857052963}, {
      3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
       1.0466650823795693`}, {
      3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0, 
       1.2555250660685502`}, {
      3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0, 
       1.4643853688797432`}, {
      3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
       1.6732452160338924`}, {
      3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0, 
       1.8821051589267472`}, {
      3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
       2.090965443684689}, {
      3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
       2.2998253201341337`}, {
      3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
       2.508685733589194}, {
      3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
       2.7175459735685967`}, {
      3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
       2.9264056700410475`}, {
      3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
       0, -3.130537339504675}, {-2.921677807891022, 0, 
       3.1305370558669994`}, {-2.712817080923461, 
       0, -3.130536974188484}, {-2.7128174173885604`, 0, 
       3.1305373968061487`}, {-2.5039568267930163`, 
       0, -3.130537425231945}, {-2.503957489201368, 0, 
       3.130537209614667}, {-2.295097028910262, 
       0, -3.130537036110503}, {-2.2950972031796457`, 0, 
       3.1305370666698744`}, {-2.0862369086887456`, 
       0, -3.130537373390767}, {-2.086237341741301, 0, 
       3.1305373905362677`}, {-1.877376817252445, 
       0, -3.130537078432022}, {-1.8773771478789962`, 0, 
       3.1305371265435973`}, {-1.6685164255069387`, 
       0, -3.130537406220412}, {-1.6685172284583318`, 0, 
       3.1305375229825296`}, {-1.4596565010976184`, 
       0, -3.1305370840047777`}, {-1.45965709466118, 0, 
       3.130537444577338}, {-1.250796149997714, 
       0, -3.1305371254123533`}, {-1.250796917495352, 0, 
       3.13053745922239}, {-1.0419363491434028`, 
       0, -3.130537497475021}, {-1.041937051969674, 0, 
       3.1305374365950276`}, {-0.8330761989646664, 
       0, -3.130537362213028}, {-0.8330768074559518, 0, 
       3.130536985985276}, {-0.6242157734718394, 
       0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
       3.130537483014851}, {-0.4153559761438142, 
       0, -3.130537143179841}, {-0.41535626074844956`, 0, 
       3.130537473691525}, {-0.20649573077243902`, 
       0, -3.130537548539087}, {-0.20649640697687976`, 0, 
       3.1305374356666444`}, {
      0.0023643479114740774`, 0, -3.130537518214238}, {
      0.0023637771202667385`, 0, 3.13053708105499}, {
      0.21122419338323348`, 0, -3.1305370031944597`}, {
      0.2112236418752695, 0, 3.1305372707552364`}, {
      0.42008438856070346`, 0, -3.1305372766429227`}, {
      0.4200841698169882, 0, 3.1305370584579846`}, {
      0.6289447230837969, 0, -3.130537429886283}, {
      0.6289438417320995, 0, 3.130536996033218}, {
      0.8378045957867942, 0, -3.1305374978960168`}, {
      0.8378040829808491, 0, 3.1305370996475386`}, {
      1.046665022832238, 0, -3.130537099569258}, {
      1.046664145199822, 0, 3.1305369771852547`}, {
      1.2555251305977222`, 0, -3.130537224267039}, {
      1.2555244536918693`, 0, 3.130537473480122}, {
      1.4643849759936627`, 0, -3.130537253225875}, {
      1.4643842714197826`, 0, 3.130537187061149}, {
      1.6732452113376968`, 0, -3.1305369930948914`}, {
      1.6732446088627395`, 0, 3.1305370804867585`}, {
      1.8821055475231572`, 0, -3.1305374506867336`}, {
      1.88210498781495, 0, 3.1305373036961095`}, {
      2.090965273950892, 0, -3.130537467367118}, {
      2.0909649422690633`, 0, 3.1305374831424944`}, {
      2.2998256616900288`, 0, -3.130537536343731}, {
      2.2998249211187307`, 0, 3.130537380722143}, {
      2.5086854243175987`, 0, -3.130537470390545}, {
      2.508684970328931, 0, 3.1305370638713677`}, {
      2.7175456716869593`, 0, -3.1305375653067644`}, {
      2.71754509998356, 0, 3.130537234053713}, {
      2.926406069752153, 0, -3.1305372014198976`}, {
      2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
      1.0043595468930577`, 0, -6.650612064757262*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {
      1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
      1.0806195515694723`, 0, -3.665334079520424*^-17}, {
      1.1105976331738368`, 0, -3.967276376016019*^-17}, {
      1.166956356190518, 0, -6.139780813753298*^-17}, {
      1.2156376741151889`, 0, -6.765852793648817*^-17}, {
      1.2590563515709572`, 0, -6.271035218943372*^-17}, {
      1.3363048228659054`, 0, -5.452038017442776*^-17}, {
      1.403364274626575, 0, -4.795445222401027*^-17}, {
      1.4815748519599594`, 0, -4.083360422996936*^-17}, {
      1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
      1.612879504311111, 0, -2.9681805755008195`*^-17}, {
      1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
      1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
      1.84134370606608, 0, -1.1754437621658815`*^-17}, {
      1.9148458828986261`, 0, -6.254942444948598*^-18}, {
      1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
      1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
      2.076195235867775, 0, 5.460336135267355*^-18}, {
      2.147043324822746, 0, 1.0479341696570644`*^-17}, {
      2.215738531682641, 0, 1.532575023947979*^-17}, {
      2.280127974352383, 0, 1.9826964745600654`*^-17}, {
      2.3982589319433854`, 0, 2.799128138239359*^-17}, {
      2.505127279395825, 0, 3.5289039943105043`*^-17}, {
      2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
      2.7185050675284894`, 0, 4.967095265032991*^-17}, {
      2.8129516459285657`, 0, 5.59628657917814*^-17}, {
      2.9012214071255618`, 0, 6.181045092373603*^-17}, {
      2.9841447772569785`, 0, 6.727652057761554*^-17}, {
      3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      0.5903332233721076, 0, 0.00018622420050397358`}, {
      0.591736290908012, 0, 0.002609304785832699}, {
      0.5986583220178219, 0, 0.01439460885056855}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      0.6204952162914082, 0, 0.05021798203501367}, {
      0.6417550470100506, 0, 0.08290994125554355}, {
      0.6624061883814435, 0, 0.11281818794547716`}, {
      0.7387665844348641, 0, 0.2118382683494796}, {
      0.8227119661869544, 0, 0.3039639273157512}, {
      0.9159062757702401, 0, 0.39326358347393187`}, {
      0.9714138769953617, 0, 0.44214844769825756`}, {
      1.0212665171779367`, 0, 0.4841694604619104}, {
      1.0811998723827927`, 0, 0.532709901624842}, {
      1.1349972068708725`, 0, 0.574932738156941}, {
      1.2099812806247134`, 0, 0.6320752090489036}, {
      1.2764464101216455`, 0, 0.6814598923604777}, {
      1.3361230472899441`, 0, 0.7248463017704734}, {
      1.3907416440578844`, 0, 0.7639939509577007}, {
      1.4409874136332306`, 0, 0.7995372106680626}, {
      1.4878419030766432`, 0, 0.8323729324650125}, {
      1.5524139631453666`, 0, 0.8772470256936915}, {
      1.6118804446194999`, 0, 0.9182002038196535}, {
      1.718673024351716, 0, 0.9909494259822538}, {
      1.725388721703603, 0, 0.9954944040167335}, {
      1.7320508075688772`, 0, 1.}, {
      1.7898783863789862`, 0, 1.0388652797252398`}, {
      1.8442626335909353`, 0, 1.0752435827807179`}, {
      1.947286990926446, 0, 1.1439092483479993`}, {
      2.04015041315559, 0, 1.2053812116282425`}, {
      2.125067595654395, 0, 1.2612972479547397`}, {
      2.214418712244248, 0, 1.3198912525475182`}, {
      2.29696370794418, 0, 1.3738145056728164`}, {
      2.373738070352859, 0, 1.423798861469403}, {
      2.445777287068955, 0, 1.4705761740760481`}, {
      2.5136854086472873`, 0, 1.514566665589571}, {
      2.578066485642676, 0, 1.556190558106792}, {
      2.6815635663987853`, 0, 1.6229604777560467`}, {
      2.7775368564801344`, 0, 1.6847270878903797`}, {
      2.8670880693137866`, 0, 1.7422376649327087`}, {
      2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
      1., 0, 1.7320508075688772`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      0.2864163468618862, 0, 0.0008305267310371494}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      0.28791933124367225`, 0, 0.007206042434050243}, {
      0.293881511672543, 0, 0.03202421727833343}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.6543862314462106`, 0, 3.}, {
      0.30556128145229333`, 0, 0.07870830025830584}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      0.3169113191400581, 0, 0.12182369217421189`}, {
      0.32792783785037954`, 0, 0.161808507688534}, {
      0.3490020511159586, 0, 0.2345412716938603}, {
      0.36883015785401224`, 0, 0.2986906238609892}, {
      0.3931050578910148, 0, 0.3726162571212509}, {
      0.4156368767851654, 0, 0.43764204466468926`}, {
      0.4434048237381806, 0, 0.513867106591227}, {
      0.46888764804285155`, 0, 0.5808380879020639}, {
      0.5004576972760991, 0, 0.6605211679656938}, {
      0.5291745023898358, 0, 0.7305383373006455}, {
      0.5648417309751376, 0, 0.814760931317141}, {
      0.5970796194351795, 0, 0.888850968008553}, {
      0.6373562226070177, 0, 0.9791226748340147}, {
      0.6735929103529877, 0, 1.0586429229314482`}, {
      0.7175244013663284, 0, 1.1531959892477461`}, {
      0.7570562324594531, 0, 1.2369304970405355`}, {
      0.7929935274196624, 0, 1.312005646226944}, {
      0.8261414100342576, 0, 1.3805806367241007`}, {
      0.8568456407650447, 0, 1.4435271823540774`}, {
      0.8856079680040274, 0, 1.5020983847364007`}, {
      0.9425085457322113, 0, 1.6170405957285525`}, {
      0.993495492386544, 0, 1.7190888665612158`}, {
      0.9967579511289973, 0, 1.725591665960026}, {
      1., 0, 1.7320508075688772`}, {
      1.033892835459149, 0, 1.7992392055814181`}, {
      1.0658596651224108`, 0, 1.862362914247072}, {
      1.0970139405446213`, 0, 1.9237916583215942`}, {
      1.1265431074847296`, 0, 1.9818304732138543`}, {
      1.181446280919145, 0, 2.0893008800543185`}, {
      1.231780095058521, 0, 2.1873864682851996`}, {
      1.2851334594623443`, 0, 2.2909888522280237`}, {
      1.334475408728814, 0, 2.3864830347778727`}, {
      1.3804065537208814`, 0, 2.475115327700833}, {
      1.4235275053014986`, 0, 2.5581320427629906`}, {
      1.4641925040528287`, 0, 2.6362581657929063`}, {
      1.5027557905570348`, 0, 2.7102186826191397`}, {
      1.5340502938297416`, 0, 2.770154325248319}, {
      1.5642383005785114`, 0, 2.827914052016298}, {
      1.5933198108033446`, 0, 2.8834978629230776`}, {
      1.621294824504241, 0, 2.936905757968656}, {
      1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
      0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
      0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
      0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
      0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
      0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
      0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
      0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
      0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
      0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
      0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
      0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
      0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
      0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
      0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
      0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
      0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
      0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
      0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
      0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
      0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
      0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
      0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
      0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
      0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
      0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
      0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
      0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
      0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
      0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
      0., 0, 2.9165393169096525`}, {
      0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.3055612814522936, 0, 
       0.07870830025830647}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.033892835459149, 0, 
       1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-0.28641634686188555`, 0, 
       0.0008305267309944116}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-0.28791933124367247`, 0, 
       0.007206042434050176}, {-0.2938815116725432, 0, 
       0.032024217278333975`}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
       0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-0.3169113191400585, 0, 
       0.12182369217421259`}, {-0.32792783785038, 0, 
       0.16180850768853478`}, {-0.34900205111595906`, 0, 
       0.2345412716938608}, {-0.36883015785401285`, 0, 
       0.29869062386099027`}, {-0.39310505789101535`, 0, 
       0.3726162571212519}, {-0.41563687678516603`, 0, 
       0.43764204466469026`}, {-0.44340482373818135`, 0, 
       0.5138671065912283}, {-0.4688876480428522, 0, 
       0.5808380879020649}, {-0.5004576972761, 0, 
       0.6605211679656953}, {-0.5291745023898367, 0, 
       0.7305383373006471}, {-0.5648417309751385, 0, 
       0.8147609313171424}, {-0.5970796194351806, 0, 
       0.8888509680085548}, {-0.637356222607019, 0, 
       0.9791226748340169}, {-0.6735929103529891, 0, 
       1.0586429229314507`}, {-0.7175244013663296, 0, 
       1.153195989247748}, {-0.757056232459454, 0, 
       1.2369304970405368`}, {-0.7929935274196632, 0, 
       1.3120056462269452`}, {-0.8261414100342581, 0, 
       1.3805806367241011`}, {-0.856845640765045, 0, 
       1.4435271823540776`}, {-0.8856079680040276, 0, 
       1.5020983847364007`}, {-0.9425085457322114, 0, 
       1.6170405957285525`}, {-0.993495492386544, 0, 
       1.7190888665612158`}, {-0.9967579511289973, 0, 
       1.725591665960026}, {-1., 0, 1.7320508075688772`}, {-1.033892835459149,
        0, 1.7992392055814184`}, {-1.0658596651224108`, 0, 
       1.8623629142470723`}, {-1.0970139405446213`, 0, 
       1.923791658321595}, {-1.1265431074847296`, 0, 
       1.981830473213855}, {-1.1814462809191453`, 0, 
       2.08930088005432}, {-1.2317800950585212`, 0, 
       2.187386468285201}, {-1.2851334594623451`, 0, 
       2.2909888522280264`}, {-1.334475408728815, 0, 
       2.386483034777876}, {-1.3804065537208827`, 0, 
       2.4751153277008364`}, {-1.4235275053015006`, 0, 
       2.558132042762995}, {-1.464192504052831, 0, 
       2.6362581657929107`}, {-1.5027557905570372`, 0, 
       2.710218682619145}, {-1.5340502938297444`, 0, 
       2.7701543252483254`}, {-1.564238300578515, 0, 
       2.8279140520163057`}, {-1.5933198108033488`, 0, 
       2.8834978629230865`}, {-1.6212948245042456`, 0, 
       2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`, 
       0, 1.}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.5986583220178213, 0, 
       0.01439460885056816}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-0.5903332233721628, 0, 
       0.00018622419983990517`}, {-0.5917362909080106, 0, 
       0.0026093047858313954`}, {-0.5986583220178213, 0, 0.01439460885056816},
       {-2.214418712244248, 0, 1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 
       1.8274021524617996`}, {-0.6204952162914079, 0, 
       0.05021798203501361}, {-0.6417550470100504, 0, 
       0.08290994125554342}, {-0.6624061883814434, 0, 
       0.1128181879454771}, {-0.7387665844348641, 0, 
       0.21183826834947966`}, {-0.8227119661869543, 0, 
       0.3039639273157513}, {-0.9159062757702401, 0, 
       0.39326358347393203`}, {-0.9714138769953617, 0, 
       0.4421484476982577}, {-1.0212665171779367`, 0, 
       0.48416946046191056`}, {-1.0811998723827925`, 0, 
       0.532709901624842}, {-1.1349972068708725`, 0, 
       0.5749327381569411}, {-1.2099812806247134`, 0, 
       0.6320752090489037}, {-1.2764464101216455`, 0, 
       0.6814598923604778}, {-1.3361230472899441`, 0, 
       0.7248463017704735}, {-1.3907416440578844`, 0, 
       0.7639939509577008}, {-1.4409874136332306`, 0, 
       0.7995372106680628}, {-1.4878419030766432`, 0, 
       0.8323729324650128}, {-1.5524139631453666`, 0, 
       0.8772470256936917}, {-1.6118804446194999`, 0, 
       0.9182002038196536}, {-1.718673024351716, 0, 
       0.9909494259822538}, {-1.725388721703603, 0, 
       0.9954944040167335}, {-1.7320508075688772`, 0, 
       1.}, {-1.7898783863789862`, 0, 
       1.0388652797252398`}, {-1.8442626335909353`, 0, 
       1.0752435827807179`}, {-1.947286990926446, 0, 
       1.1439092483479991`}, {-2.04015041315559, 0, 
       1.2053812116282423`}, {-2.125067595654395, 0, 
       1.2612972479547395`}, {-2.214418712244248, 0, 
       1.3198912525475177`}, {-2.296963707944179, 0, 
       1.3738145056728155`}, {-2.373738070352858, 0, 
       1.4237988614694022`}, {-2.4457772870689536`, 0, 
       1.4705761740760468`}, {-2.5136854086472855`, 0, 
       1.5145666655895695`}, {-2.578066485642674, 0, 
       1.5561905581067903`}, {-2.681563566398782, 0, 
       1.622960477756044}, {-2.7775368564801304`, 0, 
       1.6847270878903766`}, {-2.867088069313782, 0, 
       1.7422376649327054`}, {-2.9513189183268005`, 0, 
       1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
       0.}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-0.9854765117057152, 
       0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-0.9891719542270405, 
       0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
       0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.0466835174016902`, 
       0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
       0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
       0, -3.967276376016036*^-17}, {-1.166956356190519, 
       0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
       0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
       0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
       0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
       0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
       0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
       0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
       0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
       0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
       0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
       0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
       0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
       0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
       0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
       5.460336135267359*^-18}, {-2.147043324822746, 0, 
       1.047934169657065*^-17}, {-2.215738531682641, 0, 
       1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
       1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
       2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
       3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
       4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
       4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
       5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
       6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
       6.727652057761554*^-17}, {-3., 0, 
       6.831739988578082*^-17}, {-1.7320508075688772`, 
       0, -1.}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-0.6624061883814446, 
       0, -0.11281818794547861`}, {-0.7387665844348644, 
       0, -0.21183826834947977`}, {-0.8227119661869541, 
       0, -0.30396392731575067`}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 
       0, -1.827402152461799}, {-0.9159062757702402, 
       0, -0.39326358347393187`}, {-0.9714138769953617, 
       0, -0.44214844769825756`}, {-1.0212665171779367`, 
       0, -0.48416946046191034`}, {-1.081199872382793, 
       0, -0.532709901624842}, {-1.1349972068708727`, 
       0, -0.574932738156941}, {-1.2099812806247137`, 
       0, -0.6320752090489037}, {-1.2764464101216457`, 
       0, -0.6814598923604778}, {-1.3361230472899444`, 
       0, -0.7248463017704735}, {-1.3907416440578846`, 
       0, -0.7639939509577008}, {-1.4409874136332308`, 
       0, -0.7995372106680627}, {-1.4878419030766434`, 
       0, -0.8323729324650126}, {-1.5524139631453668`, 
       0, -0.8772470256936916}, {-1.6118804446195, 
       0, -0.9182002038196536}, {-1.718673024351716, 
       0, -0.9909494259822538}, {-1.725388721703603, 
       0, -0.9954944040167335}, {-1.7320508075688772`, 
       0, -1.}, {-1.7898783863789862`, 
       0, -1.0388652797252398`}, {-1.8442626335909351`, 
       0, -1.0752435827807179`}, {-1.947286990926446, 
       0, -1.1439092483479993`}, {-2.0401504131555903`, 
       0, -1.2053812116282427`}, {-2.125067595654396, 
       0, -1.26129724795474}, {-2.2144187122442487`, 
       0, -1.3198912525475177`}, {-2.29696370794418, 
       0, -1.3738145056728157`}, {-2.373738070352859, 
       0, -1.4237988614694024`}, {-2.4457772870689545`, 
       0, -1.470576174076047}, {-2.5136854086472864`, 
       0, -1.5145666655895698`}, {-2.5780664856426747`, 
       0, -1.5561905581067905`}, {-2.6815635663987827`, 
       0, -1.6229604777560442`}, {-2.7775368564801313`, 
       0, -1.6847270878903766`}, {-2.867088069313783, 
       0, -1.7422376649327052`}, {-2.951318918326801, 
       0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
       0, -1.7320508075688772`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-0.30556128145229344`, 
       0, -0.07870830025830548}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-0.3169113191400583, 
       0, -0.1218236921742118}, {-0.3279278378503798, 
       0, -0.1618085076885341}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.6543862314462108`, 
       0, -3.}, {-0.34900205111595917`, 
       0, -0.2345412716938612}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-0.36883015785401274`, 
       0, -0.29869062386098993`}, {-0.39310505789101524`, 
       0, -0.37261625712125157`}, {-0.4156368767851659, 
       0, -0.4376420446646899}, {-0.44340482373818113`, 
       0, -0.5138671065912279}, {-0.468887648042852, 
       0, -0.5808380879020645}, {-0.5004576972760997, 
       0, -0.6605211679656946}, {-0.5291745023898363, 
       0, -0.7305383373006464}, {-0.5648417309751381, 
       0, -0.8147609313171418}, {-0.5970796194351801, 
       0, -0.8888509680085538}, {-0.6373562226070184, 
       0, -0.9791226748340157}, {-0.6735929103529886, 
       0, -1.0586429229314496`}, {-0.7175244013663291, 
       0, -1.153195989247747}, {-0.7570562324594537, 
       0, -1.2369304970405361`}, {-0.7929935274196629, 
       0, -1.3120056462269445`}, {-0.826141410034258, 
       0, -1.380580636724101}, {-0.856845640765045, 
       0, -1.4435271823540774`}, {-0.8856079680040276, 
       0, -1.5020983847364007`}, {-0.9425085457322114, 
       0, -1.6170405957285525`}, {-0.993495492386544, 
       0, -1.7190888665612158`}, {-0.9967579511289973, 
       0, -1.725591665960026}, {-1., 
       0, -1.7320508075688772`}, {-1.033892835459149, 
       0, -1.7992392055814181`}, {-1.0658596651224108`, 
       0, -1.862362914247072}, {-1.0970139405446213`, 
       0, -1.9237916583215942`}, {-1.1265431074847296`, 
       0, -1.9818304732138543`}, {-1.181446280919145, 
       0, -2.0893008800543185`}, {-1.231780095058521, 
       0, -2.1873864682851996`}, {-1.2851334594623438`, 
       0, -2.290988852228023}, {-1.3344754087288135`, 
       0, -2.386483034777872}, {-1.380406553720881, 
       0, -2.4751153277008315`}, {-1.423527505301498, 
       0, -2.558132042762989}, {-1.4641925040528276`, 
       0, -2.6362581657929036`}, {-1.5027557905570337`, 
       0, -2.710218682619137}, {-1.534050293829741, 
       0, -2.7701543252483174`}, {-1.5642383005785114`, 
       0, -2.8279140520162973`}, {-1.5933198108033446`, 
       0, -2.8834978629230763`}, {-1.6212948245042413`, 
       0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
      0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
      0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
      0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
      0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
      0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
      0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
      0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
      0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
      0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
      0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
      0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
      0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
      0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
      0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
      0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
      0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
      0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
      0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
      0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
      0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
      0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
      0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
      0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
      0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
      0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
      0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
      0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
      0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
      0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
      0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
      0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
      0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
      0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
      0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
      0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
      1., 0, -1.7320508075688772`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      0.3055612814522934, 0, -0.07870830025830602}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      0.3169113191400582, 0, -0.12182369217421207`}, {
      0.32792783785037966`, 0, -0.16180850768853416`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.6543862314462103`, 0, -3.}, {
      0.3490020511159587, 0, -0.2345412716938604}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      0.3688301578540124, 0, -0.29869062386098927`}, {
      0.3931050578910148, 0, -0.37261625712125057`}, {
      0.4156368767851656, 0, -0.4376420446646893}, {
      0.4434048237381808, 0, -0.5138671065912273}, {
      0.46888764804285166`, 0, -0.5808380879020638}, {
      0.5004576972760993, 0, -0.6605211679656939}, {
      0.529174502389836, 0, -0.7305383373006457}, {
      0.5648417309751377, 0, -0.8147609313171408}, {
      0.5970796194351797, 0, -0.888850968008553}, {
      0.637356222607018, 0, -0.9791226748340147}, {
      0.673592910352988, 0, -1.0586429229314485`}, {
      0.7175244013663287, 0, -1.1531959892477464`}, {
      0.7570562324594533, 0, -1.2369304970405357`}, {
      0.7929935274196626, 0, -1.312005646226944}, {
      0.8261414100342577, 0, -1.3805806367241007`}, {
      0.8568456407650448, 0, -1.4435271823540774`}, {
      0.8856079680040275, 0, -1.5020983847364007`}, {
      0.9425085457322114, 0, -1.6170405957285525`}, {
      0.993495492386544, 0, -1.7190888665612158`}, {
      0.9967579511289973, 0, -1.725591665960026}, {
      1., 0, -1.7320508075688772`}, {
      1.033892835459149, 0, -1.7992392055814184`}, {
      1.0658596651224108`, 0, -1.8623629142470721`}, {
      1.0970139405446215`, 0, -1.9237916583215946`}, {
      1.1265431074847299`, 0, -1.9818304732138547`}, {
      1.1814462809191455`, 0, -2.0893008800543194`}, {
      1.2317800950585214`, 0, -2.1873864682852004`}, {
      1.2851334594623456`, 0, -2.2909888522280264`}, {
      1.3344754087288155`, 0, -2.3864830347778763`}, {
      1.3804065537208836`, 0, -2.4751153277008373`}, {
      1.4235275053015013`, 0, -2.558132042762996}, {
      1.4641925040528316`, 0, -2.636258165792912}, {
      1.5027557905570381`, 0, -2.7102186826191463`}, {
      1.5340502938297451`, 0, -2.7701543252483263`}, {
      1.564238300578515, 0, -2.8279140520163057`}, {
      1.5933198108033484`, 0, -2.883497862923085}, {
      1.6212948245042451`, 0, -2.9369057579686646`}, {
      1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      0.662406188381446, 0, -0.11281818794548079`}, {
      0.7387665844348645, 0, -0.21183826834948005`}, {
      0.8227119661869545, 0, -0.3039639273157513}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}, {
      0.9159062757702405, 0, -0.39326358347393225`}, {
      0.971413876995362, 0, -0.44214844769825784`}, {
      1.021266517177937, 0, -0.48416946046191073`}, {
      1.081199872382793, 0, -0.5327099016248423}, {
      1.134997206870873, 0, -0.5749327381569413}, {
      1.2099812806247137`, 0, -0.6320752090489039}, {
      1.2764464101216457`, 0, -0.6814598923604779}, {
      1.3361230472899441`, 0, -0.7248463017704736}, {
      1.3907416440578844`, 0, -0.7639939509577008}, {
      1.4409874136332306`, 0, -0.7995372106680627}, {
      1.4878419030766432`, 0, -0.8323729324650126}, {
      1.5524139631453664`, 0, -0.8772470256936915}, {
      1.6118804446194999`, 0, -0.9182002038196536}, {
      1.718673024351716, 0, -0.9909494259822538}, {
      1.725388721703603, 0, -0.9954944040167335}, {
      1.7320508075688772`, 0, -1.}, {
      1.7898783863789862`, 0, -1.0388652797252398`}, {
      1.8442626335909353`, 0, -1.0752435827807179`}, {
      1.947286990926446, 0, -1.1439092483479993`}, {
      2.0401504131555903`, 0, -1.2053812116282427`}, {
      2.125067595654396, 0, -1.26129724795474}, {
      2.2144187122442496`, 0, -1.3198912525475186`}, {
      2.296963707944181, 0, -1.3738145056728164`}, {
      2.37373807035286, 0, -1.423798861469403}, {
      2.445777287068956, 0, -1.4705761740760481`}, {
      2.513685408647288, 0, -1.5145666655895709`}, {
      2.578066485642677, 0, -1.5561905581067919`}, {
      2.6815635663987862`, 0, -1.6229604777560462`}, {
      2.777536856480135, 0, -1.684727087890379}, {
      2.867088069313787, 0, -1.742237664932708}, {
      2.951318918326806, 0, -1.7962394853059507`}, {
      3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
       {RGBColor[1, 0, 0], Thickness[Large], 
        Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 165,
          166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 
         179, 180, 181, 182, 183, 184, 185, 186}], 
        Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 238,
          239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 
         252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265,
          266}], Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 
         322, 323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335,
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
         349, 350, 351, 352, 353, 354, 355, 356}], 
        Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 406,
          407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 419, 
         420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 432}], 
        Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 488, 489,
          490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 
         503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516,
          517, 518, 519, 520, 521, 522}], 
        Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 574,
          575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 
         588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600, 601,
          602}], Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 
         646, 647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659,
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
        Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 715,
          716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 728, 
         729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
        Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 792,
          793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 
         806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819,
          820, 821, 822}], 
        Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 872,
          873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 885, 
         886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 898}], 
        Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 951, 952,
          953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 964, 965, 
         966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 977, 978, 979,
          980, 981, 982}], 
        Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 1027,
          1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 1038, 
         1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 
         1050, 1051, 1052}]}}}], 
    NCache[{{{
       Rational[1, 4] (1 + 5^Rational[1, 2]), 
        Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2],
         0}, {Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
         Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {0, 0, 
       1}}, {0, 0, 
      0}}, {{{0.8090169943749475, 0.5877852522924731, 
        0}, {-0.5877852522924731, 0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 
      0}}]]},
  ImageSize->{360., 390.69293666342895`},
  ViewAngle->0.47030072394368955`,
  ViewPoint->{-0.8507066507753469, -2.6059420094074732`, 1.983775299254414},
  ViewVertical->{-0.05599433283620356, -0.010644110159987601`, 
   0.9983797656792073}]], "Output",
 CellChangeTimes->{3.650749692780053*^9, 3.650749805197565*^9, 
  3.65075196893659*^9, 3.650752153722468*^9, 3.650752184780786*^9, 
  3.65075230885288*^9, 3.650752570714946*^9, 3.65080822830833*^9, 
  3.650928798794277*^9},
 CellID->1190633310]
}, Open  ]],

Cell["Create a disk to place in this and other graphics:", "Text",
 CellChangeTimes->{{3.650809635340653*^9, 3.650809649283799*^9}, {
  3.65093010742603*^9, 3.650930109952098*^9}},
 CellID->651085393],

Cell[BoxData[
 RowBox[{
  RowBox[{"revolutionDisk", "[", 
   RowBox[{"zCoord_", ",", "opacity_"}], "]"}], ":=", 
  RowBox[{"RevolutionPlot3D", "[", 
   RowBox[{"zCoord", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "x", ",", "y", ",", "z", ",", "t", ",", "\[Theta]", ",", "r"}], "}"}],
        ",", 
       RowBox[{"Blend", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Darker", "[", 
            RowBox[{"Blue", ",", "0"}], "]"}]}], "}"}], ",", 
         RowBox[{"Rescale", "[", 
          RowBox[{
           SqrtBox[
            RowBox[{"1", "-", 
             SuperscriptBox["r", "2"]}]], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], ",", 
    
    RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
    RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{"Opacity", "[", "opacity", "]"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.650751586671492*^9, {3.65075162596402*^9, 3.6507516323959417`*^9}, {
   3.650751664932559*^9, 3.6507517004653797`*^9}, {3.6507517357988787`*^9, 
   3.6507517543910847`*^9}, 3.650751988407057*^9, {3.650930080380415*^9, 
   3.650930081081628*^9}, {3.650931447609666*^9, 3.6509314484878674`*^9}, {
   3.650931621636223*^9, 3.650931629106642*^9}, {3.65093166203267*^9, 
   3.650931665812172*^9}, {3.6509317383194847`*^9, 3.650931750785306*^9}},
 CellID->1495100134],

Cell[BoxData[
 RowBox[{
  RowBox[{"revolutionDisk", "[", "]"}], ":=", 
  RowBox[{"revolutionDisk", "[", 
   RowBox[{"0", ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650931457624112*^9, 3.650931463687875*^9}, {
  3.650931755726544*^9, 3.650931756021132*^9}},
 CellID->2003832896],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"revolutionDisk", "[", "]"}]], "Input",
 CellID->1569375231],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxM3Hc01+//+HEjK5E9iyRFO6slly0ZRRkpKxmRBkWpkIaZnWSPkOy9XVb2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   "], {
    {RGBColor[0.880722, 0.611041, 0.142051], Opacity[1], EdgeForm[None], 
     Specularity[
      GrayLevel[1], 3], 
     StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxVnXXYldXzd0+H3S12t4JISAlIiKiIghgoNiIiWJggiKAYKCgiiIWCiAEq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        "]]],
      Lighting->"Neutral"]}, {}, {}, {}, {}},
   VertexColors->{
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.300145787776235, 0.300145787776235, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.300145787776235, 0.300145787776235, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
     RGBColor[0.300145787776235, 0.300145787776235, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
     RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
     RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
     RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
     RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.4523915157143381, 0.4523915157143381, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977495`, 0.20933181110977495`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
     RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
     RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
     RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.300145787776235, 0.300145787776235, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
     RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.3443927181955512, 0.3443927181955512, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
     RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
     RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
     RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
     RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
     RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
     RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
     RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.655470550691142, 0.655470550691142, 1.], 
     RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
     RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
     RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
     RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
     RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
     RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
     RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
     RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
     RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
     RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
     RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
     RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
     RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
     RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
     RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
     RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
     RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
     RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
     RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
     RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
     RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
     RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
     RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
     RGBColor[0.128162883130864, 0.128162883130864, 1.], 
     RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
     RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
     RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
     RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
     RGBColor[0.193942136402796, 0.193942136402796, 1.], 
     RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
     RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
     RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
     RGBColor[0.26078488668266, 0.26078488668266, 1.], 
     RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
     RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
     RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
     RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
     RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
     RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
     RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
     RGBColor[0.452391515714338, 0.452391515714338, 1.], 
     RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
     RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
     RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
     RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
     RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
     RGBColor[0.717216194682635, 0.717216194682635, 1.], 
     RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
     RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
     RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
     RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
     RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
     RGBColor[0.899113673809771, 0.899113673809771, 1.], 
     RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
     RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
     RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
     RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
     RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
     RGBColor[1., 1., 1.], 
     RGBColor[0., 0., 1.], 
     RGBColor[0.8991136738097699, 0.8991136738097699, 1.]},
   VertexNormals->CompressedData["
1:eJztzrsJgEAQBNBBI8uwEnuwBMHYFizUIizBwEjksvMTvEkG3sIy/bSMc5Nk
65I2t6xn7QPnnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeec
v+zhnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc84555xz
zjnnnHPOOeecc84555xzzjnnnHPOOeecc875b33lnHPOOeecc84555xzzjnn
nHPOOeecc84555xzzjnnnHPOOeec848813t1r7Wz5E/v8b/gB/iCRMo=
    "],
   VertexTextureCoordinates->CompressedData["
1:eJxl3UHILeddx/FBcKGIoZCFuClCNy7ERaVYWnrBrrpx0W5cSWloMaAIkoUb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    "]],
  BoxRatios->NCache[{2, 2, GoldenRatio^(-1)}, {2, 2, 0.6180339887498948}],
  Boxed->False,
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->{360., 275.780717113733},
  Lighting->"Neutral",
  Method->{},
  PlotRange->{{-0.9979453725517695, 0.9999999795918285}, {-0.9994861978999049,
    0.999486197899905}, {-1., 1.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewAngle->0.41127078893490043`,
  ViewPoint->{1.3, -2.4, 2.},
  ViewVertical->{0., 0., 3.23606797749979}]], "Output",
 CellChangeTimes->{
  3.65093008993664*^9, {3.65093063563875*^9, 3.650930642567492*^9}, 
   3.650931758463642*^9},
 CellID->1007470130]
}, Open  ]],

Cell["Finally combine the two to have a 3-dimensional view:", "Text",
 CellChangeTimes->{{3.650809653923799*^9, 3.65080966698733*^9}},
 CellID->331238253],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"fieldLines", ",", 
   RowBox[{"revolutionDisk", "[", "]"}], ",", 
   RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6507497365473146`*^9, 3.650749774209126*^9}, 
   3.650749831070259*^9, 3.65075192162956*^9, {3.650811561226235*^9, 
   3.650811561335844*^9}, {3.650928826104348*^9, 3.650928826646329*^9}, {
   3.650930093994824*^9, 3.6509300941097603`*^9}},
 CellID->187545162],

Cell[BoxData[
 Graphics3DBox[{{
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {
      0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 + 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{0.8090169943749475, -0.5877852522924731, 0}, {
        0.5877852522924731, 0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 + 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{0.30901699437494745`, -0.9510565162951535, 0}, {
        0.9510565162951535, 0.30901699437494745`, 0}, {0, 0, 1}}, {0, 0, 
       0}}]], GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 - 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{-0.30901699437494745`, -0.9510565162951535, 0}, {
        0.9510565162951535, -0.30901699437494745`, 0}, {0, 0, 1}}, {0, 0, 
       0}}]], GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 - 5^Rational[1, 2]), 
         Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^Rational[1, 2],
          Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {0, 0, 1}}, {0, 0, 
       0}}, {{{-0.8090169943749475, -0.5877852522924731, 0}, {
        0.5877852522924731, -0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 0}}]],
     GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], {{{-1, 0, 0}, {0, -1, 0}, {0, 0, 
      1}}, {0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 - 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (-1 - 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{-0.8090169943749475, 0.5877852522924731, 
         0}, {-0.5877852522924731, -0.8090169943749475, 0}, {0, 0, 1}}, {0, 0,
        0}}]], GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 - 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (1 - 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{-0.30901699437494745`, 0.9510565162951535, 
         0}, {-0.9510565162951535, -0.30901699437494745`, 0}, {0, 0, 1}}, {0, 
       0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (-1 + 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 + 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (-1 + 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{0.30901699437494745`, 0.9510565162951535, 
         0}, {-0.9510565162951535, 0.30901699437494745`, 0}, {0, 0, 1}}, {0, 
       0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-3.130537568661286, 
        0, -3.130537568661286}, {-3.130537568661286, 0, 3.130537568661286}, {
       3.130537568661286, 0, -3.130537568661286}, {
       3.130537568661286, 0, 3.130537568661286}, {-3.1305371483677833`, 
        0, -2.921677317602578}, {
       3.1305373580566647`, 0, -2.921677906681277}, {-3.130537181169917, 
        0, -2.7128167720324985`}, {
       3.1305369737272666`, 0, -2.712817627840804}, {-3.130537305104754, 
        0, -2.5039567948038854`}, {
       3.130537173917203, 0, -2.503957492858254}, {-3.130537426387069, 
        0, -2.295097033065993}, {
       3.130537258281684, 0, -2.2950972396282774`}, {-3.130537255364865, 
        0, -2.086236465039131}, {
       3.1305374459931805`, 0, -2.0862374158195687`}, {-3.1305372526084554`, 
        0, -1.8773763097100695`}, {
       3.130537321943212, 0, -1.877377022514049}, {-3.1305370404965607`, 
        0, -1.6685162351998}, {
       3.1305372141864454`, 0, -1.6685168175083271`}, {-3.1305370606932303`, 
        0, -1.4596562572042038`}, {
       3.1305371504645154`, 0, -1.4596570566784814`}, {-3.1305370916148902`, 
        0, -1.2507963461506284`}, {
       3.1305370017151954`, 0, -1.2507970014976344`}, {-3.1305370893176803`, 
        0, -1.041936223608371}, {
       3.130537425449025, 0, -1.041937049654423}, {-3.130537516008267, 
        0, -0.8330759434533528}, {
       3.1305371660819152`, 0, -0.8330767041643758}, {-3.1305371288310857`, 
        0, -0.6242157544387887}, {
       3.1305369744376543`, 0, -0.6242168329896248}, {-3.130537059379932, 
        0, -0.41535564391335666`}, {
       3.1305375219911644`, 0, -0.41535667780338986`}, {-3.130536991027317, 
        0, -0.20649554093176375`}, {
       3.1305374707182922`, 0, -0.2064964546340234}, {-3.1305374843484826`, 0,
         0.002364518618382031}, {
       3.1305371991731374`, 0, 0.0023636640978962485`}, {-3.130537505191758, 
        0, 0.21122426960641416`}, {
       3.130537051916788, 0, 0.21122398012357496`}, {-3.130537069862581, 0, 
        0.420084340499656}, {
       3.130537489807642, 0, 0.4200842868537686}, {-3.1305370064002247`, 0, 
        0.6289444920976377}, {
       3.130537484676312, 0, 0.628944203212634}, {-3.130537045623302, 0, 
        0.8378048857052963}, {
       3.130536970615573, 0, 0.8378040737117516}, {-3.130537115345675, 0, 
        1.0466650823795693`}, {
       3.1305373369320613`, 0, 1.0466644887463052`}, {-3.1305370206304324`, 0,
         1.2555250660685502`}, {
       3.1305373942751378`, 0, 1.2555244948965218`}, {-3.1305373927407256`, 0,
         1.4643853688797432`}, {
       3.130537369948559, 0, 1.46438445490921}, {-3.1305374047491195`, 0, 
        1.6732452160338924`}, {
       3.1305374872542258`, 0, 1.6732448487513338`}, {-3.1305369910091367`, 0,
         1.8821051589267472`}, {
       3.1305372135846574`, 0, 1.8821046309520753`}, {-3.130537201892717, 0, 
        2.090965443684689}, {
       3.1305370180497287`, 0, 2.090965105123301}, {-3.1305370098718828`, 0, 
        2.2998253201341337`}, {
       3.1305372759505823`, 0, 2.299824844162981}, {-3.1305371104533806`, 0, 
        2.508685733589194}, {
       3.130537327024188, 0, 2.5086849858850417`}, {-3.130537528133917, 0, 
        2.7175459735685967`}, {
       3.13053746634584, 0, 2.717545240680534}, {-3.1305372893055305`, 0, 
        2.9264056700410475`}, {
       3.1305370281957994`, 0, 2.926405432622351}, {-2.9216768803475537`, 
        0, -3.130537339504675}, {-2.921677807891022, 0, 
        3.1305370558669994`}, {-2.712817080923461, 
        0, -3.130536974188484}, {-2.7128174173885604`, 0, 
        3.1305373968061487`}, {-2.5039568267930163`, 
        0, -3.130537425231945}, {-2.503957489201368, 0, 
        3.130537209614667}, {-2.295097028910262, 
        0, -3.130537036110503}, {-2.2950972031796457`, 0, 
        3.1305370666698744`}, {-2.0862369086887456`, 
        0, -3.130537373390767}, {-2.086237341741301, 0, 
        3.1305373905362677`}, {-1.877376817252445, 
        0, -3.130537078432022}, {-1.8773771478789962`, 0, 
        3.1305371265435973`}, {-1.6685164255069387`, 
        0, -3.130537406220412}, {-1.6685172284583318`, 0, 
        3.1305375229825296`}, {-1.4596565010976184`, 
        0, -3.1305370840047777`}, {-1.45965709466118, 0, 
        3.130537444577338}, {-1.250796149997714, 
        0, -3.1305371254123533`}, {-1.250796917495352, 0, 
        3.13053745922239}, {-1.0419363491434028`, 
        0, -3.130537497475021}, {-1.041937051969674, 0, 
        3.1305374365950276`}, {-0.8330761989646664, 
        0, -3.130537362213028}, {-0.8330768074559518, 0, 
        3.130536985985276}, {-0.6242157734718394, 
        0, -3.1305375175611316`}, {-0.6242165824551741, 0, 
        3.130537483014851}, {-0.4153559761438142, 
        0, -3.130537143179841}, {-0.41535626074844956`, 0, 
        3.130537473691525}, {-0.20649573077243902`, 
        0, -3.130537548539087}, {-0.20649640697687976`, 0, 
        3.1305374356666444`}, {
       0.0023643479114740774`, 0, -3.130537518214238}, {
       0.0023637771202667385`, 0, 3.13053708105499}, {
       0.21122419338323348`, 0, -3.1305370031944597`}, {
       0.2112236418752695, 0, 3.1305372707552364`}, {
       0.42008438856070346`, 0, -3.1305372766429227`}, {
       0.4200841698169882, 0, 3.1305370584579846`}, {
       0.6289447230837969, 0, -3.130537429886283}, {
       0.6289438417320995, 0, 3.130536996033218}, {
       0.8378045957867942, 0, -3.1305374978960168`}, {
       0.8378040829808491, 0, 3.1305370996475386`}, {
       1.046665022832238, 0, -3.130537099569258}, {
       1.046664145199822, 0, 3.1305369771852547`}, {
       1.2555251305977222`, 0, -3.130537224267039}, {
       1.2555244536918693`, 0, 3.130537473480122}, {
       1.4643849759936627`, 0, -3.130537253225875}, {
       1.4643842714197826`, 0, 3.130537187061149}, {
       1.6732452113376968`, 0, -3.1305369930948914`}, {
       1.6732446088627395`, 0, 3.1305370804867585`}, {
       1.8821055475231572`, 0, -3.1305374506867336`}, {
       1.88210498781495, 0, 3.1305373036961095`}, {
       2.090965273950892, 0, -3.130537467367118}, {
       2.0909649422690633`, 0, 3.1305374831424944`}, {
       2.2998256616900288`, 0, -3.130537536343731}, {
       2.2998249211187307`, 0, 3.130537380722143}, {
       2.5086854243175987`, 0, -3.130537470390545}, {
       2.508684970328931, 0, 3.1305370638713677`}, {
       2.7175456716869593`, 0, -3.1305375653067644`}, {
       2.71754509998356, 0, 3.130537234053713}, {
       2.926406069752153, 0, -3.1305372014198976`}, {
       2.9264052418242197`, 0, 3.130537066861553}, {2., 0, 0.}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       0.9853419325513179, 0, -4.9403286698829546`*^-8}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       0.9891719529118894, 0, -3.5829365819913264`*^-13}, {
       1.0043595468930577`, 0, -6.650612064757262*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {
       1.0466835174016895`, 0, -4.3994540970600465`*^-17}, {
       1.0806195515694723`, 0, -3.665334079520424*^-17}, {
       1.1105976331738368`, 0, -3.967276376016019*^-17}, {
       1.166956356190518, 0, -6.139780813753298*^-17}, {
       1.2156376741151889`, 0, -6.765852793648817*^-17}, {
       1.2590563515709572`, 0, -6.271035218943372*^-17}, {
       1.3363048228659054`, 0, -5.452038017442776*^-17}, {
       1.403364274626575, 0, -4.795445222401027*^-17}, {
       1.4815748519599594`, 0, -4.083360422996936*^-17}, {
       1.5508807022070625`, 0, -3.4822798486173895`*^-17}, {
       1.612879504311111, 0, -2.9681805755008195`*^-17}, {
       1.6697463002863682`, 0, -2.5094064021085684`*^-17}, {
       1.7602563204941202`, 0, -1.7967152221747706`*^-17}, {
       1.84134370606608, 0, -1.1754437621658815`*^-17}, {
       1.9148458828986261`, 0, -6.254942444948598*^-18}, {
       1.9826002768881374`, 0, -1.2676889157466468`*^-18}, {
       1.9913420464689446`, 0, -6.302328183019255*^-19}, {2., 0, 0.}, {
       2.076195235867775, 0, 5.460336135267355*^-18}, {
       2.147043324822746, 0, 1.0479341696570644`*^-17}, {
       2.215738531682641, 0, 1.532575023947979*^-17}, {
       2.280127974352383, 0, 1.9826964745600654`*^-17}, {
       2.3982589319433854`, 0, 2.799128138239359*^-17}, {
       2.505127279395825, 0, 3.5289039943105043`*^-17}, {
       2.6163931269945153`, 0, 4.2818435900423725`*^-17}, {
       2.7185050675284894`, 0, 4.967095265032991*^-17}, {
       2.8129516459285657`, 0, 5.59628657917814*^-17}, {
       2.9012214071255618`, 0, 6.181045092373603*^-17}, {
       2.9841447772569785`, 0, 6.727652057761554*^-17}, {
       3., 0, 6.831739988578082*^-17}, {1.7320508075688772`, 0, 1.}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       0.5903332233721076, 0, 0.00018622420050397358`}, {
       0.591736290908012, 0, 0.002609304785832699}, {
       0.5986583220178219, 0, 0.01439460885056855}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       0.6204952162914082, 0, 0.05021798203501367}, {
       0.6417550470100506, 0, 0.08290994125554355}, {
       0.6624061883814435, 0, 0.11281818794547716`}, {
       0.7387665844348641, 0, 0.2118382683494796}, {
       0.8227119661869544, 0, 0.3039639273157512}, {
       0.9159062757702401, 0, 0.39326358347393187`}, {
       0.9714138769953617, 0, 0.44214844769825756`}, {
       1.0212665171779367`, 0, 0.4841694604619104}, {
       1.0811998723827927`, 0, 0.532709901624842}, {
       1.1349972068708725`, 0, 0.574932738156941}, {
       1.2099812806247134`, 0, 0.6320752090489036}, {
       1.2764464101216455`, 0, 0.6814598923604777}, {
       1.3361230472899441`, 0, 0.7248463017704734}, {
       1.3907416440578844`, 0, 0.7639939509577007}, {
       1.4409874136332306`, 0, 0.7995372106680626}, {
       1.4878419030766432`, 0, 0.8323729324650125}, {
       1.5524139631453666`, 0, 0.8772470256936915}, {
       1.6118804446194999`, 0, 0.9182002038196535}, {
       1.718673024351716, 0, 0.9909494259822538}, {
       1.725388721703603, 0, 0.9954944040167335}, {
       1.7320508075688772`, 0, 1.}, {
       1.7898783863789862`, 0, 1.0388652797252398`}, {
       1.8442626335909353`, 0, 1.0752435827807179`}, {
       1.947286990926446, 0, 1.1439092483479993`}, {
       2.04015041315559, 0, 1.2053812116282425`}, {
       2.125067595654395, 0, 1.2612972479547397`}, {
       2.214418712244248, 0, 1.3198912525475182`}, {
       2.29696370794418, 0, 1.3738145056728164`}, {
       2.373738070352859, 0, 1.423798861469403}, {
       2.445777287068955, 0, 1.4705761740760481`}, {
       2.5136854086472873`, 0, 1.514566665589571}, {
       2.578066485642676, 0, 1.556190558106792}, {
       2.6815635663987853`, 0, 1.6229604777560467`}, {
       2.7775368564801344`, 0, 1.6847270878903797`}, {
       2.8670880693137866`, 0, 1.7422376649327087`}, {
       2.951318918326806, 0, 1.7962394853059516`}, {3., 0, 1.8274021524618}, {
       1., 0, 1.7320508075688772`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       0.2864163468618862, 0, 0.0008305267310371494}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       0.28791933124367225`, 0, 0.007206042434050243}, {
       0.293881511672543, 0, 0.03202421727833343}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.6543862314462106`, 0, 3.}, {
       0.30556128145229333`, 0, 0.07870830025830584}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       0.3169113191400581, 0, 0.12182369217421189`}, {
       0.32792783785037954`, 0, 0.161808507688534}, {
       0.3490020511159586, 0, 0.2345412716938603}, {
       0.36883015785401224`, 0, 0.2986906238609892}, {
       0.3931050578910148, 0, 0.3726162571212509}, {
       0.4156368767851654, 0, 0.43764204466468926`}, {
       0.4434048237381806, 0, 0.513867106591227}, {
       0.46888764804285155`, 0, 0.5808380879020639}, {
       0.5004576972760991, 0, 0.6605211679656938}, {
       0.5291745023898358, 0, 0.7305383373006455}, {
       0.5648417309751376, 0, 0.814760931317141}, {
       0.5970796194351795, 0, 0.888850968008553}, {
       0.6373562226070177, 0, 0.9791226748340147}, {
       0.6735929103529877, 0, 1.0586429229314482`}, {
       0.7175244013663284, 0, 1.1531959892477461`}, {
       0.7570562324594531, 0, 1.2369304970405355`}, {
       0.7929935274196624, 0, 1.312005646226944}, {
       0.8261414100342576, 0, 1.3805806367241007`}, {
       0.8568456407650447, 0, 1.4435271823540774`}, {
       0.8856079680040274, 0, 1.5020983847364007`}, {
       0.9425085457322113, 0, 1.6170405957285525`}, {
       0.993495492386544, 0, 1.7190888665612158`}, {
       0.9967579511289973, 0, 1.725591665960026}, {
       1., 0, 1.7320508075688772`}, {
       1.033892835459149, 0, 1.7992392055814181`}, {
       1.0658596651224108`, 0, 1.862362914247072}, {
       1.0970139405446213`, 0, 1.9237916583215942`}, {
       1.1265431074847296`, 0, 1.9818304732138543`}, {
       1.181446280919145, 0, 2.0893008800543185`}, {
       1.231780095058521, 0, 2.1873864682851996`}, {
       1.2851334594623443`, 0, 2.2909888522280237`}, {
       1.334475408728814, 0, 2.3864830347778727`}, {
       1.3804065537208814`, 0, 2.475115327700833}, {
       1.4235275053014986`, 0, 2.5581320427629906`}, {
       1.4641925040528287`, 0, 2.6362581657929063`}, {
       1.5027557905570348`, 0, 2.7102186826191397`}, {
       1.5340502938297416`, 0, 2.770154325248319}, {
       1.5642383005785114`, 0, 2.827914052016298}, {
       1.5933198108033446`, 0, 2.8834978629230776`}, {
       1.621294824504241, 0, 2.936905757968656}, {
       1.6543862314462106`, 0, 3.}, {0., 0, 2.}, {
       0., 0, 1.9930697437687392`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 0.008128783624894702}, {0., 0, 1.8765530604330984`}, {
       0., 0, 1.7547682338914479`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 2.083871100476444}, {0., 0, 1.5209921171515646`}, {
       0., 0, 1.4280897149371465`}, {0., 0, 1.3239104139670337`}, {
       0., 0, 1.2055173116118956`}, {0., 0, 1.1147657980990906`}, {
       0., 0, 1.0122057127579267`}, {0., 0, 0.925918996470587}, {
       0., 0, 0.8280418701008675}, {0., 0, 0.7479807485897318}, {
       0., 0, 0.6572345268975783}, {0., 0, 0.5817771424227749}, {
       0., 0, 0.49631614791155654`}, {0., 0, 0.4243569404846203}, {
       0., 0, 0.34299131720792514`}, {0., 0, 0.2734102546614774}, {
       0., 0, 0.19493582036141505`}, {0., 0, 0.12668644282153832`}, {
       0., 0, 0.04999541458500659}, {0., 0, 2.162405129581069}, {
       0., 0, 2.5639856627704924`}, {0., 0, 0.0013521941910845207`}, {
       0., 0, 0.008128783624894702}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 0.04999541458500659}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {0., 0, 3.}, {
       0., 0, 0.12668644282153832`}, {0., 0, 0.19493582036141505`}, {
       0., 0, 0.2734102546614774}, {0., 0, 0.34299131720792514`}, {
       0., 0, 0.4243569404846203}, {0., 0, 0.49631614791155654`}, {
       0., 0, 0.5817771424227749}, {0., 0, 0.6572345268975783}, {
       0., 0, 0.7479807485897318}, {0., 0, 0.8280418701008675}, {
       0., 0, 0.925918996470587}, {0., 0, 1.0122057127579267`}, {
       0., 0, 1.1147657980990906`}, {0., 0, 1.2055173116118956`}, {
       0., 0, 1.3239104139670337`}, {0., 0, 1.4280897149371465`}, {
       0., 0, 1.5209921171515646`}, {0., 0, 1.6055545232396176`}, {
       0., 0, 1.6829299425553081`}, {0., 0, 1.7547682338914479`}, {
       0., 0, 1.8765530604330984`}, {0., 0, 1.9860968846818443`}, {
       0., 0, 1.9930697437687392`}, {0., 0, 2.}, {0., 0, 2.083871100476444}, {
       0., 0, 2.162405129581069}, {0., 0, 2.2387311107539123`}, {
       0., 0, 2.3106409960631926`}, {0., 0, 2.3786640756418818`}, {
       0., 0, 2.4433296396229536`}, {0., 0, 2.5639856627704924`}, {
       0., 0, 2.691240491879268}, {0., 0, 2.808218810422449}, {
       0., 0, 2.9165393169096525`}, {
       0., 0, 3.}, {-1., 0, 1.7320508075688772`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.3055612814522936, 0, 
        0.07870830025830647}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-0.28641634686188555`, 0, 
        0.0008305267309944116}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-0.28791933124367247`, 0, 
        0.007206042434050176}, {-0.2938815116725432, 0, 
        0.032024217278333975`}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.65438623144621, 0, 3.}, {-0.3055612814522936, 
        0, 0.07870830025830647}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-0.3169113191400585, 0, 
        0.12182369217421259`}, {-0.32792783785038, 0, 
        0.16180850768853478`}, {-0.34900205111595906`, 0, 
        0.2345412716938608}, {-0.36883015785401285`, 0, 
        0.29869062386099027`}, {-0.39310505789101535`, 0, 
        0.3726162571212519}, {-0.41563687678516603`, 0, 
        0.43764204466469026`}, {-0.44340482373818135`, 0, 
        0.5138671065912283}, {-0.4688876480428522, 0, 
        0.5808380879020649}, {-0.5004576972761, 0, 
        0.6605211679656953}, {-0.5291745023898367, 0, 
        0.7305383373006471}, {-0.5648417309751385, 0, 
        0.8147609313171424}, {-0.5970796194351806, 0, 
        0.8888509680085548}, {-0.637356222607019, 0, 
        0.9791226748340169}, {-0.6735929103529891, 0, 
        1.0586429229314507`}, {-0.7175244013663296, 0, 
        1.153195989247748}, {-0.757056232459454, 0, 
        1.2369304970405368`}, {-0.7929935274196632, 0, 
        1.3120056462269452`}, {-0.8261414100342581, 0, 
        1.3805806367241011`}, {-0.856845640765045, 0, 
        1.4435271823540776`}, {-0.8856079680040276, 0, 
        1.5020983847364007`}, {-0.9425085457322114, 0, 
        1.6170405957285525`}, {-0.993495492386544, 0, 
        1.7190888665612158`}, {-0.9967579511289973, 0, 
        1.725591665960026}, {-1., 0, 
        1.7320508075688772`}, {-1.033892835459149, 0, 
        1.7992392055814184`}, {-1.0658596651224108`, 0, 
        1.8623629142470723`}, {-1.0970139405446213`, 0, 
        1.923791658321595}, {-1.1265431074847296`, 0, 
        1.981830473213855}, {-1.1814462809191453`, 0, 
        2.08930088005432}, {-1.2317800950585212`, 0, 
        2.187386468285201}, {-1.2851334594623451`, 0, 
        2.2909888522280264`}, {-1.334475408728815, 0, 
        2.386483034777876}, {-1.3804065537208827`, 0, 
        2.4751153277008364`}, {-1.4235275053015006`, 0, 
        2.558132042762995}, {-1.464192504052831, 0, 
        2.6362581657929107`}, {-1.5027557905570372`, 0, 
        2.710218682619145}, {-1.5340502938297444`, 0, 
        2.7701543252483254`}, {-1.564238300578515, 0, 
        2.8279140520163057`}, {-1.5933198108033488`, 0, 
        2.8834978629230865`}, {-1.6212948245042456`, 0, 
        2.936905757968666}, {-1.65438623144621, 0, 3.}, {-1.7320508075688772`,
         0, 1.}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-0.5903332233721628, 0, 
        0.00018622419983990517`}, {-0.5917362909080106, 0, 
        0.0026093047858313954`}, {-0.5986583220178213, 0, 
        0.01439460885056816}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 
        1.8274021524617996`}, {-0.6204952162914079, 0, 
        0.05021798203501361}, {-0.6417550470100504, 0, 
        0.08290994125554342}, {-0.6624061883814434, 0, 
        0.1128181879454771}, {-0.7387665844348641, 0, 
        0.21183826834947966`}, {-0.8227119661869543, 0, 
        0.3039639273157513}, {-0.9159062757702401, 0, 
        0.39326358347393203`}, {-0.9714138769953617, 0, 
        0.4421484476982577}, {-1.0212665171779367`, 0, 
        0.48416946046191056`}, {-1.0811998723827925`, 0, 
        0.532709901624842}, {-1.1349972068708725`, 0, 
        0.5749327381569411}, {-1.2099812806247134`, 0, 
        0.6320752090489037}, {-1.2764464101216455`, 0, 
        0.6814598923604778}, {-1.3361230472899441`, 0, 
        0.7248463017704735}, {-1.3907416440578844`, 0, 
        0.7639939509577008}, {-1.4409874136332306`, 0, 
        0.7995372106680628}, {-1.4878419030766432`, 0, 
        0.8323729324650128}, {-1.5524139631453666`, 0, 
        0.8772470256936917}, {-1.6118804446194999`, 0, 
        0.9182002038196536}, {-1.718673024351716, 0, 
        0.9909494259822538}, {-1.725388721703603, 0, 
        0.9954944040167335}, {-1.7320508075688772`, 0, 
        1.}, {-1.7898783863789862`, 0, 
        1.0388652797252398`}, {-1.8442626335909353`, 0, 
        1.0752435827807179`}, {-1.947286990926446, 0, 
        1.1439092483479991`}, {-2.04015041315559, 0, 
        1.2053812116282423`}, {-2.125067595654395, 0, 
        1.2612972479547395`}, {-2.214418712244248, 0, 
        1.3198912525475177`}, {-2.296963707944179, 0, 
        1.3738145056728155`}, {-2.373738070352858, 0, 
        1.4237988614694022`}, {-2.4457772870689536`, 0, 
        1.4705761740760468`}, {-2.5136854086472855`, 0, 
        1.5145666655895695`}, {-2.578066485642674, 0, 
        1.5561905581067903`}, {-2.681563566398782, 0, 
        1.622960477756044}, {-2.7775368564801304`, 0, 
        1.6847270878903766`}, {-2.867088069313782, 0, 
        1.7422376649327054`}, {-2.9513189183268005`, 0, 
        1.7962394853059478`}, {-3., 0, 1.8274021524617996`}, {-2., 0, 
        0.}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-0.9854765117057152, 
        0, -3.3840342379587585`*^-8}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-0.9891719542270405, 
        0, -3.5829325563025395`*^-13}, {-1.0043595468930584`, 
        0, -6.650612064757136*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.0466835174016902`, 
        0, -4.399454097060058*^-17}, {-1.0806195515694732`, 
        0, -3.6653340795204423`*^-17}, {-1.1105976331738379`, 
        0, -3.967276376016036*^-17}, {-1.166956356190519, 
        0, -6.139780813753298*^-17}, {-1.2156376741151895`, 
        0, -6.765852793648815*^-17}, {-1.2590563515709576`, 
        0, -6.27103521894337*^-17}, {-1.3363048228659056`, 
        0, -5.452038017442776*^-17}, {-1.4033642746265753`, 
        0, -4.795445222401028*^-17}, {-1.4815748519599592`, 
        0, -4.0833604229969365`*^-17}, {-1.5508807022070628`, 
        0, -3.4822798486173895`*^-17}, {-1.6128795043111113`, 
        0, -2.968180575500819*^-17}, {-1.6697463002863684`, 
        0, -2.509406402108567*^-17}, {-1.7602563204941204`, 
        0, -1.79671522217477*^-17}, {-1.8413437060660802`, 
        0, -1.1754437621658812`*^-17}, {-1.9148458828986263`, 
        0, -6.2549424449485966`*^-18}, {-1.9826002768881374`, 
        0, -1.2676889157466468`*^-18}, {-1.9913420464689446`, 
        0, -6.302328183019254*^-19}, {-2., 0, 0.}, {-2.076195235867775, 0, 
        5.460336135267359*^-18}, {-2.147043324822746, 0, 
        1.047934169657065*^-17}, {-2.215738531682641, 0, 
        1.53257502394798*^-17}, {-2.2801279743523835`, 0, 
        1.9826964745600664`*^-17}, {-2.398258931943386, 0, 
        2.7991281382393605`*^-17}, {-2.5051272793958255`, 0, 
        3.528903994310506*^-17}, {-2.6163931269945158`, 0, 
        4.281843590042373*^-17}, {-2.7185050675284894`, 0, 
        4.967095265032991*^-17}, {-2.8129516459285657`, 0, 
        5.59628657917814*^-17}, {-2.9012214071255618`, 0, 
        6.181045092373603*^-17}, {-2.9841447772569785`, 0, 
        6.727652057761554*^-17}, {-3., 0, 
        6.831739988578082*^-17}, {-1.7320508075688772`, 
        0, -1.}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-0.6624061883814446, 
        0, -0.11281818794547861`}, {-0.7387665844348644, 
        0, -0.21183826834947977`}, {-0.8227119661869541, 
        0, -0.30396392731575067`}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 
        0, -1.827402152461799}, {-0.9159062757702402, 
        0, -0.39326358347393187`}, {-0.9714138769953617, 
        0, -0.44214844769825756`}, {-1.0212665171779367`, 
        0, -0.48416946046191034`}, {-1.081199872382793, 
        0, -0.532709901624842}, {-1.1349972068708727`, 
        0, -0.574932738156941}, {-1.2099812806247137`, 
        0, -0.6320752090489037}, {-1.2764464101216457`, 
        0, -0.6814598923604778}, {-1.3361230472899444`, 
        0, -0.7248463017704735}, {-1.3907416440578846`, 
        0, -0.7639939509577008}, {-1.4409874136332308`, 
        0, -0.7995372106680627}, {-1.4878419030766434`, 
        0, -0.8323729324650126}, {-1.5524139631453668`, 
        0, -0.8772470256936916}, {-1.6118804446195, 
        0, -0.9182002038196536}, {-1.718673024351716, 
        0, -0.9909494259822538}, {-1.725388721703603, 
        0, -0.9954944040167335}, {-1.7320508075688772`, 
        0, -1.}, {-1.7898783863789862`, 
        0, -1.0388652797252398`}, {-1.8442626335909351`, 
        0, -1.0752435827807179`}, {-1.947286990926446, 
        0, -1.1439092483479993`}, {-2.0401504131555903`, 
        0, -1.2053812116282427`}, {-2.125067595654396, 
        0, -1.26129724795474}, {-2.2144187122442487`, 
        0, -1.3198912525475177`}, {-2.29696370794418, 
        0, -1.3738145056728157`}, {-2.373738070352859, 
        0, -1.4237988614694024`}, {-2.4457772870689545`, 
        0, -1.470576174076047}, {-2.5136854086472864`, 
        0, -1.5145666655895698`}, {-2.5780664856426747`, 
        0, -1.5561905581067905`}, {-2.6815635663987827`, 
        0, -1.6229604777560442`}, {-2.7775368564801313`, 
        0, -1.6847270878903766`}, {-2.867088069313783, 
        0, -1.7422376649327052`}, {-2.951318918326801, 
        0, -1.7962394853059473`}, {-3., 0, -1.827402152461799}, {-1., 
        0, -1.7320508075688772`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-0.30556128145229344`, 
        0, -0.07870830025830548}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-0.3169113191400583, 
        0, -0.1218236921742118}, {-0.3279278378503798, 
        0, -0.1618085076885341}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.6543862314462108`, 
        0, -3.}, {-0.34900205111595917`, 
        0, -0.2345412716938612}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-0.36883015785401274`, 
        0, -0.29869062386098993`}, {-0.39310505789101524`, 
        0, -0.37261625712125157`}, {-0.4156368767851659, 
        0, -0.4376420446646899}, {-0.44340482373818113`, 
        0, -0.5138671065912279}, {-0.468887648042852, 
        0, -0.5808380879020645}, {-0.5004576972760997, 
        0, -0.6605211679656946}, {-0.5291745023898363, 
        0, -0.7305383373006464}, {-0.5648417309751381, 
        0, -0.8147609313171418}, {-0.5970796194351801, 
        0, -0.8888509680085538}, {-0.6373562226070184, 
        0, -0.9791226748340157}, {-0.6735929103529886, 
        0, -1.0586429229314496`}, {-0.7175244013663291, 
        0, -1.153195989247747}, {-0.7570562324594537, 
        0, -1.2369304970405361`}, {-0.7929935274196629, 
        0, -1.3120056462269445`}, {-0.826141410034258, 
        0, -1.380580636724101}, {-0.856845640765045, 
        0, -1.4435271823540774`}, {-0.8856079680040276, 
        0, -1.5020983847364007`}, {-0.9425085457322114, 
        0, -1.6170405957285525`}, {-0.993495492386544, 
        0, -1.7190888665612158`}, {-0.9967579511289973, 
        0, -1.725591665960026}, {-1., 
        0, -1.7320508075688772`}, {-1.033892835459149, 
        0, -1.7992392055814181`}, {-1.0658596651224108`, 
        0, -1.862362914247072}, {-1.0970139405446213`, 
        0, -1.9237916583215942`}, {-1.1265431074847296`, 
        0, -1.9818304732138543`}, {-1.181446280919145, 
        0, -2.0893008800543185`}, {-1.231780095058521, 
        0, -2.1873864682851996`}, {-1.2851334594623438`, 
        0, -2.290988852228023}, {-1.3344754087288135`, 
        0, -2.386483034777872}, {-1.380406553720881, 
        0, -2.4751153277008315`}, {-1.423527505301498, 
        0, -2.558132042762989}, {-1.4641925040528276`, 
        0, -2.6362581657929036`}, {-1.5027557905570337`, 
        0, -2.710218682619137}, {-1.534050293829741, 
        0, -2.7701543252483174`}, {-1.5642383005785114`, 
        0, -2.8279140520162973`}, {-1.5933198108033446`, 
        0, -2.8834978629230763`}, {-1.6212948245042413`, 
        0, -2.9369057579686566`}, {-1.6543862314462108`, 0, -3.}, {
       0., 0, -2.}, {0., 0, -1.9930697437687392`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -0.00812878362489576}, {
       0., 0, -1.8765530604330984`}, {0., 0, -1.7547682338914479`}, {
       0., 0, -0.001352194191085579}, {0., 0, -2.0838711004764443`}, {
       0., 0, -1.5209921171515646`}, {0., 0, -1.4280897149371468`}, {
       0., 0, -1.323910413967034}, {0., 0, -1.2055173116118962`}, {
       0., 0, -1.114765798099091}, {0., 0, -1.0122057127579276`}, {
       0., 0, -0.9259189964705876}, {0., 0, -0.8280418701008682}, {
       0., 0, -0.7479807485897327}, {0., 0, -0.6572345268975793}, {
       0., 0, -0.5817771424227758}, {0., 0, -0.49631614791155776`}, {
       0., 0, -0.4243569404846221}, {0., 0, -0.3429913172079261}, {
       0., 0, -0.27341025466147834`}, {0., 0, -0.19493582036141607`}, {
       0., 0, -0.12668644282153935`}, {0., 0, -0.04999541458500764}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.563985662770493}, {
       0., 0, -0.001352194191085579}, {0., 0, -0.00812878362489576}, {
       0., 0, -2.238731110753913}, {0., 0, -2.310640996063193}, {
       0., 0, -2.3786640756418826`}, {0., 0, -2.443329639622954}, {
       0., 0, -0.04999541458500764}, {0., 0, -2.69124049187927}, {
       0., 0, -2.808218810422451}, {0., 0, -2.9165393169096556`}, {
       0., 0, -3.}, {0., 0, -0.12668644282153935`}, {
       0., 0, -0.19493582036141607`}, {0., 0, -0.27341025466147834`}, {
       0., 0, -0.3429913172079261}, {0., 0, -0.4243569404846221}, {
       0., 0, -0.49631614791155776`}, {0., 0, -0.5817771424227758}, {
       0., 0, -0.6572345268975793}, {0., 0, -0.7479807485897327}, {
       0., 0, -0.8280418701008682}, {0., 0, -0.9259189964705876}, {
       0., 0, -1.0122057127579276`}, {0., 0, -1.114765798099091}, {
       0., 0, -1.2055173116118962`}, {0., 0, -1.323910413967034}, {
       0., 0, -1.4280897149371468`}, {0., 0, -1.5209921171515646`}, {
       0., 0, -1.6055545232396176`}, {0., 0, -1.6829299425553081`}, {
       0., 0, -1.7547682338914479`}, {0., 0, -1.8765530604330984`}, {
       0., 0, -1.9860968846818443`}, {0., 0, -1.9930697437687392`}, {
       0., 0, -2.}, {0., 0, -2.0838711004764443`}, {
       0., 0, -2.1624051295810696`}, {0., 0, -2.238731110753913}, {
       0., 0, -2.310640996063193}, {0., 0, -2.3786640756418826`}, {
       0., 0, -2.443329639622954}, {0., 0, -2.563985662770493}, {
       0., 0, -2.69124049187927}, {0., 0, -2.808218810422451}, {
       0., 0, -2.9165393169096556`}, {0., 0, -3.}, {
       1., 0, -1.7320508075688772`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       0.3055612814522934, 0, -0.07870830025830602}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       0.3169113191400582, 0, -0.12182369217421207`}, {
       0.32792783785037966`, 0, -0.16180850768853416`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.6543862314462103`, 0, -3.}, {
       0.3490020511159587, 0, -0.2345412716938604}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       0.3688301578540124, 0, -0.29869062386098927`}, {
       0.3931050578910148, 0, -0.37261625712125057`}, {
       0.4156368767851656, 0, -0.4376420446646893}, {
       0.4434048237381808, 0, -0.5138671065912273}, {
       0.46888764804285166`, 0, -0.5808380879020638}, {
       0.5004576972760993, 0, -0.6605211679656939}, {
       0.529174502389836, 0, -0.7305383373006457}, {
       0.5648417309751377, 0, -0.8147609313171408}, {
       0.5970796194351797, 0, -0.888850968008553}, {
       0.637356222607018, 0, -0.9791226748340147}, {
       0.673592910352988, 0, -1.0586429229314485`}, {
       0.7175244013663287, 0, -1.1531959892477464`}, {
       0.7570562324594533, 0, -1.2369304970405357`}, {
       0.7929935274196626, 0, -1.312005646226944}, {
       0.8261414100342577, 0, -1.3805806367241007`}, {
       0.8568456407650448, 0, -1.4435271823540774`}, {
       0.8856079680040275, 0, -1.5020983847364007`}, {
       0.9425085457322114, 0, -1.6170405957285525`}, {
       0.993495492386544, 0, -1.7190888665612158`}, {
       0.9967579511289973, 0, -1.725591665960026}, {
       1., 0, -1.7320508075688772`}, {
       1.033892835459149, 0, -1.7992392055814184`}, {
       1.0658596651224108`, 0, -1.8623629142470721`}, {
       1.0970139405446215`, 0, -1.9237916583215946`}, {
       1.1265431074847299`, 0, -1.9818304732138547`}, {
       1.1814462809191455`, 0, -2.0893008800543194`}, {
       1.2317800950585214`, 0, -2.1873864682852004`}, {
       1.2851334594623456`, 0, -2.2909888522280264`}, {
       1.3344754087288155`, 0, -2.3864830347778763`}, {
       1.3804065537208836`, 0, -2.4751153277008373`}, {
       1.4235275053015013`, 0, -2.558132042762996}, {
       1.4641925040528316`, 0, -2.636258165792912}, {
       1.5027557905570381`, 0, -2.7102186826191463`}, {
       1.5340502938297451`, 0, -2.7701543252483263`}, {
       1.564238300578515, 0, -2.8279140520163057`}, {
       1.5933198108033484`, 0, -2.883497862923085}, {
       1.6212948245042451`, 0, -2.9369057579686646`}, {
       1.6543862314462103`, 0, -3.}, {1.7320508075688772`, 0, -1.}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       0.662406188381446, 0, -0.11281818794548079`}, {
       0.7387665844348645, 0, -0.21183826834948005`}, {
       0.8227119661869545, 0, -0.3039639273157513}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}, {
       0.9159062757702405, 0, -0.39326358347393225`}, {
       0.971413876995362, 0, -0.44214844769825784`}, {
       1.021266517177937, 0, -0.48416946046191073`}, {
       1.081199872382793, 0, -0.5327099016248423}, {
       1.134997206870873, 0, -0.5749327381569413}, {
       1.2099812806247137`, 0, -0.6320752090489039}, {
       1.2764464101216457`, 0, -0.6814598923604779}, {
       1.3361230472899441`, 0, -0.7248463017704736}, {
       1.3907416440578844`, 0, -0.7639939509577008}, {
       1.4409874136332306`, 0, -0.7995372106680627}, {
       1.4878419030766432`, 0, -0.8323729324650126}, {
       1.5524139631453664`, 0, -0.8772470256936915}, {
       1.6118804446194999`, 0, -0.9182002038196536}, {
       1.718673024351716, 0, -0.9909494259822538}, {
       1.725388721703603, 0, -0.9954944040167335}, {
       1.7320508075688772`, 0, -1.}, {
       1.7898783863789862`, 0, -1.0388652797252398`}, {
       1.8442626335909353`, 0, -1.0752435827807179`}, {
       1.947286990926446, 0, -1.1439092483479993`}, {
       2.0401504131555903`, 0, -1.2053812116282427`}, {
       2.125067595654396, 0, -1.26129724795474}, {
       2.2144187122442496`, 0, -1.3198912525475186`}, {
       2.296963707944181, 0, -1.3738145056728164`}, {
       2.37373807035286, 0, -1.423798861469403}, {
       2.445777287068956, 0, -1.4705761740760481`}, {
       2.513685408647288, 0, -1.5145666655895709`}, {
       2.578066485642677, 0, -1.5561905581067919`}, {
       2.6815635663987862`, 0, -1.6229604777560462`}, {
       2.777536856480135, 0, -1.684727087890379}, {
       2.867088069313787, 0, -1.742237664932708}, {
       2.951318918326806, 0, -1.7962394853059507`}, {
       3., 0, -1.8274021524617992`}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{146, 149, 150, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{216, 217, 218, 230, 231, 232, 233, 234, 235, 236, 237, 
          238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 
          251, 252, 253, 254, 255, 256, 257, 258, 259, 260, 261, 262, 263, 
          264, 265, 266}], 
         Line3DBox[{299, 302, 303, 311, 316, 317, 318, 319, 320, 321, 322, 
          323, 324, 325, 326, 327, 328, 329, 330, 331, 332, 333, 334, 335, 
          336, 337, 338, 339, 340, 341, 342, 343, 344, 345, 346, 347, 348, 
          349, 350, 351, 352, 353, 354, 355, 356}], 
         Line3DBox[{387, 388, 393, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430, 431, 
          432}], Line3DBox[{465, 468, 469, 477, 482, 483, 484, 485, 486, 487, 
          488, 489, 490, 491, 492, 493, 494, 495, 496, 497, 498, 499, 500, 
          501, 502, 503, 504, 505, 506, 507, 508, 509, 510, 511, 512, 513, 
          514, 515, 516, 517, 518, 519, 520, 521, 522}], 
         Line3DBox[{552, 553, 554, 566, 567, 568, 569, 570, 571, 572, 573, 
          574, 575, 576, 577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 
          587, 588, 589, 590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 
          600, 601, 602}], 
         Line3DBox[{628, 631, 632, 639, 640, 641, 642, 643, 644, 645, 646, 
          647, 648, 649, 650, 651, 652, 653, 654, 655, 656, 657, 658, 659, 
          660, 661, 662, 663, 664, 665, 666, 667, 668}], 
         Line3DBox[{693, 694, 695, 707, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738}], 
         Line3DBox[{768, 771, 772, 780, 785, 786, 787, 788, 789, 790, 791, 
          792, 793, 794, 795, 796, 797, 798, 799, 800, 801, 802, 803, 804, 
          805, 806, 807, 808, 809, 810, 811, 812, 813, 814, 815, 816, 817, 
          818, 819, 820, 821, 822}], 
         Line3DBox[{853, 854, 859, 864, 865, 866, 867, 868, 869, 870, 871, 
          872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 882, 883, 884, 
          885, 886, 887, 888, 889, 890, 891, 892, 893, 894, 895, 896, 897, 
          898}], Line3DBox[{928, 931, 932, 940, 945, 946, 947, 948, 949, 950, 
          951, 952, 953, 954, 955, 956, 957, 958, 959, 960, 961, 962, 963, 
          964, 965, 966, 967, 968, 969, 970, 971, 972, 973, 974, 975, 976, 
          977, 978, 979, 980, 981, 982}], 
         Line3DBox[{1007, 1008, 1009, 1021, 1022, 1023, 1024, 1025, 1026, 
          1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036, 1037, 
          1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046, 1047, 1048, 
          1049, 1050, 1051, 1052}]}}}], 
     NCache[{{{
        Rational[1, 4] (1 + 5^Rational[1, 2]), 
         Rational[1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], 0}, {
        Rational[-1, 2] (Rational[1, 2] (5 - 5^Rational[1, 2]))^
          Rational[1, 2], Rational[1, 4] (1 + 5^Rational[1, 2]), 0}, {0, 0, 
        1}}, {0, 0, 
       0}}, {{{0.8090169943749475, 0.5877852522924731, 
         0}, {-0.5877852522924731, 0.8090169943749475, 0}, {0, 0, 1}}, {0, 0, 
       0}}]]}, GraphicsComplex3DBox[CompressedData["
1:eJxM3Hc01+//+HEjK5E9iyRFO6slly0ZRRkpKxmRBkWpkIaZnWSPkOy9XVb2
3vNl7+wkFb7v3zm/z+uhfzrnfvzh8LpuHtf1HHx3HmqYkJGQkAzQkJCQ//c/
u8l0a+mMpmSqkNrxY35TEiT//x+594v1kYkAtAvv5omxPyz5v/7E9cTlkYkv
KNrkuVG0vTixmyqFBbTqpKKR7F+fN/qliP34u/dLwxNZaCnvNHm0vQKxx5qU
sN3kLUAkRRb3r3CqEDuPwi+JVh2MXA3aLDb6rxG7CvOn9ENK5YjB6GGEauJ1
Ynclz6wcnqhEQXf2dETZaxF75WpTd6hzNeK9m0D9S+kmsZOMz87q8NahOBOF
S1c4bxO7RAflFktRAzppNvY4fFqf2J9VHmRs1WlGuqJS1zf6DYldV5fXr+pP
C+LJ9rKKkb0DX6+RHHJIqQ2Nig26qCYaE3vglYuxzp/aUWzOseh1JhNiz5Kp
TRme6ED3ztoXRdmbEnvbBe08SdEudCKvpkt51IzYl4QnykKdu9HSOfblNaV7
xE5/zKb+T0sPyso3oY1Mt4CfPz9ppw5vH3p2IUvgCud9Yr/C7U3IsepHFwvJ
pH46WRG7OfP+aZaiAbR9UV03fPoBsb+nTVy23k1ARoSrFw4JPiL2L+Tn/7bo
DKEKHjvFjX7oI6+MnT9dH0aHDcJvNHk/Jvbl50ddqv4MI9eI70Yxstbwe7Fd
9liLGkGzQz8ePFuHzmCd53NIaRSpHmB5qZpoQ+y8Dxw/Xl8aRamGF90OGjwh
9lMWCsHOn8YQY9SdwHWmp8QuaUoXkS45jp6MuMU0VEFXu9MRMzwxjrr40tOi
7G2JXU8/5OveDxPo/J2eYtuTdsRupXsnWVJ0EoVEb9cpj0J/qSWUYdU/iTZH
D/ccCHxG7J4aSzmhzlPIkF9tYk3pObGHqOUW1gtNo3Ljpyt1m9ATrziU/mmZ
Roe+hG5HpNsTe4GC/HehZzPIZbxiz1OTF8ReJ7OnTod3Fs0cmuO8wvmS2Hsl
25tcqmaRsgnTEd5G6DMXgttzrOZQSux50Z9Or4j9t7hRzwTLD8QwaShdK+pA
7NQigoMsRT+QzWFXtfBp6OynFkdkjedRp2nqLZtQR2I/cixn0nr3Agq9bil6
SNCJ2MWPvJqLSl9AjatbBfTO0BX45ZZadBbRlr+f9EY/dFVe2rXt7UV0TPRw
zZjYa1hHc7q2GYWakhu0HpdHLMClexSP69fyA5Dd7wEOKiMT9L+e89h//1r+
FySy8M6E0ugpsecZPtBcZEtFrGlqEZXUTsQ+GP+l6md+FmK410dLafSO2PV4
/UYfT+ejPQdNnynmuxM7IdBxa4ENo7fzz6wrqX2I/bSLOF3OwXJEVlciOJHl
R+xLMidCfuZXIse4XUMURh+JPXWLX0hEvRr9c77y8TBdELE/LODKfTxdi54b
+Cgr5gcT+ylbRvk0xwa0frGL1NwkjNgXz1C3L7A1owt76G9XUkcSe7etYxpb
dwt6/ud0bod+FLHndtivZx9sQ7nT15kmsqKJ/ZOwraTmg3b0q8vWam33F2K3
83n87md+BxL9/rmGwiiW2LUX7jf4U3Qhm8wifrbcOGI/q2LOLKLejTKihhwO
030ldvZvxrptoT1oyZusT9w4gdjXqQyiHk/3olMOAmKK+d/g+zfRnWYQ7UdW
9y/7aO9Ngu+/QvNUmuMAStK1nDMzSYbvn0/d9mr9IJq77KXwrDAFvn9HleIF
tiH0MaTnWiV1GrEnLfCTKZ4ZRllMFg4NmdBDw6Ji2bqHUYfb38QO/XRi/6DC
qzT5cgT9JPnQO0CTQeyv/ob+yD44ilie8VBNZEF/8I3L513NKBJdTBWdN8gk
dv2bQSKaD8bQdVPpO2u7s4hdjZqt+xDLOLIZbPPezIaOcv3tf+aPI/8bd4sp
jLLh82DKyFNpMIEy69dm6fbkEPsBVu8yf4pJ1C7jwsGWC52hco+JceIkWsnn
UOC5k0vspDbu1CLqU4jpzDebw3R5xL7MR51Etj6FhL9ejDqZB3205d3VttBp
pMHb2CRunE/sbY7kq1EyM8g6UP+fJH0BsVecfB34eHoG+dEtCSnmQ88c3Dov
7TWL0t++1r56t5DYv3i+HGQQnUOtf5neae8tIvaAi3+chnvn0LL1lwyDAuhv
Z+0OpTn+QIyzYsNmJsXE/vTzWrWjwDw6Y1RN94ihhNhNLttYXq2fR9d6dC4+
K4Sutb5Ez/t4AT26OmvuZIqJXSHuQcYC2yK6PHZJuZK6FH7+mj80S4oWUUc4
5Z3L+tCNkxOplYQ1JRsutLWWX4R56Utu5+qMeAAS3wy6zy4KLhk8lL0yI/4F
xU8WFLCJgj9zZKHBehopKFNNCPM1eRO7hLL92rR4FjLsrzdiEwVPyD7G7Y+R
y0eme8nHuV+DGzWENnk9jRJ0X/aCKV9TBLFfDtjOoU0rQ/mF5574fwAHjuaz
1k+LV6IizRtibKKw3ukIx4a+F1ehksWHv4L64sEfMpnVaLlaVObmkcv9GtZv
2xEdKqf6elTBH/8s/Ais02yVB9x6Gk2oqrj8PF9TKrE3nCtnD7vfgsaPPdxU
vwDr7pJyYxRtWiua+P1Pz/8DrK8UvZ5j9qttaOq7e0nHMKyvA4/GsqfFO9C0
HwcvmyisF1/nBaRt34lmDOIctV1ydvzcNmq/F3eh2eOiw0F9sC5s4nfdECXt
QT82yqT6TsDnfCJ/LyFarhfNV12N4n4Nn2etBi5zRtc+tOA/SKrXAZ/naoLA
imN9P1o0tLwTfgQ+n+eXT79coB9Eyyc2yofs4XP4jVyCUk+DgFb+vOfna4LP
4T42RZ/6j0Poj/FumXQf+LwpsgjRhd0fRi+uqK+oXygjdqewkxo36EfQv9NB
0Stj0AsOi36iTRtBr9iHNPw/lBP7aur5gXL1UbS9KUAueraC2I+fR3z2q6PI
afx+ZscwdJNyOdMzH8cQaX2m8VP3SmIPV76SOC0+jpzT/zCziX4HzzuuLkX0
jCPyIOnKnEHoDPqaYtr2E+itg+sTbZcqYlea0rWn3zeJKEyaD/0+XU3sbx4Z
4u/Fk+i9MltnUB/0og2TXa8MphC1sN67829riH3N2VJJlHQauXF8Ees7UUvs
J/c89pqLnka7t2cn7Luhm320bY+Wm0EeE2cCuV/XEXskz0sO3ckZtKfhmULR
0Xpi741/rcfoOos+ZOBftzugM59xia4RmkP0nynjN181ELtKgeeUY/0c8nFU
1Q4/0kjs72T9jp+1+s8x0wAq1Aq9pOHT4wX6eeSn0p87ZN8Efzc1w3Ji0+YR
s8hBc6dDzTCHDEX/va2xgAI473HwNUG/Y/5ViuXnAqIi0RkfvthC7LMk4QJV
V29IXv0x1njVGvZxB5weKU/o+yPPE4XIXd8RPidqK1/H9WNQyunAc2764FKX
3vEkLfrk/+bP+K+T7z/BHCWeqT2un4lQBnm2qz7403Tp2s0w8Tz0eTvVkDUk
htil5Od1teiLEfNhgunke3Dm5mH5FKrVUuSlsscq1zqR2Bm/MZ8a169AVDYX
bFz1wZPaE6OppXXfUalKVtHxWPDEOT3tdJh4Ddo0qEesIeDGBTHH9OfRdei8
zWj5pg+4sZKnKqxF34hs32/IT74HHxIl9mUK2zejjM8MtU0vwYczhmufqVZb
0GLSEZVca3CAPvp235pgGzpWKtkcYQ4OzI5VcI3rtyPzdk0NV31Y71UCx261
BXQgDZsci3PfYL1Hm/mFlNZ1ouV/0knHY2FdOyRs9KeQdCPv943zByJhXevO
Ge4LE+9BJxhunmINgfUrfqLmtsf9XlT/efwRTSCsX6aHp8KeR/chC/5HGZs+
sE4X0wIHzXr6EXXy39VlD1in9Sub+7X+cyxO3EVs8j2sx6+iJvpycgQkX8pk
1/ca1uM724ZwYfshNK4Untf0EtbdmYHPDxl0htGbdqE/5Xaw7nhfNXpTrQ6j
g3rZF3OtYX3R85CmbX0YQWWTUq8SrWB9bZaItqwJjiLDRw0lEeawjuYMzJd+
VPzn24Y2SYAxrKM+klCGcf0xFP5mTNpVH9ZLTVTz6f6NMRTxPle65Disl1wZ
cvW2gHH0QPnVnXPfoMeOiT+uPTWBJBlk32QcaYW55a2Fb2ndBKLrpP5yPBa6
s0B4eq7JJBr83FQZ9988/r/+uKq1NYVkCiXpB0wciIRuYEaxEhsyhV7y61KG
7G/fMTeeZwoTn0bK07xHWEOgSyTcFw5onUbcyROK3hwdxH7sSqSGx/0ZNPs4
0ZwmEDrnXLu1M9UsKhB/7PaGuZPYqT2p/J9HzyK3v+LfNn2g/zp+MfPRpTl0
s/RfnR19F/x9bHzQbtYzhwTflc8te0DveBC9qm/zA/1Wct1zn6ab2Mv3djFr
/edbDb3aicn30BPSaERVE+aRbzuzmuGuHmL/mNu4PMJ+XVI6LJ0z9LU80av+
fXL9NmJ+yFzQUcXH+S3x61Xp3snYiEWjEEXrSG/nAPi7tsf80/FriYj07xeu
7opw+Hy+E/hlLZaBRLotr3g7wz5obdenyObyHDR1+h2VSAzsX+6+pVY+fq0Q
BbuHV3ZVwL6jk9x+zXUQoyMr/VKXVsCf6LK1Zmux/9ZnhDmvtzPM+TdfnxTg
e1mJepXXNoeZwBkGaTP75vIqlPH79YBwDDhTTRLZ/IqmFnnE0he+FYF52LG0
59Dxa/XorkbI564KmCvEnRjt+wIbUcQ2swTLDk/m0ZVm18FmRKule+zSCnjS
5ijtx83Uip4lRXKZXgA3UoYGi6zF2tA42RSNtzO44Y7sp2p12pH6zRMbuXXg
hkkEGxPfyw5UnGozPcwEPkhvZ0g8i+hERykLumlugQ/7Da6aNZd3ocDbJNXC
MeDD75I538OT3Yg8UyHn1hz40MHjWvSKphc9pPkQ+1YEHEh1ODTVcbwPDRi0
ByS/AAc8CKWMx6/1o8s5nG+7KsABc0k9iTc2A+gWZVr+NgWsa7nwDdO+wEHk
d+b6GZYd651v66PvmQICqrn966ugGqzrTT3hItfBIbTt8vnApRXo8/pmqw+d
hpF4pkSQeiCs636vbFduphFkRRjaa3oB1m9tCTlPdcwIiqF542JPgJ63oJ5p
LTaK+kQPb3s5w/qN44m8zFM9ihgNa21jDsM6DVBbGKzVGUOXPe4v5NZBd3aQ
sHk6O4YccvaaNjyAdfo4xZ2a7+U4yh7JGBxmgvVoQOgJa6CbQD/2aGmu5UBX
pT8i8ixiAvGf22iguQXr9KLk0xr+M5PopnGoHM829KMPKvSayyeRjxcqEo7p
JXaOcMZV+xtTqDp/VERRsY/YKZsMXA9PTqGt8XeJt+ag/9xM3t9mN41EGYT4
H3n3E/vYiX8Zr2hmkOXFhuC3IgPE3qp35bJQyAyKNn3I9LkbOv4QNNhxfBb1
+jK5J78YhM958aS1U8ks2lucTVrOSyD20HlR6uPX5pDCtM7zrgrob/a/Cese
mUNPmf8tzZoNgZ9VWnaF3uqSBdY8jq/FrxC9MjwbsWyHfZBP+NeEL9uu8Hu8
xWdihyNRkN/P7phtOBcK4bZpFeZNQKsW7skFGPZrNVajPHY4DYV4cj2M2Ybz
lgpV2s4bi1lIJuXbaU8Ec1HxCVEPYd58tGa2/3kBhv1UPp2eNMPVYlT7bKI3
ZQjmn95f5X9tcSkKdUu+ELMN5wBdpt1dJt3l6GHw05BPvOBPe9dc+o3FSiST
eOmfB4J5pkWB5IMsVTWiJTifLD0FzjTmsJgL89aiJ5OT+gUY5pa6w0KyfGfr
EWHhinfWVXCmOvASD8PVRqS4noJThsCZSkqNjS3TZpS+zbT09SE4Y3hRZNYW
tyBuarsDMdvgjIFNsfaD+lb0lqH/Wpg3eKKXqPjdpLsNLXCg1594wZPbY63C
emPtSJsvJt03FTzR5b4deWOxA5UJUY16IJgfbl6fpFP524lYP4vRVJiBG9oe
j17IUnWjK2FmfKWnwAetij/TF5h7kGPU5/PF69Bv/H2rJczbi7Ji69ULMLhx
XWRvpdCxPjSTsHkv1wV80LD8fIbvbD/iSTnlnHUVfNCI4Y/gkB1ANzKMgtPZ
wQH1/uQ9DFcHkVuOf0bKEPRrzOfsqW4RUEnB97rEePDhmnL51JbpEPpZsj76
9SE4EC8dd/TF+WEkVCH0N/YsrPd4PcsRWzyMDKpvMcfscCD++ekga/kRFFD/
4VhkNTgQ93FN7UH9CKptxrJh3rDe49ILKCz+3/60fflWsDas97hGxyKT7lEk
2sP/5BMvrOvYGTkbI70xdG9A0zNgaken2H1Ub+y/uW7Y5YtvKqz3L3zNwzr3
xlHHeH6Rlx2s6y+XAj7dWBxHu2fmOjwQrOsvN2+qXXs6gSJ+edlWkg8Te8xT
HgqVvxOo4Hc8WYXZju47Vqj4ehJ1/in1Kqvf0ZO/WstSTaGlf71cpadGYE6o
tRJCH6b+25+uxJX47+gTwsMXmKeRAOkekeJ16FGkvwPFP08jKXIBXHhrFPr+
YlVh3hmkSyGpXIChB5933nUydgY9otLuzuMfg3nSOP/S+xdXJdcuPRQ++0qN
6FWGGUH0GKUXuqSEab8wf4B1J0Z2/ihlOPrm3ckewwzn0j0hdZYRb+OQbvEE
S0ETnCM17mMpFKJMQUMZw2HRzHAuNNJ0kqKvIgMJd1j5yx8Hl257tx+PeJuD
1tTmuvObwKXuq89u3JUvQHm15vtOPoa5SJ1h/0shyhJkLzdpGM0M+yzT6WF1
u7FSFD6UrkF7C+afmMuZE70V5Wg7dOmJ/HHwZ/jru+cSXyqRoe6pT46bMP/s
p9Ghi3hbhcrYH+TnN4E/uveORpGa1KCDnUn9qxHgz6faf6J35evQG7+5zROP
YZ7pEGquqRJoQONXjx4wl4F9DaN71G0hyiYkT3dPJpoZnFGbtVnymGxGcXXx
dwfGYW6RF+CXsRtrQeRyNrK0t8CZu5p7PL+2t6KsaL8bX2V37DverXX2VrSh
u6QZJvLHwZOobAIvbVY7YjVstR1lAU/wRPU9iS8d6HvJkovjJnQCa3qmVUAn
st3P8HnfJDjzTz54M/xtFzr88tS3/CbwhNv2jWLLk27U06dWqJULnlyMu+9L
atKD3M4/aFiNAE90uzT7hTV70YWgD4M+ruDGc0okcFe+D839Slo48RjcCBIX
fPhRrB+FajZs190EN/JMGfOrBAaQatYcg7kMuNEd+IfsN+sg2maiPUhxDHz4
VTWmIkRJQGmPj4pEM4MPrOsNgbq/CMioRUkO/YMueiRn2GNyCDGduqc5MA5u
fEu8+lHfchhVfHA1fd4IbuTLyl2wGxtGF361X6S9BQ7U9p8b8r41gvxjjStv
NkPvtTnx9mv7CJq7saryVRbW+zTtQaEy5VEkt+tN569c6L9j2Jp6/9vnhmUy
6csfh/VOJUFrs3JxDK3diZ70j4TO3rHNTps1htSYhB+OsoADR+7/LOI/Po7i
ysrWT7tBF981YyTxZRxtP1J3ctyErhA6SKm5bwLpHBihbno8Tuyaom2JVgET
KK35ke++SegmDVXX3u+ZRDSOJFyWuhPE/vRu4Vr420lkdNInOr8JuuO/1ODc
f5Moa5D3GLXsJMzbJgQJdF1Zspvra+0InzrRKxEhufAze93R78ejW1lacJ1O
5dS3itN7g1GicfvTLC24XrZ9iPP2XY8YpOsldp/eGeYoHWE9rdN7v6G3A8pn
srTgOlFvxDVBB6U01L/88rjRfdjHvYuzFrjrkYlEqFKO0DvDvCScHHDwSmMO
8tg3dLDwE8xLhMwc3tN7C9AyB/XeLC1wyb2gZx+bejEKjYn0dDcCl0IMN/c4
KJUixZPndxvdh7lo2diL9vFsGVrJa3U5awfnM4pmvLvvelSgcFkLCnpnmH/C
LNKotY9/R0pNZG/GPWH+WbWSprrSWIV+6oSQFH6C+UfpcRvFpQc1KHJMxME3
GvyJeGK86/TeOiRwdnIzUwv8WbP7ScafVo9evMyQ4L0N/ii/eEfKpt6IWssc
Xrgb7fDHgY2EZqUJHaZSLlgzBWf+ll7ffqXUgl6qsG8Y3t+x35EJdVjnbEVt
vmNnGx7vmGcqxzcfzbaiI92ptmftwJl/8idezRa0oVf7XmZHv9wxt1Q//Wfs
0Y7ajC7/pHMGZ64rlbwYvNWBhOJZRJ67gDPbdZR/tY53Iscfw4/HPcGZbypX
7Vv+daKuM8lpV/3AGa2mTxtKjV3ouN3zxYJP4AzpteFnFWHd6E2R/MnDYeBJ
cqvgb4kHPaiXlMnKNxo8uXn9sV2OZC86pUhI/BcPnuzqzP91am8fklXQXMvU
AjfStMhsE4b60IJ5YcC9Xui3eq6sHUzrR589+ER5b4MbVLr+T0KdBpBcikt7
BwF6Zn//Kqv6IFpqmbd2NwI39PUO2XjzEVDI6nUmqXHou4fur1CvEJACW0H6
min4kG2Y/di5fAgtnzugnjgD/cyyw+9XSsMo7Nb7JcP74AOlMH9eQfowuuzw
w5ttEfqAdbXdOucIWo3UONXwGHzIyLQ8K+o8gsIr8ppe/4Tu+nPv+qPZEaQ0
yfPgrB24oS+WlZOsMYrWqN/RzW9AF7HVsZ0tGEWRx+aSol9OETtN7j+xI//N
Scpq6io629CH1iPXjD3G0K9HuXN0ztPw8z8nnx25OoZC/Pd7VOyaIfbjigKR
3HkKkvVZM4P8xRpEr5qdznxM/vYOeRnwT88QfIlf3xTzaCjp20cUIXVBY4YA
1/GDZQ/Zk0pFItvWO2l6TXDdTVXM523St1h0JF2eaoYA504kR/55abMmIr+N
m+IxWnD96+aeLBVSqTS0Jf3ARK8JrmeJUsy2aq1lIEt35wB2BdjH0W3xaid9
y0aW9+pHpgmwj5v4pTlAapiHIj9obnznApdKFj2MtFkLUVf6EEOMFrj0abps
MqmuGNF23RN08gOX8pb+ipFKlSKpP6tIrwlcEpgP/J0YXIZseRy0L+yGuch3
5kyh1lo5SpShfsiuAPuvrYmGV6TXKtEjESXZP6XgksWomVTSt+/IQ56+eZoA
LnUTyMi1KapRnHa7bvc/cEm2P+w7qWENKr0XNPmdC/xJ6z7nmlRQi/pf6Fln
nQN/9nW0X9FmrUe/PhzcitYCf9xaHtCRPWpAjJFTbr5PwJ+1BpqWpLpGdCwj
idXJD/y5U/vFT1ugGSlUPo56kAb+TI1GHCWVakFGXeIn9JrAHx6jeQ+t+f+c
nP6bp/wD/NEcujCfGNyKgv6Uyl3YDc546LmqkV5uQ5l73rcICoIz5f2dqVpr
baiZR/k2uwI4s3GTnzEpuh095aD+SSYMnpzueWRNeq0DvYmaPf+nFLqpVkm7
1mYH8j3a6Lh8FTwJ66AVS/rWiSIyU79P73CmQ+NmIKlOF0qS8KMdtgJPaFvj
1rUoulHB9yfq3f+gS1/9qZOU0Y1q1LQ/NXmAJ88apQtIDXtQV/f5we9c4Eaq
sje3Nl0vGjPcx1+cAH2yduBlUkEvWp7ZMs86B27sv3yUQGreh7atR1ISq6Ff
r7JD2qz9iO5fxc9oLXDDXe57ZFJ5P+J+F3cheAJ6WTkTGdmjASRI7+bk+wTc
+C1laKy9fxCJf7KsciUHN07i5MqkukEkd0Btj5MfdJNLfwXInhGQRsJpDTs+
8CS08LKLtsAQMhRmDnqQBr39fOB0UtsQsipcGzRBs8ROMbB8iFRqGL2Q6+HX
a4K+LySoMzFwGDk3Fty7oTcHnphcXLArlpYcPvyYO4rmBtEry9JTu9jmnNC9
luv7SPb5w+eERM6Wdc4HeVVTvtzmhut6RXyPZiMMP6OpuLGZrQS4n0eKT+0U
61wkOiA7fGybG67HRZ+5e69PIBY1ZDSNbo3CeTi5jH1MhGECen6w+PNWAsxR
pho+g3dDkhFzraagY96O+zHOtNOyzqWhGZJG8m1u2McFnCd8taPORCXn5IYc
HHecI0nPyPcJZKOAR4UFW6Owj1tT+jkqIZuLLL4KBzoo7HBJY9sxwjAfSQ0n
PN5KgHlJU3f3fjKHQsTKwafqQAcuvb/DWnA3pBj9OqLC4pgHLuVYHNCuzsNo
uIKKDM2CSzb5rH9Y5kpRvUHF4hY3zEWel0IuV22UoZy/DoMlquDSl7IDn+yo
K1DUpwv1Do7gUpF83IQgeyXyFPmVJ5m+47pM7THRPoHvyK45PW5rFFz6oZru
7CFahe5YWgWUsIA/FG3irRKy1UiVSsjZQQH82a9VxLugXoPOxow/lHwG/oj1
ST+IMKxFB1Gk3lYCzD9q+tVF1x7WIfr+W8ol/eCS2agKLZlDPfpjy37egQ78
cTJtu5np2YBs3O4xR/CCM59ntb/eDWlE97QVdzvmQc94MPiL9VsTMhAQIDVQ
B2fqV+7IV+c1I81Vst+Ss9CtL/5UKjJuQVfKhhd43oAzjpviyyxzLUjKu2Ri
ixuc8cDPg6ysW5G4XugAIQt60OsiVLXRio4fs28vUQVnvshuT/K8bkMHN7Tr
wnfsg9IpZLzsqNsRR7VYmYMjOFNc/Vasxbsd0X9kztPnAE/q3KoHBNk70C7j
5RTJdOhdyrvfvg7vQH9ON8fyXAFnxuhUj/UJdKLFraTQrVHoi83ebcLJnWii
wd2f8AKc+efb9txDtAv1B5u7l7CAJ9Q3WPnGC7tQq7nC6/Bk6KxsOjUSst2o
WvzQMwcF8ISvJ/jhx7puVLyL7KH+EPSTwYNsC+o9KLNtyETyGThz4faBEoXe
HpQQWXybh/EHsSvyGJtEGPaiiAch17cSoKsOx+75PdWLPkg8v0KQmYe/10PS
F98unZM88bRvdIxUk+hV92TrzbIaO3RE/ltBOTVcB9yqVPUrrXFBDIdDmMqp
4XrfZeXeiz5dvshTaKT6IB1c12PI8jhZWvMJvQ30Lymjhn1f7z5JvqWCMCQb
JM65shvOo1plftP4dEUh0uBem4N0O67H2amTf23+goZVJc0SXGCOCk789g/X
xKOSJu+AMmqYozaHyH91l31DYVdHynrdYI4yYtFbXCxIRi9bhBeXd8P50p1D
t36S66YhXfW3+3Z7wvlSQAnVsndXOjrf1ql0kA72cVU6WfPc1zORZ4L/xf2K
4NLvFcPZ+OYs9PeehEaCC7h09APdlIhKDrI4OmEuVgPz0u0jBWO4Jhf1zX5w
LKMGl7zKTIeV5fORUqJ4oKoSuFR6i3mwu6wA5VkOJfW6gUsra7jXWLIICR53
rTCpA5f4fe53LRYUo08/Tvct7waXNI9ytr84ixFlcu/SK2VwSW50dIpctxQ9
tXKm2u0JLumdOj+pxFGGJk4c4wlsAJdsX3qPe3eVoRsL7aIH6WAu8q6dGO0M
KEeVKS+VU1TBpQQ2iRHu6xUoOJfpzH5F8Kfc2G/IiLEStbGbSRhPQR9Imx6M
b65EtM8KFRNcwJ+1TcmB+Q/fkWzP3uuLR8Cfvcof+0RUqtCLc3f1xWqgCwbN
9TzfXY0yg/LuvTAHf2QmpLtxTTWa+73naRk1OHNLOKiTwqUG8d80cqLaMf88
dVxoV5avRbfysz1UlcAfrwa5Nl/yOuTPufuT/wz0r5whLd1ldajhuX50r9uO
Ocd0uWm/Uz3a1ZeRzHsUnOnPVGw0lmxAEheo8k3qoP8kCa9P+NeAngTfqky0
AH/o1X7WLhY0oqQ/qc3Lu8GZIyFXasSeN6Fx3V39ZxOhS09HVr0424z2FepM
vlIGZ3TF1ivL1prRDe7k5Yo56BfK4kbIdVvQhxekmzSe4E/1VOvw4fwW9L1f
k/racXDmOv3mkBJHK9q8+I05sAH6sKjg0H27ViQWusUzcB/8sbp1neDd1Yqs
/mkcPUi3AL/f1w6DGWJtKPx2vJh5MnSr9oB77/8ck1Rw74zuiQKvmlzmduWn
WCAXi3g3tSjw6vUNdoG8FHv0ODZoQDUKvPKyHhijIX+Lwj7qPfm5DF71XTiR
nZvijiZkGN+rRoFXAaSoQjjZB/0tWG2NrAWvCkymEmnIAxCTSNf+n8vg1Uit
d8CwzicUoDmQxU8H51FUJ8+9yk0JRhG+jbqqUeDVCb9hE69d4ehbYwmJnRjM
UUIv5OKFkyNRFk1aXGQteCWRHMTNoxONsHyUSp0ezFFXh35405B/QXWv/VZW
l8GrO4zSu9aSY9EsQbqBvgK8eir78dmwTjxaenkhgp8OXHJ9OvOjnjwBrXGJ
WJ/ThjkqJP6SUW7KN/Qn75i8ahR4ldLr2xl98785VfsQx5058KqMdlLJa1cK
oljbN2crBi51XLpQ8jw1Fe32Zy3xcIR93OpZxc/CyWmI4Qy9b2QteLV57fH1
r87piLWZ8m42M7hEaRFCx6OTgbistsXr9MAlhjffq/1PZKIDtL9phuJhXuIM
XXxNQ56FBBKWBlaXwSv+bE4Jx54sFBjzU3sXD/hzokn218/kbPR55VEZfQX0
s1NWaRZvclCo9PxRTnNwSZokyGJYJxdF+NwL4KcDf1Q4yw9pncxD0UMTmycy
oGsJ/yDUk+ej2JN3zM5pg0uGymyfpXvzUcIrQovMP+gWd6Wu56YUoKQG3Quq
UeDSk1cWdCfeFqJU7u4YbQXwxyEwoDr6ZhHKsLhOd2duxzlPaslrjlPFKDu/
2fa+D7jkVzN90WtXCcqjVhm2FQN/QkeYfpH3laAi7Rql133Q4/5IpD1PxQjH
yWV6OIJLPW4i2XYypah8rXRf4CHwRy/wsp9wcin6LnfpfWQt9NFovYfz7GWo
xj9/8dsD8Mcs1Vrlq3MZqh8Vu5nNDP78KHQRMp4vQ01nMspxHvTHNaGUPDrl
qM3p5PE6PfDnV0f6WE95Oeps/vaxgwz8eTlSVep/ogL18BzZJsRDJ13oD1ML
qkD9VjHmMyrgz/s/S/Y05JWIUMTbtroMnZKKUqfSqhL10YZe3ApcJHZCDPfd
6OeUkgvvG/4QJsGrMI4TFzkfyqOyN+/VDo6BVy8pDF04HmqiOY+rEXxj4JUm
DjinwWyI1jpvsWfcgPsT5l48P8Hx0AT9N2gp8o2BV87n9A8S6iwQhVjBmxlu
OKfytI+i1WB+hHbrluL0G3BO1dPDTClWZo1c0dhmkQJ4xX/2PQnHw6dot8Yk
N98YePXg4+8/f/Y9Q553Z86/cwSv8lYt1gbr7BG93Q/tGW7Y95FrDC6WPnuF
fNwWn6rmgVdHeo6sqTM7IabQFf/0G7DvU6Eyspa1eI2udP/pcf8NXlmLBy+K
ljkjD8N/U0UK4NUnk/b7hzneooaZzV8LAeBVccCeWfaH7xCdzTYF3xh4NVoh
b0ZT9R6p/SNhvX4G5iiqVYfxP/tckfc7skPvHMGrEwfzjH7YuKEW+l0iuY3g
lYb6MmGwzh0xBlHIzHDDHPXM6ejtZj5PpMFHpc5tAV6FpRr3lj77gPy/URuq
5oFX5YRQrYxmL9QhsvuhIyW49JNybkad2QexFtM6pN+AOcol3OVrXYkPOh7z
vuqxOrjEJX7ITNbCFzWaUTW5/4ae3FgqUMTqhx4cd+2MidjhlYneuGiZH9q7
TD1YpAAudfzbiE6+74/Sst3GO+ehmwUEGh3mCEDq9rt/LASAS3+OiRyIqAhA
K5Ieq1QS4JJXRTOB/eFH5E++5++BMeh8t+6H+XAFItEaT7IL7uBS1gr1bZqq
QNTpSbf7+hlwSdE9lsv58Sdkq+7FeL8Heh+fTO+ffUGInW0v5ztHcOlBPuGT
TU0QyuvzPhB+GFwiVX+h9cPmM7oZwSCY2wg9YJqd1YQ3GP0x9j3V8mTHHOWU
1T5YF4xCBJnOznCDSwXs6n5atiFIYt5PkqwCulrq/LVmvlA0mM6swG0BLo0o
uO+93BiKHGwDVEV37NeeEA43lT4LQ7wXWTVV86BT2VZ4nj8Ujkq3P942NQCX
gukMlTOaw5FRJdtdR0rw52TsP5pjLyIQmdsny6Ad85JhuMq4OnMkilHlsEm/
AS4dng2Wpb8XiSSYPtvX/YWubzL68XrngZLkBxLfO5rBq7qO1aQMOkM8t+fr
DaFG8Ir7nNLhDLpHuNxUKE6wEbxqfcfxy53lGaar3ooqEgGvKmZWR9PpnHAS
86yaYCN4Fe7Tf4WH8S1uq+hQsSYBr56frchwZ3HFv23wlSIR8EqT8I1rnd0T
72XSPPRGBLz6JKNUlk7ngw9aXOEXbASvdrFdWjPb64dFy9HBRlPw6vHMaSEe
xgCswCXGZ00CXhGKDul1MAXim9ZHD7AH73gewYfD150lCFvW8fIWiYBX+cZ7
vkuxBWPku9s7bRK8OnyWZOMXeyi+fOkd/RsR8Mp/98/jyZzhWH1m+4OmE3hF
smiTlk4XiXU/2tMJNoJXOT1WdZ70Ufiu9JrnH07wyqrcbNxsbzS2mn+4p9F0
x74vyWhLhiEG236e9YjIBK/6Pt7i4GH8gh3lTWitScArH0dN4Q3GWOy6POQu
pwpeKd67qtLBFIf9wnR3sweDV1saSqapzPE4RKnTbWYS5qssCVknd5av+Mva
VZoiEfDK8vClYBPWBNx9zUROUQpc4mc4myXF9g0PxB18mzYJvW/jdBM3eyIe
+TdUwfkBvPIdOzr9iz0JT2qEkb8RAZeUGg+RtXEk47mvurI/eqGT5PLsS+ZM
wctb7G80ncCr3EgOcVeuVPzrRmd5yWFw6aw8zdd0ujT895sfmWAjdOYLlGK8
XmmYhPSajK8NeLVwkrzckz4dU2jTOf/h3HHuxE9y9Y9XOt6dXFdmXAo9jmOz
32xvBt5L7kraaApevab7Y97pnYFZbspLi9OBS3pk62syDJmYM5XsdUQm9PPr
q85pPpmYh6K0lFoXvGL5sbSXhzEL8996RWJNAi4tDc+HevhmYaH0C1L9cdAb
OmeFNhiz8Umq345yquBVfN1UjqlfNhbRy8bJq9Df4HHZDqYcfC7TepstGLwy
yBppkfbPwZdoTiMnKfDqQgJBL5U5F8sYzDvMTEJnC++f3ReQixWzv5VofACv
Vvx67NxZ8rAKrflWoQi4VO3Suet3QB5WMhKQFOiDXvditeDwa5GS86Ha/Vx6
4JX7yrpkz2drPKqX9RsbgFeZRQvR3Z+dMbVLvSo2AK8OOBkdrpj0wDxDEhHh
3rAfrOabvdH92Q8Hc2v/LjEAr169iWFTlfqEY6v3RqXYwX5QdOJ2T/lkCE63
qVEK94b9oC0/rWqoQiQmeEttVLXD+ZV6x9SJ7s/ReGwitLHEALw69q6Snmn+
C56+uBGVMwfnV5TiUYsqUvF4wVfTNsUO9oMjk69aXPwT8OpU+pU4cvCq6JNu
evlkIv59iZ433Bv2g58un/XbPJ+Ct5SyN+o+gFf5/9zOhyqkYdKnY2NV7XB+
dVjzd8L5R+mYPJKxqZwTvApINuXq/pyBKetRXokBeEVK2en+pCIT0/yyii6I
hf3gQ33Zv4zzWZiWL9QzZw4cG8hJt0xly8H0KnW2GWfAK6W9BwZUpHIxg91v
wxQ72A/mmnmpzN7Lw8zRh5W/FYNjh0r/Fbn452PWxhticeTglR+H5QmB4gLM
8duZN1oJvNp+1BtWPlmIufjTacK9Ye6yqlWkN2QoxjxqQ6ufO8GxAb4ch83z
Jdi3iHKx7gN4dcX+0GKwMcZMbfvHa06DV7fv1Z4KVSjFAVOivVXt0P0/kkxb
9Jditk3lpkpb8Kq+7Gzk+UdlOIjJuKKcE7wiW3igQ01RjjkF7fNKi6Cf54pj
6P5cjkMu+SaXGIBXjxQGa2JPVuD9179GF5GBV/HWLK+fVFTgCHP8qSAWOiFc
+bysTiU+4NDlmXcZvGKrd15mnK/E0f7zr3PmoKuu5ycMv/6ODyXsssvyAsfe
8i8bpbJV4bgS7vsZZ8CrwquCXA6JVViwQ9gorQP6yguDNhWpapwwo6SVYgeO
CX0NdOfurMbHtg2Vk7jAK8OORpnZezU4meWZ1Ldi6EEkFH/ztmrwqaPeYl8N
wavm4xKZLv61OA3FHY0jB68ob9pYagnWYWHNYt4vcdAvvfvGL1Bch7MsOlii
lcCrJ+kj/avq9VjcaY4m8gf0xEGOgPLJepz7kWw7zBsc66e5puL7ogGfSeT8
GSK8Y+6qx+Nx8pIlTZfmXvn7wPXBSDOWlDjCS5y2R+9QRihcH3xxeqowluCJ
yx71OKaHwvVBP7Y7DP/iPmKhW87zNJZwX+hUQItMLCEU1x4MPJEeCtcHw90i
Lhyhjcab7JZ3B9/AfVY1NV3tf+Ni8Rk6qRAaS7j/8ycVvVWLTAIWeb17hksI
vNqvKE8ZS0jCjX+f7EoPheuDh2RLmiUupWFT2yFeRQbwKm/05r4jtBmYZFnp
4uAbuG9B1XnNnLE3EwdbZmnZrMPcNcrnm/037r+/O5M81jSWcN+CXdlxsskn
ubjR0O1DBAHmrj1GNWotMvk4c/55B5cQeBVFcjekgKEQkxw7NTpxB+Yu8cjt
qS+EIqxqPr6YFgqO1aMQUe+kEhwc+3nzRdeO+xYehpRKXCrFk6NqtIoM4JU9
mpk8c6gMixzYxcl0BeYu+b1n6Y7QlmMnvfzDg2/Asb1Db0X2rZTjxuAHol+L
wbHelLabjL0VmKuHX8ZmHRz74nDAibK0Epux9l6VPAOOPVB7EPc37jvO1PDS
o7EEx87zFDUsfajCpD6ylh1fwDGKBZrViSfV+Grj72cRBHCspVibs/9WDVaj
0JYV8wTHQj7EohaZWrwWc6aOSwi8MtVbNfkuVIdDZfaok1RBP3NC2rOAoR7L
jkx2T9wBx/7988pIXa/Hs45l+vXb0KsbBnq+EBqwL0/oRFooOOYfenT78/dG
fK7Y9n7geXBM//4zAe+kJky4pb76ogu6kESV8lv/ZvzuzzF7ox3z2B+K3fkS
l1rw8c+UpIoM4NXw/GmV3LQW3H52xOV4MvTvndpDZw61YvuuQnqmHdcBE4sd
rJM+tWK+p4Ef1yeh+8TGUhyhbcM1zI/3Db4Bx2w/NARFObThhxnKMeUHwLFb
T1eP7Vtpw6zqh49+Ld5xDq/HhQNN2nHRIkn6B11w7LC8tAZjbzs29uo/a7MO
fc8J8wkPlQ68+0ROiU4A+LbC4v2MsrQDp9f7yEueAce6/2XTvhbpxDoWlg38
TdCLxwfC/8Z14m1qhes0luBYWAO5sC1XFw6PP9C3QAWOLTMyx9nIy5UY7j9r
EWwF75XyKYgXo9N8gwXo9peJuMD7Wwz2v/Tfo+mP28+nCYi4wHM3tnqHPP22
QzHLfKtFQx08j1ytZiqzRzMGH23Z6BZ2gfvY2x4USF49+hXXJbjbbwvC/QwE
L/qLfttJ2OIN9/6GOnhe+Kl2eojFbBp+f7LLQEUc7mewN+vn3KOZiTVDeNKF
XWCf6GRHEZSMs7EAtRkZZw/MXe9cTrFdPZqH156kXt8WhH2i+6ebAUsBBbhy
ZP3LxHOYu7zj3zD5bRfhADWpX/V1cN3wY26yj4gFxncLXRUzuGHuahyzdLGY
LcVcAeYqKuIwd7XMOSkU8pZj57o9T7E+ONa2+pFij2YFniFJDxN2Acc6/36r
vO1eidXPalbFpoJjPeSlb5Lxd5xvtbHA0QOO9dF2ymz9rMJ8X8LYPUnAsUHm
WdKrR2uwW5+01LYgODbMvV0aYVCLlxgmza3VwbFRfhanpYA6rKPo7jvxHByb
OCaEpOvqcemrkwU60eDYlIjklu92AxbMahutr4N95dzF68Wjok3Yd9aWFq2C
b4uy5i9FLJrxxgFu0QxucGwjtmR/+dUWfEcb3xaQA8f+Cim9sphtwRNV6TIq
4uDYZnL7ANO7Vsw1St79rg761hl9iULeNqy2qWmJ9cExkpzpEOOCNuzM8XX7
9wp0sgs2f2k123GuyB9/YRdwbFfJpm7WYjueU1MRvL/jPgdKGdeC2+4d+IBF
eFFsKnSqKiYuCoFOfOPd0rUhWXCM5krY82TciV0jZSY4eqDTNh3p1dTtwsWF
Ac817oNvdBoZ57Z+duHlrkk6TxJwjL5LIijOuxsLrJyL/h4AnUG3el3taA/W
pfMQ3xYEx5gI6trrlT3YS3Cw7lwxdJY7AzkRBr24XPaUgbU6+MY2acp2+U8v
Xtd/vZo4AZ3dYvnpUkAfPmbf7jLxHHzjXHjRGXSqHxt+FNjHSw+OcVtTiknX
9eOANLs0nWjo+3/5BMzcHcA19bVyfuLgG68990/f7QG8OcndW18HnXMr9vqF
4EF8lOyBFYUB+EY2WftjkEmpJGeUpOjXb7i/PSUtM/nNjAte2MyWbueH+0Uv
l+2bcJ75hPdeXkhv44f7Rfd1pm7wLUbhw76kFYXZ8PxygFKrk/NMPOax2m3R
xg/3i+4pWaEaG0vG3xgDVqruw3M3Mpzu1XyL6VgsZ/+LwmzYJzq2c9Fq/MjC
5brx5GlbMHcVfEhUc57JxXGOHApt/DB3/VKU8MuYLMBz6nruKpdh7jpD1tg5
OlaMzxyKbqq6D/dliRNSPN0elWLbX5NM0r7g2I2Ldil8i2W4qOaYdmE2OGYd
hFryrSowacijELE+cMxnjWpF/UclVrDKHkrdgnksWaOFedaiClfxbjJ+ZATH
6lODxJxnqvG0K69oGz84NrPHSJvLvBbTrkhr7RUHx6gshJ5nTNbhk7fuPlO5
DI4dql4OvmLSgK9Vvg920wXHZA4VFI2ONWKbEwlFVfdhX2n42plgf6cZBwbW
E8gdwTf0UMDJ7VELztueJ5H2Bd+awmh8O0+14n5zBn6HGPBNr2E+im+xFW+1
CssXZoNvP/60ZliltGG+i5pmv6vBtxdCORX5Vu1Y/oudm1gf+EarE9xBcaID
m9MFJ1r/AN+C3ztMqP/owJ62RY2pWzC/Hc2+8ysssROnDhEWfzDseP5lTIFq
1qIL3/tCQvORERxTYjrGIX60G//tYQzODIbeI7VXyHmmG3+g4z/Wxg+OmT9c
Pd/0tQfzyogWLSVBXw/rvsJl3ovTbOVV94qDb+8bCm+ZHunDMolahBM7noNj
+xtxP2OyD3cMmT1UuQy+xQq9fbUV249NWZ6TWLZCF9Mx97piMoDXL7v7uumC
b5XvVSICDw1it1chB7/uuC5wI/t02ujYIObOSMqs2uHe2BhL2ckYAk6eLJab
WINuw7TRan9nCEtyN3eSO4J7ryMfPB5jGMYtV4dND1KDb7W5w8/dHg3jO2+X
16V8oTM0azifahnGP/PI3Ay4wDedyUr3zlMj+N08M5dDDPTITXH/F94jmP2g
QGLocXBvmiUhhG9xBCdoiUsUZkM/dpz7S7XaKBb1UGzslQT3XF923xu1VS05
sXm+p+ocvM/T4cn0ZVtOT0x5YtevhiUv4tefNjqj95QzFDtju5X6JXgPA4Pc
eh07cyyWzvqVFSQK74Fx7dacesKZhEtd0x/VL8G5lpNYH+mMdzqOPCnO5qgF
+0QJRxofduZsPBTE/CRIFOaujZpzPAqBefgA+XJrOhPMXVlM5klPOIuwgVXT
qfolOO96ePvThZhQjJvnOhWszcAx1uvG49PeZXghsnLNQQscW123P+akXoHp
tTK/eMiDY62hftbszN/xCdro60Gi4FiK9Lf8lI4qrFrqQxbLD455TpaRKATW
4PtPHdPTmcAxC49exUHtOux59IFhCSk4pnh62esJZwNOHLq9t34J5jSBTuou
2v5GbFInMDT3EHwjtz+wPya0Ga8dChO3NgPfHu3dJ7w/tQW/c2Tx+q0Pvg2N
xHdOe7di1j6PCQetHe8hyRJ5nvWoDX8RJb9EoQa+Fb/H+5zU27Got32Ahzz4
duymcqmycAeunFmeY7wEvgUf6zZmZ/5vrpC7JxskCr7t3rpDNbbaicfDh4N5
ju94HrBl4VtKRxd+sqG98oUffJuJtlezz+7GFDealY7tuI6p85RyRT6wB39M
UYhKZwLfahT9PjLa9eLDNCW/z+4G385y8Zwf1O7DOcZi10pIwbf4HwkDX8/1
Y8WSpHi5DehsWMzpCecA7uY4tF23BPPee98yfqk/A9jcJkRLfRo8XDNWrabt
H8T/TGm65x6CeybivRbdhQQsx/KdLHUOege1CX1M6BD+UOZ00tpsx3PBVr91
ciWHcecDCV2xMeh9WiVH96cO4/37fr/7rQ/uMUq9/efMO4JNajPTC/t2XHcQ
utI0/Z8DKbYPBx20wL3XTAyRaiSj+Bf/MRqZNuj5fzsfZz0axZKtk6IUauDe
0niILNfIKH7vEG1YUwtdsMmI1Ul9DDcf0/f0kAf3DHOPTE2UjWH2Xs48tTLo
QZHzecrC49jgfecY4yXwsNkt0z09ehzHi/ju7cyDTmXz/DY78wReGla5GCQK
Hl64jU6+ejOBhb2ozW6lQdfqsRR4n3qtJHdM8V6jObyXWKZYjFW53RvP+V84
P87uAXO+7qXdV9ojcJTgT80x9hBiD5lblLMjxOO4N7GKs+pwDl8qVPZWqT0V
/125Nj7KDvvEFRGlUbrxTCx4xqF0fgGeK6RoP0NmR8jF7dPt9LPqcD7PYc11
cLinEDtGCulNZoFjRxnJZZTaMRbScUwcZQfHeHrWTvdOluH2vZ0bhB3vl4s7
MltKN16BS4xZv8wv7HifoR3hmszId+yPpOotd7w/Kq+qbdiWUI3NuS1XZtRh
XynNVv0osb8WS65/5DQnh/OxOpNCkuGeeszcXio1mQW+Xc9O9WHpasTTKXNm
d03Bt4FdXw4otTfjYnc271F28E34qEqP5HQL9jOVzjGshfP/dXWFA72TrdhM
5v4gYcf70AqfS5nbTLRhHm9l55Ns4Jtj1IU0uvF2TL05/HF+Ycd7XWpFf8eP
duBVC9uEpGpwj3r5pJTMSCce7KEtttzx/qVGDiHXgaEuXKMQ1XL0ObjnK8Xf
YkvoxhlZ4uMz6uCelvl+DsbBHhx+sGH969Edz0H7sBsm9vdiNx8jWnNycG8k
l/GrfF8ffrL1i+fIAPS4IdqloZ5+bHDfU3gyCzy0pKI8Z989gK/08SnEfgAP
T58icWLpGsRil3Nv3jUFD9e0/lSndBAwX46KFT8CDwsdfu5Vah/Cew6NOo2y
g4dS19cTl82H8bqvXUDUEvSDZj+bJaeH8ej2nq+GteAkxYvlVQ+zEdxoFV3I
Gw0eTnstsPdOjuC8/rPNBHvwsC567uJh01H8RalxNOw6eJicM21gMzGKq2+d
eXGSDdzzrpt4U3p3DBcz/dvl5QzdmjAaTzc+hjNrq7zmF6BrrgzV6xqP469O
vhyqt8DDs5SDi/Gj4zj87O3opGroXFx9zGtGE9h/4fDxPaI7zv1OdJ+VGZnA
brHL2ZY7npseku645W04iR1uF6H6PeBhuWar48DQJH7C7FJ79Dn0L/eaYoQM
prBFnfp19wnoLq/qq20JU9jg9b7BGXVw0ti3Zq5CbxpfOzdlqlSy43kBbrkU
Oz2NEpeNA61R04pEr2S9qq4lvfHFtY2kRhyN72HeaOkrTnwThaVwURR7YyDM
S7oa11/Lf8NNyi/dWjlhn8ixcvdJ4pt0/Pcslwx7I7zXdzHnAAocz8ZCh/L+
3HaC53eqXwzQvJYvwMeoE2+2csL+MUIqqMMyrgTLbm2IPVmFeayQ7NvVxDdl
+ObPy0zsjfAc4uEJquwDWRX44eynhfw42Ff6VZtwBY5/x++GJ+tuO8HzPpsJ
FY60rDU4tEssfvsm3Edh7sk34SRfh2+alku3csKc1vHA8cqvpw347shMavR7
8A2pD6ZaxjXhh7cZeZ6swvzW+TnM/ZFlC7bvPucpbwjzG62HyqXEN634vYbh
H7ZGcE/65d/FiZA27NvoYj59Hq4L2Fp9iz6Q1Y5DL6d25ceBe0n6NzVvNXTg
+IouOQ9mcG/0KjV14HgnzpDcyrjtBO6xS+cWtPzrwsX5Anwn52HeUxU2taJl
7cE1oqre2zfhOsIbftYDCid68ax2gYO5MbiXx1LZ5iTfhx+yNom1coJ7ixQ2
7wr1+vFa28iP8y3QBdb5zv16OoBf+qzFRL/fcZ//dMvsaa9BTKZGc4v2Enjo
1+sYZhlHwK60+5merO54n1XdyWtxJUOYvvZ07UACOElCePD6keUwDngv5yRv
CE6GaFX1fVgfxlxyOmdT2MBD8eb9oolvRnAk6f0FtkborYpPP9TsHcWHsWOs
4xtw0qq0YXIiZBQnvfS/PX0enKQ+f0iKXHAMi1yIZ1Zfgh6T/uLzgawxnL9e
UJcfB35KHm1fuSQ1jlF20+uDeuBnX/RRlVsN4/i79eg5jx338T7ldo59pjOB
lU//Wlythc4Q0Lv1cXwCt87TxN92Aj8T95zRyXw0ibUT9+t/Fwc/Fd+5prf8
m8SD5mdYT85DH90c2r3gOoWND8s3BMaAq69sz96lZZ3Gs2M6b7Zvgquci17F
glHTOO+a+H5RanAyy2ySTeHEDH5xqvSZuTH0q8OXHhnnz2BJ+isdoSXQZ3U+
1jrJz2LS+fZTrZzgp2Prj4PhrbO4tF7Pg+IpdLWQIDfxkuslqfqejL/IZYle
nXZqnmHu8MM23oIXnxx0Jn79eP2gMnNHNJ4iUMfYHIRz+NTu9uh9kkmYxfaV
YLIIzF3Fy+P/mDoycBTlhpbNQTifj143+MrulovPamRyMiSCY66bfdf3SRbh
pjCrgSQRmMdySRMdfZ6XYpOZIxFKRXB/V8Jb806mjnL8imv5tM1BOM8PpTp8
7OPJ7/iylJpfmSnMaV7uY07sbtWY2TRxdW8i+OZEF9X1eawWEzyoNfUX4Xql
jY/+8X2SDTgh3SQnSQTmNxPmfc7hQU3Ypruc/a8dnKcdr/9h6fO8BUtu8j5X
KgL3Yj3rA1vjWvE7X8l5ZRJwj0ftWxlTRxu2ODS/3+bgjvvK9rr9uE7aga/m
hqgFy4F7DK1m7B9PdmKxK1ccy0xh3nPzU5DputWFuQZ/p067gofkNwSs2N26
Mcmj+OG9ieDhS9ZdQTo5PXiCTIvxbOOO5yi7Rss/j/Xiuo+7ZPQXwckHQWXz
fQz9OE0w0/odI1w/nboZybFPcgB/LDSKSRIBJ424HWX1LAfxSzWGjnZNcLJ/
QO9BeBAB3xkp2fXXDpzUDJf4PPR9CF9+YiV2MBjmxulUujs+z4fxSap9pkpF
4Gcsw6v10wwjeLeqifK5HfvlO49/eLbGjeBXgUVjyiTgJG/brYPWl0bx8hDz
SwNf6APC9blMHaP4rpAli82O93x+9r+gmmkxhruty5PeZ0LX+pkwep10HF8p
4pQPlgM/mTU5n/38NI6LKR4PJndCb8l2pft4cgKfvlrztMwUXP3A9jta7PsE
jgnipe9ch37Fzuxc161JzD5qGzftCt5S9XQ12q5M/l9X5x1P9fvG/yihUKk0
JZVKaJgNuVsUDQ2jktGgRWVEJCLtoSEqRWnJKEpk5J1RsvfeW4iWpIzf53eu
+3tffr9/n4/zOJ2Oc173fV3nul4v7pJclkbvoHm85MVaeydcbOb67GSKRwUj
d7v79k+UVAt3LN756Ex11FuNv7OubY9s4eoFCwTVMpH/2+k1s2fDF85gi9xD
HRPU23exQ6Pv1n/hUu+5LzbpRH58qu2mpU6t3PKG0hzr06jDiqfq6stGt3Fh
CosOnh2DOtxZucXx5PM2bqbDBb67g36vCdFIEJuq0c55f6i+G6KEOrzHf+GT
uIJ2jn+EmuKHZOSuXmo/utP14gP3HL4R5beM6VXN88YVBoW3uJQXG77NM3RC
nWw5e0+/8DGn/tVg7DxDzIkI7b0zbsiHUC4tcbWhaQLOP5wVMlirX/iG+y1W
8UTWEH3a39409QhKe8fdUFja42iPvjQNUw8mDHDvuefbhk83TcB5iUvblrgG
7Uzg4h3ztNaIYH/s0cR4Sf3CJC7f389K1hB9Id5Vroob0P3EtXw85CUWgPMV
2QEpO4PSPnMDx30rHe2xDm3av6FHTzOdE77IZ90+BXWvTz7XZ4DL5Mbd3z/M
NAHvdSN65k3Rl8zhpF5l+uRa4O8F3kZWh4J25nLzEpXk1ohg3Sod/yp6wCeP
Uy68Gx8ZjnoYOv2HkH5hPkdaBrbIGuLc7OIzytuDxAs5nX/mjb69qJPJjfbP
B3SLOD2xjBNiAaiTuuuif+tdLeZMpRVF3NaiTpYH/dMMSivhVCZnZDvaY/1r
Iapxe0CwjIuZ6TpJSRv188fR0w16muUcUVDc2z4F9fNUXqJSkHsF91G1MeRp
B3JhFYEzA1wlp7Pizm+TBNTV2z5r8/T6qrgc7fUrJnqhro7pSx6tL1nDGWzr
v5hrgbpqON/i3UBsDVexKzz/0hLU1QemgmZBO2u5PRb7JNeIoK42XA8U1O+p
5VqOTtjfV4V8XqL2qwGfOu6IY1pYZDjq7bGfrQZBqvXcL/dTf4964L00ctaV
fr3Ces7pysI1soaow336Cs8GbBu4Id71V+tkUYdXn8/aGCTeyJ3z9y727UV+
8d3RLr3wRk7khba0fjbqc/aX0Q8GdJu4m697D4kFoD5LTHm9JqijiZsY9yoi
xQ71edeGbe16V5s5v497+k+vRX0OOPXr1oBcC3ezecQsSVHU55aXt5cFpbVw
+pYNnx3tkS+oUa3XO/iFm/j9vVVR9aB9sTEllwYEW7ny4z7iStqo27GrHBWD
nrVyfn+PRXm+Rs5nN7lMT7ON2+2qs6t9Cur22qexbgP1bdysYbP4tM8iv1a0
SzbIvZ1rvtD39GkH8gLB/hw96a9ckGixDv921PPJS/xPDHBfOaubYZ0mCch3
HFoxPcikg5ObcMkrdh7queRe696N7vrxMlf9Zx9MWMj0qutUyPclZ7y4muen
Sg90HWWPFxe7p7nkzBPOYfz+zP1d6OsuW2l8szD5JecSLOgj+uc849OLrncu
PhPBrcwwWru/C/3eg9//GC/4JJpz/1180qwH9U3tqZ56YXI8Vz+cX0/0D/rA
79EyCs/9kcBpTZCXj/mN97c5S68kLz6TzD2bYzBsfxf6w7crvC/2H5vCDZ26
okP4L9an4dIdrcOfpHLKs/R3mvWgHjqMl+q3Uv6vvpM/9CnyD/oNqgtvHlOY
nMV5Kbsqiv5BnTztskLcLyiH+6ju5be3G38P3funxDf3Ry7XtebFiJjfeD/U
srGWEViWz8lsjLcf/Rv1c2678KvFZwo4A/38OosuvDeOtAhYbJleyCXNt3tu
8hd1taN6aaL/2GKu/LVLpfBfrJdzduSvzzcq4X6qXhz7tgf19k3+4cLhT0o5
kdhb2mY9qLe3Nw4zXdpexs0ifq4je/D+eSLlfouVcgWnnhT4NvIP6rDRShWb
R86VnN7aN227/+C9dHls5r+C5CrOMv29tOgf1Ofrk9+s8hhew53V/Wz4rhv1
2d3QVdAvqIbzy8+7urcb63Q7r/UZUZtquSjDyiSxbtRti9wJN3J/1HI55c09
0b9Rt7eLNei3eddxX0x/LDD/jXW99vqwyQLL6jn+hl7z0b9Rz5ddcK6eVl3P
TTkgeD+2C/uZCh/XPVl8poFTbh+TZ9GFOi/FP/7g1jmN3OzFYsMuOqHOjyG1
CpbpjZyS01h/k7/I+Z1Df5w92sSRuIlLlZ1Q/3+9c4zyH9vMbeiXLBT+i7yp
S9M5OqqZ275i5rFqR9T/EkXxlflGLZy5+9yRb3sG+dkerRL4OtDCWScrPLvk
iOdCbEhQ2vAnXziX4UorzXqQh36x95y+rpW7tG5xhYojnhf+s1frLW1v5Xwu
LXcY2YP8xt5Rk/Sut3GPM1aJ157Ac+TMw/JKK+V27pXYutDIP8jtKp8HnC9p
5+I2b1x35QSeLxaT7fY/cv7Kfb65tX73H+TbDVfIx07v4AoLDF3UTuD5ouMl
8r0guYOrlTCeJPoHuXJuyduOA51cy/Y9EXUOeO4UPLqsvLRKP97r35gbYfYS
TK9+Ta8Rbijz4roESrfpWOqzx2/W7dhZX/aEs3Sb+VDbEnO+Zl9rD9Nb94rr
JAoj1cYcY9zF4vjQ+rIIbi63TkvbEnN2Ws7avfQdE8OZaexzM0rB+9u2p7Y7
9NZxXGYVqVIdg7lgpnuWuJ8jidxBv8x/XDzWp+N+vCuuK0vmBEyMJmlbYl5P
qttiBWKfwj2S/KKaNwn9nF3GvHP3HZPGLa+01zNKwfuh0iO1ku6QDK70/jCb
Bjv0U21ZGKWgty6bWzo/NUV1DPoWbjLzXVnyPYcTErtu8G8/znvIzjWyPEfy
uKKvBo1cPNbLQ79N9lG+ms89yZS08xiP+wJVUWUJdWUFnE1oA7+2JeYHvXO9
1359bhG34mrwDdEk7BPeWrtzArEv5sSsbKbnTUI/aqtRk1d9TSrhKjYseeV9
7C7j64pLLX3HlHFB8kM0jFLwfjvD/66Ptmk5d0IkJUNq2n3Gey12JHaHVHBa
7VeNGuzQP7Z4/qSvT/9WcuMy9FoD0/F34fDfJRP01lVz3wuvxqmOwXuylukG
ab71NVyJ5vehd+OQK68OUS35XsN9eKu3/t9+PEdmzBHZ8OpOLfdc5t1N47HY
Nxg90nL3OVLHed6eUsbFI+/rSLc3bqrj7AVcpWccwnOnLU/uivLVes7keN0B
j/H4u09p5OVHI5UbOM1GzbCmD8g/3WuLrCtr4BT0X3Svs8RzKsJlfUa0WyM3
7qMICZ6A/YqAPcG11+c2cf+Uj50TTUJ+XWtk9/7sJq7+SX7m0SN4rp2ad1iE
2DdzaePUxudNQh/Lw2Lp0hKSLdxrj3u7lD8i3/FjntrXpBbu7q++x97H8BzU
Krq0IfnQF85t3+62P1OwjlCOad3tO6aVO1CQrGiUgnyGn46DzbtWbvOauU7v
B+WzjHYPuqJt2sapRVxOkJqGfeM+8xEB04e3c1KzOoXcU5G3aR+K6g5p54Z7
bd3cYIfnbKlCWkbWtq9cx9BIH63pg/ZZxsyre/r3K1doO6k6MB15RNfFbudH
Hdz7eufZIx3wXA4o/SKit66Ty5P9Fqk6Bs/lC++1Z8h1dnKJtY/Kmi2Q51O9
Kuvl6VX8//hPqldygjy94v7HdalePXbn6RXjs6helazg6RXjzlSvTD7w9Irx
ZqpXjYSnV4xvoXoVWc3TK8ZNqF45+vP0ivGxVK/UTXl6xfhnqlcD03h6xfgp
qleJVTy9YnwR1SsPP55eMd5E9WrmAp5eMb6R6pXAKJ5eMT6X6lVTB0+vGOen
evU5i6dXjFdQvXrxkqdXjEdRvbp0jadXjN+gemV5hKdXjFtSvdq4iadXjGtR
vZo/n6dXjE+nejVajKdXjP+jevX9K0+vGC+kepWXydMrxl9RvSor4ukV45pU
r9K1eHrFuBLVq7hInl4xLk31KnQ2T68YF6N65e/N0yvGe6leXR/O0yvGW6le
udnz9IrxYqpXNk08vWL8I9WrvQY8vWL8DdUr/U88vWL8IdUrLVWeXjF+jeqV
2jOeXuHnn+rVXAmeXjF+iOrVpHM8vWLckOrVyN88vcL3k+pVrzlPr/D9pHr1
tZCnV/j3pXpVpcnTK3w/qV5lv+XpFb6fVK8+yPD0ivEvVK9e3+bpFb6fVK8e
C/D0Ct9Pqldex3l6xfhrqldnG3l6he8n1avYeTy9Yvwc1auwOp5eMT6R1oPH
oR5kevWd1oOOgbx6EP+/tB4cJcGrBxmfSevB71APMj6V1oNlUA8y/ozWg7VQ
D6Ju0HrQQJBXD6Je0XowHepB/HdpPUjm8upBxltoPbgD6kHGQ2g9eAvqQcat
aT2YCfUg46q0HhRU4dWDqHu0Hly5nFcPMm5G68GTmrx6kPFVtB58C/Ug6jyt
BzuhHmRckNaD4xbw6kH8/NB6cNEbXj3IeAatBzep8epBxl/SevAw1IOMX6f1
4AWoBxm3pfXgU6gHGden9WAi1IOMq9F6sBrqQcav0nqwD+pBxl1pPTi5gFcP
4vtP68HF23n1ION7aD1oUMGrBxnXo/WgrRmvHkR9pvXgDagH8XXSevAV1IOM
y9J6MBPqQcan0HrwONSDjIvQetAD6kHG+09CPXgL6kHGv9F6MADqQcZraT0Y
DvUg4/m0HuSgHkQdoPVgFtSDeK7RerAS6kHGA2k92A71IOP3aD34D+pBxq/Q
enBEJq8exM85rQcnjeLVg4wfpfXgnC28epDx3bQeVL3FqwcZ30rrQc1CXj3I
+BpaD+pN4NWDjM+n9aDxDl49yPgJ2m//Df12pldltN8uHsTrt7PHa9N++3no
tzP+hPbb+ZN4/XbGT9N++4pRvH4746G03/4B+u2Ml9N+ezX02xk/S/vtA9Bv
Z9yX9tslH/L67YyH0367+idevx3vXbTfrmDP67czXkX77cuh3874L9pv3wD9
dsYFaL/dCPrtqAO0334Y+u2o27Tf7gT9dsaf0377Rei3M65I++13od/O+Hva
bw+Efjvj62i/PQr67fj5p/32vdBvZ9yU9tvboN+O9xPab7eFfjvjx2m//S/0
2xkfQvvt7tBvx88/7beP0OH12/H7Tvvtt6Dfjp9n2m+fYszrtzN+h/bbH0O/
Hf9etN8ud4zXb0f9p/32COi3432G9tvVz/D67YyH0X57MvTbGe+m/faN0G9n
fDnttxdCv53xM7Tfbgz9dsZTab+9EfrtjI+i/fYj0G/Hc4H2239Dvx0/57Tf
zkG/HXWP9tvPQL+d8Tm0374W+u2MW9F+u4g9r9+O90nab8+BfjvjPbbQb/eC
fjvjhPbbt0O/Hb+ntN8+9SKv3854Ou2310C/nfExtN/+FPrtjG+m/fZ90G/H
eyadZ8iHeQamV3PpPIM3zDOgntB5hhHVvHkGxgPoPMM6mGdgPILOMyTBPAN+
Duk8wx6YZ2D8JJ1n4PfjzTPg54rOMwTAPAPjj+g8w0OYZ2D8Jp1nOArzDIx7
0HkGDZhnwO8jnWcQvcKbZ2Dcgs4zVMI8A97b6TxDCMwz4PeFzjOchHkGxh/Q
eYanMM/AuASdZ7gK8wyMX6PzDHYwz4D3LjrPsAvmGfDeQucZVsM8A+N/tsE8
gxzMMwy6T8I8g/hQ3jwD3t/oPMNfmGfAew6dZ6iDeQb8PNB5hlSYZ8D7D51n
eA3zDIxn0XmGezDPwPhaOs9wBuYZGK+h8wyHYZ4B3086zzAP5hkY30nnGfxg
noHxCXSeQbyGN88w6D4D8wznYJ4Bzx06z/AP5hkY30jnGY7CPAPjI+g8Qz3M
MzD+ic4zGMI8A+obnWdIh3kGxlfQeYYVMM/AeF8xzDNEwDwD49F0nmHucd48
A+P2dJ7hPswzMK5E5xnGCPHmGfAeSOcZzsI8A94r6DxDD8wzMH6QzjNYwTwD
47PpPEMtzDMwXk/nGQxgnoHxh3SeIQ3mGVC36TyDGswzMP6Mzou+gHlRpleL
6bxoK8yL4vtP50V3w7wo48fovGgTzIsyLkrnRacu5s2LMl5H50W3wrwo3m/p
vOgamBdl/CqdFzWFeVHUMTov6gTzooxPpvOiXjAvinpF50Vfwrwo4510XjQV
5kUZ30HnRW1gXpTxJDov6grzoowr0HnRKzAviucLnRe9C/OieD+h86LPYF6U
cRU6L/oG5kXxnkDnRRNgXpRxfzovmgXzoowX0HnRcpgXZVyYzou2wLwonpt0
XrQL5kUZt6PzonzbefOijL+g86IXYF4U7z90XnRUPm9elPFxdF7UG+ZFGdeh
86KSMC+K93M6L/oE5kUZj6TzonIwL8r470qYF30D86KM36DzokthXpRxeTov
mgDzooyn0HnRdTAvirpN50WzYV4U9WQxzIsawLwo4z50XrQS5kXx/kznRc1h
XpTxTDov2g7zoowfoPOitjAvyvhQOi/6F+ZFGfej86JuMC/K+BI6Lyp0kDcv
ip8TOi/qCfOijB+l86ISDbx5UdRnOi+aDfOijD+l86I3YV4UdZjOixrAvCie
d3RedBLMi+K/S+dFS2FelPF1dB+nCPZx8H5F93GEvXj7OOzxuXQfh4N9HMbP
032cONjHwddP93Em/eTt46Be0X2cZbCPw/j3PNjHaYV9HMb56D7OXdjHwXs1
3cdZC/s4yOk+zi/Yx2Hcm+7j5MI+DuOSdB8nEPZx8PXTfRxX2MfBzzndxzGA
fRy8V9N9HAXYx2F8Kd3HGfaKt4/DeALdxymHfRy8p9F9nNewj8N4C93HuQj7
OIyH0H2chbCPg393uo8zBfZx8Jyl+ziCh3n7OPh9/wb7OD9gH4fxGLqPUwX7
OIy70H2cVNjHYXwV3cd5C/s4jA+n+ziPYB8H9Zzu41yFfRzGPek+jiPs4zC+
je7jWMA+DuMT6T7OVtjHYbyC7uNowD4Onu90H2ce7OOgntB9HImbvH0cxsfT
fRz+IaL/dx+H8W4n2MfpgH0cxkvpPk4Z7OMwHkv3cT7BPg7eG+k+Tins46Bu
032cbNjHQf2k+zgfYR+H8TV0HycW9nHw/kP3ccJhH4dxIbqPEwj7OIy30n0c
P9jHQV2l+zhesI/D+Cu6j3MJ9nHwvKD7OKdhH4dxW7qPYw/7OIzr0n2c/bCP
g+c13XdeBvvOTK92033n6bDvzB4/lu4734d9Z8b/roZ9Zz3Yd2b8MN13LoN9
Z8aP0H3nMNh3xveT7jv/hH1nxqvpvrMa7Dvj+UX3nR1h3xn/v3TfuQr2nfE8
ovvOA7DvjM9P952nw74zfq7ovvNK2HfGf5fuO++BfWd8/+m+8xnYd8bXQ/ed
n8C+M+Pz6L7zR9h3xu813Xe2hX1n1HlH2HceJsPbd2bclO47e8G+M36u6L6z
DOw7M76M7ju/hX1nvC/RfWct2HdmfALddy6GfWfGz9J95/2w78z4zz7Yd/4D
+874/aL7zpdg35nxHLrvPAX2nfG+R/edQ2DfmfGXdN9ZA/adGZ9K952zYd+Z
8ct039kM9p3xcxsP+84/YN8Z7zN03/kM7DszXkz3nUfs5+07M65J9523wb4z
4xF039kX9p3x+0v3nRtg35nxVLrvrAD7zngPp/vOx2HfmXE1uu8cD/vO+P2i
+86Cs3j7zow/o/vOurDvzHgl3Xe+A/vOeB+m+861sO/M+Aa67ywL+86Mn6H7
zjaw74znHd13joF9Z8Z/2MC+89Ba3r4zntd031kL9p0Zr20EP5kE8JNhenWN
+sn8BT8Z9vi51E9mMvjJMD6M+smogp8M48epn4ws+Mkw3vge/GTegZ8M43LU
T0YL/GQY30v9ZArBT4ZxX+onEw5+MoznUz+ZP+Ang/dY6idDwE+GcWnqJ3MW
/GQYX079ZDLAT4bx7dRPZiz4yTBuR/1kdoKfDOPXqZ9MDvjJ4L2I+sn8Aj8Z
xj9TP5kJ4CfDeP1B8JNZCn4yjA98Aj8ZE/CTYXwK9ZNxAz8Z/JxTP5kn4CfD
uCz1k/kMfjKMR1E/mTbwk8HvKfWTEcvj+ckwXkD9ZJTATwb1ivrJGIKfDOPf
DMFP5iT4yTDuSv1k/MFPhnFR6ieTBH4yjN+nfjJ24CeD5wL1kxleyvOTYTya
+sncAT8ZxtdSP5l54CfDeBH1k4kDPxnG91E/mU3gJ4O6/Rf8ZGrAT4ZxN+on
YwN+MoyPpn4yAto8PxnG/aifjA/4yTCuQP1kZMFPBs9Z6icTC34yjGtTP5mN
4CfDuCX1k6kGPxmsF6ifjDX4yaDOZ4GfzNBonp8M3qupn8xt8JNh/CL1k5kD
fjJ4TlE/mWjwk8F7EfWT0QQ/GTx/qV/fQfDrY3plRf36FMCvD7+/1K+vAvz6
8HVSv77p4NfH+BPq16cIfn2MP6d+fYXg18d4EPXrcwC/PsYNqV/fVfDrQ92g
fn0m4NfH+A7q17cA/PoY30n9+gbAr49xI+rXlwN+fYzvon59j8CvDzn167MB
vz68D1O/Pmnw60NO/fougl8f42HUr+8H+PUhp359O8Gvj/Fw6teXBH59yKlf
nxz49TH+mvr13QK/PuTUr68X/Prw80n9+vaBXx9y6teXAX59eH+gfn0q4NfH
+Fvq1+cHfn2MR1K/PkFpnl8f4xXUr+8Y+PXhuU/9+r6CXx9y6tcnDX59jFdR
vz4D8OvD+/Nb8Ou7DH59yJeAXx8Hfn2M17wHv75f4NeH5/tK8OuTBb8+5B/B
r88Y/PrwPqwNfn03wa8Pz51M8Ov7BH59jDdsAb++f+DXh7wQ/PoWgl8fnvs7
wK9vH/j1Md5UCX59d8GvD/lu8OvLAr8+xpsbwa+P35Tn18d4y0Hw61MDvz7G
v3wFv77D4NeH3Br8+h6CXx/jrV3g11cIfn2MtzmCX59wM8+vD/+/feDXpwZ+
fXhepIEfchH4ITO92kb9kKPAD5k9fj71Q/4MfsioG9QPWRn8kBm/R/2Qc8AP
Ge+r1A95+ESeHzLjntQPWR38kPH7S/2Ql4AfMuqzFvghF4AfMuN/VoEf8hHw
Q2b8AvVDFgY/ZMYnUj/kx+CHzHgg9UPWAD9kxhdTP+QS8EPG+7wZ+CHHgB8y
6if1QxYEP2T8+/qDH7Ie+CEz7kj9kB+BHzLjHtQPuRP8kPF+Tv2Q1cEPGe/z
1A/5Ivghoz5UgR9yEfghM/6U+iHPAj9kxq2oH7I1+CEzrkL9kOPBD5nxPknw
QxYBP2TGP30FP+Sd4IeMf3fqh6wHfsh4TlE/5H/gh8z4dOqH/Bj8kPH9lAc/
ZB3wQ0Z9pn7I38EPmXEn6od8B/yQGV9N/ZAJ+CEzLkL9kJvAD5nxwmXgh3wV
/JAZz6Z+yMrgh4z6T/2Qy8EPmXEf6ofsDn7IjDtTP+R54IfMuBn1Q84FP2TG
11A/5BPgh4z3Z+qHLAV+yHhfpX7In8APmfEfa8AP2Qr8kFE35MEPeRz4ITMe
Q/2QY8EPmXF/6oe8B/yQGT9D/ZCFhXl+yHgPp37IL8APmfGjNG9CA/ImmF4p
07yJZsibYI83pnkTopA3ga/HFfImZCBvgvFjNG/CH/ImGB9D8yaCIW8C/44N
kDcRBXkTeJ+neRN1kDeB99J8yJtogbwJxtM8IG+iA/ImGPdVgbyJn5A3wfhh
mjfRA3kTjC+jeRMDkDfB+EiaN8Gvw8ubwO81zZsQgLwJ/DzrQd6EEORNMK5B
8yZGQt4E488EIG9CFPImGBejeROjIW+CcXuaNzEW8ibwviEGeRMSkDfBuBbN
m5gEeROMv+Qgb2Iq5E0wLkHzJqZB3gTjLjRvQhryJvC8/gx5EzKQN8H4Zpo3
4QV5E4xHO0LehATkTeDnhOZN3IG8CcY1ad7EZMibQP2heRP3IW8C/19fIW9i
GuRN4D1nEuRNPIS8CcYn0LyJGZA3gecCzZt4AnkTjJ+meRMykDeB98w0yJt4
DnkTqKu/IW9CFvImGJekeRPBkDfB+FaaN6EAeROMn6N5E68gb4Lx2OeQN7EI
8iYY78yHvIk3kDfB+CyaN6ECeRN4D6F5E1GQN8H41e2QN7EY8iYYT/CAvIkY
yJtg/HcY5E2oQ94Efq9p3kQ85E3gOUXzJhZD3gR+f/dBntcryPNiejWa5nl9
hTwv9vjdapDnlQx5XqirHpDnNRryvBgXpnleLyHPC/+OnpDnVQh5XqirqpDn
9Q/yvBgfVQl5XmMgzwvrgpWQ5zUL8rwYVxoPeV6qkOfF+MUWyPPShjwvrAti
Ic9rF+R5Ma7sCXleRyDPi/FLeyDPawXkeWEdoQJ5XjqQ58W4qjDkeW2DPC/U
jQ7I89oFeV6Mfy+GPC8LyPNi/H4C5HkdhTwvfJ5gyPM6AXle+DxekOflDnle
+DwukOd1GfK8GF97APK8vCDPC8/ZLZDn5Qd5Xow/WAZ5Xs8hz4txbRnI8yqF
PC/Gf4lBnlcV5Hkx/vAP5HnVQ54X6kMd5Hm1QJ4X493pkOf1FfK8GH/8FvK8
fkCeF+Ob/CHP6w/keTF+ag3kefVBnhfj25ZAnhc/5Hnh/YTmeQlCnhfjAzMg
z0sE8rwYL5gAeV5jIM+L8SARyPOSgDwv1D0+yPOaCnlejBv8hjwvacjzYly+
DfK8ZkOeF+P8NM9LDvK8GC8ugDyvhZDnxXhoKuR5qUCeF95/4iHPaxnkeWG9
8AbyvFZAnhfjCwIhz0sT8rwYF3gAeV46kOfFeNkNyPPShTwvfH/OQZ7XBsjz
YnzS8/8nL5Xp1esp/09eKnv8DaH/Jy+V8ScJkJf6C/JSGR/iCnmpA6N4eamM
71KHvNRhkJfKeIUz5KUKQ14q6kM55KWeh7xUxhcvhbxUYchLZbzxDuSlXoa8
VMZvdUNeqijkpTK+wgDyUj0hL5VxhzLISx0DeamMZwpDXqo25KXiObUE8lIv
QV4q4ycPQF5qOuSlMp7rA3mpIpCXyvjcFMhL3Qh5qYy7/oa81GuQl4r3cxnI
S82GvFT8POtDXupoyEvFz6EH5KVugbxU/Py8gbzUm5CXyvjCeshLzYe8VMbX
CENe6jjIS8Vz/CHkpcpBXiqej4shLzUD8lJRJ3MgL9UK8lIZ/7kf8lLFIC8V
7/MDkJf6CvJSGV/vA3mpmyEvFfVtPuSlfoe8VMYDPkFe6k3IS0V9M4G8VCXI
S8X7fBfkpRZAXireh69CXupxyEvFe5EM5KVKQF4q4/1xkJcaBXmp+D3Vg7zU
7ZCXyrh+O+Sl9kBeKuN8HpCXeg/yUlF/pkBe6jLISx2kM5CXWgF5qagn6yEv
9RTkpTIeXgd5qdMgL5VxYyfIS+UgLxXvJ+KQl2oGeamMR7yAvFQ+yEtlPOwh
5KUGQF4q4+7tkJe6DPJS8fNWAHn0qyCPnumV7wXIoz8DefT4d9SHPHoryKNn
fI4t5NH7QB4944HLII++FvLoGR/HD3n0vyGPnnE9C8ijF4E8esZvp0Ee/Q3I
o8fzi+bR+0IePT7/Lcijfwp59Ph5oHn0YZBHz3gqzaOPgTx6vLfTPPpkyKMf
9HeBPPpmyKNHnVkDefTtkEfP+Dp7yKP/Dnn0jB8IhDz635BHz/iFMsij/2fA
y6Nn/LkI5NEPgTx6xlM0II9+OOTRM267GPLoR0IePerVFsijHw159KjnNI9+
POTR472F5tFPhjx6xt/QPHopyKNnPInm0d+CPHr8e9E8em/Io2e8gebR34U8
esa7aB79fcijx+/XZMij94c8esYllCCPPgDy6BmfvQHy6J9CHj3jauaQRx8I
efSony6QRx8MefSMb/eBPPqXkEePf8cwyKMPhzx6xh1TIY8+AvLo8Z5fB3n0
UZBHz/i9f5BHHwN59KhXlyCP/j3k0TNeSfPoP0AePeMWjyGPPgny6BnvoHn0
nyCPnnH7OMijT4U8etRVmkefAXn0jJ8vhDz6bMijZ3xUHeTR50EePeM+NI++
EPLoGZf6B3n0JZBHj583mkdfAHn0qG/VK5d5fFusIXO8rK6eD/VqRXPujoTP
DkRKMygmUQj1yuLjxpsfPp8nQrN9xROFUK+815cuu150g7jJ1qbMEEW9coy4
PP/DZx9yyvtWfILQoPuVpIb0t5gHZMkd1Uk/RqBeSa3+I3y96BHpultqO0MU
9eqGw5ahgdlPSOlGjf0vzmP/ij8kqJf7/JxEZXl6JQihXtnWDP1dnBBEvHRr
E0ovYv+qYZxxZ2dMKLHJUez8PgL1KmiW0a+hO8OI7haPqSOu4O+A9fGC3z2L
wolCXqH2DFHUqyk7Ir5O2faGnH1xa5nkWtQrvZ9mrc+zI8ivg+pbX5zH/tWV
q6LNShsiyd55jQdUPqOOJc+Jqec+R5G81quuCUKoV30JFjXrNaPJymBV743a
qFcqu8ZWFifEkFeHq0NKL+K968hvrnSvRhyZJn8hyTwNdezZdcuizpj35Gr7
wrLvI1CvqudNyj+pxpHekNJvp9bjvetyXV3z0J0fyGErd8ERV1DHAhcsadKe
mEBKFeSmeWegjiU7ezZ4FiWQdR35yjNEUa9qUxvrCr0SybuXzutfbsR7V5+E
eu2UbUnEK0p8keRa1KvJ+25W7x6TTDIm7Fff24xcLbyl8nl2Mhl2Inbti/Oo
Y3r9GhVfr34k6iWjtnXOQb2yXn+7TGnDJ2K7eJ+JymfkV++0lTiOSCHBd94d
PHkA9SqocWUx9zmF1P8ROZ4ghHqVoninUOD8ZzJlx+7Tgi+QN7h25K/XTCXb
ot9e3qiNejUkc03ejaFp5PKkET63viCXnOybU5yQRpIcTQJKL6KOLd3/PUvy
dDr5V/o6VGoe6pVhxNrMvRoZRHGpYLR5GnI7Pr/0F70Z5NA9o+TgQ6hj1zf9
Su2MySQBf19lfx+BehXqq/NZxTGLlO0cVq4WjDyt5eGnk2rZRDx2e9Op9ahj
zSrdyQld2URnSuj3pDbk7gnPaofuzCHuJ/n6hK+gjo1uya2ZHZ1DYsr1hTbL
D+qri/VVa0/MJT+WBY31zkCuoDK32tIhl8je759WYYk6Fmu0rcqzKJfs7t06
b4Yo6pWmu0vla5U8cnPXc5UDg+5jHubLOhzer9QomG095ZEw/j7o/2HBMIm2
08QkZ9vUIVPx90EFvjX249uukzMpw50HpuDvgyNnHGv1N7tLip7Vf+l/gfs1
dtKbFoxve0jGr66RG5iCvw/WL9p3sEzmKYl/nVXXX4fzDFtXOT32N3tBDsx4
f7f/Be7LJGy9XrnPN5QIp+rPdX2H8wx3FuWPHN8WRqqGZA4dmIK/D2YtqQp0
EHpDXi9eU+3iinNW/1VFmmUyb8m5Y7Ex/XV471LX+VWnvjqKGAUqertoYZ1o
u3XA1d8smiyoeWHd/wLvXUE7R0jyu8SSoROlN7qIYp1Yu2d8zD7f96R9zoZx
ru9QxyYenm6Y8o4jRUmC/KQVdSwwevzfcW3/nY+mSZ39U/DelbTcd92nngQS
9M+lMn4j6lh1wnQfB6EkcttnabqLK+rYX81njXMnJBNXpd/vNMJRxyTS5JTL
ZD6Sg9nhz/rrUMcWbQp3v6z8iWw7bOUVPw51bEOeaq766hSyXFDW3UULdeyA
QZxUx5bPZO7jhqMaJ1DHzpStPOJvlkrEyUPj/heoYw9NUuI2H00jfWVG6+PL
8T4WV7dhJL9LOmmxn7DERRR1rMQib8ebKxnk4MWDY/2lUK+6Wg0D9/lmElPD
tSNc3yEfc7Ty9/igLKIvI8NnugV1TOHnHs2Ud/99737y/9FoRf502S/tuL05
ZEVCTce0M6hjb/pUv49ryyEqnvGN/YPmFhI4xztWNrlEzvh+RVUE8my3OPKp
J5dMl3PKj984aN5y9UDTNLc8ItFjmObXhLxNYNU1B6F8MjJFJcHFdVBdmeKh
kuOZT/huj31nMhF1TOhSSsXcCQWke8/3lxrhyCU2jPBw8ysg7Quzn04b9Lvh
LLGNcmUyhaSuP+R+fx1yxRzPPMXQQlKccelW1UnUtxU38xwvKxeRzHsHLsWP
Qx3bpDdeuiG2iCQe0HLzC0VuLLH9s/rqYvJOddYJFy3UscMl947eTismocP4
j5pUI3e8VynRsaWEPM6rNtc4gfp2ftf0eK3SEnLn4ftd0wbVm7en7TX3Nysl
1474but/gfxBzVORP82lxFndUadq1aDfDdfKPJzyTksjNuJL5cz3W5le8bst
uh0adJa4mM5s+VKF86J8T45VhwTdJp4rlm79UoXzoh9Wz3LiW/GQmObuCTPO
Qp+E0yrXPUKCnpIJ4ZqCX6pwXnTFnN5rhuODiWvPDtXHBrj3d1okYgPfijDS
vPKIuXEW9rXMBFpzDbpeE91L7l4TtLCvRfqlDEOC3hKjg+m1LVV475Lq1q/g
M3tHrl3V7/k4Ge9d/Z2XdxuOjyWJ4dWjHxvgvauyJaEpJO096So8OPf0TZxz
qPr2T4VvxQci+/cnMc5CHdv01ftP8L0Esmuai+HSETjnEP9lUaxBVyK5vkro
6AQt1DGFpoxTfJuTyR4l7dV/P6COPajbvyIk6CM5qSmW3VKFOiZazT/UUCCF
3DbM31nci/cx5/IHH/nMPpNXB+80fZyMOtZevPhCSEwqST1pbBOxGHVsV0G+
juH4dFJ3dUZ/gAHqWEbOEVH+Yxmk17/54g071LFlmcI5IWmZROJ1yPjTN7Gu
DE59ctNQJpssSLZ+dCQM9U203n8e34ocol2kqmCchfqmtfvrZYOvOWRfy793
69tR31yql34NvpdLXP5+WLN0BOpYpPGFTXzr8shdkXM5c+fiPa2zvPCVQVce
eTNt/a4JWqhvc3bOHBMSkE/2TxT6xa+IOmZacsyGb3MBsXvUuuTvB+R3DOLz
DfoKiPu8TNfvuqhjOQUjVUKCConnm1cfW6oG7ads2+HNt72I3Fe/ObLGCvVt
Ze6zbgOBYvLio92W4l7kjrq/toe8LiZRmwx9si6jvr3OXBnDZ1ZCkouXVH6c
jDrWut5ziqFoKck1mzrz/aD724y0CueQmFJS/aX/QMRi1DejdfOq+A6UkXab
2pfBKchvfXIghuPLSc+/pF8BBqhv6Ws+PgxJLCeCZ58tvdeIfFiSOD//sQoy
Tuzi6Rt2qG/qK832GkpWEmmfw58uDEV9s+NCk0PSKsn86ZtETt9EHrr8nwz/
iSqi/mLhVgdp1LfG2HXnDWWqibbi2DtHwpBLLvVuCcmrJgaxXZXmBPVNruL7
LL4VNWTfmpKZxlnIV/veKQz2riGHMmMO6hmj7i2wqFIn29ZrJE0OTK2Vxvn2
vbJr/BaNukQarev6IwzQp+7UgqCkhaPuEZ+9+ccjDNAHZpbMpF37Lj8m6tdU
LMXc0X/soqKxwcJRQcS6Yv2iCAPcE+z23zzXRTuMJH13lt9tiXVi0DMbmX2X
35Dxgi/niLnjXJZxqNcMncxIcnBq9YxYH7x3jYqIlFo4KoZUThQaFWGA966E
mJKpElvek3OPH165tBv7XdFmfSIu2h/IgvlLRuy2RB0T33dtpHVrAil5l3te
zQF17PB+qRH7LieR06sPCYi5o44lHwoTMpT/SGSz+M80XEEdkzyyUlAn8xPJ
2+47JNYH72P21nkCy498JifrlVxuBGBdmW23d9jCUWlEXK2p743BoD7YiV/8
M8PSiYXza3WpXahjbifP8klsySSxCS4nL+1GHStzkRgi/COLjBJcH9Nlgfe0
yQnbBk5p55C9Gyb0mFmivn1add+le1IueXejXi3DGvXNNrmh71hrLhEpfmWv
5oD6JqWlcKo1Jo/snur8NsAZ9S0j5Xjv3sv55O3udb9E3VHfHLXjT1YaFZAR
z8cpOZ4ftL+fPvyfgXwhMW2vsW64gvqWv0HXKae3kLxdFBqmexP17XSWT492
ZhEZ4eDYGeOD9zeFzTUnkh4UE9M4zfmzH6DuleXO/aN+pIRE8Ilb3QhA3Tu/
zdohUqOUCK+tCu59jrqnUhj9e8GoMrJAS7/rjQHqW50Bv/2L6jJSdiDW62Ap
cs8Sna4ZYeXE47K0stQu1Df1nbfs7p+uIAtens8vGKR7X8rLf47fUknKcr7a
XNqN+uZtPMvWU7qKePzcJr6iAfnqassfQj+qyAKJmPAuC9S9b2Zvrd0Tq0np
4ulbgr8g1/3u8ueUdg3xMDr3zcwSdU9Gcea7mPAassCl3VOiE3mvTYpD96Ra
Uvpw64IMa9S9vDeH1ZTda4lH0rsst1/IX/wa1X2stZbMb5p2RM0Bde+0SkRk
6NY6Uip0VvRrD3ID++32rTF1xEOuLSTAGfVQIapXZc7MejJ/05YN2weQD/3z
sGvv5XpSeiyqTdQd9bBwsebbhz/ryalbkpeThqHundobvfzcSV2Nj8uPKqqd
2sT0qmp/lbLc8GtklDY38slY9Nv8rsK/ZN5wP+LsWTjh8Vj0n+zxTTvs7/GM
LH7fOC4mC/3ueqaOi5Ud/pK8fl3zIGAszpH2Zc0XKEt6TSQKrG5pyuPc+ynP
fHl/j0iSv6mtODoL93T6dU/o7dOMIddTD0ydb439LpfRks6yw+PJxjVNZgFj
cb7UtaVmi0P9B+JRHb51pBHqWPy6N42lSYmk7v43O0151LH+wLOO6k+Sycqd
C3xc+7Cu1BDeLurv8Yn4TzgSHZ2FdaXLwXmP+Mw/k76CkPKf/lhXvk/tVd6n
mUaMbrb1KVhjf6xPNvvzJ5kMEq07b/qBVYP8lC492iU7PItMED24KmAs3tNO
tdp+u9yUTY6nPd9X0YD6ZiIzc5VDfQ5pXW27eqQR6puLvsiVwPxccjfgpl7g
atQ3v7NdhaVJeWQd32tzTXnUt/i3VVIjI/JJt2mufd041LeqxpSD6k8KyLP4
b+dd+5D3jw9/Y+VVSPQlR9+d2oS6N03rXp+fRxEZ5rwgKDoLdU/D/szaHLti
ElG2KdYgCnXP9JnlDT7zErJvyZGMn/6oe65F+uWK+qVk7J2rldcvoO49HE5k
9mmWkaTfIR0K1qh7Capzj95WKSe2+hkDaTtQ92otxkR/kqkgMyPaRh9YhbrH
7/OX/8/4SpInPnKGgBzq3oyU+g2yw6uIu/U8pYCxqHuruzO8d/6uIoo52mtI
L/J9cyJrLjdVk7r5B/UrGlAPE4N1b5scriE3rl6wcMxEPcxbvWapQ30Nkf6d
v2ykEepeffniak+jWnLi6d7kHdnIf9oqeATm15IcvZ8bAlej7g0VmSGbsL6O
zB12pvB3FPJxTySySpPqyOk34iaa8qh7s9RH2v5YVk9K9gQ03Rq0p6xcMDBh
ZEQ9WSiueLRuHOreGstfcTPlG8iFhITuhReR6w/7slv9SQOpObbltGsfcvP7
lcP1pzYStem1QlnWqIfHlfOCrbwaiWf2sRtTB9XF5zI+bT4n0kSaXYZMPrwT
9dB7X2yXn0cTIfOvB0RnIX/U++peVG8TuVEpJSe0GvVQ8pOBQ6znFg13m2mu
bqo6TK+Oq/l/d+CuEyO/wBdPBtBPOMZI2tyBe0j23PxV/HgA/Xijp9jmKkq9
IOmHLoXGcLinU2FVN82BCyPmVyYffTyA966KjSML9TojyEBo0MIrBOcfKhSU
LytKRZPM/ZKOMRzqWIWo8crRuu/JvRONpS+rUcc6fif+s+c+kP0XQ5c+HsD7
2FeL4iLz4kSidO+4r48U3sfai9rC9TqTyUDQ8t7LBOvKdq0hV1cLppCmSvf5
HxZgXdkWOe6AolQq2dDUZBLDob61zZZdLa2WTl536HhG6OI9rdV7+bTRuplk
UvdL7mU16lvr8K09/RbZxHVA/FvgUdS348uUWu25HNIo6DD98QDe3+xs3xse
Sc8l60eXb37gifc3u+C1H82L80j4ROLmI4X3N7v6XEXj+nwyUfpx+I1XqHu2
U3Y91OssIC6ygnWXCdanttuaRDf8KyQ/7qgIJ+1H3bO9fOzkasFiIvNgv/SH
Bah7tkl/W5aOLSHbH91d8r4buc0/DwNFqVJy+Wn6lhgO9dBWaVSyrFwZ4V70
HYw6j7pne/juImm1cvIzdIF7hC7qnt3jmf4TV1eQ2a933wufgLpnVx4qMlq3
kuyMvPX6ZTXy42MXOwkaVZFrMR/Tgp+jHh5fn9jcb1FNEuO76wKPoh7Grnw2
7+SSGtKVKPvvqRrqYazx4Vp7robIphiNfTyAPM5x4R0bzVpinH5V7mEK6mTc
7a5NR9JryfVsbvUDT9TJuPAYgUNb6khy/neje4aok3GZrnHmxXXkT/FMOx8p
1Mn3X9bY7jauJ/IV+le8mgdxgRHzjOvriWnN+Sc3XqFOvpfOrtl+sIHcaoiO
u+aAOvl+uZePXmcDSWlpK7hMUCfjd+zYtPl4Izn1+5p98lDUw/jj0wQ2/Gsk
Pn+e8yftH8Rv1MeudWsi4X8/XEtIH8RDA21WCzaT9N7SyR8WoE5yqVay5Goz
aez/8Sz+1iDeqFizdGwL6R8iovS+exDn++OtereFTBwqw8UaoX5yku83Kkp9
IYoCGutjBu1dRi9xHzb/6ReyVtCw+N1M1MnAqMzvtRO2afA9CJ90302T6dXX
qWvKbVVuErm5rhuuu3vg+Sh6dpWtSgAxWWvz0NMdfzfUEjngI785mDz7+2Ry
cRL6Nviclflto/KadBcd1vF0x98TRwr4PMxOjCS+C88KKj3G/WhXD6H18ptj
icYlv+SiJPyd8edQp64LlRz58b18xfIf2Ad7k9CVbaOSSJL8Dkh5umNdaeU2
X0baOZncXt/VVyOO/fzZK/c7ZSd+IhZ/3CoUH+M9rWbIw+xTwqlE7alYrIcS
6tvdDyWz5DenE+GtvneLkvD3ym2nxziVeWcSq4Gx6uOCBvnlrtDJvlCZTYr0
d8ot/4G6V++68uYU8VxCQh5OtliK97cP1ZVxNip55Dl/s7CnO+refeLUnLo9
n4zeodATlYa65+gvIS7tXEAcX9m21Iij7hkMvFY/4V9I6gRiioWNUPeUTHX3
ZycWEZ1dQ1IUH+N9bxTXdmN2UzF581or0qgN9bB92oW4U8KlZKrw1aceSoN8
Ml1mNRfIlxEP03yv0JOoh8+qPoyR31xOvr6d5FGUhPfAMxrG6mdsK4jc8LDo
AQHUw91+PRZl3pXEbNG2ReOCkGv0376xKKaK3N71O3DuJtTDqSaKcRcqq0na
+bvTl/9A3mey/+fR0zXkv//2nS3eqJPt195emCJeS5SrqkdZLEWdLIsfOi3l
cS05KHzmvFMV8tSOLW9sVOrIA+XZA9fcUT/fTXu4blpKHckzTbV/PHvQPMmm
jsrU7fVE8LJlR1Qacm8XddvjrfVEPXKURcaRQf4VLy8JSTs3EOva15U14qif
tlUlDzJEG8kzEQP9rshB/lpic5RO+DeScrWeDGEj1M8tGsc/z1zUREbtvb9m
2iBdXXEkyTg7sYmsuUbiFB+jri7wG/PTSa+ZOEbXKa1di7oqmWV6YXZTM3nZ
cDbYqA25SH+oZJ5DC6kfJTvzmCfq7T+F3tenhL+Qicsy7nkooa62Guusk/X9
QjZaHBW/W4y89OqdygL5VuJ2Q/xS6EnU25T3TTan41tJZNxbvkQp1NvIr8pC
8pvbSFvzdseiJOR+kmceFNe2kYlje7+17kcd/jPET+aTrp6GcHt9pq7NCqZX
808fW99ocosMV4gll0zQp51P90dgg8ljMneh9+KLJujH3mYsH2IgFkqa9j0P
bDqHvuuHVN8YNpi8Ie/Ch769YIL+6tXLN+94oPqOaA68Mhvvi78z6ml+3Wkg
9p68lKmyaDqHvjTmszVfCv78QCZuELGKGuSfLxU0dkGDSRI5bbPU9oIJ3tNK
FepefUj7SOw2RMTJP0V9uxUetvCB6mcSaJpOxvvi75UbVVzDHQPSSKVNXWLf
dby/CUZvVDQQyyRjzvVoNp1D3UtQn/pG0SmbaN4dnZrljLq33KzrruDPHOIY
MmdDlA3ua08O2FXWNTePhHIa2f4HsG7trk+a3GCST2rz9LdeMMH7XoGMnFGe
VwEZaRt5aPEgPQzff9P3Q1ohedq7MkT+KerhtRc95S+HFBNyLvPr9EH+XYfb
zKY+UC0hpaN2LBjvizq5TuHzrsuWpcT2bsMxYW/USZmjCx44BpQR0ZnHXvdd
R53kD/eu3F9STp6H/Pv5/TL296p/9EkaiFWSlarnVZrODaqLlc1N1qypIhWc
uEOZG+qnr32Gn6JTNXHQ9nuX5Yz6ubzi7tHR22uIeL7s30QH1E+5U5megj9r
SOiut8uibLCOnjyNL6z/ai1Z27TiVLDVIB9CTjmna24dqTuaEe9/AHX1j+mB
b+3/1U2negyHeO1FXW0ecn90g0k9mXimfuUFE7x/Fj3KXljeU092nItaGS+P
uvpx1dAteV4NZM76U3sWD9LbiHpV69QFjeTXqNVnXs9BXX3scejGh7RGklgg
9ET+KfKbMn7hUeZNxPNuVvKzQb6mbp9yc18OaSa7TLwapw/yHzu2X+DHU99m
Mm/mzuG+kqi3pkJLxB+otpDuZqk5432Rb3phqeiV20I+hjSu9ZyIOrxc5+HW
y5ZfyE3r4APC3sjl2/Jt3AVbiZmq9cUzY1GHp1wRvOUY0EoU/qkG9V1HPkJh
2Ztjy9vIX643zUEM9bkn80j+/pI28tkjse37ZeQtRwJ+mti2k9vaF0QshVGf
i0cVjTUQ+0r2im1SaDqHPD5MWHnji69kXv7YTWbDUJ+tQoOFtBX1NZSW5uUm
LlNlevUyqvDnF1Uv8rj3juUEZcy1OXh0tc4X1SdkfFNMjIQy5tH85b9/z3jr
S1KyUZaTzkId01rv1NWiGkEyy9J3Syhj/ovY7WeSj9dEk1diQxumuKGve3FV
nqbx1nhyfdVSC+ks1LfNXgORI8MSyJLYxXa3rmK9qRw9Pr1FNZnM09dTkVDG
vtnEKrnqj+8/kcmdR3/fKUPd6+Vf9TNgTSoZcfFy1BQ3/B2zZs52wdPp6eTv
jOcn/OZgny1pw5EpxluzSGtc4hLpLNTDgsWJEx5Y5hAruaN9W5aGD/r/Zj4a
GZZLzP/0Gt+6ivVslHGJnNPPPGL88VJ8QQ3qpOyx+rctqgXE4OZEKQll1Elf
9w5i6FRINpk+czU8j7+fit7uSf34vohoySvX3ClD/XR9PkxPma+EaPQkrChT
QP38Hj2qKmBNKVH9pPtoihv+3ro3Y/KBMRfKyPxblXzGBairhVUyP1zTy8ls
s8N7/Oagrq79vtC54z9dmqbQk1g9yP8weqj6cOOtVUTi77mZ0lmot/ISa6+n
364mF/aOWBV+HfVWd5ys6APLGjJMZ8uPLUtRby8+mL9VT6yWuC28E/CjHnni
bGWfkWG1pE+ieuutq6jDva+WVCT+V3859ckMVVZDHVZZQqSdftaR7nrLNwU1
yI8krrFYdLue2Ka92Xv8Eupz4Hqd4BbVBvIt7O9YCWXU59oC3W/+JQ3E0mdl
cmQl8ikm+iqGTo3ky6kLdobnUbf1mnc6iU1tIub7smf9WYi6fe2YGffxfROp
05EovFOGPKXHfNgp02Zissj47BIP1HO+M4e1lflaSPmEJyplCqjnS0Wsr7UF
tJDt/a2NTsWD/NZu2+cHrPlCChoWeU9xQ50PneY8cWfTF7Il/YRW3DzU+abn
bsZjLrSSzHDu964C5NMXnQ/4LNtGdO4Mf953CvV/R8yVZtf0NvLJZaOh3xzU
/1urb8qrWbWT1eZegiQXeUaGj3XHf/rDrS+Pqh7kJylg8CDyadhXoq4448Dp
WXgukOqAf7u2dpDoiQcnSmchtz4QuGLcrw7iM2DYULMMz4X7bTvtX8fqa0SM
uLyu9tBspldHBKzTu6K9yIruiomCuzG3K876lmRX9BPS237WfPhu1DHO7Ih+
p8QrIv9qk3+yEOZw1T1/8ulXdAQp3V82cvhu1Ld9UjfrrFuiyfnpFifWRmNu
RZO3a3+HBEfutZ+wSRbC3yWVz6uKRs5IJD8+x89tjEB/m65VCr6/opPJuqfD
qgV2ox6+7Z8pq7Qlhfi56dyeLYp9NvuYyVHWLamky/j6+rXRqJOq9mM0w1wz
yPqlRXwHzPF3hO5FQvkdEtlky0ixXclC+Htohb1rmERxDnHuWRhVYIJzHXEF
Tt1vZ/xX3zVvE2+MQF29r2ivoX8kn+QV2lt1jcC62Pm69dlf0QWkL+nuZ4Hd
qLfGHZYZtwSKiOzruJkSUegjvXzDgbFKW4qJ3sNql9mi2A+UDNq7M+9+CXG9
xl+muhfr6z5B00fWLaUkyFlGZW006nOV+c6W0crlpPDQuuuGo3BeLj5Jf0GY
awUZsuNw235z1G0/6S32uumVRH7tNa0TsVinu7hueN8hUU2C75VsThbC33/D
Ombyr11UQxLHHHLJeIP84YNHTyWKa0jJhX/BBSao8zc2SGk3OdeSjoErpRXC
qPPu/+63v51RR4Y5TBNsjEBuEzT5+tnPdWRyxyvlr6ao/3t33FHSP1JPFpqv
3NM1AvsDekISxbPGNRCtijzPvrfI10TdcvoV3UB2bdv3XmA3nhcqFmOmJZs2
Epu0rlZRETwvZMZ7JtwSaCIXVp6fKBGFXCJZxHxvcBPxezdRa9oePEcEbS8J
KW1pJm8XBNnOFsX+are0UAh/dzNJf7bs0fx3yFtyzurm3W8htZKZWap78dwp
dR3689GqL6Tby6RXQwzPndT5bt7WLV+IqMg32bXRyGMq+5esvNZKZp5xM9Td
h+dR0BXnytHKbWTJX/GzhqOw7+G77O/pmtI2omv95LVpDPIrrQ6zwlzbiXmL
Ss1+czy/nO92pbjKfCUnTVNEj43G88tqne1h3fSv5GbR9mUnYpEbd38Tk7Lu
IIEbWw+ctsBzbdOzI687JDqJad3y9clCeK6p6bfrx8d1kqYHw/esM0E+wbwl
98MXfY1NuUMU5G42x/2PD/U82V3b6EV+SL2d9tgJdczugsK62sYn5NKnmXsC
nPA+ZqH9wCt3+ytyzcX+Xk851pXyZ899q2mMIEWTyocGOGkx/tQ8XmKHVAyR
ekusdCahD/M0rd/quds5ojR36+GecvQ73TDWJ3yWdiIpOT7s4cZg9Om6MPRN
ck1jMnFOiix45GTAePLPrOL77ilk+piDwr+1dzA+pKG1dbtUGkkymaKhM2kX
4+oFw/vHxWWQ/SGZNn4tJoyfSJ4xJnd7NhHo47b1lJsxvnOn1M1Pf3NI8cxJ
Rx6v3oOP3xrqO0s7j7zQsbmwMXgv4946y566++STk9bpAd3i5oxHrEp9WdNY
QDbemfX+kZMF43lLDd9pKBeRadyp4vV1+xn/ptiYcN+9mHxrLPrepX2QcTE5
2/S/OSUkUWShyMPwQ/j+z+Qr3C5VRryULs7WmWTJuM4Uz6pIq3JisbNuxa/T
VowfGCvZMi6ugix2W2bk13KE8XMjg7/bjKgiAnppS2fNPcb4k6FL/uVsryZH
mn+v7SlHXntqr7vPthpS7DRTP8vTGnPiHOed//S3hqwU27zn8Wob/LvYf7/c
9aiWBD1yPnqiG/lom3fXZ2nXkbEqL5w3BtsyLnXE9fa2b//Vd58LL84wtWN8
wSGte+4+9aTJiN+nW/w44xoWov7hGg1kc+f8JxmfkG/aU/C4prGBRLsbhT9y
smfc2MQ3cNTVRjJT4kK8/XwH9IXbuSdUQ7mJXHkRkb6+Drmzgexrq/Im8lu9
tmS69wnGr2z9FnnfvZmY5og2dWk74r7bpqjYdNkWkrp36c+0PuTBOi4f/ua0
EMVuiyEPw50Yj9HS/Ch74gvxvXRL9Lj5ScbTVomkbZdqJQLTPkzWmeTMeKlG
ftb5T63kSHj7HKlM5F+W3suPtGojJWsmqfw6fYrxP6q7SxrHtZOVJZqrUpVd
GBdSmls5Lq6dBB+20fVrQT5hQWft6r1fybgBv122910ZnyMX2WQzooOQ1Ebl
WXNPM64651Tbo/AO8kvcOVbMHbnWzDXfcrZ3ksBd4qt6ypFvlBrZNTDQSXY8
C/xcr+LG+HDjun2NZR7k29ppFzdZapL/cbGD5xYtrdLX2PUsze3NoNznt3Lq
tzjfTrJz2ucDY9Qxd1X0To2kXGcnEXqpPqR1UB6rIH3+BC3e8zOdHE2ff9pT
3vOz1xNFn99Okvf87PHaj57bHAjpJKfdjM92COHrn3F/gkF9owdJs1bweeKE
r/N/jx+3r8Ljv8dr/P+PT8or/r+PZ88zir7+6aG814/1S++z/bPr7cjUC1VV
Mkdl2P9LucVKZVheJ1l2I9L76TbML/7f41+d4z2e+/8fP/s67/HYb9l84U9V
k77GBuXEJcGOw9nr1DErVVIu6iRSG9xmH5TC128aqTu2qdGO7F0seem503D2
+l990nZI+9dJqoZ2R447iM//v8dvK7a5+N/jNf7/x3cN4z2evf7/vZ4sRd7r
QX2jr6d97NA5/70exv8PNm8dWw==
    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxVnXXYldXzd0+H3S12t4JISAlIiKiIghgoNiIiWJggiKAYKCgiiIWCiAEq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         "]]],
       Lighting->"Neutral"]}, {}, {}, {}, {}},
    VertexColors->{
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143381, 0.4523915157143381, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977495`, 0.20933181110977495`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.3443927181955512, 0.3443927181955512, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.899113673809771, 0.899113673809771, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.]},
    VertexNormals->CompressedData["
1:eJztzrsJgEAQBNBBI8uwEnuwBMHYFizUIizBwEjksvMTvEkG3sIy/bSMc5Nk
65I2t6xn7QPnnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeec
v+zhnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc84555xz
zjnnnHPOOeecc84555xzzjnnnHPOOeecc875b33lnHPOOeecc84555xzzjnn
nHPOOeecc84555xzzjnnnHPOOeec848813t1r7Wz5E/v8b/gB/iCRMo=
     "],
    VertexTextureCoordinates->CompressedData["
1:eJxl3UHILeddx/FBcKGIoZCFuClCNy7ERaVYWnrBrrpx0W5cSWloMaAIkoUb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     "]]},
  Boxed->True,
  ImageSize->500,
  ViewAngle->0.47030072394368955`,
  ViewPoint->{2.0347142900897013`, -1.5955656816693613`, 2.182683649360062},
  ViewVertical->{-0.06121920600665906, 0.02961145337869876, 
   0.9977269672808321}]], "Output",
 CellChangeTimes->{{3.6507497442672453`*^9, 3.6507497750619593`*^9}, 
   3.65074983353365*^9, 3.650751971015451*^9, 3.650752006154592*^9, 
   3.650752188977133*^9, {3.650752481282085*^9, 3.650752495214046*^9}, 
   3.6507525751262693`*^9, 3.650808255645495*^9, {3.6509288049057837`*^9, 
   3.650928827404195*^9}},
 CellID->1659405620]
}, Open  ]],

Cell["\<\
And here is an example of a contour plot of the electric field energy density:\
\>", "Text",
 CellChangeTimes->{{3.650811583618898*^9, 3.650811601385174*^9}},
 CellID->118059209],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"ExSqrtDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"EzSqrtDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}], "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"First", "@", 
      RowBox[{"Plot", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"ColorFunction", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y"}], "}"}], ",", 
           RowBox[{"Blend", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"White", ",", 
               RowBox[{"Darker", "@", "Blue"}]}], "}"}], ",", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SuperscriptBox["x", "2"]}], ")"}], 
              RowBox[{"1", "/", "2"}]]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", " ", 
        RowBox[{"Axes", "\[Rule]", "False"}], ",", 
        RowBox[{"Frame", "\[Rule]", "False"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"AbsoluteThickness", "[", "10", "]"}], "}"}]}]}], "]"}]}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650810504192172*^9, 3.6508105742224216`*^9}, {
   3.65081060923237*^9, 3.650810613438971*^9}, 3.650810731067524*^9, {
   3.650811506105813*^9, 3.650811514942278*^9}},
 CellID->1496579925],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyMfWVYlUvUNiB2d7ceW4/dzvYYR4/d3Z0odnd39zGO3d06W2xsRFFBFAkV
FOnY1Id71j37fRYv1/vxZ18302tWzZp4Sg526jzMwc7Obmc+O7vfv+ovhxm/
XpfHeV4el1njq7+hZzqNN5dpvbFMaweNP1nzx0ngrdb0MI13WvEXjdXvy5vA
K1W6AF6rymvsoerXeL1q3wR8UfVP43eq/xrTL8d6nPwX4wXGeIExXmCMFxjj
NdLx5U1gjBcY4wXGeIExXmCMFxjjZfPGcYpxAfNfjBcY4wXGeIExXiOfvLwJ
jPECY7zAGC8wxguM8QJjvIwvOU4xb3xcwPwX4wXGeIExXqMcvLwJjPECY7zA
GC8wxguM8QJjvEzuOE7Bl3ze+LiA+S/GC4zxGuX85U1gjBcY4wXGeIExXmCM
FxjjZXqF4xRyx/mSzxsfFzD/Rf+B0X9g9B8Y/QdG/5ke5DiFnuByxPmMzwMw
+geM/gGjf8DoH9PLHKfQW1yuOd9zvgA26u+XN436++VNo/5+edOov7Wd4DiF
HuV6hssh51Ng9A8Y/QNG/4DRP2a3OE6h17ne43qByw3nQ2D+i/4Do//A6D8w
+s/sLMcp7BDX01yPcTnncsP5lPMFnwc+LmD+i/ECY7zAGC/zIzhOYWe5HeJ6
musxrhe4HHK+53zG542PC5j/YrzAGC/zkzhO4UdwO8vtENfTXO9xPcPlmssR
50s+b3xcwPwX42V+IMcp/CTuR3A7y+0Q1+tcj3K9xfUElzvOl3ze+LiA+S/G
m5rfy/1C7jdxv4LbXW7HuN3geprrRa5nuBxyPuXzyMfJf69b80dJX2u+IHle
YQGM9NcKC6QDj/8NL2c14xf0Ax6rfk0sXeMD1v67SVpLaYx2U/sFXXk/F6ry
Ahj1Ih/mB5i3i3RgjBPzFJ9k/RO832gX5YGRHxjlQEf8n9MVGOX5/3l55ON0
x3wAp/bL54WXA+Z0Ah1BH/An8gGjn8B8POBzno/zDX6N/Xp5E/MNjHqbb/xd
Yax4Yq3PU7RVWAYpLJEOjHTkv2L9yWbGr/p3NlNq/+e/oBvyof7bVhyg2z+t
sEitHB8/7wfyIx3/B39C7zhb6Zagx495BEZ+0BH5na3lXTR/A4PvkH+0yi+Q
jnkEhn7D/KDfqdDNBD5JTU9hXFw/gL7o/3nVvh4vMOoB/dF/pKP/wBgvxoH8
4Bf0B/UiH/qF/kA+UB/GBYx6UD/mB+Mq8Tt5Y4SmL8qDn5AP8wk6AnN/Hung
T04PyCX6j/ECIz8w8v9h7aej1huwl8BtrO3ZmzE+5Ed55AdGfvBTKZXfhHTY
Q+C/VX4T+svpzvUU8qN+zDvoyu0A0kEn9Af1AqPce2s7aXT9sGPgD7SD+Qc9
uDxyfQv6YfxoH/kx36if+81cvjGf6Af4jcsF9Db4HeNAv8GXnA/4PAODD4HB
r/hNza5zO5wa36NeXg9weTVO/Qs5AubjAn2RD/ON9I9qvs2gm6onXrpZ8XkJ
fkM6pwPmK8bKbr80fyEdfI18mi9pPpCf+3Xcr+DlgPkvyqfG56A/7yfvBzD0
jaN1GkIkt8OgC8+H+QDm/iDSwc+YH9SDfMBcbyM/9A36gflCP5GOeUB73N/g
dgDyxf0QyCH3CyB/4ANg6B2eD7+oD/kwX+gX/z/kGv3H/KE+9Av/R/3cz+P6
EljpC4s4bK3+Lek/i8xgzfdZAj9Q6RL5kQ6MdOQPsdLlk64P9SN/nLV/T3T5
Gwrr/BxXto7XT9ff0dr/7zKNtR8xKdJRf5y1H9GiiErXegfzDPnn/ef8BLoh
f2elLwQw+gt+A0a60b5YNMZ8o341r/EC9QOjPswrMOiH+pAfGHzD/SrII+QM
GOOGXGCeJ1r7GanpBfoCQx4xPmD0B/oVmM8/zw8M+kBeofcwLuQHvwGD3y5Y
fxN1OsYHemB8o9T4dDugB9qH/gEG3dAf1Iv2US/aB0Y6+A3zifrBr+Bn8CvG
C/qCn8H/wDdUe1reMD/ASAc9kI7y8O9Af/A/9BHsJ/gL6dy/M9odOxPaRz3Q
P2rdaG8CP3O+gH+G/gBDXlR8xcEEeYHd4X4F33fgfhww5h8YfMIx5gXyzv0i
vi/D/Rq+75FaXAT9QzrokNo6Cv1PLQ4C/5D7Y0gHP+v2mB+JdE5X7mfy/Snu
3yGd+w3cLwB9gMF3PC7A10nAGC/ah71Gu8A8ro/8GD/S4SdxevB0zod8vY/x
gj7ASEd+1IN02H1gyBEw9BMw+mPU8/Far6N9YMgv+A7zC7pzOUH9qclNanwE
DPrzfRHMI+iLdLTH95tQn44nsPb5PKXG15A/vn8DukNe+L4NjwPyfQ7ux/P9
Jd4/Lmd8HlOL83A7CTrxdvn6gu/38Pb4upnPO58XI7Zoe4Z2QGfwm3FdF6/t
E8oDozzmAeXBRzyO50Z+B+pBPqTzX9gnHrcARj4e9+LyiXT4FfBXMZ+gE4/D
cL+T22GkQ0/Aj4B/Br3Hf6HvgHmcA+nAGA9+eZyUx/+QDnpxfY380NfA8Avg
x8APwHhAF7QDOvB4Il9nGuMcdmbQCf4PMOSP+7OYF/hvyM/jTNAvRv1oZ8Y4
0B4w6uf7BCiP9pAf/hMw0o3+XUo7xu0c5AXjAF9iHOBj0AHp6BfS0S7SU1sH
oz3occgN5BX/Bz/wODXy8bgZ9Bf6CX8a9EQ96A8wXzfzOBnXC8jH6wVfQp7b
WX9D9S/oCf5GP1EO+ohj0BN6Cv44sEm1p9eFKA+M8pAPbu+hN8CPsPdKvuPl
XGv5jzod9YLfgHncEvMIOkJPoz9I5/4X9APmBXyKeYHeaaHoKkBfrmehB3g8
7f/yk9DOVGs/fxJfhWs7xeMKoDf+z+MPPL4PPgA9+TxjPrHe4xh0A/1RHvOK
8aB/qBcY9WA+0H/wFTDkGRjyCIz+g48hh8CQU9AVdAE9wb/4P+QI84R00A/6
nseJMV/gb76/wfkKGOl8PwUY62nQH/Tmcg/9C30EeqN/6A/oxfdnUB72AfI0
wZpur+0F5JTHAfm+E+jO9SDsBepHOvgBfAQMPuV+PzDy87gM7BbSQTfME18H
8HNVfF3A/WBg6AXjuY2XN3kcFxh+GvQN2gN/YlyQI2C+fsE4MH/QJ+gPj79y
/5+n83U3X2dyzPeB+D4TMOgPPc/7iXaBoU8VfcNlSyvOqO0szqsAj7G2kzZF
/AV6Av0ERjwHegf1Qx5QPzDqR3n0F/KL/uIX+TT/Ex9Dj0NvQZ653cH8IJ3r
ccghMPQN+Ad6De2B7yFnKA/9gPzDVX69/kJ/eD6MBxjzDHut7GCCtteQE/h1
sOc9rfneawy9wfUg6MDtGvplXA/b7CPf30c56D/wy1truWgRbR3XV12e+wto
Hxj1phbnRLoxjhkh+yu60Phs9gv8DDvD7SXkZor1//5kX23+GOYbGHTBfGH8
kHcjHWNFemv/v+n+8Hgt5gH8Bv4A5ucDuH3j9cEe/aPkT8dvcV4O2EnJn15X
AmP+EO9FOl+nwn6BP4HBj2gf8o72gdEe9Bww5Bz6AenQL/BboP9g9yCHkEv0
E3KHfsGegQ7AaM8Yz49g8cFw7Y9i/vl6CnoS/4f8A0MOMb/GfXY7M9+vAsZ4
U1uHgi8gH+iHUf86aPpBP8OuJFjLp09x3oKf7+XrF/Ad9DTSQT/oG2Cj3QvX
+dEfyBcw7DX6h/lpak330fLOz6lgHPycCvcr0T/0h+sb6BfIKewn5AwYdER7
oAc/9w7+gT7B+CBvqAd2HRh8DHkDv/L8mCfUz/UHxgX9wf0Efl6fr5u5n8HP
VQBDjvW+EbWHX5Tn5zZSO9fE9R7q5fXwfvH4IvS+0kcOZvAx8hvj0hbtf8Dv
4HFD/B98A3sBDPlX9eEcWqDWR8gH/QUMfYD/Y71iPLdjZ+b795AD1A89Bf+E
rzt5/IHrRWCk83OykBvwIeQZehj/Bx0wPrSP/JADYDWeRPnWWs8DCf2P9lPb
R+LntzDfsC/oD/QWMMbH93P5eS7wOY9ToT7IG/gRfgr6A/nDfPHzXZgP9AsY
fMDPQaa2j879XoyD7+MCQw9yv5fLY2rrcPwf9cAPwnyiHdQL+8Sx8fyWza5j
/oGRzuUX/QKfG+XPojHaQ35g0A1yxeMpwFiXQx+iPI8/pXaOgJ/r5HFLfq6I
/2I++TlGvk7j/QIG/8EeAUN/4f/Qf7A7kF/QHeWAuT7j7cBeAoM/0C5P5/ug
SIfcoTzsGz8PBLqjX3zfAnwKjH6gPN+H5usYlAdfoD34w6AD9DXohP7y8xj8
vAfHPO4BfcLPZQGjX/wcV2fVD8Extxc8Lg19BL6A/gfmfi/SoZdQD/6PX7TP
7Q7mDXqf2xceJ+N6ku8n8vNDwKhf61uiAz//CbsFjHFC/ridRD3czig7ZZGd
rPX4SOBa1n65a4z1vOI3i+D54QcjPYdqR+eH/QT+bO3PC51/q0rX/UE6ME/H
OlnNA85v+ur+oH1gtA/7CL2F+ATGC4z2Ee8ARjr6Aww+RXvAmF/QXa2b4vT4
gVGf4t+EFPRBfcgPDPsAPQA+Av8AY/6HKbpRvyN03Ab+CugC/gYG/2O8oC8w
6At6IR39Bcb4eDrKg178PgXkB/KGcaE8+A8YcRi0h3SMl/sjoA+wcX8xnsVp
4lPcx+Dn7VAP+gN5QX+AkY54GvQF2gO/GvdFsH/gq/nNOK/xOh3zAQz9b4zH
OOj9AKTz83P8vhrX59BDWN/DvgCD//ELPwn+ADDqgR+nzy0rOms7zM8p8X14
vk/E44LcjqV2r4nvo/C4vHH9bbs3g3S9r0wY44PdhP/Oz1/z8+r8/AQ/z8b9
Eh6Phh8DekGeMe+pnXtGOo9H8H0rYNAH7cIucYx+wt8Ehl/Iz7/yc0ncXzeu
w+JT+E/ID7kGPSCvwJBvlAf/p8a34FM+r/yeBt+P5H43PyeFchgf5zt+zg76
jNON8xm/FwbMz2/x/XN+T5Of++d8a4w/xuq4NuwZMNJhv3k/UQ8w9Bv0O/Qb
9DvKo18ob7x3YmcCH+IX+gz6ja+reRyTnzNGOurhdAY/8XPM/N4b9Cb0MPwu
xcdRmp/5eQDIDz/nxdcdwCiP/iMd+g/pwEiHv8HPUyG9nuqv8Lb+P1qPk5+f
4ueMYf8xv9DbsG/AmD/occgvMOiGfkPvAyOes1W1p/0JpKN+YCV3ido/A525
XsO6A/OFOBv6xePz4BO0wzHyg56oj697oIfQH35uB5jH25AOuQb9IZ+gN/wT
YOhHtAf68f5A30Ev8f0HHRcieoB/gEFX6Af4L9Dv8Jegn/i5Fn6vCvUBoz3o
BW6feLwdGOMyxlVCSS/bzmHxfRp+DhN0MsbhbeeOUB56EfIEvQl9oPoVQ3Y9
UOfDfh/kAXRV7cbo+C/qA3+hPew/Qq+iPehdYPidwJgn7IeAf5EO/YPxod+K
z8IF5hv/B0Y56BN+Psd43jBezyPfF4L+RDrso7YDxOewZ5CL1NYx/796CemY
d35OHP2AnwH+hD3mep7v16Pezsp+aDoA8zgz0lEP6jW+mxSu6WY8dxKi14/g
f2CkK/kL0/tDsHOIn/L9Vdgh8C34GPoX88DPUcNeGNextvuC4BMe7zee3wkU
kCOcE+ByxOUB6ZAHYKxTOebywdMhL8bz47bzAcCQB/X/H8x/CtLyDfnB+QeM
A/mhhz5b05N0v4Ah19ivwPwhnsj36zF/xnmyrYON9iY8xb4e9CD0APSpkg/s
C4ZoOii79kPbxTPWfMG6/7B7kD/wP/gG+t4Yx4zUeprvY0Hv8HcHIF/Qs5AT
pPN1G+YX8o96+bqWv6OH8pBL/gv68bgz5B0Y/ij6BczXT8Y4eZzGSOf3g/h+
Ml9PAWO80DPQL/z+DeaPxwH4Pj4fh9FO2+418vsyKA8/Hhj7a7w9vg7l6x3U
A8zfK0vtni2Pc4EOwBgXMPrP6+PrJH6OFdhN8Wsq71Pa+Im/uwY6Qn+Dz1AP
6oU+zlX2Nz6g6Y50+JdIR34ePwZGOzxuzs+x8Xcv4BfAPkM+4RdiXmEX+C/f
FwJdjPcnbRj5+b47j8NA76K8cR0UzuLIUTKPtd/u2l4gLgx7gnGhHcinsZ04
jaEH+DsZsJeKT+zMPB5ufNfBzsTvo4DOqA/j4H4M8iNdvUeWpOPdqAd+Efwt
6HmUS21dgfr5+XXYfWdlD1L0g+/zgo7gO8iR8ZxCmPa/oMfQL2DUz++F8/0Z
/g4C3zdAO+Bb4734WL0eQrrx3H1siv0S+APwe3g8BvYfGH4R/Aukg//QH8w/
ML8nhniNMa6RqPsP/w0Y9YMOqA92F+V3Wel8Q/vVW5UfovUk8sNvR374KcD6
nU0qD77l7zjw99l43JWfXwVGujFO5KvXc/xcNeSvsPUBrxuaPhyfJz8HcoL5
Qj+BQQ/Uj/GjPuhfYKx7OEZ7kC/QBXIE/oOcAaN98DnmwxjnSNT7N7CfnF58
vQo/F34s97eN91jtTJgH9A/2DeOB3QE23kO1Mxn3uRP1/g3GB36HXMGvhdwB
Q86NcYEYvS4H/0PPAfP3TYxxjFjtv4OfjOezEvW6HPJoXKcn6nUN7iPArqrz
tGm1vdD3LIgfsD7g7zpB76K8Ue866nibcd8sSdMRdOfnwKCv+X1bYPAt6PpW
ybXWc9AL/BwP9+/4eS5+roHfS8P8YP8L4wXGeGFnjOc641jcKV7y93z4PUF+
D5ifQwJGP1K7Jwo/hfs93H8BXaDvIT+oB/ID/sI8QJ+Bzhgf0pEf/iH0EfKD
j/n+BfzU1M5x8X0A5E/t3BUwfxcxtXeJuF9lPE8YKBEfAcZ60+i3RWh6GOP0
sfp8Buw1/GOkA/M4B/iW37PAuPF/rMuh7/j+FD8vA3sG+eH3lPk9Nx6f5XFr
/j4V9CL8X8grMOQZ9tp4DsKi8wFDv4FefB5BX7QDzM/toz6j/2I7/wI+Me6T
WLR+RX2gm14PWfEBjXeRP4L6kB/1IR0YfIXxAWO+je9iWrR8AUO+dDr1B3aV
+3uQC8gr1gugB+yhXg9SfcDov5Z3SgdGOvwNpMNfAEY68oNvgNFvyBv8IMgj
+ABygnmH/4BxAOv+EP2AQT/dP0oHhn6DneHnV8CvyA+MdPAP5Mz4DnaSXi9j
PLAH6D/8Jcgz9DP6w+0u6kH9/LwK5hsY8oD+Ix3zwd+XAj+Cv7i/YzxvmKjX
weAfjrk/g3TYJ9hjxAeN54WStP5QdsHOhPpgJ2An+bk2YOgNxE1gb8FX/N0I
pPN7F5hXfh4afhwwt7u8fqTzdT/WUfxeOOoHn4LuceRf8XdyuV+i3wshvkst
DgoMuoAPeXwU/QVfwO7xc7L8nUV+DwF2C/mhD1Af1unQk8DoH/YzoD+gv3nc
Eflh5+A3GePJYZr/kW68fxyu0xFPwjzx+Cv8HKQb47GJWo9BHoDRjvEdAkuK
dwqM7x3E6/LA0A/oD2+Pv+8EPaT4LE4+tPbbW9sbY30RKd5HMr5jGc/8iHiR
Gh/qd0MJYx4wTj5PfB7AP8b7R5YU74/wd5j4vRzeH77uTO1eONL5e0vcT+Pv
miA/fwf2/4p7o59IR7yX3yfF+hCYx2v5PVTQDfoF5WAngfk9CcwDv+cIvxn9
5XEX8DPK8fNf/J0OlOfvtnG9AMzvDRr3s79oPQe+5nEy/u4nMPSWMQ5vSXUf
CBjyiv7xdRzkCunA/N6D8ZxviE7n7zHxfSF+b4Ovh4x+aKDW59DXXJ/D34Id
Rv6t1uQHOh37Gvy+A/gQmN8PRz+BkQ47yOP2/H0npCNezuOZHMMfgn40xjES
2bmhRO0/gY/gf6jzunZmxMvhz4AuqB9xZfhvSIdcoz4Vj7AzIR0Y9aM/PD4H
/4qfEwCf8nce+L4rP2cD/Fb1Q/urfJ0OfQS9DAx7wN9h5fcsnK31uaSI92Pe
4b+CftCz/LwTP/fI75nweyn83irSoZ/4+0/QU5gntAu+hxxhnxy/GA/sJvxT
lAN9gd2sv+d1fqP/Z0uHnoW+xvwgvz7vpuy5XnfBLhrvecbq80edVf3azuey
4gN6nLus5W9ojPzoD9LRPuQdehjygPUN5AX+CvwRJW9e2m9GO5Bf9Avl0S7s
KvJD3pAf2NjPRJ3O7wXxe9OpvdPE31Pm9wORDrsM+sBuAxvPX8dpOeT6HHwr
rfUG6/h1avfOjO8I/9DnNsC3xvMtP3R9wPz+IviIv4NhjOPbzsvBXsAOGN/l
89XxN+Tj+2H83CzSwR+QC/AD5AKYr6OQjrgV30/j84h0/s6R5h+qD/yF9sD3
xndCfHW7fF8c/YVegLxwjPyYB8w75B3zCj2FdGDME/Sl0X+z6H0R9BsY9h30
gXzzewd6v5Xsub4PR3qd3/tO7R0arEegnxBPAwa9Yf+Aub3g8RzYV2Doddh5
yKPRL4jS+obfR0N9+rwQs/+on7/7ndo74bCHsBeIy4APgJEOfgIfIp3zOfgS
6eBj8BHfVzTal0Stn/i5odTuYUDv8XsZ/P1Gfh8HcmG892+71w8/Bhh+b2rn
fvi5IOM6Nl5wP9p4ninluUykwy/Q58lpvPz/yA99ArphvMZzV7ZzeXyfCxjj
4Ps4KIfx6u96WOt1ofdT0up9NaTz97a4v2S8h45z5SHs3p8tbgf+hf1Ef2EP
jedvY7Qdw/j4eX60D30BDD6GPoCcQn8gHRhyqN+9JTmFnYFc8/UNzvtAv0AO
kY52wU/G8/fx7F1rvPscLmB3ca4S/QWGvTLGxeO1fwR+xXoF/pPSWx80zm4t
/04a7UQU0/P8+zO2973g74EO/Hy7Ma6ZmMLegv8wPuM7sMl6yPr/r+x8WRS7
Z8Dvu9nOv4NPoJ+hx4GhJ2GPkG48Z4P7AP7UT/hHARpzvwf2EvwLfjaeU7a9
94V00EvRGeeHv+l1j9GeJup9EvTf+F5loraHsMfGd4ri2fovjp0jj2fvBVs0
hv3C+gEY9eP8APQJcGeFBfQNMPQx9ESitR17E+wzMNa3iK/97+f1wzU/Gd9n
i0pxHpnveyIdcSD+3pr264lvkY/rIfAn+A/2EvMCfQl+RfvG+zSRuj6Mj7+X
pe/jkF6Av+ys+pfiXhX6m1rcjPtp/N0I1A++wv4c5BYYdgZ+Ib8ni/z8u3bG
fQe8O277xfrZGEdP+R0h1AcM+YQ/gPcloddwvwHrCWDj96Usmu8Qz+DrQH7u
g98n5d8jML4bZ2H+RFyK88w474B+AaMf/B4qP1+Bdvm5XtDXeG46VNt10Jd/
Py41PwXyh3Ui5M24/x3J9FWU5O9dgV/Bp+ifMX4Zpu0zt8f8/QP4/8a4WRR7
t8H2fUH+zjvmCX4w6jN+7yE8xXeYkA92H/EV6DP4mcbzzLHafiM/9meAkY78
RrsXq+OysPfG7zbZvl8F/Q09AXuzy5p+Q+/fIh3lgSEfwKAPsDHeF6HjGzze
gPkwxg/CNB9BzxnfEYlKsS9lPGcbmWLfFOOBHoec8fOVSEd7/HtQGA/aw3iM
+scWH0d/sP6E/sF6k7/fYhy37T1RJV+x4ovyj3Q8BPYY8w//APY3TvFlinvN
eF8C6dATPD/8epwXBEb9sN/wNzqTfef3cBAfB3/BH4DcQL8iP9YJwIh/o/xb
K36QYr2LcwLG+GdiinNjWO8Aoz/Gd0BjUsRpEJ9U5R10fN6YL2Ucmd8LhL/J
75fBn4GfCPsKfub7JcZ9+XgZZcWXpXEdZztnBT2Ce1uwr/BbjfY2UMsX+A3j
h58ADH8O9MR8Qm6AjfcZHDQ/gX+gN4D5PpQxbpqo49nwG41xetu5NEVHfC/Q
dj4f/j/kDRjlgZEf/UN9yk/6rPUj2kN+YKSDn4HhXyA///4g+N1I90itv6Gv
MP8llHul14fA+h1wwrBLRjmJF+AfYORH+9DXwNB/xvVZhNZ34E/MF39vgscr
kR/6CeODXPP1Aew6+A/0hXzmsuIDGoOe+vvYJFfG/ds49s6kRRr9EQv7vr1t
P5Wfb+HvOvN3fPg5cWCsB/j31EDf1O6NcD793/dvLameU4Wcw14DG9eBodou
AoOOxvNo4Xo9zPUO9C/XX8bzJ/FaXjEvfH8I6cDQN/xeKPgJ9gb0BEa6M/kv
fF1mPP+Q8h168K9xfyBOY36uiN/LwHzCzmDe+bknHg9EP4HhR6V27hT8AL4E
38I+w55Bz2B9DD8F8o75xf1eox8UKIx6ISjFdzeB4YfBPsEvAr+gHtAF7WLe
UN643o7S+gT9gR7g8Xv8H/yP9ngcBPKFdY5Rr0Wxd2Vs7xjxc1yYT/h5mE/F
tz/ILw0n/fpTY/QX+nCk9f84B/XNtr9JdIA/wv0N4zrNT2PVvp+u1/j9RFs8
LU7RXcv7W8UvWr9jXPD/wOew54gDIC4C/tLrXuI/ox22fU8F8Rj0B/IFzOMM
4DOkw36A/4HB/+AH9Je/l8zP06Pf/Jwt/FXU56bskvaDgHn8Xpdj55jhVxq/
a2jR+hSYf3fbeO4qQnJ5wvoK8gYMOcP8wz/G/APzdw4hb3zflseJ+Tl44/0V
3HtEHDlGx3O4PkQ9/J6F8d3UGHlE2RWKF0TSvHtpDP7A+gjyATpAjvn6DPoW
/IJ1IPgL/An7wv1fYMWvDvp+LzD4CvwA/oCd4/cggFGOv2MIzN9BRLvgX9AB
GPP9v38XOVD7NTwuwuNcxnOW4Xp+wJfQ38DgF6N/gnNJPsQHEcwPj9BxA75f
ADmAnPB3r4DBjxgXP7fGv3vBv3PBv9PBv+sAPYb64Q9Bb8GfBYaegN7F9w9Q
L+KbwIhnGt9hitVyjfYQ/0J7wGiPvz+tv59g/X+ojiPyuCTu00EOcR4P/jrG
Bczf1eX7qHwfH3KPeQafwh7BrzLurySx+5zxbJ8rTteLecF40H/wIdZfkG/Y
M36/E7iz0vc63gi7gHUN7IKzsu96PLD3apy29Zjqv0XvFyE+A7pinoD1dy6o
X9CTkEfQHf4k6A5s/J5GrP5+i9F/TKcx3p+Bn4T84E/kB0Z+fr/NGFePY9/N
sqR4n42vA1OLK2FdAv4x7uOFab4Ahn+m2rf5a0Y9l6j3F9F/ox5x1N8bxvwA
Y35QDvZPyVdMinspsCfQO1wPYb0CfYS4OeQV8gk/D/MNfsV+rOL/AL1OgR5F
v4HhfyIOgPz8PhP6D77n9xOM/ptjingkMNb/W5W8a3uV2nfLlH1P0PEPtAeM
9SfWk7DfxncubHoH/gLsHzD3T7GuAebfu4c+M543Skyx7wT7/8Faj70J/pXx
3flvml/AH8Z3nsK0PQZfY30IuoOPQEfoP3xfB/lgPyCX0P/gXzU/abT+Rzo/
Bwx9Df3W3Pr/eyn8ZGDQBXSAHoWehN1DvB/ziX4Zv8MXn+I9e66HgY37OLb9
f2Cs16AfwL88HgEMPoF8Qp5S0xPQW9AToD/yAyM/6G3MbzuHA/mDvKYWBzN+
F9qif43nR8O1febfjQLG/ICP+Hf/QG+ko5/e4W0G+7eIEA0Svrp9+BCk9/+g
n4t9u9oscniYDDl+PXOPrrbvO7dKO33Gjs/Ret+4VqYJiWsGBGm5gt0Z9yJd
t/EVu+j4W8mzVizaUXnjvk5yu5NH+p4q+ktEU3soB/n6RekxKl3HPyqWdNhX
cGKQjvein3nNxSf/bh+49z4r1uVKqfGJuUse/mi+PlKOCWjx9zCPb/JNnsGb
mmSLFTnuDHEcmcdTuLudc0jzJUasuVgvMnyal9jUJr58rsshEr+PVLqMU+ny
OeW/b8TyDpU/+Niy5kk6Wzz6gMJ63XCE0mE/KL+OGwzPbxqXWPuxnFsudICf
U6T8L6/fth5vLsqhlfs1LrA2Uma/8m/aY4Utwr5Noakf7F1lDsJP/7FikVNh
uZ1wHio/TJUXlF++UOmS0gWly615DFhsq9ykTdYWyXQZvtRc7JFtXkoS/6xT
dBLbiF49iN8wr5gf++C2oaeGhYkdqj5J9cmF62qXadTb9o7mMoVt7x1R/o3U
fuO8Tec3L/NBrJrY78Yhvwg5j/q3heqDfai/4FzLtc1t3/vJc36M4/MdkWJm
3Z3ei3pZxI4uvXsU7HBBbqd+r6dxoHwDVV6WDHdwnDskSsetyius9f6SoHo1
cjX2F5kzNB1c+K5NnhtSeYaFR5d9Z/YlxIqzjS6GvHn8TLZb1mXI6j4WMTzm
wIIjpc6JWdS/iqp/4gPl763yi7Yqvwyk/LNVfnm1s8pP9UuqX/QJKel6YHm0
9Krw9ura/3zRnhweay0vUb4O0eMNlU+k/h376vrm5VDbfkv5v0W/B3OixVSP
HJ/erPEVLyc7v2zUxLa/DT23OPraaZPXTfFCpaf4jkereJUOPfNuy5iIa40j
JOqD3kN9VWKs+eUzqg/pqC88TqVD7zRb9HzqnPoRsgz1d77qr+xP9HBT9BDr
E/YczOUVpPUUfv2VPpL1at07fepAyu9kZzv52XP4j0A5U+kXMYn0S+/560dP
KPJBPt362LwzIEL+fXzc0hK73OWG0btKPvojUpZR8i0g3/NalruRo8VzMeOY
rB7Sx3avbci/4T9KRwbKKfn9Sx84Epri+/OxJ6ztixHG+sVu0h9zVP1iuqpf
Uv0ig+qfeKX6J1qp8gLlMb7ManzChcpPp/4tcGm+acPnM7KeU+Vz7TZEymGn
5zeOTXtWOnQdffXoxkix4441XdSndJ9T1nSBdKbvZV1FXx1/I30tRit6isrU
v41EP8jh9urpX+cZEy5Wp9+xr+/ib3JKaLn0u4uGi2ZUH+iVN+eWHdNPhejf
hWQPBlP9Uza6Hvf+O1yc3zghS6UxP6VX9b2T0k+JEH2XL5tRs2aQ7NI2e+E8
nSJSfLf1SNzDlvZFfsr+NJ+gd02az5lE7+lU/1FVv7id23vu2FW276vCr0vb
sPWo06siZJ2il53Tj7C9q7zXpem60xnCRKFGobG559m+b9v07feoDaO/aT25
U9FD9rmdc3/W7VEiR/ZWq051DZB1fCqfyu0QJIauG1Uham6YnKToJWYoeskJ
zT2abHlq+97iJxp/JzV+sSJH9VLlX8ZqvbqKMPQapQuWrvUg9Ma+wk1KeG+J
lI8a5Dxrvy1ILg/YGf+4X5h8qLAgLNZ0CPP7MC1IPFpUPWPuVl3l4hsO/slY
XuiUseJvvJrS7YZY0wXS81e3poteU0+U2zg0SFrSLFg8onVnUaDz9d9YHF/6
eHgylkhvVMaaLl239Pzt32j9lvQsYm+yv6H7jfJphlvLazv9aOuN7OFvI0QP
l9hPY2v6izmTSl5rdTtc2/0HKl3jh5R/puIHeYL47QaNfyXRA3qybIFsVe8s
iJRzKP8B4h/ovdIqXevVMoSRTljuU/Or+Rbys4P4heyJiFL2RC4JWJVr1FCL
mBB356/5zWfJDop/5EDin/kkb9OIf471ert+ftcY2eXCyZL2xz7Lk4RbKazj
yqfCBp5a/NpHfM3ZYPmPBTF6v/EHYchB8V8Dz5TPFSUKbanWIMPGr2KCoq+c
qegrDqv6RT9q75sqr88ZDfDufbZnnxhx5+algecuf4Y/muLdu8fUH2pfn7vq
Ud6+xrXetveZdBywRtdN2ZaGi3rTluzP2t5XPC4esds9e4TIR/I1VtFHzCH5
mkr6yPtS1abufWzfAdP0DbfSV9PnhOoP6C+LqHTZS/VH31vU6UGqPNZlK46n
bVR7gr/wzjljadnKtnv+c/26VemSOVpcqrMsZ54wP7FQ+Ssyk/JXdLyqRNK5
Of9M8ZceVB7xB1oPpHi3zpX6O5Pqv6Xq1/FiT3Hm0lhv2/n3twrrfbwTGf5o
0r1/iMh90XNVhT6hwrXklb+21QkR5G9o+Ut8VtLcf3Ww3JC5d1iXdbb3SAdE
fvI8+CJUnw9fNLjgkeC492LBPo/WtyfH6n3SZhv7t0nfP1bsH3dXNr3joe3M
i1KbzI2KhMruFwNHzfT9ZXvnXq0PZD61PtDruJqqfjlb1a/vuf+l6pd7VP3y
Na0vKlB59G8hlZ9D/UN5E/XvMpV/T+0nmNX6BO3XofHNp/Zt7w2q9pfT+HaX
XXbO67GPONa6eq1DnSNEmzzK3sCug8/TKXsjZu6LbJprV7B8GNHswqmtoYLR
V3x64Htk2uYgubry4pjFfcPELlW/PKrql0eVPdN+i343k+xZXdW+9ptYup6n
rx+XLpqYJ1JeuZHd2TzvnTjZd8DrfnEReh36XvmHwvv8k1cZOvnKRPtXjj2y
RYgx85d3CpztK81Ds97YkT5Cnycr1GHxF0vGCDGN9B/s2+HK1W5cPhgrMq6d
1Ptya3ex7rtTscYbY8WcHKcHuZR5I46qdJldpcvlKl16qHR5iMqXofRVVP44
paN86BpVP6XLU1Q/5Bn6YNmsZw3aHo8WE6ucLrI64ovwVOMTdg7W8cmuanzi
nhqfPi9fVI1Pzqby21R5OUzNp3iq5lP7ja+J37sqftf77E6U35Xmv6tav2k/
DfHQIcQPqM9N1SfGUH2Qa/B1AM1nx/anEuovdZdpX33MtbVcpJYbmm/RQK3n
5Gq1nhO/1PzL42r+RRkqn0GV1/zyjco7qHSB9MbkPyFO1H2ez6+CDpHiVKLL
p5qOgVr+n1H/R5P8o/8VqL701F/Y+82VvlR1fx2hz70tfxVSrExyey+/n3VZ
UzBETDg6aalj5lCt79zCp3ca+D5cdOgTILMd8dX7dvei96wfl/uz+Ktds74b
l0fo/YFl25d/nDs0QuvPN6q8LKvK6/23fcoflIWVP6j11iGlT+Uu8hdLUTrT
t3q/OOziyVzxkWGiRstzIRXtg2RA3yPLRs8LE1GmF9W/Zg6Un2f9m+7FzTAx
t139D9VdfOTGfisfvWgfIe6r/sumqv9ioPI3ZUbyN7G/nI3syTtlT/S+cBjJ
b4KSXzmQ5Pcu8fdgqi8pm7U+vV+dRdUnvKg+0KnrH1Hhn4OiZeOJtWcGlLB9
57iq8o/l0l8XZ3hviBLdJ65t1KFVgNhyqFDkfhdbvD7snijvlrze3FQusemG
qDvy1+brN8VtH9Hb/sm1t20j5DCXyPTrjvmIfOcq3HftECF9lX8sW5N/3ETx
m45L5vdpND17Lts7ngUV1vdX110rPz66RLjed7h8Pcx1SS47E+KG/SM2dhs9
xvZ+PvTfi8r5R6zvYLuv8Ypw2cYXl77ZadHrV9QzJelnRb/6oXL2kR41bwbH
pXjfvp6bQ97yQ23faWlCGPHZ+VR+V4mtNcZusn1PPbxvsY5pXG3v+tQe9ceX
LtMczLDXS8/1Tlx4O07709My3vzyxw+bPf95023sp5u276vPp/5hXP9Se8AV
OoYNGydt90dkxil/XW+bVuMBRC/jdz7i5PnxO8df7OAnEktXfDnR1/adeIzv
OaW/++/NgIrrbPdNQJ+52W5kd+0RYYsLpFs22P5OmM63kNKBd1P6DZpP/e4y
lW8+7pRLaMMEcZDmn7+n79PjkXtJH9v72P3Tb8hm3hCn6eBL6WivJdWH+osE
9d2ffq6Dvs8CfMav389iW8Pk/sWv5X4nB3Ox4o6ZvPaHirZHxrx9tNvBvGLk
xPbLV4RLN8uWbYVOx8uT2f68k/2wn/xeyce58u54OSHmeJoFo2dI90ET+5Zc
FifPvvg6wmvwR1G/2/ZMG+snSPOVAK/gbGnMv/5ZXO6ae7ic7LY3cce0BFnR
NOtS+i4RssDm+SMPrQjTv89ve/cf7honp9WqtGORg6/88+9SG8pOcjBX7rBh
7Dy7LfLbX4MHB1+Nk53SlL7l82yjjOySYevP7xZxpu/Jk+Vn7JMrI2a8ru9j
b5o4NMu2GcnrC8u4fMtnuoTq35Insq45Gm8R7wp8b5bvXajoeOl6uX4rPosG
8/744/UaizB/bJh1dNdo+Wtr1eVnBvyQo+9lSVe2bbToOvTljLIdfsieh+7Y
PUnWF9X+aOA08UOgHKiwLK6wuEflv6nyoi/lL0fpz658Gras61u5JNedMS29
o6XDw2qvRrd1k53zbWkpvKJk+x6jO4U2d5PZS+ZeNjMZR9cd7nphUrQ07jNG
yU8NzQt3e4bJbsvTl8i4JEjaL1m7+d6LKHlx+ZKF2Vu4idNdn1qck8unybir
fYu2buJDwC//2sk4bnqpTAPX2Jldd0anqfvfT60Pso3rWLLCo0CZL3vsmKj6
cba4ediKM9P/jNPr+z8XjY4v38OiceukmXtLjrWthy+fKVV50WgbLj3Q9arf
SBten8O5RcsRNpxgLuh2ZJgNj554p3/GoTb8ruSooNGDbbiFW47pTwem3G+4
MH1G5oxlSup9g4X1Hrf61a26xscvvsn8oWADjUcXmDjiy/imGs/rHv3I42UL
jTdtnlPxWY1/ND7qlma1y+b2GvfPcD+qz6xOGnedMf13+zr+Xebao9/ta7y3
trV9jbO+n/C7fY3b5Le2r/Hybtb2NX64ydq+xg7f7/1uX2Qr9nJLyXl2pjJ5
XU3V/3orcyhsDs9jxaIPzR/iLTVp/oCDiB8XK34UxYkfOyl+FGkVP4qcih+F
R/UxbYOS56tWpd6/lnlECa+0U24l9Pgu6ub9VG7Dy0iRX/GjyKH4UczxXPwy
Q1/bL/jGUqv1p+/JfFbh/Iw7+cfb4itHG570nPk/cLn73pEf/wc+3D5njqZO
Nlz2XbOKB/8HPjhoavP0E2y4TNDR/qP/B/5vsuf0ZxNS7heVWHMzc6Zk/gEu
O93p0W/+Ab5+zG7Vb/4BPvrz0eHf/AM8aWnODO+S+Qe4UfHeo37zD3CGqwdc
f/OPfh//aGTevsn8A9xvzY3f7es44uCY8b/b1zhfRWv7GgecsravsbmltX2N
d37q9bt9jadOt7av8dHl1vZFL8Ufel6IPzS+O6X8/KzVbd8FJ37S8btalB+4
kNIfmk8RP/BT+sr2fW41/1qOe9VqOsfRFKXnZe/iD0Uu14oWcmhY+SrTY+UV
u0O9S930kjcVFq6EzZS+W+HkdtPPjVgUK8+WydvuWJEAuWblpvSXGsVKU/9r
NS9k/iqDVbrordLFOpUumql0fX6q7B/ZNqdz/CI3/Tm2dXDTROmcudk/Djs/
yrmFPBdtWWC7/9e1pvfTAy4JcuiwbDu+B94R9WYW6zVpa5yO0wWebl2n9yTb
O4bdVX6Rw5hfx+lgz8NbDP3wPlu0GJ43t8evxb6ajk9J/uoo+ZMvSf7qK/mT
TcgepCX5y56+zIgJw4Lkoy2XZ//jEaX9tKJdb3pm+GI73370aq+A+QO+yrXH
DifdzBqt4+jPmpztu92cIFeLPJmybHPR4z2g+i8xXsQV0c83+UutbNn3q+iV
ZrCvT2bbewQYfydjeR2XHN4p84rXEUmaDtivb6fmQ9B8iAlqPvR4goleFmXf
TB5k34ZQfciH+jrQ/K6n+pbR/I7v6vR9b9UAOb2RV+MvDW3vXP5B9nGsxfF+
/npxWo78Y93zvW8YK+wbN+ocl/GrTCD7albta36qQf0n+dB2w4f4dQnx43ri
1zrEj5uJ/7rTeLEuSLuox+joEa/k1BvBF062cND3D6cRhpxReorvWZP+FeeG
ny1UMOcDuXhm9Q/r98SKTM7F/kqyuyNl9Zv5P3+y+Y+/sk3YMmp4lPSaW+74
icmhmm9OpM3wwnVZjKYv4lnXhvS+PmKcr3Qx9c23xDdBy/W8hi1bLZ9p0fvd
9a/eWFRoke3cLPxe74ZjztZr8Up2KpA5NDq5/+g3zlPc7rjgzyGvfcRZap9/
j+C2al+Il39WGzrS9v2Bme/nNl213vaOr73TjwFl71o0xjhcTj507/A1QrR/
8efBTJdd9LoHfOpfRZ7wG2+7vz0iMv1Fu/yxwl/RR8trySXpAhYmuMt8ewr1
vtXQ0ZzlsKX9lHIvRY8Z5Rvlbu9o7i7Grjt28Kv4O2jDq7T70pi7PdgZ6bEp
RnY8OaB4bS87c8Z+P980zBwsQyubFzY+lygHJi8QFozxEInZn29sc9DO3G5y
3+b9hgeKO/2n1eoyO0n+OhfdIltxe/PmV65/rSwYK3dO6ieanYvQvzmKZ6xf
wCdcmiYVzjGzWaS8VebcwKanvsojZebE1oiLkGW6dL23dqij+fvaYX33lfkh
5296XGHw7kTp+dGu2qzD32Q5lW56QeklZx/oMHqBo+nTwtPLGlYMknvrHuqy
9FC8bJVl+qLo2Rdkj0FXIzceiZdf9n+dtyzirLzZoOrHC2ftTP32nO6Uedlj
6T8mU+1u9+1M1ea023/4+FVZRtVnfqrqE+3b3hHZ68aIzJPr/4wtEyxKUXtu
lF6R+nNJ9UecXjB2dcV8niKh+dDaZ7LFisSLq73ux3qKK25ey9fax4rgvoqe
0YqeYoiin7yp6Ce6Ez1vE36t8ot4yn8z5Pzco1cS9O8kNX+ypZo/k71xvk0m
Nd+yu5pvUymaf+C3i635RQHKP4j4AfXtvLy6682BsbJzmZGZKzYKkb0vWccj
z6rxyETzbbHw8g352nXilfbnY2VUW0tIbLMryeuLoG6nOsTIeT5Hz42t90AG
rMjRbtaBWJkxonzjrFlCZeluo742XBou7Z1eL+pgDpFlrw47ur1zpDwxuHL/
5kt+yRkzj3YJ6hohg858uH7o009ZcH+SfZGF4bJDoV03m1tC9HoE8bLjeR8O
WhVow0sK5V7a7X2o9m/OXj8T0KRvpJxK8qff+R2v5A8Y8ex1Z0u9mnkpmZ+O
NQ9bPS1WxyeQvp/0C+TsGtmv1cp+6X2sAMVf5nuzFX9hvZP0YVe5hi28RCOl
f3Qcb5HST7bzN9S+8buJsfJf0i/Qg4dV+2IT2U/okwo0X5fAf9I6X8JdzZfI
0c46X2KZmi+xUs2X+KrmS4zesN4SXS9AJH4Y2zJb0wjR33Xz0tIzvolHOy81
Gn83XKz/Ucxj9J/+4syKCZtdR0QK73Dr/Ioman4Fza+g+RUn1fyKmWp+RbCa
X1FYza/oVDP/zHlx8WJu0d0vLg31F4Xal3OaPTNc/74uZtUfYpzSH6J/+YTX
I6PN4kfv+f65fGz3G447e9QOdbDdLxnkqei9mPQ/6NuE9D+wXs8pfhFtBvZP
027C9xTvgRxQ/KH9pgDSx7BzJ1X72u+qs3j6/nv3YoVp9cPJkVctwinLG9O5
ne/EsNtPqjjnsQiHN/5lDmZ4K4adHvf83BuLPJK79fRCBX1kU5VfOqv8kvJL
yi8Hq/ziPOXffatpZB4ZK348y9ageB4fOYTqL0z5m1D7K6i+EdTeTlVeDKf6
v7mr/vxF7fek/rYds2912GqLCPxR7vQfq5/J68s+nd5/zCK277ke9WzUI9mO
0i+rdHGL0oVKF+1VupxL6ddUutxH6ava3u23MZ9F5tux9EaZKn5yQmSHGmO/
Rcu0tWqsKDnETz5skzNXCadoeeick13Gi/5oT56n/lyl+gKoPz8aOSW2DIgW
SS4TSnr09xOfFr+PzzQrWnQRnyrW3O0v9ib1zbW8p+37GtsPHM7cIW28XPS6
cpclR2zf12h42sN+hOmjticDlD0Rh2b0rXq/d7x8XaPImrcVnompXd9Uqzw2
XlbOubT2i0au4t2/H5s5jorT8VXc1/4iLnmuPWoWTaPHO3w7a4urUf3Ca5+q
/6iqX8yk+qeo+sUQqt9D1Z/iu3fn/lL1g69nbntnX2xmlMZ3Ms7tuf9AtOiu
/E0xW/mb8kmB9AMC6tne7wRdpqvyGt9W5eUG31cthrh8lnWe7c2RtUCU/I/o
Uaamtb+S+isHqv7q++qJOd3uuruYZS8ab0uyz4dpvM/VeOVkGu8OKo/xzVTj
k57rnbLO3J+Q4rue38k/26fmV5+H7xZU7pBz03ix7oZ74sn9n8XxM4+cV02I
FwV2vq+XccYnQfMvFqv5136hJHoBzyB6/kvjr6XGL9qT/lqm9Jd8T/3j3yUN
Uf2TxH/6fYVO1L8jqn/yGPWvpuqf3Eb9+5f4c5qyZ9refCd+z3DXyu/yOfH7
EsXvkuih32dYS/KWRcmbcCZ5s9S0ypt4Q/I2Q8mbmOeU98pZl0R5afLdKzOm
vxU7SF5GEr2aKH9X3+93cK172GeLnV4fOBKGniSs1weX3i3OX2iunUkEOrWP
rP9WbDl+0+nyRDtTzsHL+6X57KH1+wnSr/rd5VsPN4V3s71D3OxW1eEPQtPo
uH+Lsa+yNx7rqO/9NKf0jsrfFZ3I34V9blr4xkr7vUmy1u6a4zcFWPQ7tLQf
ovPh/8E9m8ed3hSn1yVjy1z4nG+ARbrZ9fQ4v9L2fRD4Iwfv7rCEd4yT7Rvb
F4mfdlcu8f7Z/7JXguxC65/bav0jdz9R/j//Hoivsjfyvapfr/NO/Ezv8vCg
i95nAF0XOsW/q3bM9k45xT/k490PilZ/Hqjz63gj9e8S+Zm31K/8WSLifGW/
GBGpfuV0iqvNV7/yp/L/TTvI/8d6cV73C4+WpI+Sezr5xe+1d9DfI9HvNWyM
X1R2dpQsGLWx1IisNjpiXEu7lM6x4mqyn/dw9dAi3SJk5oSIeYeT/USPrxkf
l7sULoc1/tXqVotgWa1BvXZ78kXKzKGHynddHCJbPd0Z+2j9V7mh6eJAMc/m
xy1fUz72/vwYuVr5r8KN/NdmRv9HLlX+rFhK/uzh7FWXL4n3FPlmR+zxtouV
T0+b47I4+4vboecO//U+VsrYxmtK7/wqur3rVuvnItt3DX5V+by5Zb8o2bjw
ar9LE233XA+QPzSH/F1f8oeKkr8bu/v+q9rTg/U6GPvbZ8jfBV5J/i78nTlE
z8KKnro9+Kv+FL/v6zEwc0a7JF0/4hMbid60n6XlCvcSotKf/jGhRqDsv3pi
9rvB8dJn0JRmL5yCZd+i2wYv6GP7Xop+f+pIjiVD3X3krJabJ4X+a/PTK6n5
EtlpvrJ/ia1aqWOECKj+Is+9Wb/kja9N1mXoFytmdivUcmq9ENlXtSd+UnsD
I//qMNApXoacdTned/In+XBLupBauW3vRXx+3iPPpCd2JugBWo/r9yAwPugF
jM8xg3V8+j5MGcIhtL5dq/hb8z3kAHIBOWkZ2uH140nBKd6XWKHmS+PTaj4R
D9DxKooXaDyI5gv1Yb42qfkS+0i+MM9lSJ6Ab5McXya5xrwPpvjBV4qvIH8v
ige0U/pRv7MXVGnikFJdbPt/Dyhekb6g1X/Q/nI06RfwJfRLCJUvSfyJ9pzm
bsjesrPtHo7+vtH2enLveAvGp7+bgvHHKP0rBOlr/F/H55bNrRXWwc6U1V7p
Y/59l6Kj3XzWZ7R95+sX5a+q8ut2mqj6NUY/civ7Y1qm7KkoTv7rjgF2Q7e2
sTel+++fUnOnfZUnlT2XduRv7Jnj/VdcfouoNLSbS++Gn8QB8t9fKv9dvFf6
RHZW+kS8SuO4JGH4ATngfNvarldiRbFP3pkvZgoWHvZ5OvyoECPa/329TUEv
2y/WK4dpPTviTMuRHfvbvs+yI+2X01dKp/w+y5++81Ze2vJDHtw062KWWdFa
j0GPfKR4ese5JSd4/3tNhmVeEB711M7ssXZ2vwOTP8ppZWuuKVE7QT49WXN2
/YIfZGDPb3lvDkqQjWqnXVvb/63cPOrHtFEXI2XTZbtmHXN/K1/6BPSveClS
dqmRJFc9jpHVvo/d9VfdCDlc9Vfri0eb37379iRE5iiXUHJWiO37VaPvT5u/
+54tbtyj0KrBDTpF2fY3Dgf0em+O0fbvKK0PoQeK+Nc7cbdClMZ1xp05eLRY
tF6Hm8nf1e9axbYeP3RKsr3b1i9L8WMeYuKUvcc3PY2WbzPt2b15+SMRHLL+
0rzcUbLcMLtqH6famzuVGlv8r43+cqfiB3PMAcUPF53SbK71OkH3E/pyUNKH
8GGuQXK7mp8U30MpQvOzSflH5sHKP5LDt/3T6+fZRFngYbEqTks85Fzy114p
f03b2+uF0zitnu8q39D6JE6tH+QIVV5EPlDlZ6rywofKDx61wTu+e5KOQw5R
WNOtYHWXVz/O2JlX13XKMHvTY3F1aOkiK4/Zmd85zev6wOepeN9mX2XnBkny
2f2WVTZNeSRQH8pTulhP6YVUfaaGxvpM+Sao+kZTf5+o/orZ1N/H5J+eIn8h
jfIXhCf5C/2VvyBqkb+QQdkfrQ8jRNpeNVuEiCVkr6Cn99J8QI+x+RB5N+Wd
75zM33k7j2zY+2KkGGTkb023QorfNK6l+E0Q/0jiH8H4UTB+Fd9rWeVJbFfy
JJqr9gTay0v21EfZU/En2dssNN673051OlDc9p4P5L8ajecK+Tdm5d+I+XuP
7Kz/zE9UOZGp4fSiMcKV/J0upJ8qKX43FVf8LojfTRbF72KJ0g9iltIPYmvC
/G5TMn0QRU81zJK5f4Loo/SJIH1iGj9202P74BeSvyd/q6jiX1pf6/NMA8g/
8FP+gbiq5CvF92NmKvnS473TPrjGkf1hYjzpR8x3A99e7bfcjRH5dj6s0LZ6
hPg23tofXU+VL5//nhQZKR/tnZ5wZ/93+WpX5ZWOfUPl4+VFMpT4GaL9degT
YOibh1cd94S7PpMnbnxPu8ghShbKrOb/J+mPdXlqrLm59qAs9HGiW3SdKHmx
cNK0vA+uyc8Ncs0+XjVKzsut0gurdFGiiEr3VumIpwiKp4i/VX5RhOr7Q9Un
PlF943KpdNS3l9JRXwGXwc3+do3XcYDA7RP7VBmdJD99ebqh6/UDonOVpB+h
/ZLkxaJLIkZMvC5+qHSxwkeld1TpIn8xlQ6/ZpzS3xr3UvpbrFfra0HxBZ3e
m/Q7Ky/vKvsgcpN90PvAFP8tR/E8yC35o9oenlbzJ/xo/iJVPFNWo3jmH7Xl
Uv/Zv+QZ39CvN5LlKh3Fr0tRfBP2Z8sgx0rh/9ju5Y2h8bVS7Ws7+4zsWTbV
3+Rxqfg27C36tZj8RRbvFgerfa3y1PRTmld3m3X7aLjoub1Nq3oV/eS4nqXH
Z6gVI490rZPpY0s/WdVn+cCyGyLljXxvxyxJXseY5csSe+5+l8PGz18+bHO0
zONUtne/dt/ku+kHxofnSfk9FhevF9/75/8qv9N8//C1zqfsRPNdSc2nvKnq
F3dU/eKTqi/F91Y+qPoE8Y94o/hHtif+mE/1XaD+V1b9F41pfJPU+MQS4o96
FH/apfKLP2m85UgfviL/AvbbscfV9DdmRcpL74asjCudJB9nOzet7Pln0oPs
U5EHVvsj/RMnvrHbbfseS9LGzfs6jfkuq14puyzfhnBxgfQL7DPTL3r9upj8
8wrkD9Ql/biL/IFg0o+DaT31jvTXv7T/0l7tv4jr5C+Ar6EXh5I+09/To/i0
27aWi+fEJ+q4dIAaj44XIp6S8V3zbe/8I8XHH6sf50tMlCy/jl9eDpj1fcJD
O/Mlv4qBPVodEd3nDqpfqqWDeW1Y5ic5q7uJM+T/zSD9flrpd1mY9PtxpT81
nS6p+kw3fVV9R0vk+Oqz4qms3m7yoCWlY8SZ0y6Hp/Q5Ll/PDt51uVOMsPfM
6P7nnEfyy9IMSzrdsdPrgFwU/4F9+NsYv9HxkRG0vtDxFOP6Qq8Loiies3HW
7CPZLBEpvk9yVdkLva9cOKFI1am9Y/Q+zUqKL2A/eZUx/qG/T9JPrZe1XJcY
+epcd6cE+fzNyZH3/okQxdW+h8xP+x/w50vnvPMw7d4YnOfU49bf36X1ENop
TesnFi8zHTTun8h81E4xahd6qNvMtJsydYmQ3nkbf9vlF6r1p9eeqf3qZQ4V
rU4UfphjWbjMlaZ3mFvFUHGy3H+LoyeFy0tu5wL/uZDWlP3sDpfKC13k6hnn
+9xOxrfSpXHukt9F3ugUVWBHDtt7JYW9Vz1zi7M3TQ7sYd/i3UfxyK97+mYz
05ou2I8/Gr78vdg8SBTI0z+taemSCstCa3rrdXAc+WtLSZ/Dfu+fkeBepUio
/k16UmFvSI9Qsapn8fCaoSGi+S0X06+CHiJfzRfdCu60M12bmDh0bs0YEXb7
Qt13RYMl+QPa/wO/7HyYPlfG4oGiVED9gcVMtu+PyK7te22p9E028MmzfMGi
aPkq36hWW/O4CrvNA3OVqRQjqyj+FsTfEv6uq/J35XpaP/wi/28w8Qfaj75b
9NfS8EgxbK9738HHw0XFJr/eLMxu+37IsqeBr+58itP3GPL0iqqUcC9ObotK
iFla753WGwNpPXT65mS7/KO/a71xUfVfNKL+iwSH8e4Xv8mwQ3/3uR6c7Cdu
XjvAP/67vq+Hc/N7X7xdM/d8lI7bLVf0kd0tAbUSk/0cnOsvrOilMcr/q8qL
JdVONlv0/aP4ljno5cCZ0freXemDT+1H946WpP8F6X99zn4/tX/vpbPblQHe
4tC6LoMft4+UZo/XXZ2OeImaXfp1GDcyUr5U+jDFe3BHdyy5l7goQoQeq5E9
TQ1/mfbE8OmJwyNFo1Y1ivlE+csjrQaX3NI8UmS/N7y1p7QI592zksY9Tl4f
R9l/v9DPIg7MK1/Y8umnvEr27zHZ18HKvoriZF8HDp1daGLnJDm8jntQh/n+
IuPOAxNbbk+UXoHnbzf79xvmW/Obfm/u8cr3FRZ8FRsV/5vfKv6HPJkXGeVJ
72fReWTzBHUeWRZU8mW+p+RLrqLy9VR5Xf9Zki/I6xxKP1Y9MWvb9Yfkwh0/
CnR6btu3OO21Z4Sfl0U82Dvx15s+aU25Nm979qWFt2T+tZxycOetm+7hImhe
p0rbV4XKbDm/PyubO1ws/rG3ob1riCxeoPHD9ZuixZrw8Fpj/4kU454N+1jZ
a5tcMcfDdf1gR1Pn7pnrz5gZKeq9GuCYv8lPMaubd/PrtaPE8hdpi+y4GCy+
Dbxeys/D9l5du3nLQ1csStJ8ArqOmXR76KcTyXId9zaLcwfb9z12t7HL3uWg
7X1e9H/S0V+efx+KltmH5A1K6BMuji3rP6fUoUiZZ8mb6ldG+AjfAk/dkxwi
Zcl4vxXLkj6LRg8Xf8+SK1I+n2NYz+h7AC3iVz+Oyxsre6SvWndB1TDBv89x
XPGj9Ff+hqih/A1tb3Z+v9UrysvOTOchUnwHdMD1NC99qtruFViUfpRhUaE/
i+wK0/er6HyDjpPp9w+yz1hXapCvNKn9Sd0u7Ew3tZ8u+9WL+LItf5y+N+f9
q2LdPMNs3znDuz1n1pWt0TDjZY2rKSxo/07bTTrvkOK7jH+r/ohPLd+2y9c/
TtOJ4qF6nPCHauTeOTP4Z7iot3mCh1NihE6H3Xrer8gV32S6Ab/+1bLCjiO2
+xU/1Xkz8TDb7ZlTA0I1H6CeUEq/p9L1OrK08byN2XI6wv95t83SdcCDpXtG
OZqjjOdtzMPexPp8rf1Z9JsyN2ZGVkfzVYrP4jfjjq2Jpc8mSM+iHl4bbyVI
Oh8k6XyQTFtg8pOJtT8I86SrFVxHJkh/Oi8UR+e11te8ub3F5BCRLvukdCUr
JUo6v2R2p/NSHdV+pZxF+5WL/exGH1qbIKflurRj/Y4vstD9RTmzjHYwdyuy
99+TDcyyAp3PekjnnRbUii7h/CGNuXlcrlVT34eIXcpfFV3IXw2m/aBNFC/P
fqDf/M/77EyXnM9/iKxkEV1p/60DxZfbqfNWMpM6byU7E05D569ovS1ovS2O
qfNWMk6dt5IOXrnOjz3oISeXqdHU/Cxa2s/a0zk8o6tcmL7QxOmVY2TM0z0d
6ja6J+86LM32smC0zJHd40rbrU9lukprbuQqGyNvqfNh5mV0Psxn07R3e47b
mY8OdinoEP5UnwcwF/ds8j3BTe5qu7tIQWc7c2KnVVE/vTz0+yLPVLp4ZOyf
eO2p+jdd9U+Mn2ntn1ii+iciVP+Ei+qfyKP6J6h/4rY6LyeOqvNy4mKvSeM3
XvwmzkzL3sczOFLLS6cSqn+HXvVy/jU6gX3n0CJaqnRxPGux9v/VjdLvet5T
5yV1XDwnxZffqfiy7O4QfcAc8EOs+jFgWNaRMfIc9ec4nd97Sv05ofqj99vu
qP0BeeRFraYz2vhK/t2/DuRfXiZ5g1zCL+456+jGXo9t38Xe3ar1nEU3oqV3
4rJrDvGx2g/Z0coc3tM9RmO6z6X3gfEe4Z55Sh8B15qj9BGdl9b6LjFnt8vX
99jeRwL9Ds++nmZ444/SPC28VuLTlN95nJTn+sRr/h+l78lHu4NGO+h3ss6t
8i//5YCdPk86Sp0P1vov+9nKofNzJ2q/Zy+NB/rOl8YLnK9Z36H/tLW98wb+
G7Ipzft3A7/x89biHdEf73RgnBePvR60oWmUjqNdjOz0y9LTdt60UcGqJb6c
iNX2s5+aD433qfkQE5U+k31Jn307adV/Avpvk9JH0p70kXNSu7iwe59Fq8e3
h2UZZGfep+53iUC63/Vgv1VfmLtPsuoL+U6dP5e16fw53f+QdP9D+iv+k4eJ
/+aTfvpH6Sc5V2FTe8KflHybHpF8d1XrWZOLWs/KG80vxjV9bGeaPCR339zu
hyXdzxJ0P0u86OkwrNoVi/Bzbv7o/ocfwqt4XGjmARZh71aoyvEvP4XlyNNR
PWrHCtOXW0WargsS1B9Ta9KXz9X9F0H3sQTdxxJ0H0ucUfpCzCB9EfyyWNc5
Zh8xf1tItzvFo8Xif5KypW3rI5oemrfM4XCMyNqylmcbR2+xMOezqFwLkudD
3XcT5dR9N0H34UzB6j6c2EHzkZTNOh/iBt2v+6boL+i+naD7dmIz2RMHNX9i
ubqfJ+h+ntiz3WqvRN1iVnsl5hI/9FH8YFrxxOrPCfhzk432z3RW3QcUdB/Q
RPflJN2Xk2cUvWXzSVZ6S6K3dFD0lkRvSfSWA3aeX/ThSajsoX7FGYrP+qr4
nij8ykpPOUPRUy5U9JQmRU+ZSdFTEj1ltPvYcrtr/ydDYgZUFLdjpeOa96My
lt8qA18v9MpaK1pmW9Br8bE8Zll18I4CCSWjpfOiQqWHBB2TtW9n/rNutxhZ
a0id6OYbXslF6Y5F3BZxcvABh+gBsS+lV40op0XTY+WSPeH9apQNk/ldGoV0
Hx8h5zdM/KtBpVCZa+Dfb/pPDpfFCsavXDsqRJ5t3KLohfNh8k6dE9cSEkOl
/7zG3i03RMmvU7bnsNvwQ+Zf7F358YcwuemWT/bRzX7Kly16rnQ6Eq7vY/cm
/xD6dGD9kaHOVSKkj/3GHzmKB+v3CKCnzo6wn5P9W6T89t+PzpePvtX6G3GU
i+q+qvQi/wz6NxfpJ+P3ICxygNJP8vQfF/29jkXr/S3EG8dERi35vs72XYN8
DUeO39b5qxxaLs0wnywWvX5cGTN7XuQK2zvjK4+t/JSpf4ztewnqvm6K78xV
IP92l9Kvur+flX7VGOv9sDrHJ50rGyjfpa93/VizaP3+UQ+1vtXYo+5fz+/n
jUnxXe6lgy31DxT4Cv1iPmTUL+ZBQ5V++aT8Z63/Byr/WmMXZW90HBPn6dIp
eyMcclntVYrvggxS9gr3l1N8V68S+ddkX7R//S/RB7ivuq8q69F9VZNbxMZM
/b2lQ8iqn/vPWUQmkqeZpJ/KkfwsIH20luSrCemrsGtP/zggXstFr9pOzf9n
nOjaO9O9javey3OfNr+pEmkRF72rplvW6bV8bFcs4PjwWOF//j/7Gq3/E5/P
VH/veTtW/Plr+hm7yC1iUqcd15rWjBbL51vlT1RT8idqf51VX34+JtJd6Nlh
dbcYUUPJnyD5E4WV/AlvJX+i0ucFxUq08RMhh08HttwUKbq+KRpd8fkXsWR/
fPen7hFiyznPet3zBYjD6zyjfaZHCZJXQfIqFip5FXmUvAqSV0HyKqSSV+Gr
5FUEKHkVJK+io5JX8UXJq3ih7iOLGeo+slin/HNhUv65KD/Fp1D0mjD9675y
56SVlcLFhy+mZr5nwsXVuKDmq/3nC7e10eEL1sWJ2/+17t5KuIjgwz8Hh423
3bv72Trvhr5eUbLps9f2w9a5aTlEHPgcyX+okn+9XvZU8eIU797+8T3H7C/b
3XWcd8b6F71WPbgni7Sv4j55T4L2M4i/9bsvn2n9CGyv+FmfW4X/dYL4meRB
p8P/GkbywPovnh1U/Yf/c1HpH70/CHmdp/SPjrfWUvpHjFb6R8f7Nij9o/FG
pX/0uyTYr21C/hP6E6zoLTI/t9Jbt1tp2TPXr64WOWGAqeS/LXxk/nEtHnfN
Eyfvtgn8cPJ0shx0cLm8NMEiJ76qUuZUoTfS8Y/yd591scheFe93ezzJTZ48
0TL7mPUWuX7ntK+7O36QNVR9oiPV9yfV311hMeDVuA2v6seJe2tbj14345W8
VPVXLfOIOJE1ZlD2sXueyI5Fa7dr3NsidjXdcfiOo5v8fHb87O1XLaLVsim+
d+/dl9ksa+6YR8WJKy+dsqRr/0QOovpOqvpEJyo/WZUXF6n+19HW+gXKT1Ll
hS/VX0jVLwar+uQ6qu+CKi+Lqv6J9qp+eYDq/6LKyzdLVfkcqn7ZlOrP8nTe
vLRJFllwe1JipkR/OXSv3e3Q1nGy1PSxA16/95Md243en7d3rDyw0/2vShe/
YDzyBNHnH2rPjehxhvozjehF45ETiB7oT16i1/rYkLQnnRP1/mn3lidWr8oQ
L39W8w8tNMFddvdZ/O+jJvGy4ZLcM0vFJeulafPGBU1OkNW3jtkwtOkrkbHX
2KsOWxOko+udJbMnPxUlykQ8TLMxTs5YOztq1Zi74nav4Ij/VsfL23tHZm8/
1UXcjG6682iyPcH+jdNx8enKDtt7H/Qehu1+qGpf9Kb2qX5xleo3q/rFRKrf
S/VP/EP9y6z6J849Vv2j9vR+E/VH4+UF6nT60t9Nx9Xxfs7jISXSFjpnwzPe
/drU5p3t+zWHdua5sGpupMYt9nZJSp8pViR0zRm2U/qJunfdGu+bFSHf5bfW
r+PSiIu7qvo1nqbq1/Pyn6pf46aqftmN5qeboo8E/W8p+kjQ326flT6S6COJ
PjI9zV8HNX+yK9F7EtXnSfQcQfkzED0zUn7MRzS1d4vm44GaD7lQvVei42c5
1XpS69ONiv803VoWdspTrGi8ePvIwfl5fx+RcXGrITnmxImNQe8sRU54ihwT
0iU0PJIg3rb7dta/whexSc2X9osY/TR+SPMH+jWj+WH0FU/Jvi2i9zZWk33r
QfGnOTQe+G/ZaDyIL66l8aDe5jQeHzUemZ3676f6L9PR+A6p8enzJK/Jf/VU
/quOHxC9tD/VhfTDdqUfRDbSJ9mUPhFjSJ84Kn0iInMsnDjvXpy8/G7i7UtR
X8TeG1OT/lqXIKsNfTy+2/Yv4nqfeTdmdkqQp1qXNi976Ku/G3Kqy6YsJ93c
9PsjNdpZ3x8RhSke56DicTr/VZVfv8/fsavCzL6LosreaL802779VT9mfq/v
zWL+/izqVG+VKVZUV+2b+ndS759QPNCUgeKB5/MdW/8uOR364zit3w7Qey6L
aH34ht5vQbynmXofRv5zsZvvzAa278xhnr+o92T0umBuiXnZLc1t38mieIT2
Y/0oP+ztyXWNRiSMt92Db9wwc8PNV2Kl55HLoYF/vtBxYsRzW1F/2qn+6HTE
VQbfWh8SWdt2b9f9YLUX1U/azpcspv69ofVverX+laEqfmGKVfFO6UTr8Sr0
/ky3QYUqxVdP0PEuvQ+g9ndlrjLOgc6N7Mz6vHSxrc3rJkbK9G/SlAgeY/t+
doi6fy4/vbauT8UvWp/mI393Ma03TeTvfqT1ZrFV1vWrwPq1/ULrelXUofXq
c/KnsZ49Fd6iR3BpP+Ede6BSdE6L3NW5wbPLLYLEXceu7pd7xcn2GXOtWG4K
1/5hA3qPIz29D7NjfeGpZ1cFi0x1voe2KBkl7SO737q64ocQ35bm/adEsj9J
/nAhWr9OIH/4A61fEW8aRutVP7Ve1e/DSopvRNJ7P/A/G6v9AJlT0dMEetL7
TCb+Xe5zWcbMOCPCZJakol0WrorV62Sslwq0PewcmidYllPzITLTfMwdeujV
1BFJosCK4CG7zoZKF3p/KJDiLQEUz8qm4lk6fjZcjUfYOajxIB5bQK2f9fkZ
+L/TKb6H8TWk/Y48ND7Ui/Hx74gfVeMTxK+S+FWfQ/iX4nnAvSjet4beY3pB
8R7I57Inld8/ehQjijR0GuQ05LvWJ0x+tV0qSfHIjyoeqf1xjPONki+Nhyj5
0376SmqvgGpP++lIX0DtXTG+L2X6TO9vLKf3OW59ruLRKdkvLxpw0PRor7/M
qPS5KE3+4Vilz4UD+YftlP4XJ8k/PLlUTCz30XYuHt9zmJ3TXVa/8002aNLl
8+MZjjo9k7I/cirZ19zKPsmnZF/PUH0YB+pboOoTjag+pMfTexNP6b2HphO8
j9+fa2cKbLK063fHYFGb4vWbVLxe24NSvQ82PXfFFocecyn+fs5WjvoeVmlK
Bx5L6adovYTxwI7MoXjNalr/IP7C6tf3wEqq+s2L9jv2rb3goHw47+KkNW52
5ilhpkORxT7IPY06jrq1LEreqb9mTpOrHvKGpeqS+gej5LeT287nT9Zjd4ek
Xfv8ZJRc33plPf9K0XKsXUzu3TvC5PaRpxpX6RSk/T197mBE4TQletjOHZza
mbCnwYdI+XbM23mvRvrr9S7iNl2iD+e5X9z2Pn4IrY/t1fpYv4sL+7L5yGCf
3c1ipB35s/pettF/1Rj+J/NfZdPQemOXVPog9j2vcXDSmWjZUM23vjd2SvFH
iu+adSd+c/m2KF/0gjj9/cbr5P9jvT2e/H/gyt0/Zhx9207vTwQ/LexY28X2
fSpK1/dlfqh0PW68z9JGvc8iUB7pVah+4Ocqv1hP+f8ke+ao9KfYSPO/W82/
OETzf13Nv+7XFkVv3Q4w8Y8g/hFzVHlxk8qT/RRkP/W+7bwz3zz7OvwSLYqG
7bwRHa7X7z3TVixcubHtO7FXyP55Kvsnvoec2tZ15xfx5fWaa2kdo8WmnvWf
hJX3E2L6yconasWIw2Qf7yj7KO6p+dHfxxlH6yPMB82XxvPJnuRS9kRUPLc7
MGl5uLYP8MM9V8yIutr+pxC10gUsOhml+/vqRudH/66z7dNAz7bZuWhL94u/
ND3Bv51Iv/1H/i3ii84na7e//+OjPHqgc0L3bfES3x2Efu6h5EVsUfKn+R9x
kbMkb8DFSB71uzwkb15KHrV8Qc/d9DOV2fYmSvb9r8etZvK79i+2DpjmfmdB
MPt+4E9RdFLp9ndWhWu8qPvPp7GuEbr97nevZyp80IZ7R5X5f2Vdd1zP3/ev
iMiWkb3JzFbovBGyZ/YeEWVkk0/2SCIlMkNkSyj7vI0oW1KUaJcK1bt6t/tV
59z7/vL7q8ft/Xrd9br33HOe53nOvdvgrAq33syJ61UuU557Yp63HbBttN7n
tyybTKwfsWVrGqo5r18x/cUr3gE3/9inQ9fqF41epqVjS8brrzH+58j4vgHj
hbsY36/BeOFzxvOjGB8U8mo89VeWub+SxzGF8HzZ77msT+iSPiH7Hd2j6kaF
ewxGrnl0OV9bjTeePn1xsXICdq//3kx/VTaeTbloNaVGPDo0+lDH6kQ2dve5
+25pTjbezDicYF0nEXk/y/jeh/x+V3ofHPn97fQ+bLm3dUfVlzHo6nr9ZP+P
mbDsVNj3MWHR4HBq+cuAP1l4tZ5Vp5HbImGb5cx5FpOy0Ve1cortl0i4kqyu
sndcNnpR/dCT+7eX6ocd3D8rqh/cqX6cyfv/NJ8fp//e/xpe8x58ObFJJnxb
9C65QUgynjwzsOOmwZmQEr9nxv3NuXC4+vnbVg+SsdOhQxtSr+VCi0Nal4f0
TkazdNu0gOG5Et/vz/JZrNParK+L/baD9i9W4/37mP1Xdch/BUXsr+rF/sEf
7M/K+Uj+Q1f2Z4h1LORCbJcKW1e8LIRTg/Y6nBr3FO/cr2P4Ylk+RK5fdyO2
ZjBuWKHTU/9SIYScDFYFZbzFg0fqTzp2XyPnXau1Ozv2h0bO2zbosiUpUEsh
5GGsgSK7/p98rH5WdXjm5hzJTxJ2no9rlS/JPTX3KKWz/dGRcGhsxXh0CuHR
+JrxaOMHb38XzciRclfoD6v6Bz+f+TMT5nwIGOv7fiPcsn+8f9eefKzvRXh1
MuHV2G2JocF6/YPQdEDF0ZXUmrxOrl1trm/dm48tud0O3I9kxsPfUPvS3mvd
T9fz7N0MVAXXqlzUPV3aD4I/Vf3C/BEVqmfJ8tpTFTrVXq/CXUE+NfLXpsGS
LU1Sb8apMD+pta1/iww4XHV5ccTSTDzecP4k1bw06Km4mlTvagZa9DSN3HVC
V+pZoizzIWoVOew+l4iBfssaqo6rUZyPHzjfWW2yP6T8Fvp/e7I/QNyH1u+A
6tLYtBDceG5kUJ/wPIlrkRwuOe/rZb2d/ypUyjtr46vlO3XPxUGZIb1/RSZD
+a5T1l37loMNqD/wlvsTat6wo/OZRLzao9vsqVmZkDPRqvHolCR8s2ilacr1
TLDenFHd82k0DH9SIedGEzWeWTXHb9qbKHD21q91fIAan4w36TtjcSToGla9
OGmrGoce/3286OZ3ef+rwKVM3aY962ycjW1X7c1Onfpd3hcbTPIKvrO8Es9P
sggxceqRhctfevp72EXJ+4zFvqzZ1sT9rmEWvPI75TD/dIK8d1bgOnn9V1ZO
2p4Fe77kvhjQIxeWDqofVmd/Cj61VLyON9PYLV1I/sE9ln+6e6f4u1TOk3JY
3L/6M+BQJXWDZOx/e/yypNRirPfw3J0Jy2NgxebtFb9fLEbVII/uunGxcL/X
nHGtWhbjzYiPW7VGJgCvB6kXD+OyWB8zPu00tLF9hrDy1KwFEYXQIMX6a3zM
K0yYqN7fM7AQUr+oBs/4ruGtCTkf/vPp1fTvGt7aphNHRkUlp+Fw18reX0Zl
ynPD7OKvNb+XZ8Dt7V6xQW3S0KfFlDHPvmWCyjrX+IpOqrzfMOpoW/VcdZyU
F4dIfmjiz2ecmHvXNwsLJnx3efPnjzyfhXyY/+GN8b7YTGxqPtHt2qBsGLk/
4W72Z00eULYvlP/YH8rtnmX2AQj7YODcZYt+lNQ75dShJZF+2spLW1RfPIJU
+DZoZ2HM9Bx8RvHG0i8t1sMsxm/EfX2n2L6fxvxBMX8C9+nBeIH4/wKKj8ZJ
l2MWPe2cIXEaQ+bJi79V9pG882V5M2pkMw9fQxU+aBtWwflDGq6refXEQ7sM
jE+dV/moURq67CxsGhmhwuI5t/ffPZSO90i/xG+Mrwj55laxf+2gp7l4rnOf
tOXm+bAr/vzrNr7ZOJriZaEbx8ueonhdTV5ntovfPndzHRauwjbB6c+xKB9H
NNzxU88lDcc5zfZ//1++5AVwvpL/l48782/+qHy+EeczjmB+RguqH8Zw/WK+
PRhvmM58VcmDZfk6i/WX74y/yvtHF57eP7yljrJv2u5r9w5kw2SOD+5A44Ur
NB/4H80HHMTghOcl835Vb6F+tYE5oGc1+OiXCdnY+kbYw+YJeWBH8R8S9xV6
YySdd5DM60f8LtYP432yPIfxiGmE38nzLJT6qwDu7z/xHzD9XSdVQKCOPGcf
fi66v7xvPn5t4vLj7ttimM54qMB1LHi9T6b1rhD97dDb0zk1W1sxlfFK8bwf
1QcRXJ+8X53iYaSf5zI0Cbu7UINLpPYJfpe+ppzUY35xObis/74YUzR1VZOS
dZJG56Xkh4i/ISxv9p9xbbd/prZCzBPHOyl6cfxzhZH215od11Yc1r/YclbJ
Ot+zxad3t5v58v6Yqk+NKy6M0dwn43Rm45DGt/OxWJX5dFPAFfG7vP+G35fl
WW5eDi1+5sH+PNsrj4rP4WjKp4NXOd+PBfkHMIj9HZxvCzjfFpiyv7Qb+0df
U/wrcn4PeM77M5ztP2G/+zD/XcjDZI/ypjBXk2eyoaGqSMtZS9nr7/gl5RXW
z1xIP1Ny3D6Kvy2OrSxs1kqNNh3dh9yySMPHLe7HGI/JQb073zs8W5WODhg/
dqY6C38dO/G4z3UVwu6fj0ICMvHaPM8OPvYZ6En8TvmdhF3WeMGVAP+9aVjJ
50jvA2bZmv1MfE8MZb7nKsKPcAfzPT0Jv8UKjN/qE36L/Ri/zeD4OGPmq8u4
9bUmqSktM/Eqx4+I/gg/4OM6z3NfVcuWZdO6x4KXllNjgted1gmjQuHTfr+G
p76p8RDFy8JVjpc1m73g6dqVH+FpFZ/oF6lZ2IPwL6UZlOFfeN4k/t6NbgU4
fNWrVbMXJmGTSKfQPxn5Egfa+GbclLeQK/v5ZX6/KJ+NWkqhP/lRPiLlYMpH
hMFaaxYv6VAgcS3m/yp0xpfxfxErVpl4rlux1NMfU1mOi/OFynNR2LnP7V4f
HlohDvh56R/l+EQIpPhEaBTllT+2XDF8n9bS4cilj7IdpPmTZZ4/KOb44ss0
X2BB84VKmi/Zjgk/L8qivrOM11ek7w1VGa/vT98bUnzq25nqFkuc1oHydcIX
ytcJWhEJm7tkFMJF/6oPqqmTJV6jN69627UxheAVXrYfII7j+W7TfoBDbK/c
Vx38VNEgGPu81zNzK81fdLnasfQSe8djkZX9hxJ7YAt9P4n7nqB4PXm+CLwD
TFR7srzSoSXtJ7Cl/QSPaD9BRdpPEk9pQ/sDatH+kOfUXeoP9Kb+wCHqDxyn
/sA74jPBDuYzmRGfCW4zn0noN1O6VLjnuDwXOs4FW4sDwaAYmbt2/HkN73rn
9jGxflM1dpdLxZddJzv9wMrdnIcMrZ8r4704fwhy/hCplxym56EaPy/05ieE
d6MB491/Mqc6L2yVhzrdhwwwiEjCliH+po5bc3BJuvaxmYfj8Zllfs+RfXPQ
7Gnc8M8LElDJeDm/D/w+8PvQgt4Hfh/i6X2IeFL2Pgwc7LonfoiWMjmqYrNY
r0jcM7u/TnAnLXl/8gx/C/uJbQql/dLBtvyz34+KZLlnbM/h9XUKUf3ZetTl
Y1/QfciHZq+jC7D7kzXJ17uEo0fQpDo9TYvQbuiWuR4Zkfh12/4mAZ3zMbeL
QxWT8j9wbEKhRdrSPPz0SOEXnxOB0ZQfSPLDG7z3KhgUUSjvP2p4p4lLgneB
LE8K9Z24PqwQTwTr6ajG35ZxpH8onwY8Y/zVnfA9aETvy/vVuH5Z9qR8tTCC
8tWK+sHgE9Uvzm8ryncg8UNR/z/xplJvOt2riuGY29mae4pZ/l4g+Svt3Wss
z3V5fws56E94G2wjvE3yxTv8fT7AKD4fDrB/war+pBH2e2NwsmX/4RXDsnDQ
/qVjBlnGYUB1izfJD7NRzKc4r+vzfItyLYMlsz4dy0fDvlYbFVFKbOOUdyjq
aj4O2FBXX9nXDwOruQVUDc3Dnhdi/9x59gAdZ0ytPeSl5j7WWuoK70I3ZIPW
+U3rFsxNgrj5xi0anMwGddn6TwRuT+oLjfn7iPJEnv/VNP/4itqDo+epvdrU
P/hoSv1rTf0DH+6fe705Nkv2F0g7aeyFe6dtphaD5f3R2UOc48X6V6TQ+oe9
tP7l/emzaP1L3kt7Wv+y3IPWP2TR+ocTtP4hXFm2/uEMrX8woPUP/+Q7g9H8
PZ7R9wA7/l6W9L0gmfHBcLK3oRc9Dy/5+82g52Eaf98V32vl1N2ryUMr7v9a
/nT55fgf2diP/VHV+TxO5PNC6IcTJ62/+zK1GFLWTWl+eHkMjuL5mkPzhQN4
vnSjSV6c4PEN5f3djudHyAeWH7KcR3wgNCE+EPQ/HubUfkMSzu3mdm/JMxW4
fns/5v2HRBz4O9F7UZIKzpK+ABNZX2jK8mw1y8NPLM+qsTw0YX3DkMYn5dsH
/r58Pkkc+znLX32Wnx1ZvonvK+SfKFtzPp9Uzm8zWcvUusfuIuyrneT1sVE4
9GZ5+IPXw3GWhzokD+E4y8MRvB6WGV+apl6lK+NDOb5aeZviq/FF3Tl6Xod1
lYnDih/+GP8JhyZUTPh4S1fivUO4LM7x2xTfrWxC8d3wqOqmhjtP6irT/JZo
2f33Efh56f8R7TYgfVhhRfHXKOKvD+p5xa11DMWgnl+LFp3Q+Ccn83kp9Jvu
sStrV3fVlI/e2NKgQok8Evs4PSq454QJmnLtcmtaHryfC096BvSsUdsfKz/p
ff/UyBzo4t6j4tBWSnzjMu/mcfMceLfMEg3fvsThx71Tzx/NhdwrfeIUdufg
8A3XwUGhWgpRn1f9J5M3/CoEp+vtmq+7qrnHQNhnb82f9zLzVcvyOq0C/VlB
mdIe//b3eS75TJUSB881LZ8nywIfjWH9ULz/nc/3qvy8kB983svyRdZ/FbSe
5XmlR/cJQAvWhwUuKPw9qVM6tBwZkgD7yJ6GG2xPlyN7GtqxPX2B42XlPZ1s
14bQ+GV5C40f2tP9Tjic73eamrLVM9L3N97s6jxoWYNyyjG/37a54hUPd+qu
dFj0oJwynfXDWLaX1v+tHyprUf5M2MX5M/meF/nXL8PRof5MFVrUC6nZ/0KW
1PunsL9HlMexP4jlk8SNxpJ8Qp31JJ9Gk3zC8SyfbDcPnFr+RAE29C994QHW
Bb/TidcLMCc9q+WmU/bMk8uDRhHOI87Z+2Mz4ltp8rLxPu/OfKt/7HGFIc/X
GJovxQKeLx+aL8UImi/0o/lS/GO/K/r/PZ+Kmny/lqjPkuoDUZ/YnzlxaVNd
phZK/uOgI7YONX/m4Wjm/5sQ/x8XMf9fi/j/aHCf+PzbSP/FE8zff038fWR9
GFkf1txvw/69OaxvCPwwmP0znuSfwbtnnnSx/Z2MER+ijvRal4VhQzaGfOn3
E5e27L/E5lQmupA/UO47wUPYzP4/Ua7H/kGx3lNovWOtJP9j+vdz0fVKm3MZ
7aOx/4KzJ889zMGlgeZ9h26IhhqDKnkWVsrFlad6jTfqGQX1+Hkneh4667iH
fTqhRnf3sTkms5LgV7zB5Jt52Wgwa7Q60zARTl3ZPnCGZQ6u/dnh3fD3P+W5
GU3xJfCD4kvkfpzF+RNE+RvFl0i/qbAfl1N8CXys5fz5cmQyNF13tvmg4Znw
eW3T6veW/4TmRkvNhruqQPDzWxd+dbm+NRG2DW15PqLkvBR64x3aLzCU9gsc
jLyuu2qCK8S5vzUxKl8EI08TX1DYGf/wBeU594j1xy3srxX6oxjHdPZf/uOP
BX/25wq5IfxeO+j7wT/+XaiTfWDJ7CGf4NKQXsVR83Nh/5vLMx/MCAXH+yt+
mJnnQqFXZg/9CcHQIOryxQ06ORDf8MSMpjF5ct89//3uxOP4fFluRHx7sCW+
Pbwivj3YEd8edIlvD7OJbw+3iW8PxsS3B7clzQZ4a+VJ+2zwi4jxP4PzcFzZ
OKMRRzlarnqQK8u83uAcr7cY7p+Y1yfcP1H24fbmMr8/gOsT93RacHui/Ize
l/oEj1+Wb3K8wGzuf1xBZId2KZr7oOvsHjKh2518WZb33U0vu+8OBN52MLcM
b4M3rC/neZXpy2BA70v7qTrje6LMz6M96dfgUs1XMXp0Pg61yj4f3zkFP5M/
Fj+yP9aY/LFYn/2xfP+LxKvFfnhJ5yVmUn8xaibdzzeT+ovLqL/SP9Y6hOSz
fJ7u8wP5fA6NT3HUaKjXCjWYnuo82O9hPLRubtIsb1QhhlZVBF5K/YSPHW9M
NIRCzG3/ePzCghBc1GTHq+f98yRfQtwfOFS77P5AEPhmecI3Qdg/4WRfwNk7
tTPj9heg+Z6J1cq1eQpt2R4KXF9mb4A8b36WnTfCnsQ3+mRPJlJ7oFfur/ag
Yga1V4feh1Z0XoEB2zf7uX22v6A/2TeiP7CF+7OCzj84XrbvH0CHTW9VG7rG
g/VAwwqDFmXh7yv9ut7PiQeXjYmXtw7OwgGkf8Ns0r9xM+nfMJT0b7lvbo+s
8/pBz2xZrux97EeNOWrcTfwB3MT8gVDiD+AW5g+8If4AXmb+AM831Nal+xrF
+A0YT5bjz6Xz+gzb4z/4/pjpFJ8BRyg+A4zoe8N2+t6A9L0hn743FCYeD965
Lx+6Zdwu2pgdDot0n4/Nf5EPsd49nBwUX2C+k43jAXUxTO7fwntQnxip5+nT
+GTZn8YP/n+PD37w+C7Q+GAzy2/h12Q8RSHqmcvtzaf2cCqPR8nxJjncX2vq
Ly7g/uZRf7Edj9eb1/cjHm+dDrS+RbxVzal0fgp99Qfvv/68XwbSfsEpHO/y
nOeT28dFPF/W1D6+5vlqy/vrCs+3kvfXd55vtp+VQt9dROPFsTy/jOcqhLzb
lZY9HOdpKZLTD1VbnP5V+mdUdJ8V4O1HS79M1VEIHFS7d9eTc/d+xOUP2jZ5
0T8f3HzXjJ5g/AYX+FcZNd8yH5adDw2fpfMRa3bT9h+0Nhfs9uZd2mj7Dl07
Zj913JEr/XAN6b5T5aZa3ptz16klb28O398zmO9fWsz6nC/rv3fZPxRJ/hx5
7rbR9Vkw+pyWUunu61Z3XCw6zTi2pWCAllLorW4118wblF2MzD9DJfOzBc7V
Ncs9JyBXg7uwPYMt196qMGb1Hdy9pdDA+acm750f5QPAAUPX34GFOdJv5jTv
4aaiz5myHMb+OgX5v+Q4q9lXO/RETxNXu6ZDQh9Vsab8Y9zapg3aaPiXtefs
6Nv/bC6OfNF6xYhXcej6OKi1diNNnK8V8xeE/0Xoq6J8g/wxyPGlwPGl2Jzx
2Dusf9qTfgpCP5V5Frg/orye+zuI+gPu3J9JGaabNu9PA4M5dbulLFbjIof+
nqMVGdD6V/3JDxvmSv7Iucnd0+ZVVmM5n1fe1++lQZfcGW/UI0rkYcsjdYwq
p0HHu02n+JbYkRwPIOfzn3xv2I/8O+DL/p1N5P+BdPb/uDH+LdbdP/g3OhFf
FlYwX5b9QxIPvMd4uD77l5oxXm7H/qetzGeqzfx2oT8njB7YbNTsP7iA81mI
87jX9YuLJ5SsM5fzsVl/dkRhTeY7f+F4nC3Et5P8etGPrsyvE2U75t9VZT6M
eF7wYToxH1/M11bL0bqHN6Th5QsO7aY550i+w2D2/4VwfNA0a+/mIfMK5DkT
Zhw3ZGG7AqmfCXt5Sd7DOSuGfsOhqmaV9Ubly/Nc6A/zRxy331IQhYcZD5B5
Bf/GA6S+Xxe+/eeYlQXDaD9JnoY77SdZHng6vF94hwLYYXZnw+3JSTK+tSrJ
WxD7S5/2F/wTPwLzmK8g5uU+28PmrN8v/Gw3+eSKDFwTnbfdsFCDH3/Yp9xn
uitLluO0YOzlHZnA/Gtg/rXU06PZf96A+WKiPcFfr/tP/1qT/FK8Y/m1j+SX
9Bu7kvySfiUPLot62/H7zAcB5oMoTtP91VKui/51Yn/5LpK/sl98vyfc4fs7
DVgfP8L2nJBP0SQP4B/5BTdYvj5ifu+WYfVb3yp8gIO6NboUcS0XvupFGipS
7+PODye1n1/PhTTFqqFB7c6io2NVi+/+ueDYfPCXGZ9TYJO2TmSsST5835mU
E7D9N7zKjQ7zuFGiR9+akfTLLBuOOOnM13r5Gw88KjRq6JAFT0+bJ0wb+gvP
etSsujEmExIn21ytXy1Vrrsw4gNjL+YDC7v3JfOBxf4R8sGC+MDy/E7vNHHd
S9ffeHaeQZMO4zR+AfF8VT//1fc6JcvyTyWajHqcquEbEZ8axzJ/WrTfn/nV
otyR7oeXvDyxPp501DFZ7ZAmywHEX4En7P8ux/66tuwft2Z/nivHAywi+QaD
2R9+heQl7GB/eTLJy3/vB1COLIq7suZjyT6u5HEvZaaWMmPjd9Nt2d9xW/3f
Sw1Xail3be9zv2l4FCY6XteeWlyAq8l/h/3Jf4cfquuE7k7ORcOzbZo2qK7C
D3R/u+TRiPihtNVxOaOOanhEfm5elzd8UGHYFLMql3bkSrknfl/L8uwSyTPp
r+/ebJhR82NqPJNf7F4wNgs/2hitvPopU+IfAkd53sXBMTVShe2Ifyl/F/aS
DfEv8RCtL7zL68uL1hdG8PoqoPWITrwexfsRvF4CaX1JeS7aN+H1Jf6fQPwI
DKD1j8to/eMPWv/4mtY/jiB+ImoxP/E/wh/kuvgHP8MrtX90/1IzAnb8VJw+
VjUXo/q0jH20PgCKGwcfedeopN/ET5F6UkXioyj3Mh9F5WtrcDWoEOMXRrSb
4pqCv8PL/NeYTP5r7NfgesG2loUSRzpH+0PiWGK8n3k/iHL+HdovYt5teH/0
o/0g6xtN+0WWWV9Vsr6KExn/H0f4PxqtOnnqvlWh5CNMoN/Bln8fF7GhUtA1
LaXQZ0cbZfSb5q6lHNhy+Pvj7YJh67dZNwcNKcYTxxZYhZwOgPZcn/BT/0e/
QyD/zvVJ/fjFoFe56Xe1FA/fBcbfvPUcxlD9isZcvyX3ZyL7K8YxH86f+HBg
z3y4GOLDgTvz4QqIDyf1mN7BOnXaLUiHfOafCb3KkfUHwbv5R1+Q5W6kT8Ak
yh+Jxpw/Uuc2refdtJ7hn+8j4j8k/9qcv5cojzEpW19YSOsLDjD/SZxbvL4U
u2l9wU6SH8DyQ/KHfNcYFGwcp4mbWcZ8bKF/M98b+ftIHgGvV0ig9QqDaH1K
nGwkzTfc5/leT/MNCTzfzD8E5h+CmvmkQh4LPulX4nfJ896e+KQwkfmk4nuI
8+MXyQMY+zc+DzPPP9F67ZKN7dqYLl8Znox5HDch/r6k+AlszPETYvx9mQ/0
D98FF/3NZ8EG/D2KeL8L++bW2vBLjzqrZfn0om3Xrppk49vxO4+ttXiEEZcn
u6/voHnek36Hf96HqXVehN9s54k1quwvaNYnG2by++H0vsgvAZxfAuw4fjB+
HcWDC39+q7/9LxIH1Uqg+IMZhHdBV44/aEB4l4Y3wP0X5ds8vpsG+pGWDT2h
YY/Tjfx6Z+Ms6h9w/+Tzd3g8/9QHX8b99Ty0G5ux0BY196qtKFtX2spVgwI6
rr8agwvY3p7K+ELs/L6/99vnY/4Srza1L0Xg6sF2ncfbFMt276eaamNUIZY/
q/c0KH0H+FQeMfFueCEuNa5gNEnfB+LGq+YMnF6Ms7Nrby9yewir6H3Zz9DL
X05MX1IM789548PIMxBLz0NKFj3/gOqHuxeo/ptUP5Tsn7L6q5G/AipwviLB
nwjuWG/RwTF5EFjw1PP9Kk3e0YH36ncca5IE9rU3ps9yVMPLge03+Mcng9kX
naOHonJAyfFOQu8S37EpxTfBP/FPUNmG4pvEPhG4xV3Ge0S5KuNBUzleZhvh
XbCb42V2MB70iuNlLjEeJOTge3831eqReXiJ9cvVfL4Gs375hs/Xu+wvEfta
nDtbGG8/eDmvUvfIX7jg1IFLMVtU8IbzW5tQfmgIpvnAfjwfNWl8Uo/cF/Y1
wXpDKq6eanG5Rf0s6BG0N2J1VCoqgi/a2hdmQgz7b6zJfwPP2L/zlfw7EPjw
zdG201PxlUlj0+VxIt90Kra26WF2o6ZGj01kvuU11ifsWJ/+yfpEIOvTYnxL
+kWl7HVUwfT+weWW68eWrOPnfVrP1eQBe0f2jyYvGNk/uIrjmdw43mi5snX1
dkE56P67zedHtkk4ONHrTEKVHBzYr3WeaVYCjli4u4X1dTVWLOtnEtrxfhBy
5ROtZ9xK6xl5PWMCrX+U+4XWM97g/ZJD+wVXUvvgQe3DEGofzKl9GEPtS/6L
2E+ifbFfvC7/VT9s4fqjeX/t4v4IOfCB98sb2i/SDl/E8zmP5hMcWL/4QPoD
jmm4+vHV04UYfWfy3AG3X2Fjln8C13Em/B/GM/6/mfmEcXz/txmfb+I7plcZ
mV7slgc7zaJXt1qVKPtRYe19tcGsJKziqtxXblEeiPlvxfkEPxFfHQayPifO
yzucj074saR+zPmghN5Zm/NBHeT8c2KfL+X8dKLsyv6MfjQeiGV/xnmW793Y
n1GF5XvBp4XQT10E5x/Z3Z51N1j66/oEVV4w5UYIPJhQZ7VRZBEYlK3LEOD5
hCiaT0g6plq3/lcw5q9vvijtRxZon+1zIcE8FJ/c9814fScb/Pi+C2fmkzYg
PinqTSc+6Vj+Phe5PhEP0Tfyx0AX3QCYNv5cpMKnUPLbXNkeSmB9RviLb7A+
04ftKXeypxRVN/1lTyke79m5rfrgYLwy8U2e3beS8zRt0K/wrW/we4+6JhmF
2bA68UjG4bbPsfKQ+Ji+9dTw8+OXhxmNXuHEytdNd+mqIaWTesCIfsF4abPB
xF7lcqCa6l7FVwaHcaNl3ndlFzVY6fdrdnzmZfRqWtSmdic1ONdr/PlqpcNo
uXrirTYTc+CM/s4Qy7ZKDElzdfZuqoaC2Eu7bWv4o9eGrkNi2qrlPoki/jsc
9dU/5wpPscFCy9ykZfmwdHu3yQl9b+GTkQ/VMfb50F6vllmylQvuanmj7rqC
Qqg59tujNRHXsNe+VL1DqYUwgv3tvsx3EHpWI8aHzRjPmMbxLRsZrxA4zy3m
90cxHizwECPGg4W90YfxvqYULyztSclH4XigkaS/SXtSxC8MZvx2CscriPcE
bmLIeK7Ao8qNIfxP4GVr6P5JER8hzxfRjypne7vf36aSZe1qOYu6eGTBiVUz
YdDNTPlXnKunZhs97ZCYBb8Cberm11ZLf3Ik2btSLxX/f0P2LhT2tnp1a5Va
c08En0tF/kMsajxMl3iSA9nX4MN4odBnj+zRf2MelwtRDYzrhOmpBL4l553x
JDkvqbw+6tP6wFq8Pp7R+pDxWbVp/LKsR+MX/CoZp7mc+FqKv/PfZYDZ3/aQ
7O8+jl8WeoCovw/bP6LswPaR52q/Sc0C02FSjEtV53Np0h4R/KyVxMcCwcdq
SfsZjvB+ZnwExH4W+GYQx6ObEf4k5et7xgdE/8R67c3x6ELeRrL9MENVe9as
D2o4fPLwkVXVUqD3hcUxEXVK9kM58Fzm8RP0UzZt7N9Go3fR/GSDZXBAle/v
kyC0bDxqmBdoHDr/apLktzN/TPLyjxB/DD+Mv3nuYIfn8F6307ZR/XIwj+QL
nCf5guVIHkEVkkf4m+QRTCB5hHzegf5xOu/qkT0CbI8Ax18Bx19JPLc87R84
NSW+/dmnmVClx4mjmzdkQMUe73pVKJFDscl9az1yywDjzLDiFw8KsMr8HRbX
a39Di0+JUfc9CrDId469gUckxr4eHJl1Kx+nlM3HV2y46cXQvfvyseB85fa2
2eFYWe/6f9/P5KN2WOtQ46yvuC1l0si9H/LxAzrstPAIwzucP0Psu3/yZcA/
+TRg2fTINcPuJOKA4N6jglpqcEKrA58hrkkmDLwx0To0KYXv1VGJ74nu9D2R
vycOp++JIi50FH0vFHzraszHnWQ4a/+5J4WS7yu+r87ZGN+Vz+Ohky0YjFFn
g5fNuZXGtRNhDOkjYMX63SzC7WHv+BaVy0/Lwnw6b/EMnbdYn89DYzoPUdy/
4RVYdv7iXTp/sQedv7imrL54PNv6Tv3gsVkQtOl2175N4vHQlTtj9i3JAhvW
zzxZPxzI+tkI1g+FHFk+4mm9A2MT0bB1t+LDKTlSX6m29dzN5jtz5LzTesmB
8af/tGpQnIRPLun46LXMA78TR3ZM+5KEb069/zpzXZHUP87FTTXWzyxEO6+2
kyarkuFUckHy0m5FeMzHZ9Cthsmgx/jXf4xPtOf4wKG8PoU8X1v8q32cSTpM
5XhBIW+E/+cn+X+A45Xl/hZ4Zz2OV7bfcrl6i6wCfOb/NC9vcjxE7Qo0+Nms
UPrZ6BwqRPCyTX65NQ6WHzR+M6KzjvTfXjQ52ifIXEfxbNOH2cVLg+FF0ZXd
l7vqKKZCxtyTTUMhyv9DramGOopR4y7/mPbnK3z6vs/8dWsdxYHjAa36ZIfJ
+Irm19oMTYrWUjTnfBriHIqt/Oawq142vKhztEPbmqmw7eHoxV2eZYPuhpMf
Zu36BW03XK/wfKSGVy/kTWCb2PmJa1Lk+bP05uvAGX6pUD3zwn/hL4UfJRU2
WZb/EpihpXR9llrX5UKyPNerrnc3rfg0CV4GjYMNDbSV4vuJdc54kPLrUfBu
eeb3P/kxYuFHTKrVTN8sVMS1Phwxxxl7tY1udVJViHGsf/Qh/QPr7lhYTZFX
ove+VXfb65SNR/icPU1/5Tld9duK/eqATLTv6xDZRS/z/+W7EfG//+BVSrEu
/tzdl/H0ocafWkTx1hhAfD44w3w+gZNlxt7bj/Uz8erXuZ0WT0hku06DY3O8
o3Iex2+KdSl+D+d8BTIPPvu//7nPV3n2TjuPWbYZOLVl+bFvLNLR9R1Y7O6q
wuH9GhZnVsnAA2zPiHU7kPiO0Jf5jn0ZPyjHfEcnxgvE8+Npf0h/Y+OXvZb2
NtRV7GwUcTVyQRyuP5j0fHtvXYWwo2wIT1EcJzxF6iNK8gdANPkD5Lkt7Js8
8h+AuF/dnuNLp5G+ppQ8XPZH1CF/hNzPCo4HFf0Y+Kiz1Yv0cgoxX+Zcrhg2
Xsti6E182HC/V8jmfDxlXbVBlW8Z0p9B530GerrMuXOi1L/B+U/MCL+TeMaJ
2dujf53IgwXkj5TjfMn3NfJ9vmDE93t84Ps0rzC+Lvab0BcKCU+X5XDC26Er
38eJfD/IcOaX1yN+ufI288sDSZ9RinWdTfogdqT7uuX4hJ0ZlGm2b+bWDIz9
U2afwA+yT8T9gVChOt0faMjxeZX5/PjM8YICrw3k+EW+7xMacvziM47HEzj+
fBWG5nlrcH3mv4v6JP4r5qUjxffAO47vEeul23tjr8p+TyXuKPSdW3y/g6hn
AbUHu74M3bU/PBeen4xKCDr8BfYPO9kgLjAXXgx/XHDb5ivE2PpeSqqWLu0F
e3oeO50qex6d6Hl8Ss/jMb7fegDHp23l+tVUPzpy/d/4+dMcz2bA92Hz85jL
/XHm+q9xfx4N+dG58fo8yVP+rLfIyOV9IQo+2lGKx5FyyonjhUR5H5Ul7u7B
8TuiLNav+RzwvWaaBecbpRwzXfAd3M+uNEgeU3K+23t6HvX6BtrtlxS0sM6C
ZjZDcztY/sRxFoGD273PguG8noTeLtaTRXF0BT2HDHA4FeVW1yEVpx/VWR7y
MQMMO7d9tCMkFfvlH0wecz8DVlF8jYwvIP0qFm05vkbwFhTUP7xA/UPuHz6k
/mGhUVn/MJTnR/DVxfyIc4bnD8TvYn7E75e5P0I/FP1ZRv2R/LUBPF9K7s9h
ni937k8R9Ufir+2dB/3sEJWFjej+ZDCg+5PxzTfLQ+5XwyE9bsV0111Z2I3j
n6qEUvyfB8c/VeT4v/ere75oG5YHVpOHDHq0N1Xy7yt595o63T4VW3N842yO
Twzm+MaaFM8DKo6HzOtG8Yx8f6FyHN9f+JDjW/T9y+JbMObSzto6VjpK5w01
LxTUfY5K4o8phZ+C7TelsKtEvI0b32f4kuNtnlO8DbTpNs6xV8k5KvDuLYML
E8Y/01Keu3Hxx4wld6HxhaNf/VFLWfHyi+12cY9F/xTvb1D8DfdPUYn6B62p
PoWoz4HqU+j6/FWfYtclqu853VeIOnRfIUyYUGYPIdtDcJT5YbuIHybiiRT/
xBMpQjieiMeneMLxRJPdbnVfaZkD40b55FbIjMGX+1yv7E3PgW79Vvzs3TEO
+xDfHrYQ3x5rEt8elhPfHufssp6XvkBHsXzAGLd03ecwR13x7J9pOgrcu+WH
7rhXMLvuiU3GpnFSjxHrc4lFr0ybO5lgw/ysFsTPgmnM36pB/C0YTXwY2MF8
GHPis+JC5rPmE58VDzCf9Z98UjiN48umMb91L8eXDWZ+ayDr50KfF/aFHvHx
8cKDPvum9A6D5/F9i5z65sLBuXbzbG3TMFzlfqXYJR0zQqP9HA3Ssa91Ba3G
JhlYIe9gvzF2f9D9jIvxSJ0MfG56OmXpip9SL6LzPRlVmRVC9s3PxL4cz7CO
51eP4xlceH571w5Jv/UhR/KfelXp3rRrHR35ffk+QYUD3yco7ut05/sEl66I
OBVZop+/CfDrNGNpMPo8aX58V0Mdxa/T3Vq81ArHPlSf3A/7+H7C+VSfuP9T
6cH3f3J9ykCqD3ypPuVdqg/6cn8F313iov8l95k8ORda2Cdod8FcTBsb0Cyl
djS62uZGN/yZiyNa7UzasiAKGzDf353z63M+fdjE+fQ53z44c759D+b3i3Oh
E9cfRPWDO9c/gOoHQ87ff4zjCSpwvn5zjh94zfn8p3J8geCTRX8u46PD2koP
Y9qkavLA9N0U0vzCkVx53pH+k4vG259u69QoHJdxPJI4/3Qi9+j3XhSNmTYZ
iVAuC/1WLfzkpBWNxTqDnQ/UyirRK5LdA0rkf+dJeq31Wj9FR79adYqOFaDJ
/tWxurkPcNHp6o2T3QqwWVn7ShR8b3E+WNL7MIPfX8n87P/YXxX/jdrPo/bh
xd/tQyfar5p7+NiesaX9qrlPgvfHwvonvNY9zpPxo0K+W3uue353VQJ6vG8w
RWuIjiLIPlSpYxwMd8obTS9eoSPl39S9t2oEriyRF/O79cRxbrCwdX/fNSW/
L6t9qK3248twt2arNW2sdRRp444tqDBMCRsWLt8bZKuj2DGg5rpnkX7QkvIX
oQXnL3LcN72c7hE1NvbxOmwUlYvbN9y3jM/JlvbD4kFVtba/ToDo5KNelXOK
ccLIPUqj/rGQGXRghHZ/LeU/+QAkn6ruuVW+P95K/FUp5if206+Veqvj0XT2
8RTzL7lYzyFg9qTweBzY6XHC0RK96Mwi7S57cpLQq22vSUdMNXH/zrHm5RsH
5uDUDQ6J/mbRcPshqqafzsHlh228/8uNApehy7KCvXPwodedR33DvoNDvkuf
ueE5GE/6nrRnxLnflvOHVOb8COL3x0egfP7XQik/Xm2MeNHFRwUz5h8yf9v3
N1J+8vIK/a5mEaBIxiaDdYeujS0veX+xfJ4uoPNU2jcdmJ8tzlehx3qy3XqU
7ViBM74lfR1+c/+FXZrJ/qJN5C+CKnq98ro4F0DYH1d9z9gEmPv391HM+Jt/
LPmbTf7ODyHxkEucb0Xo3+L5w4RfYzTh15IXJH5/+TdfT9odnX7d1m9hUnJO
oE378M4lerbpknI2S35KXpiQ73FWDdeezc3Bl8THUdozH+cW5fPCZM7nVT6y
TJ/CP6RPwXv+Ppb0feCH1QHDy0tL9La3TbpPDBP3n2SV/L+NyeL5KTJOar9P
18t3txaCq32xXkh8GFwP6/R1wGrNveLxnJ9wRZ0yPgIaMh+B43tgCPvDlhqU
8SmgJvMpQtgfuu8s+fffk/yAQpYf90l+gFY5kh/JL+7uWFAhTdrfdTmf3nvK
XwdVJp1+fy0uAQVOI/DJ7m6Hr5lOyYJ3rQ4nBg9Ilfnh/rB9I76n8Ddvcv/V
RCdMBZNMG/0p3+gX2tzwVbr5qqB7ZvvFNcdp8tLfjNB7n3VIDdeG9UrcPDxJ
jAd2e7F/l/URA7fmUG58yXqyqxrbeGsCbtAxrPslWA0/Hg0L2NW5WPJchP/t
KPnfUPjfQsn/hj5dds0+HlgIy2dXwV4uKegesv3e0oPaSoG7rHtwWH1vqrZS
4CL+9DzOpOdl3qgLP/7y78n8Ek6P87tWvhIq5ZLAPX1N/eaHv8uCvBFaltbq
IuzYvrVqQe1EuGXqO/F6uWKJw3zlfDpi3bB/E3ezf1PoPy6Er8I9xlfFOe60
4E2fqSX6cNHNqo0r6x2XcXBi/d2m9Ydi/fHzitRb9Lzw3116P7282XstRfdl
ODp7wT20zV/j2/a1lqK33/DzE7wf4YOdTh88g7QU346efDdipAPaTOzXttz+
fPAKJfzjPuEf4MT8YiGXhJ7ZkfEpIacrEH4GCZY1DF59VeG8fgY9A4dngfW9
8t4xFTLx0gijtNUdSvYV/Q7W9DvOpd/hJv0u7A1FW7Y3hD59hu2FQwFVDLu+
ymY7Khk8jI62z3z/E2eZHPZu0lUt85ht/Ru/lfLQid6XcqT7K6vVQVd/wIMf
lVNnm5TYi7/O1VHs/AbVm/keWb0kC++eGm7z61Oe3BdtzasHK5dqeBXtmS8k
7DrBF7JjfOuXr0mVVY+KUPARlhG+K/MtXSB8V1nTvgzfRcZ3lVMI38VowneV
EwnfxY+E7yq/Eb6LA7IWbb7ucBorG+7favFREwflwfiTaMfyndWKLzXyYfYt
x+Tsg8H4YN2FsASvQnjcp3qdoIah2O7doMEZuzT3pk7vOiJgunchbI3sdSlj
mK5C1XHYlq2Ho+S+qJV3wOx362Q4WTHufFfvLPk9xP0cne1mN/i+/pfEZaId
ahy8vigHd5uPTVZcVcGt/THVHM1ycOC9eYmNb2SB24jdxj6fsnFqszljTlTM
ApX5pWjlWLXUc91GVVk2sWoW+m4KDjGKjYao/tbJbumZaDrg3h7r5Rngueb2
+FFFOdh98erB8eoMuDSowy3l9RzcfOijkXclLcX3iBpddLfmS3xyNeGTUHVY
y6Rwy1zwtLXZWHxKBVv4+Qh6XvoVp5UbPOuIWke5b4n/8C/f0vFTQYTrEm0V
FtZ0e7awWhYc6BVp6ThZ46etQ/oMbJ3dJnxcQTK20X81rXxPFYxi/kJdP+KD
rCd8XOFN+DhqLw3fWVNZsg/zCk8ODfqJQ7q8TglsrqXUe9TxRsvdUeBE+ip8
Zn1Vd8yaBbum50H2xClez1oloQP1XxnO41UM//bQaH2OPD8F/rf1bg3b7ztz
sTPxqcGL+dRC3znJ53cM+5/F+S2+R9DvivXPn80R86lcy3hvEy7b8Pxer9/T
63ftPGiYmVLz1SsN/07IpxHBrndCCn9hzunevc7YZED9LgPd3Sb/wdnvnNts
NVTJ80vlUhx0vJ4KFi7u5rVxksA5MqB6ov9Hk0cpGLhTq1uXcipge1P6j7bx
fITx91yfEvOxjX4yPliTvthVNxcXJTsOSErRlvmYBA46LMLl7YHbGTiz0ojN
42tocN9DeXMH3uuhhrZZz3bYWSdAP4/OVk57imXcCOdDBT3Oh2pL+VChkPOh
mtP3VDSj74nnvWv+DhpQgNUGadsWeUZhhvG9u/WHFGDcXLuVXZ2isFXPOY/2
1ivGGmQPoSf5t2At+bfQg/xbcIP8W5J31WytzflBS3Lx5rDZrv6bCmT+9Up7
HtcNMy9gnlcUNl579orPzAKw0nuZOXBblsRNY7Yrcy6uy4b5r6a/2tWmQK5r
8T0MtNatXNdQJXHq+lSG5oqC7MBG6Sj+it/r8vON6f/Qmn8/F7uzev2wPOha
t47VjHYPsA3/vwk/d55/D6pT9jtcoDLO5TK/j75UxrmwuPbXZSkQN3vvRYeW
LXDjiWbx2itSYMW6TkdGTemGrrlf/NqvTIFfZnWnRZzqi1cnueyZYJcCvbY7
ON+2G4gBt4ZNs1+VAlkJquX5dYbi9xo6Hc+vToFbwxePG3hvBKpt7xe+XZMC
JpOXeZh3Hos1Xtu9z15bMv697SonOYxH664bStvHDXEX/beUtK/Y3LW0fRxp
1L3J6JL26wX9LG0fZ0S5RJW2/9vgbGn76Ddi/cey9udMK20fzby9fUvbP3G1
Vmn7GKAT5lra/qqcV6XtY9su2++Xtj/cfHtp+5jyrUGH0vbF+LvO3lM6fhDj
v5/dsXT8IMb/7VGd0vGDGL/DwLLxgxh/jQtl4wcxfs9KZeOHbB6/R6+y8UN1
Hv/cxWXjBzH+37HepeMHMX682K10/CDGv3t22fhBjL+dftn4QYzfyaps/CDG
n/YktHT8IMZ/pVrZ+EGMf+bDsvHDzvxPnW/apKD/7DvHg6Y1A2XsI+fzS1PQ
KvzofwsdjSH/tfdvjyUl9ZWf3MUqsQ/0uu0y2tk6pcSOq7yi+1kFrDix6fq2
xSlY7pp14K0P5nBlx8Jq6xaloMXTwGY9ii0g3mbMsqVWKegc1nbD7U6joJml
ybvZC1PQeu2zxQ2uj4WB5rGl7UNTJyPvwGnNcE2Tt6Xtw+/Oz8qXtI8Xc/xK
24c3R9LvLEzsgxHBnqXtwyStg91L2sdq1xxL24cXPdo6lbSPA3avLm0felg/
jutebIGr584qbR+8Tlr2L2kfvftalLYPlayzh5e0j2L8GbP9SsePYvxnp3mU
jh/F+IfvLBs/ivHnhZWNH8X4R/8qGz+K8Z/VCSodP4rxq+u1Kx0/ivGfdy8b
P3YcOv9085L2BX4zVku/4/YlmvLqe7534xZrykftpg0eskhTfthBJ9h7oaYc
FXdpVqUFmrLuqXEpS+ZpykaTc9e9maMpjzFa9aReyfoX5cqfvCI2/k85wD40
K/J/ylva6NUYsFxT7vvBpL3X/5SzNyw1r7hCU77Z8uSsJf9Ttnn7bv3b/ymL
7++4r13p9wfx/Sdff1r6/UF8/591y74/iO//GA+Ufn8Q379iZpvS7w/i+49t
V/b9QXz/YzPKvj+I77/Souz7w00nm5PVAnJggeFX08aO0TKecIL/9sNNjDKh
q3aXaW1D1fK8snY5mKfuk4CF4TZDqg3IxA78u+ABC715x9hyE4/VTYc5l4bG
Dq6gyScyg8oyL8pM/l2UZ/Pv4nmXV2lPatj/weC9A1QdK2bIemo/zgDV7SxM
cV6YO3RzHBan5DsH7s6EYCpDudSyMm6m9+ELvY+7uPyZ6xPt1uL6/in/257E
cRxofHK8u7jckeZD8qIjuX/a3B9j/l3M5/8B2gmhbA==
     "], {{{
        EdgeForm[], 
        RGBColor[0.148, 0.33, 0.54], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmXmQ1MUVx38zy7HDzszOzM6wIB4sJETO5UZWRKsSqySof8jlLYqVSkRY
FIxUqSWoOUyVwqoRCSoekEQOL8QDNIA3ai7lSETLgEJZgQVNNMBCYr4f33cL
/njbPf3rfv36ve87urfhquYLZqaTJLlBf6rU/lXE76KoTtRb1Ev0gegkUV6U
c/9EUcnfG0QFUU/RKaILUkky1OuL/s63GlEP0QmialE3Ub0oI+ru38wdIhrs
NbSNoq6iPqLviipuvyMqu2WvTKck2am9J4i6eB/4Zi0ve58uGi/6oehabTxd
dI76R3TwSVJCm9r9GhutsX6iAaIxXveUDvy5eL8lhoP0e6zoDFGL5i8UTdG3
iR2S5O/isScVcp/peQsy0R9snQ31Ofdq/DS1fUVfad1EyfAT9Zss4zjvcZ7o
3CTkY8415nu+v62TbIe050eSrb/lhQdzJ5nnpamYjxydrNOKbYasg6wnzgwP
zoTcQ7ym0fKjgym28TTOIv5XW0+sHShqzYR+v9a84fo+THSx5w7zfHTf5DMO
NK5ONiY6GyMn2n4546PaeOlhPGVt5y7+PdbnaPQZephHd6/rYt30t6yNPj9Y
+9TYAVsLRfNE870W+5zqvfr5dzePfU90j+g20e2cSzxuVXu39+/vNfWe28dn
HWgZwMvkVPACD8wdbYyAld7GSoN/t/sGv8E7/oYPfAb+UsEf/CEj2Nqt/qRU
7A22+xsb2L6jsdDRv/GnlaIlogdFT2j+CtF96t/r3/RXevxnSfjdfPveCJ2l
u/qz1C+Uol9binmsvYOzZON7vhQ84NVL647o9y+EjZsUaDZp3jOiZ0Uvi1aJ
Vos2ip72t3+6v0H0ir8/yTmyoc+uCj43CeSfaKxF4Jgrvj/S+J0KVjO15xbR
nCTaraLZ2EJrxkiGvxVD5+Affb+eDT3+rxh+gc+fpfHtrBPdlUQ7x/1Xs4Gn
ddpzicZ+I5qZhN8stE+tt65XeZ+F5slc1iAr/r7Fsh1Wu1H0O/WngrMk4gBj
G0S/VX9tEv3nk/DZBea5SfLsEr9/6OzXpWIN8zvY5sT7l7CRaIXooL7/Xu0L
SdjoCdv6XmMcO87x2ZvFryS9DJOsp8pRH/c8cPKw/WCB6PpM9B8SrUli3jIT
c39t+7FmKT4i7IwWz9niPycVmFxhfT1oPi0dAnOD0mH/h7z+sSR88l5j5BHR
o8bNo/5O2+J5Sy3jQmPuMcv3fhJ5kfx2SLTPWHtd9Jz1/arXrPHv5UnollxK
jiQHvpiEPtHvOp9jpW16yPZ715gA7+943nrvs8x8q2wr+G62zZj3lm3FPm8m
YX9+v2a54PG2v7PmDcvKvBtFi7X/XPNNe5+y8dHROsU2q637VZa/xXp8xLpf
7W/3HKfjZd5/jedhj6es76XHYeRh8wBr2A2M/UoCtKYDG7eZb4v3eSU5Fhte
To7503rrpN3e7He7sXCPdb/OeljiNYyBNXCGjU4z7rDZ1+pfURX5uTkTseNW
83jnODtsto4neu41luVdz0PH6HpGEj6Of6PzFY5/+AD7XO71yL0xifg2Sr+v
T4Xvc47Hrd/7rF9+4wP00RU+QYxdbh1sMq+UxvYmETtHpiMWgNVrjYOfJnHm
F40ffLrZvkd9Ma8q6gh0gozUFVf5TPBgDPmnJlE3bkkipz+gMy4STdXayfp9
ZRJzqE0muu76Rr/3J+FvN8juOzXWOR31AWsmJeGHfMenjqajbpttvX1rJ/Wb
qkIeapMGFQyXVcU4+t6dDp0PFqjP0PjpVfH9cs+pSoUc73tPvrEvtddFogut
a7CMz/8nHfuiB3wYn0Kf+PRBx+FveZv/E8YK+sU2zMc3iKPER3yLum+K95+T
D501FmLvadb3/ZmQ5zzzv8w6p76aZlkP2AbU7YN03hGuvU7yOHaZoPFbO4Re
iCv4PT5/ZceIra3WcZv1/LaKhIHae7PaYdnAT0WydZFB+mlOz1z4B3l1HnZM
wg/IVWXxHFsV/Goqof+s2u6is9U/Qe2sTPjYj42xs623GT43Z8NmTa4hdxSD
Z7ES8QIMY9/bjWV+t9kXkYmz9qRGSUdtN8cy3mj8tvvmYudrZB3r+pm6jPqP
mo7aqrt/U7d18++exij4RM8565/aq97zqLupuahxqf9O9Nzp9gl8I0mF72Cn
9ntOxfbmPkCdyz2GWnaMMdPk3+13JPahdqzz+j4eQ44Gy9h+hyt5HjXc3Kqo
KaeYL/vgu2DufGOW/EEOBN9v+vdzHiPnEDve8jfiFL5CHFolQXrLJz+vhM7v
sK2Ip+SDuz2XnLrJNuT7bcbRDbYZeZi4StzHl972fnybb+xBC80Xe99hbIBT
anTqtDWW91Xbo946mmScYnd8a7Jtg/+MMPaIh8TCs5LQCzah5tpejDmdK8fi
FzEEbIFbcAW/cdbv1R5v99tzbecmxyfm057h/pVej32Ib1elgv8C65Fzw+tC
80Pmob5/jTFP9ix1DP9qj+VTrePFrlfRFbUn/oNeZ/ob51gkZd3fOe4u5Cny
CTm9IPvu0NiuXOTnfbYR3/d6ztMC21rt2zUbsYQ784e+M8MPf9oip9lMfJAu
L3ENP181/HT1v+R8ag+aL/lxd63kFZ89aifXRPwqaG1X8UyL3tOcask0T3O+
1P6TvCf3I+6oO9xH3lZjK1uOMx6SHU/NRkwqFKIOhCdzyRPkC3JSF43ht7XY
JRt2uVlrM84pKcuN/KtrYg35jnpruP78siryLJgh9/EugVMyfks+9my1jF3L
MWevzlTOxv3uY8lWl407YI9C1PvomXskuiL3o6/6XNRVR0txbnTB2Udko8ao
19qVhcDHn4nz1v+dNVEjfVAVdRL8Kq4nGBt+XP1ES01FvfAD8TlsWT73uwHx
c4/vvEdykUcH6Ux/LESu2ibb5ctho5254P9ep9ijqi76abXN+eD5pmT/vuWc
rfZ063l5Teitq3WHHcjx2ILaqZdry/Gev1bzPxSvq6WTbtr/tWzcq9fngy/8
0ccb2dBb0TKCYc4zviZy6pFC6Kez6A9as6oQ+e8v0uefClF/fFgMecAHOJhg
GcA4MQr8Tzd+q41hBO9kjFVsA/gf8DfyRZ9s1DqdpLcT1H9JfDZI/ndr41yc
r74cNdau2vBDbLOqFDgDbx2k22k1Yb/mStyHiR0j9P0rrfm51v67NmSkf4ox
C39wS47F17gzbinGG9DgfNQZ5GDicWM5ajgS5LPlGN8rnvtqYy3+mkmHnPgE
7wK8D9ystlKMt5rVknlAOvCMHfuWow/Gy7mw77/U1hTCH/HLS/OR00flA3Ng
72guah1qHupocuVEvwXh8/h+32zkxl1+c8FP8Jfh2aiBqIWGZiNf853cix/C
5xrttSwfeWFIPvhO8LsNtR013snZ8IfJfqtBt6c4V23LREt+rK6Ej+Arh7Kx
ljqRun22/Q99M4fYj47BHvkMG4I9csAt4tNL+WOldJCrxDjY3J6NmLhHOjla
jPed/xYDg2CR+NfJsQ7c1ZbDF/CJcinu7ZVSYB98Ent6Oh5ih/WlwCTYbI/7
xB9iBGchlxIjeCvhnaRUinON1Py2TOics1I/z/L95RO/jVznOEg8vDYf+sN2
5MXOuegTy0uV0Al+SczljkPtjd5Zi/03Z0OGmfl4M8Kn8K2GXMwfnA3sECfJ
ofjK4eNqAlrqgR6VmENMxba7bV/018V13j6/laIH8Mf9jfPVuK6mvh7n3IB/
fVaIuHpaTfgr97Ql1gf3OnQyoDre3+CFfrhDcn/sm4s4mqoLm+Bj1A8Z37fo
4wesZ+2OfPBcS6zLx151xYjxw70vfjbAsZR33y/8tj7EmKcm+qYQceGZctRi
xADiAz5VXx1+9Vw5+HytGFBbDJ/8SvKOzEf9w72BdT29Fp/AxtgXXHBvBxuj
7OPcD446v1ySD7mRn/cq7mhHfE8jruEby9U+Xw4+H6ufK4Y8yMX50UOxFHnl
S+cNznnAb9m0+93f7/HRtm+rbdz+Dk5t1t/z+jm/kl+od7Y6ZhI713ov8gMY
/8RvgPM9nzdO7o/bfYds8Tj5cJRtj19Q61F7X2EbtWaO/Z+Dd2dyMnUbNcE7
taH7QbbpMuMSTOLfjdVRC1BzEZ/BzqdeSw24zfJQY9Nus2zou806P2CctOtn
r/u0/MYXWt0fbR+d7TsyBD/ei474DQ2d7Pbdbq7j96eO4fj0Z/brrb5jcp+l
neU+GOLuOi+JONHsdx78DRuP89otfgMq5QKH4PrJUuzFuy9xfadj+xc+J+up
1Xu5XifOLfJ96n6/jVzsvLHLNdI3uYjd5MkZmbDZObbdDGNpRzbuIfz/B5tQ
J412PbLI9Tm8HzB/allq2str4ht9YtIX5o+e22U6zzHssGPy9HzokJpoRj7i
GO/ixGb2JO9c5LXsRU1GbfaU4/0hx0X0utU6XG1sU6+15zkwU1cKH8QXy8XA
8ZnO/8RD5rQZT9j9o3zMYS7/iyCmYANiQpvngJHD7mOHBvvCQWOSuLHRc3jL
6W17MWdpOWLUyJq4D7KWOPm8179gPCI/OXqDMcn3pnz4Hu8c+3JRJ1G/98pF
bCHG/B+42opo
           "]], 
          PolygonBox[CompressedData["
1:eJwtlElszXEQx+e912qf997/9f3f+9cWVF1ULLWViO2ACDeqEkVsEWtrTSoh
OFgicXBB4uCAUxEkDjiIkFAkJLZoEVtFggNaS1rL55txmGTmNzPf33znN78Z
tLxxbkPczFYiRcjztNnPmNnlhNnV0Kw+MPtOwBp8M1Nmt/B/wH8J/3n8iXKz
w0mzBZy14CvPmdWhHykxSxfMijNmDeROJr4mcAxhTcFehD0E/xjwD2Bb3mwH
Z/vRD2HWEluBf2jcz7q470dktpX7GrljEL4S7HH4RhSblaJnuPMod9dC5krW
rEB9zcTvBe8L8REY/XuYbSE/RD8ZOHdhnEJPR15rNXgZ9L7IDOwQux96NzkH
wR5GTZXgDYDzUrB+ITfI/8jZa3zbiOlFLa+xW7HnY2ex31NTE3qSs5vEV5G/
mtyB2PewF8O5ifv2UGMzdy3CHlnqNRewl6S8t+IorheQCnJ3gXkRvavMbB61
tnO2HbwU/I8n/Q30FrnIe18gJkQv472WoX8mPovekXFdHKvAux85d81AF75r
gc/GNPBuU3tD4G+vmWgM/Ew+zYRm4xt894HVQs6jwDmKq8468L3Jeq/Uk3Z0
w9+NfwvqbLiOR2ZpPvHfzfpMaDY0A5qFj1nnLs5z8L2nxk5q2YC/I3IMYW3E
7ox8BjQLu8n5RG4P7FUx75F69YP6F+I/ht2z3HOUqzcqIfYl9T1M+Jvobe6A
0Rb3O5+S+yTnsziWmMfouYK/vWLekt8I3u6E/7E24h9E/hbi/Bd/C/bwpM9M
QG514FiqSbWJk7ipJ+rNBGR6sWOuSPnMa/aFcZvYK+S/5a5aJE9+gvk4XORv
XpdyjuKqGf6Z9hnWLAvzHbFXsd9hz0cKaZ8pzZZ61oT+B47tMf/zEf4Yf3is
Zpl5TaA3w6GSXg1GzqCfCX13vCH+OvGjkU3oNeS0Bf4n9DeWc1aBrybtf3UC
Z3lyX5V5bi/wToBXD4dhpc5J3KrTvhu0U1rBWhs4d3FYp17i34w+Hv9z7PWB
cxOHDehFed9F4lDFe5zlznkx7+E59JqU360/qr8acLYRXx/4lqHviLx2cd6J
/iFy7tohE8HvXfBZ1o74BP7UwGtRD8ZQWzzvvdOMadZeBM5dNY/Dnwu9V7pz
FPZXMCrjvuO061pzvrsmkf8MPRt6beqRevUl9NnXzggzvmO0a5JIN/GnA8/V
TtRu7Mz+33VIgfh0zv+ydnIK/XfOc9WjCP0fU6DIVw==
           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.38192363591998607`, 0.4379284343488769, 0.5945560734527878], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmXu01WMax/fZt3N2Z9/P3qdUjGZZaJIhObnMiDBWroPRXFIolQ4Ka5JM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           "]], 
          PolygonBox[CompressedData["
1:eJwtl2t0VdURx3duHjdwz7mvnJOERCmxFkljeBgID1uxwBcF26UoffBqeZQa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           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.5608586818454426, 0.500812955281146, 0.4893674202569922], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFmX+4lVWVx1/uveeeezznPee855z3RiKik1wcBdQnNRBEokbtAcKxmRGw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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHu8z/Udx7/HOb/z+/38ft/f/XtSErbQFpqmIpSdLfRAWpflVmJE9yEV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           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.7397937277708994, 0.5636974762134151, 0.3841787670611965], 
        
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1WXu8jWUW/pzLvrT39+393U4RRRGVa5QpmeioNIXQjIrJUT8xQ5SZn0Iy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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHm8jeUWx9+Dc/Y57f3u6d37pLhK0Ui4yG3QpGhCc6GB+pBuhnJvlJy6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           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.9029918168844019, 0.6274795422110048, 0.2992746323416459], 
        
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1mXvY1VMWx3/1Xs55veec3znnd04IpZRcZh6ppN6IiCHzUGaQcWdcokaN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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHu8lWMWx99zP8fZe79773fv3NK9qRlmIqlOTZGKZD4JoxhUQhEVMxT5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           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9315756900354334, 0.6989392250885833, 0.38788463910984333`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNWWl0VdUVvoQ3JL777rnDuwFF5tKKdmkVVEZRWghOFMPcUpmxDoBQooAu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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHmUVcURxu8wm/jevPveve+BioKK5AgaT4gaWWWJOMTjwg4aExBEjQgD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           "]], 
          
          PolygonBox[{{2977, 2976, 5033, 1863, 5035}, {4667, 1586, 4666, 2976,
            2977}, {3495, 671, 3687, 4204, 4205}, {4638, 1569, 4637, 3776, 
           3777}, {3777, 3776, 4130, 1193, 4132}, {3823, 3822, 3742, 376, 
           3132}, {3033, 3032, 4191, 1244, 4192}, {4376, 1388, 3741, 3822, 
           3823}, {3882, 3881, 3689, 392, 3162}, {2897, 2896, 4251, 1287, 
           4250}, {3889, 1020, 3890, 2898, 2899}, {4187, 1241, 4186, 3032, 
           3033}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9601595631864648, 0.7703989079661618, 0.47649464587804063`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1mHm812MWx7/V3XK/v9/3+9vKUsJNEkK8jKkkkrqNSsttT+hmCS1arVG2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           "]], 
          PolygonBox[CompressedData["
1:eJwtmXu01mMWx3/ndG513svv/b3v2wVJRSUzDTFrKLpIzjlJl9MplUqUUqrT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           "]], 
          
          PolygonBox[{{2974, 2973, 3993, 1083, 3992}, {3971, 1068, 3973, 2932,
            2933}, {2933, 2932, 3894, 1022, 3893}, {3965, 1064, 3967, 3789, 
           3790}, {3790, 3789, 3917, 1034, 3916}, {3135, 3134, 4642, 1572, 
           4644}, {3310, 3309, 4064, 1140, 4065}, {3165, 3164, 4670, 1588, 
           4672}, {3830, 991, 3829, 3134, 3135}, {4078, 1154, 4077, 3164, 
           3165}, {4019, 1103, 4020, 2973, 2974}, {4194, 1245, 4193, 3309, 
           3310}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9887434363374962, 0.8418585908437404, 0.5651046526462381], 
        
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtmHeUVdUVxi/MDDPw3rxy37ujIoqgUqWIYlkRpSNFilIMTUFDVQERiBRD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           "]], 
          PolygonBox[CompressedData["
1:eJwtmHeUVdUVxu+bjvPqffeOSFAiJggo6kJsCEqRKiggEKkqINUoLUykGGCG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           "]], 
          PolygonBox[CompressedData["
1:eJwtkUsvQ1EcxEfjlWi1vW0XFxsbEk0kdaMisdUIpY9EJB6hJW1XLNjzBXwC
dhYWtiwJH4Gt95o1Fl6/f85dTObec+bMzPmfwfpOdTsiaQB0gEpUGumURj0Y
ZEErLvntUhPe75EOQD0leV1SDd6MSVvgivVLsIguiX4JLmak025pDj5i7xi8
kvECHvE+I+sZXsNn1bxC3yZ+N2ivQYH9SXQzcAGfE/ymMy7LMrNh15z1RVfF
e4XsFB2W487DvL6jLu8J3VtCek+4u9idSuhi6CvwHh12QS4tndOlrddp7cwX
KDOoT3gCTR4sgD98y3S+40yBfrfwGDmB52ZjM2qgS+PXghv8J/neCO9t97fZ
2IzW6ZChSw2OkH2BLki7TtYtCRLAB/fkjuM1jHYI/IBDzvqslcAv+7NhT+tr
faxXk1kE7E3xPR/2L6bcu9j75Dn7wFp/mGWZffbGrH14Lssy/wGM2EUs
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.9499999999999998, 0.7499999999999998], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtl3lwltUVxm+ACLnvty8pYGQfQWnrFqB1sJVFNARkczQIwSayBHWAIhYR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           "]], 
          PolygonBox[CompressedData["
1:eJwtl3mQ13MYxz+7bdvu8/v99qjdFR06RQeiDEYoMdpUFIqy2VC7coUaiuhi
K0pb26G2QsZ9J0XOSs4xxtAYwjjGMcYRgyHyes97/3jm9/58n+fzPM/nuT6f
X9dJV4++Kj+l9DlUAD0YKb3ZOqVH+DgT/AM0Ki+l24tS+hE8pSylNq1SaoZ/
fy6lPpUpLYY3jz29wdeG+cPgTwO3b5dSdb7XA5G/r9z6O6Hzy0xKf7ZNaSdy
x0JjsylNQv5lHJmG/BTkO5RgG3wI8nuR/xmZUciugj4rRR56BF4zdDO805Hp
gT/XYaMePA7+dnhroRvh761IaQT8fznrA+j+AD3DWe9n/T54I2cYx/owbG4A
v478INbLof6sz+D8wfluhD8D/87lWw28zegfAz4Fe/+gaxjf9rC3mW+PI38X
8iuR712VUhY7t0P9kH03LKs9b4OnIVPDbyN0K/wjkP+vOKXbWO/D35NkE7wC
ug3+buK1C/yS1sh248yXFTlnXcFf4MMo1v+hvy3yZ1f6rDrzOeBm+FXgPsS8
ifhcQj6GF6b0sHTAfwV+Hv5fi/912B5c4dpQDoeAB5PPA/Av4tup5c6JctMN
6os/teirRl8T+gagbzh7dmGrmD0lnKcze84qtM1LkV0LXQ+ejf/V+DMQ+S1t
yBf685C/GX5dK/u8Hl4v1r2Qb8Sfs9C1Fhtr4C9Gfin+joM/tNA1odo4F5nd
8KZDY8Bzid+H+LOI9RLkOyOzDTybmHcBb8GHkZylN/huzvMeuLqlHt4EnwN/
fp5jdBS2hmVbfEdHMbG4N9wb6pH14O6V7iXlZxa1tIgzLWPvg3ybwd5G1k2s
N6mGWf+A/J9Fjvn34Enhs+mMC8C5jPmqx4tZP8q6mN+F0BD8HR3uPflzA/hU
6B5sL2X/HPAJ0DrWq1jPlyz2azj7RdAv2LswnHud71h0jw3nWjkfAO4V7k31
aF/4a7DZK+OaVG3eH86NcrQJPLfUtVaL/pHY2kEOvoQ/lHXPEtuU7YlQNes7
c87NF/IXfVvhdyx2DvexvomYT2nlmlBtHBLudfV8NbhjeDZoRpzWMmM0a56C
5uPrk/xWFXpebACfHK5F1eQ28DLs35HvHm7A3ir2dOJ83dW/4BXwl7bkoxH+
znLXz2+ccRf4nQrXemvW74Jr8P858rULf+aQ/27lti0fuoC7c+auyFdwxj3I
LsdGQcY9r94fBdXmO97Dsbe/0rUqm+3Z2z/j+En/0ZoF4dkj//uBX4Ouw9YC
fHhYuQz3guLZV7Lsyee3AToR2/OgR8FPaP7g386cfatj/wHO8xH2e7S2z92w
v5r9rRQ35Zq9M6G7wIvUN+DLoSXgpaqrKpPwHdCF4Ab254HvhCZVWYd06Zt4
8km+Sad0X0M+7y1yPTdg/6uM75bN+HhwlWeYZtkIzjyZ+hhBzOoLHMOzOUsZ
MpuKHUPFcjn8xwqc0yb4V6J/Y5H7YwX6FyC/Xb2lvs76TtAs0EwYwvpFvo/E
1jPoe6GlB9WLAW3Gt+k596p6dhV760rtu3pyDvtvyrpeNRNq4a1mf0/2DWL/
LfBuyLq+NSPGwl8Gf3/4TtTdOKWtz/oQ+ieAj8zYF8WkX8YxUWzkYy35+7vC
98Vk3UHgFfALkRuPvqn4uoT1t+B6aEfOOVFu8ltqRTlVbpVz5V49q95VTbxK
fS8knq8VuIcac86xcp2BtiP/SZlrVTPnV+IxGv7i8AzTLBtf6thrRs3kfN/h
4wVFvqO/Bb8cnre6M3aAm9gfGd+hukvfCM9+3QFbwM+H46OaGAw+HXoyz/o7
gM+EtuU5H51Vo+iYGNYp3WPCs1Q2+7fkVLlVTau2N4b7WTZl+0Cxa001t5J1
6/DbRm+cNeDJ4beU3kxXgw8N155qcLXeOTn3r+7MlcRyfplni2bmT9g+NOPa
VQ33RP6q8KzWnXQM+O5w/NXjE8BF4frTG2Y6+Lic7wfZ74j+TuFcaY/2tg/P
X92R67TOeHZrhi9vyaFyqZwpdwPDs04z73rVSYnvbtkbQL5mhWe1Zvbs8J2j
/KrHfgIfjY7j+X0WOp/6nReuddX8cYptWLfisVYzJtwr6pmTwnea+kkz4Zfw
GWVbPrQB9wnPqi7QjPAdqtmtmF+q+OUcK52/vp1zpFzpDiwMn1ln1xlukb/h
u0kxqg3nTLnTHXl+OOfKfYnmDXhW1rWmmquhtqtzltWe09p5RmtWKweX6G7K
2FfN9IPAufDsV02NA+8N94J6oit4f9a2ZPNz4vdQuFZUM83gw8OzQO83vfU/
Dr8N9Ub8BPxp+O0rnZ+Bn0bfCH5fkV1y81e4X3WH/Q3uHb4LdCeUq18r/bbR
TJkAnpt1L6mnppa6hlRLesMcLBx+i+tNvgd8RThXevPtBg8iPueF70DdhdmM
30Kan3r71OecG+Wojvj1QaYM+Q7wVuruydmWbC6Av48anFjkN/uv4MvDsdH9
OTU8EzQb9AbYCu5c6btSd2YeZ/k9/FZTzan2KjJ+uyjGivUf4dmrGXOiajXj
u1Vvlrbgr8K25cNhmpv0x5X8vg41VLmmVdvq+S7KXfi/hfZ8Db4v/JbWm/o5
8BHh2a14fxN+k+o+0n+Wt8D7wm9J9ZB6STlSrtQD6oX/Af7wx08=
           "]], 
          PolygonBox[CompressedData["
1:eJwllFlI1FEUh4+5z6KNOgNthOWSpm0QCSVBDIKaEwVFJiIJZQumadRTJI1p
2S6jlRRYibaRppYIFYGRL9WD0R5o0IqaWdjm1ne4Dx9zz+9/lnvPuXOj84vW
7ZoiImkQCBUukfsWkUE4GiKS4OQX7QX2S8hCexclchjtEXY33AkWCQgTKUe7
hd0OSUEiG20i0+0icRRoRXsIvyNErODiewv2AoW4ZJjLehyeU2MfdXcSm4Md
YRWZGSrSgVamOf1EYtBi4SxxzfiF8j0cuxf/42iDDpHrrK/BIfLNdhpdv/dB
Dlo/56jHr5N86WgrYQk+lfCAdRfsYZ9t1KxGm8T2p8YnYm3U3It+hfUI+hs4
hk8j+gXOW4A9C98zaN+iTL0YtPfaW+wB6o7T7wiL2afut4vY7aynEjfpL5IS
bnJq7rewhhy9xFag+7DjIA/tJ1oZWjV2NGSjfUXzsr9V2nMQzjFEjSTyzcHe
DwXU8KGdROvHHoBKYufQq6VQw/oyWiMU4/eanJloz7B7oErvBVo62hPsx3AE
rSfKzL8N2waJaD+4HxU6X+aUin83PqE2s6+b6DfAi5/XafobSQ8Ktd/EvcI3
A+2p9gbm47eJO9TC3NKwU2AR2ga026yXgZu82dge8l0l9hfacliMXy3MIP9a
7DBmVWU3d1DvYibcJW+Tw/hqjFtnhJZLvjq0RGIToBytgzOUg4d69zRW75ue
l/hm1uEwyjG/Y5dCE3YDxOM/j3wHiE3V+UAGWn6EuYN6FzthNdoWtGGb+V9M
oI3BaXw+0Jvd7D8be6GC9getj7kGsr/1aKmcbQV1vfy5L2JP0P8El5mdznAY
LpG32GZmrLN2aA22VOQw89S5DkE9foX4lUKD3juLeRf0fTgFf1n/gw6+5dJ3
D3vZTL1pVvNNffTu638gVvvANwfaGNpWfWvQauA8d3kCbRvaF+zPcAK/EvYz
wb4iLaaP2s8sqOZsAdgefYvYWx39KqVvo/peQStaLbQzrzj2Eg/nyOemTmAA
7xF2Hn4l9CoZrVLngfaR+gc5RyzncLNXp9X8T/T/YrWb735W8y7o+6D71v0H
o43wzUfsDrtZh6AFgc9l5qTzCrOad6sRv//d0sO/
           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1WtM11Ucx/FD2gOHoZA1LWeFa6ZUZoK2his0XeIFEaeUl41/KKCl5L3Q
xU0F8oL0B1O8VUsfttXKHjWvUVs9aRO7eMmylYUX6AEtWfo668HH9/me7+f7
/Z5z/P31kcSquStTQgjb/FGQFsLSwSFsyghhMx0cEsIBah0YQu2gEGbLN98f
wuL7QlhCNbw/Ubf1dLmbmI8n7B2nTnGmuFSPkXhOfPqeEG6L/6Odep0SP6P3
RMpLD+F5mkT59qfcG8JUfAdbsRmT2IJnUkNo12+XuF7cjFtwO9biTqzGHViD
veb/Q5NiP3NzcauZfztHD3XTPP2KqJ3vKzVt7r2Xt8N6K46Wy6Ix1N/7POuc
uTRarkdNhx5f0jj5yWrH4vfiLPk2ajKz17t0UZ/8JT0u4yz958hNxAKcgY34
oJ4X3HMD/0Ws5n1Xn7cwobaEss2YQDlU6SyrqIN3jriQfjT/B2pSV6muQc9C
967mKccae9n61+IK8XvqD9PT/Ev1H2Fdiq9QgX7LsIwW0WzxuPg9WF8xI6F+
sz5rcROW4H5zZvI1mbve3nb+S7w/U4b81/KrzVhDj+mTxzsKZ4pn0Wdq9qk5
hnMpS64wvi2e1OM4lce/U3UVWO7tSjGBZbgYl+EV88fqc4TvI/EO67/UpmEX
XqdrlC7OoMHUxzs0fgv8ld7otPOcoXrr6859yvpR+V28mbwjqUouzfkWWi+i
f/W8RX20332T9pbrl1SzAo+JP6ce5zwrnqdnERXSSnGF/VexEVviN4u7sQE/
NfuA2jZxq3gPtmFl/Ibi3eTn6/ON9bc0xfwXaHX0m/96/I2Ir8r9Qb/TYf0O
0TC5UXIPxG/WWy9wp3o1xZgrHk/f8Y+x9wRfrZrU+NsUD8Q6cT/zG8T9MYc3
Bdc6312YHf9d4Znmvdbzd+I63BPvQ3/SVarmzeOdTO+7ywf0i7dPiH/FYfqX
xG/AeeqdbYu4Dm/wDcC6+Nu0vkl3m/2cs57j76RGudd4kma8qP6Efgvl37RX
hVW4BH/jfVn+Kf75+BIV01T+CsrU+2FKtfckz1HrXjXFat+Iv29324gLxF/w
T3OvFjPX2Hub/zzvBToavzX5LvXX6CG+EZTCNxz36f+x9TY1n2C7OB879J+O
A2J/fYa6Z463TMcJOByr1JfxfSg+i0VmHYnvHf/+aIN8tx67rW/gRb0et06m
////wh3boNt/
           "]], 
          LineBox[{5690, 5754, 5706, 2968, 5762, 2952, 5730, 2960, 5690}], 
          LineBox[{5698, 2996, 5738, 5746, 5722, 3004, 5714, 2988, 5698}]}, 
         "0.16`"], Annotation[#, 0.16, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1W1M1lUYx/GTiZEPqVm5LGK0BqXpEFdvmkIZCoSoDGygqCkDARXpTtlE
8AHKkE1xuvk42Vxbt04zQ9NVPtbM1damjvmiUlnrRbUxm631QqzPWS++/M51
Xb9zXef87/99k7GssXT1QyGEPf688HgI9x4L4bWxIaRbT3syhBxkWKcgbWQI
mWNCeFEuC1fGhdA7KoSD9uy356cRIWzi28fXRrdgM/aIn7MvHR2jQ2jHWt5X
6Dq6UZ8OPbr0+p22i3+je/n7eHaKb9JZ6gVPhFCIGeZdpevtz+JroRPpy2jH
FhTwt9I2nMc5XJLbQAftPatHvjk7rS/LH4j9nLcFVTz71KrpR/GOarv4bzvH
MrkBd+q3vkuPiufzlqLeug65zlMmno4V4ho84J3gLs9gDJ7GeKzhfUSvVEzi
H0FXmjecXjXzWxyWT/PMh+iRqle5eI5zviseUP+RPyk3VDxP/j1aQmfbk49z
ZpTrtwCb3aeCbqLFenVb/6qe1OcIMtBhbzvWqiViP7yNZqxDH3+zWjfvDlTF
z8nMRbQSF9Vnxfl4EyvVCmk1zVOfbPaf9k2hwzyDxc6+wFmGq5+wXq/Wgi/V
r6t/RW/Qo+4y010f5cmjqfSaXMK8D8Wd+ABd2IY89dn65iOhR47cNCT0mkqz
0WDvF3SQ5z4mOd8o3gFaFc/r3FOsr/HkWNfKTafdelfwV4j/FmfyDOI+Tujf
o8dxehKfYhffG/wz4zvJ04of9CimPfHzcd/t4kb7npfbbU8GvaI2xOyHsVVu
GE3BKr5/xcG61N4H1oPxO2nPIXv20nvi/TTXzBlIOsOOeHZsxxFxpefXa+5p
PU7RC/p+w1uvb6a4jmbRr+Uu4wzOojF+p/Q/xv++dSXfQlyQ+1jPJE7GXuIz
SPCMfsqzkGuw/oQ20V/0XqK+FIuwHO9EVa+htajGpdgbTe42OX4mmIipyI6/
UeYNxXj3nedeSTqXvqQ2H4VqRSjALX3GqZeol8f3mpbROWpv4YAZS9SXoktt
Oe30fLahyfq6+mr+NViIVfEdj++6/Aqk86WhB4fQL9dpX477lrlXvXU5raO1
2Kg+N54bvTyfxedrbqm431k79NgqbjCjyboozorfBRTHdy9+19Rr+AtoSvxt
5WvG5+Z8Fz8D+j09TRfr+aznXkUn0D59NqgVogivogTFuKPfz/rfwh/O9U/8
TYy/wc7cqt6Gv/TI1iOP96716/E7QXNH/v9/5T8+xdZA
           "]], 
          LineBox[{5689, 5753, 5705, 2967, 5761, 2951, 5729, 2959, 5689}], 
          LineBox[{5697, 2995, 5737, 5745, 5721, 3003, 5713, 2987, 5697}]}, 
         "0.14`"], Annotation[#, 0.14, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1WtM11Ucx/FDoVtJYlyllmZZK2ptra0VYERekJU2/4BguS4aPaj5pwgI
WsuWQ0n9Y5paIpImhKut6aYW6NJ85KWWWLP1oJulSI1RD2hRs3qd9eDD+3yv
53t+v/PjP2NZfSKZFkLo8OftjBCGJoewMiuE8ziYGULjlBB+ywlhlLZfHUIB
fzNfEz1wVQjH2DOtP8Vp6q6n2frcK/dG6xvoPvaYeAmO4lSx8VzMCyGf6iaF
0K//x9RLBeIjeuZa59A5dUXZIRTTPdShNkVJdZf0WyrnH9xvnjQzn5DzL/uU
+N94Ehv1nCj2il7peDktpAfNl+QbxsvUr5J30XqIOvU5rbZS/ypKULZ+1ZiF
+8y4Wu0Kfeara8dO9l3823Ete0xutVm72DW4mK6Iz4XdFZ8RXsmu0e95bGev
4W+wTshdz663/kmfBv3Wsl/A1zGJp/i7xPvZldhNO2gBO8McD2GmvCZM8FdZ
51AuHeDLw8/sN+ac+8zwB1507mG6PT4HvEAN/EX2KqY69iwsiWvP7Cl1j/Et
kNNpz0W4AvvEGnAPHhA/SIfpKB2iXufroU+s3zLDL/rVUL5+S3C32PtqW/V4
ia6L71jen2LjdNB62F7XOEPKrNdinzOtl7fNeofYfjzKlyb/O71+VJOnbz7d
r+d59s90jr4XT5eXjO9FXbW6Mjkp/TbQM+zZ8dmKfR6/E/wCN/OfwQ/jfcGz
9q1Q9zVu0usWed16bxT7QM4u/mJ9nlZXK14avxFayh6R+wgWYqW8O7FZzYvU
RK3UQo36Vdqjisr0TeAasy/C4+y56krZ83BAbgUOqiuPs+s7Gt87tth/r/w3
5TyO8/lu5ruJZslZbpatWBfvsxnX0Vx6L95TPG2PZvEN7JfxDWzBC/wt4pvY
rZjSbx11sJuijW3xrmIv/2rrWu8kzf+DnXxL4rvn36jXTL53+BY6Wzem+I6Y
c7OaveyHcSttoQnsHvHaeIfiNxW/C3aZ/MXsQufchRP0Sqd2+j3e1/je6Vl6
juqpUF6B+FSql5Pl+WVTJuVSDl3S/0vxr6hE/hkcpHeph3rpL3v24TjuwR/M
M6LuSevl9C17t9gT1t/Y51Hs1Gsn30rrV2kG+yPPo58G6AjfNuqnAZoufhin
4SEsV3sHVuBtWBrvIc5hlztbRrwjOAnn4a1iQ2Y6a5ZhOb/yF7Gr+VdZt9Ey
9t3xN8GMbfja5P9/M/4DI7PcDg==
           "]], 
          LineBox[{5688, 5752, 5704, 2966, 5760, 2950, 5728, 2958, 5688}], 
          LineBox[{5696, 2994, 5736, 5744, 5720, 3002, 5712, 2986, 5696}]}, 
         "0.12`"], Annotation[#, 0.12, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1XtM1nUUx/EvtslSIG/xR1lqxpyXspk1kLBgZs2cw8vUWRMUL1mWttKJ
f1hsCpgGy5a5GaKouAcLL01ybS5Ww8usBKQsdNMICVlmbQ21Zev1XX+8/XzP
+Z7zOef3e3geRyxeNev1pBDCRv8kp4UwYnAI5feGsBk5A0Iokhspt5TeSA1h
6JAQdsrn9w9hJV0un5C/eU8IHw4MoV1+O71I56qdj+P6a/gdVPcp/UJcRpNp
o9wnzu3On+kbymd2ihl0C+9jtAHDcNl9YlAIdbji3IU75nyurp/+/vhF7jGe
Kc6v8hmubw59gc6lGXSlmlweeebm0VQ86pxCx6gpUTOWtvB9X+00z7ku7smz
ih6gdUhgt/mT9NXQeWqP63lR7wo6ms8s+Qm0QC6fzyb9M7yTxWqLMCW+Q7oM
S1Dqfj3fUeqn6XuZnuW1yF2FfCWely8W/0E32jtNz7vyW/Avvxlmjne3LX4m
2MdjMt1P82gujug/jHpstn85VusvdrcebTz/FDfwP4an+E5CG+8KPVuxN36u
2G6/7+kP2Cdfi17P2Kn2ST31yOZ5J/rQSlTgA30fmbsDX+kJ7pOQkK/DIfsu
oPW0Rn01quJzoBbJfPtikZ5C/Bw/f/RJD6GDvmGH0+7PoAylOIkmPO757ov9
/NPVThRfsMc6PsW4xv+8uBXNyFa3iV+vunF0r96bzgl6i9bSb9R9i5+c23GJ
x8X42Tv/6F0soC8hnVcD3aNvIT2t5ySGyxfx7pF/yw53e4419E2sRbf38Ij6
PPs+g1w06XvNXZs5U/R2qfna+SptpTfUd/PNEjeKs+l18Tm19+vNQiZK5Mrc
Z7rvcu6kTfyP2uWE+y+RwSs3fodpv/i7QFvNfog2ih9QU+w5M32W1eIcHrvo
76hCj7prGGx2N58J6n6lg8TNZj8hnojxeFo+y/wN+vq4m8qrw/lZdwXmFCLI
rxH/E/Pul4iX4m/xbSyzSw461XbhQe8zA8NwVZxkxjz7zMdMO+Rjh1wJz3ew
Aa+oW4GZ8fvFeytOqbkkPuzZD+GyGYV6r9C/aAGq9DarOYe77PZx/O1AqXw5
OtS0xHdldlb8W3J3C724wH+1Oavib5a42vzd+E5fC1oxwN1AjFObRkfKPYzn
eB4UT487xe+RcwKpdjgq7mvfHp7X8RvO6nkvfo58KunbaiYP+f//gv8AgSbh
ng==
           "]], 
          LineBox[{5687, 5751, 5703, 2965, 5759, 2949, 5727, 2957, 5687}], 
          LineBox[{5695, 2993, 5735, 5743, 5719, 3001, 5711, 2985, 5695}]}, 
         "0.1`"], Annotation[#, 0.1, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1Ftsz2ccx/HHdqEL1Sp1nEbRYZuo1WF140IvxBKky6YLGiQzZnPKmPOy
JW4WG41jR0rNqLEaYTRDqNNaiq1FHbY4JUNRrLpsFt3riYv3//M9f5/n9/vl
nz5xeu60ZiGET/z8mhJCGVa1DWE1zqSGUIU+7GGtQricFEJdyxBW8u/RU2or
kCO3XGwNXYu22JscQirdQ++q/UXvHXpSfS17m/rBLULYSktQLn4MR1GjrlrN
b7ScbjCjCMWYoGef+vatQ3iNvopz6sbzz9J9+u/Zu1ldJ/bLaI+O6IBs8S16
Hph1gD/D/WbiEPum/u7tQpjFP8xfRpcjVayADmkTwtDEEAbZNRAb7Ql6HtEm
c1+M+/h1cp3pG+qz0I+fhblq0u39lB53hkyxTPm+GKT+T3e9jevmXcNidflm
LqI5aociR12G2Gz5OWg07yr/qfh8Z7zCbi3+RXwe+j4yb5T5uc79mdjb9AO7
J+N99FA7iXZ1x+NypWacoFf0bGOfoWX803Q/raJb9BTJFfLX8b+hRfQ9+g4d
S9+yq4H9BBf4B+IzxkHsd9aqeD6cw1Zn/NtZq9mlZifIJ7rXOPYOuR+w2BkX
YSEa1bVU8xd9Evegzp4GM5bq+xoL1M3HWbvT5LrGZ8zuRt+kXzpHD/YDz+tz
diVO4xS66GsQn2T/NLPaqW90hrX2FOIfdpnef2lfueZiPZEg1oteorXoIH/T
vI4026w0eivOp//Fb9+OEvwkl+Q+BXYl0wT7X0JznIzvA3nqs/T1xxQ1U+yp
lq+J71DsmPyHYlPRG5vt/1nuY/Hv4jvDsPjtOe8z9fNoM36JeKBt0E+szFky
7Eux43V1k/kDnXE8/6m5aWamoxuS5VbhqB0j+d3jWeJ3pe4VmhHfgfxOs39E
JbsC5erX27HU7q9Qb/4SfpL9D9n5dg2gmfYXs9fQTXQF3W32bf0r2WP0TtCz
U2wirec/jO8U1fxR4iMxAvn80eLjaDFdTzfQdXRjrDdze/w++TX8Q/QizaPD
3SPRuYebU8GuRLb9gzFa/oj4uzRXfbHYfbMOx/8H9g7n/pZup0W0wL2+ZxfS
XfSEut/1Ndldr++PeIf4X8J/AbXoZfcl2pte13cNTXpvxP8sXMBjz7eGNoif
T3n+X/4/0qvhjg==
           "]], 
          LineBox[{5686, 5750, 5702, 2964, 5758, 2948, 5726, 2956, 5686}], 
          LineBox[{5694, 2992, 5734, 5742, 5718, 3000, 5710, 2984, 5694}]}, 
         "0.08`"], Annotation[#, 0.08, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1GtMl2UYx/Eb2wAlDgo4ShjZPKSCzQ3mluXc2qRm5My2BNswX/VCZZhL
WrK20qzliwZtCastxVclFkotlYN4GIuUdOYBwqGmoAi5ImrQln3u9eLr776v
w++6nsfnz+yNlS9tSQghrPXPgswQlqWGMHNGCE/RJ9zb00PYkBLCrxkh3MQR
ubMPh/CM3HI8jRVq78gN4QaGp4dwF1PUfpQdwh4sUVeMotinvpAuxkIUYBEG
0viZNc7jT0ya08tjgj4n/6K+lbSUlsQ+vvlyhTRRXTKS0Id6+R5eNfbYgV3q
VoutiR7uJTjk2Y6L7zb3fVSbuco9VXyXfAffq+rTaDoysFRNLS0XX8tvPX2Z
tupr1tdg5nH5D/m1iHXz2WefMDOEMbn9zk1y3Xx+xLPOV2gBPUuP6T2KJ937
aSHdmhXCNryB8+a1iF+gt+Mz0rfEF6t7k1ZjO27J5eGIcz4N9hg1ewRT9QzT
e5giPk6zxcbibrRT/SmcRI77VJqoLhmXzXnFc0yI9clN0l9ij51OYBC3MYRa
z9Mv9zE9j5/wCf7VnyN/h1+K/aZhrrql5r/mnb0q/jbfBjUfiL/ufknNZrpX
rB414pvV7KCbaBnPK3Z74P9gltgqc3Jpqlxa/M70tvFoxRz9082ZR/8Wn4w4
T9B/aCOvfHWPYTnPz3l9ht38Don9peZrOh/fYLX6Tbgo/jNeEEvXV0rf1bPV
/J20ir5H15tTjiLPW0a/wqO+j1zMwiCvPXJDtEnuIBrte0CsgzbSdnrYs7bR
cr4b+K6jFbQs/o7tm22XLGTimvhJ+hDtsttcfcVq5tAz7gdRb97zZjWJddBa
c/LsMyJeF78X2ibejlZU8BswK1PN45iNH/g3i3fT6/G7o494D6PxWzHvS+cV
8ftxXkbH6O/4nn+i/mQkodcOW/j8hpV2u09L6KfRy3kEY/gjvu/4e9JfShvk
95u1T/yw+S3xN4DL8W+J93WJdtF2tZ10ox069Va5X5Q7LZbgvpfPOJ8v7Nbi
Xuteh2+dv0OP2qty52gl/3fUVngnPVn//x39D1VfyiI=
           "]], 
          LineBox[{5685, 5749, 5701, 2963, 5757, 2947, 5725, 2955, 5685}], 
          LineBox[{5693, 2991, 5733, 5741, 5717, 2999, 5709, 2983, 5693}]}, 
         "0.06`"], Annotation[#, 0.06, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1Ftoz3EYx/EvNtrMTpgzW9gU5hjm3HChKVJuFDJjbEIkhTanXDheyOnO
IW4kzIXDtlyY1WwjSc1hm7OixBZtxnj9cvHe5zl9n+f5fn//lpG/eemmLiGE
VH8OJYdQ2yuEw3R1Ygj5+Mof1CeEgeiSEkJvfktqCPF0lFgr7SYeg1i0JYWw
rGcIiexnzo9JCKFDbCztdG6E+j90OO3oHcJvvFLbiCb0MfsEXsufpA/6hlCF
+5im31t6wNxPanulhVCibpMeK/grkebMVPlYtVNoDqYhU91BZ7PoX/Oz7dNV
7TjaoDbF2eX2fs5ulx+qrk1sGP3Fn0i/IcHMIVFOLIs9CpmIU/vU2e/umiy/
WO+U6K34qZGNRCRhl3iRnXfSYnrVfgvNLkJn9D7YJ7YfpdiLPeiQz3eHS2Zf
RgY7HT3dYR0txBqsRQHumH0Lt3HFbt3VVdMedLr8DExFTvS2yNV/sHsMwkCM
tke8fTvl4uhn+XLx9/r91OMz/UHf0To8slML/5vaVvqY30BP8z/o9Yq+p6do
ufoHqMY2O21FDXuA+gvuWmzmE/ZGepFfKd+f35Qc/Vh9Q3ucFc8TbxZbQofQ
HP2Pi4+RH4vBYlX8+xjNz/LemRiJG/rU6llGtzh/z/x+/Ap2JbsCq9z5vLPn
sN4uD+WL6AbE+u4xyNb3kdomuXTzGmk9v8DZj9Hd0WBGc/Qm4rnqd8uNF5+A
RXaeb588uoCewWlMskea/pPpRLw28w0a0YwmtOuToGcbjY++E+6as0N9odg8
XJO/jhj9S+T3oBTPo9+2/Bz2XMzEbMzCC7zEdvcuo3Vqb9J6elTsGI4g15wv
4i361KT8/x/yD84Tm70=
           "]], 
          LineBox[{5684, 5748, 5700, 2962, 5756, 2946, 5724, 2954, 5684}], 
          LineBox[{5692, 2990, 5732, 5740, 5716, 2998, 5708, 2982, 5692}]}, 
         "0.04`"], Annotation[#, 0.04, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl0zlPVGEUxvGDqBBmBmaGmUEhMWBhoBFQAWNjZ6GdMTaghXYu0FhoxA/g
p7BQK3CNWmBhFFRwL1CUxbggMZEGhUACLr8biyf/c573ec89906m6Vjfwd6y
iJil37mIIl3LR1ynR+mIoeqIWmzIRpxQn6Rh/X0s4Az/lPo0jej/JDOwhOlC
xEox4mgqIqMeqokY1Y9Rtf5zJqIGH8vn8Ks+i1/wmewEf069KN9lxnPeJG+T
zDy/hD+wLrnj7BvN0YhdGuVSdmvCfvcv0IDcIH1X75HZjPXUkJzJvsZV87bL
rGG3zD7P7cEumvJOOZk8Dcq/wb9yrfLhfL/sEq+C1+y5WZkWfOFs0V6/aFyd
NidFVdQou+pbn+f30yEzls1o4re5O5l8f7k8NfOi1rvw1mOLvgzLaR195Pe4
XzCvSHnqNKMW79lxxnmHvs5eu3A6+Q3N3Ys79UX+DpzS35XPudeur8Ys1VC3
+eVyhzHrbg0t2qNFvg7XZLZihn+Ht+SdC/qfVChFLOA8rxIXkh3xr3m3ZG8n
v6ezA2av8s7Z4yxdVG+zx0bZlBkbsJOf8p3SlKFXMpOe+YHeU4fzq3SZrlA7
TfArZCvppfw7/Vsapzbny55RZf4KntG3ymxRD6tn1bvtdZz63J9K/hv2n07+
C1iPD+RGsdyMMezV99ET9Q2Zp3gTSziID/GTuZe8d6e5R2iAv5b7/1/8B8Os
emc=
           "]], 
          LineBox[{5747, 5683, 2953, 5723, 2945, 5755, 2961, 5699, 5747}], 
          LineBox[{2989, 5691, 2981, 5707, 2997, 5715, 5739, 5731, 2989}]}, 
         "0.02`"], Annotation[#, 0.02, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, DisplayFunction :> 
     Identity, Epilog -> {
       GraphicsComplexBox[CompressedData["
1:eJxF03lI02EYB/BpmqVRUKlJimc2LUcYHvNg4VGu1JlZqavpZnlSmV0qlDMP
DCwZmujmspozjzkTLHNsTScy0UXpbM7UNeeB2y81c0VaYAX2vC+8vHx4vu/3
v8eZcS32sikOh4v6e/+9BJKNYWNjWYrbPKJt9Ktpb5fABe9UWC99Eazn29n6
2X8Be36O2L5rygBu2MMzjt/Xg/uogw+lpAWwfb29U830PPhUKDVP+WAO7Pgr
lelBngV7CbnMnEUdWHvzGUHVNA3OqGPx6jK14Ph7Ca4CFw0Yj3lQ455MgLOi
Y0p0M2pw4g1KsK+vClwpXYiRvlaCSabqcwSTYXCmWpbNX1WAg2oL94ly5eD0
qZWJBFsZmKI93DbgJgL7SjljhmIhmPj1YoompQp8qGjZsudWJem/2+VLzQXx
7WAJedA/QNYNxlqeZ0THy8DcNgLH+EoOFtNLrY90KcD5e2s/UnYPgxUfRsNG
2Erw9SE/9wobFbjhfZh16oAaXC7oarKInACbVI6S+8w1YNvmVnlDhBasesF0
NS+bBlNbPUtzdDpwEMcisP/ALHimovuHW/EcuNO1AHOenAdreXe8zRwWwCP4
cOZqrh7syA53GpAYwNUtCWvE3xhYKQ0Zf3N2EZzVS7NyqFkCb+4D2MgLFBxN
QvsRyRTl74xEc9YKfqi2Hc0nn+7os/6G+iRJ6d4WjSifXFP/STGG8m4dPml2
/Shvls1SWeah/G0K6dEWJbIcS2TMY+h/BPEkkSNE//E/+U3lDJRnj51JLhEj
x8o9xYV65PzH/u6r31Ff4t04lws81BcQ9JIVdR7lBftp5OMdyJesfPghGuRj
RU7KHiNyXObBsrV11M+oH68Wc1F/KM1nq/A0yncGz0gaW5GveInseGpkMp9/
wnkZ2Y/OoSWvI/8BvPBPPg==
        "], {{{}, {}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[10]], 
           
           LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,
             12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 
            28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
            44, 45, 46, 47, 48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 
            55, 74, 68, 63, 59, 75, 69, 64, 76, 70, 77, 50}, VertexColors -> 
            Automatic]}}}, VertexColors -> CompressedData["
1:eJx11H8w1HkYB/CNi9opu+gHqu0qJXuEWD+a9Kizd+ooIcXhKqQfGyoO19VV
qFUTofNjj8LQsEw2xHaHcHIk2ShhEsd89/d3N9XUqrXd9sc999f98cxr5v3H
85l5nmc+qw7GBUQbUCgUP30Z6qt4ZpeoclYN/zo+G8d2/6SG5eztpi4rJWhD
+3HBISoJQcd36AQBU+gJ69hPm7oUYKexrjl7dwI1qTzgwZTIQaitc2Z5jKE9
T4u5zi5y4J0y/W5T+AjqnWvflJElAw7VrHOn5xBqtndfrxtVBoIBgu64bRA9
qREZzLsihXnNUwOP+SI0+KaoL2m5FETTyS7Zc/rQdYuocavaJFBkGNNe/rAb
9fU6Fe1+SAIWvIWUrK0P0OePquW9VhKITyf3F37ZgTJ6zbsXDIuh5M7BnCGb
VtT0pOU3ujwxSBf43gum30MvnxN+e3u/GCa4zdwtNg1oQ3od289ODPSZWy26
gVp0tN9nhvaJAMGDrBAGUYkygri+y0YJuPbQJ9M+pgx1TystPt1EQNu7CH5l
Bg/NCehqtywi4Nzd1b8YhGejHsaBd8pSCaAYBmqXZKWht2P9e1rj9fnWCk/2
0UR0yMJ2Q1GkPtcFvpyzOvw/TSr2OIbqc/80ZqfWFu2YbFON79HnlJKWvGob
dM+bNbmDn/MwBqvvjwiUlu5clvC5Tyu3L68nAT0rcKY5fX53vZMR1zodZSnr
qBdPELD/flPeC2E2qpNll+anETCh2Ux/ZslDC8rOXVXz9HN4TfgYXy1DFyY6
/MwWEuCVHlM+p7gS7Rrg1POG9X1cxtN/TaxFrXav7F4xS4Bj007XN5p69H1R
QdIPTP0eLUYOfzwlRIMb61OYoWKwGExf5i1vQX/MXXv++HV9rhu/MdTfjl7g
50zufqK/nyn2/LWKTrTyTPyxAnP9fS52COHwu9Gl+bHGGZES6HyUUOqQ+Qil
m67UpDZKwKvxyFhKiQilbt/8odVKCkYUk2wjt0G0hv+846sMKTAV+4S25DN0
o03U9hdaKcRXM1xWfz2C5iyfG+F4RQYTIbpCv5EXqH8Uv9DNWg5W4us3vU5P
oPPLnFhtg3Kw+81Tq3adQqNeHqn60KwAul/Y0pwbYnRuXI/xxXEl/N+/9P30
moQxgQztqWhcd5MgQXtWXc8JkqFBzArx4y4S+KmhyZaXFGjmUPdA+AUVxPq5
JSaPStB+y5YnAz4k3P+4nufKVqDyQCE3hqMCpXnY0rhnSrTcKKGuf1oFh8/Y
J6e5StA+W9p6OzMSXANJg7VuctTsRHn1ATMVJETmx1XdUqJPei/95D6pgi3k
7/QzHSR6f0Ya+tRLDaxr9wadZGK0edRzOlqjBPtt3uOF7TKUtoSzw1lBwraC
ErsGsQJt3zhhsrlMBa5GytGQUhJtqdl5o5ulhi+06oLgoyq0RreL+1eyGg6H
Rbdk/SlG+xhJ10cVSojwcReZXZahDzvMXgmGSVi4bMvlubkKtLZ+0Ya9F1UQ
IqKFeFuSKONV7QrOPDVYS7JgMkCFNr13WPwuXg1tHsaE1d8qVNGy1zeiRA1U
VtVzrUCMGsa4F1cRStBqHDKN4mRo1SxttKafhCiP1/sSjynQVea3VtikqCCK
qWESY0o0KXJWWPpWBeXTTm+5r0nU7WP07mF/NaTQ8+1SRSp0MHRj1BBPDf8A
TlOcKA==
         "]]}, Frame -> True, 
     FrameTicks -> {{False, False}, {False, False}}, GridLinesStyle -> 
     Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotRange -> {{-4, 4}, {-4, 4}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{{}, {}, 
             
             RasterBox[{{{0.148, 0.33, 0.54}}, {{0.38192363591998607`, 
              0.4379284343488769, 0.5945560734527878}}, {{0.5608586818454426, 
              0.500812955281146, 0.4893674202569922}}, {{0.7397937277708994, 
              0.5636974762134151, 0.3841787670611965}}, {{0.9029918168844019, 
              0.6274795422110048, 0.2992746323416459}}, {{0.9315756900354334, 
              0.6989392250885833, 0.38788463910984333`}}, {{
              0.9601595631864648, 0.7703989079661618, 
              0.47649464587804063`}}, {{0.9887434363374962, 
              0.8418585908437404, 0.5651046526462381}}, {{1., 0.95, 0.75}}}, {{
                Rational[-15, 2], 
                Rational[-225, 2]}, {
                Rational[15, 2], 
                Rational[225, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[-225, 2]}}, {{7.5, -112.5}, {-7.5, -112.5}, {-7.5, 
                112.5}, {7.5, 112.5}, {7.5, -112.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -87.5}, {
                    Rational[15, 2], -87.5}}, {{-7.5, -87.5}, {
                  7.5, -87.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -62.5}, {
                    Rational[15, 2], -62.5}}, {{-7.5, -62.5}, {
                  7.5, -62.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -37.5}, {
                    Rational[15, 2], -37.5}}, {{-7.5, -37.5}, {
                  7.5, -37.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -12.500000000000014`}, {
                    Rational[
                    15, 2], -12.500000000000014`}}, {{-7.5, \
-12.500000000000014`}, {7.5, -12.500000000000014`}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 12.5}, {
                    Rational[15, 2], 12.5}}, {{-7.5, 12.5}, {7.5, 12.5}}]]}, {
               
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 37.5}, {
                    Rational[15, 2], 37.5}}, {{-7.5, 37.5}, {7.5, 37.5}}]]}, {
               
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 62.49999999999997}, {
                    Rational[15, 2], 62.49999999999997}}, {{-7.5, 
                  62.49999999999997}, {7.5, 62.49999999999997}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 87.5}, {
                    Rational[15, 2], 87.5}}, {{-7.5, 87.5}, {7.5, 
                  87.5}}]]}}}, {Antialiasing -> False, 
              StyleBox[
               
               LineBox[{{7.499999999999999, -112.5}, {7.499999999999999, 
                112.49999999999999`}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{7.499999999999999, -62.50000000000001}, 
                    
                    Offset[{4., 0}, {
                    7.499999999999999, -62.50000000000001}]}, {{
                    7.499999999999999, -12.500000000000023`}, 
                    
                    Offset[{4., 0}, {
                    7.499999999999999, -12.500000000000023`}]}, {{
                    7.499999999999999, 37.499999999999986`}, 
                    
                    Offset[{4., 0}, {7.499999999999999, 
                    37.499999999999986`}]}, {{7.499999999999999, 
                    87.49999999999999}, 
                    
                    Offset[{4., 0}, {7.499999999999999, 
                    87.49999999999999}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.04\"", 0.04, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {
                    7.499999999999999, -62.50000000000001}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.08\"", 0.08, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    
                    Offset[{7., 0.}, {
                    7.499999999999999, -12.500000000000023`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.12\"", 0.12, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    
                    Offset[{7., 0.}, {7.499999999999999, 
                    37.499999999999986`}], {-1, 0.}, Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.16\"", 0.16, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 2}]& ], TraditionalForm], 
                    
                    Offset[{7., 0.}, {7.499999999999999, 
                    87.49999999999999}], {-1, 0.}, Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{False, False}, {True, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {Automatic, 225}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 
                 RowBox[{
                  "0.00044473489780827837`", ",", "0.17536854503302018`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.02`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.04`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.06`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.08`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.1`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.12`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.14`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.16`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}]], "GrayLevel[0]"], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.6508106723511457`*^9, 3.650811575989161*^9},
 CellID->601690876]
}, Open  ]],

Cell["\<\
More detail is revealed closer in, but it is still not that instructive:\
\>", "Text",
 CellChangeTimes->{{3.650929022686602*^9, 3.6509290320623713`*^9}, {
   3.650929090644156*^9, 3.650929104107831*^9}, 3.6509731719207363`*^9},
 CellID->781908485],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"ExSqrtDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"EzSqrtDisk", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SqrtBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
       RowBox[{"ArcTan", "[", 
        RowBox[{"z", ",", "x"}], "]"}]}], "]"}], "2"]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"First", "@", 
      RowBox[{"Plot", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"ColorFunction", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y"}], "}"}], ",", 
           RowBox[{"Blend", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"White", ",", 
               RowBox[{"Darker", "@", "Blue"}]}], "}"}], ",", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                SuperscriptBox["x", "2"]}], ")"}], 
              RowBox[{"1", "/", "2"}]]}], "]"}]}], "]"}]}], ",", 
        RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", " ", 
        RowBox[{"Axes", "\[Rule]", "False"}], ",", 
        RowBox[{"Frame", "\[Rule]", "False"}], ",", 
        RowBox[{"PlotStyle", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"AbsoluteThickness", "[", "10", "]"}], "}"}]}]}], "]"}]}], 
     "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotLegends", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650810504192172*^9, 3.6508105742224216`*^9}, {
   3.65081060923237*^9, 3.650810613438971*^9}, 3.650810731067524*^9, {
   3.650811506105813*^9, 3.650811514942278*^9}, {3.650929006694335*^9, 
   3.650929016439949*^9}},
 CellID->1435267006],

Cell[BoxData[
 TemplateBox[{GraphicsBox[
    GraphicsComplexBox[CompressedData["
1:eJyEnXmcz9X3xym0WLJEpSIlJdkioXJtlSWyL2mzRLJLlhSiqJAla1T2RJE9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     "], {{{
        EdgeForm[], 
        RGBColor[0.148, 0.33, 0.54], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNmguUllW5x9/5ZgYYZgammWGGYHDmm8FKRUMtEkzMS1h2zNsRFFG548BR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           "]], 
          PolygonBox[CompressedData["
1:eJwll3lw1OUZx19yQOKSoFl2N+xu3MOgcrTjDUWdDgge7QgUj+JJQB0J0ULR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           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.35010824805008983`, 0.4267473076214373, 0.6132590490695958], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFm3mYVNW1xW91V7fddFV1W9VV1VN11S0aBXyKA+IACQLPpyiCAwg44RRF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           "]], 
          PolygonBox[CompressedData["
1:eJwtmXd4lVUSxj9MQEJCArm594bU+90EFVh1pQoodS2oAaSFooKICq6oYBdF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           "]], 
          
          PolygonBox[{{9407, 1456, 7257, 7267, 7268}, {7259, 7258, 7257, 1456,
            9390}, {6832, 6831, 5920, 1429, 9337}, {9320, 1429, 5920, 6822, 
           6823}}]}]}, {
        EdgeForm[], 
        RGBColor[0.5054106468014115, 0.4813264253934673, 0.5219630702509275], 
        
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxNm3mYlMW1xhsYmIHp7iEzPT3M9HRPf4PgGo2JuMRdAUEBUXbXiBsqIC7I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           "]], 
          PolygonBox[CompressedData["
1:eJwtmXuAztXWx3/GuM+4zO1hnplnnp9xKTk6elNKQiJ3GQYjdULKnRFimKGD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           "]], 
          
          PolygonBox[{{8359, 8358, 8356, 1054, 9541}, {9534, 1054, 8356, 8367,
            8368}}]}]}, {
        EdgeForm[], 
        RGBColor[0.6607130455527332, 0.5359055431654973, 0.4306670914322591], 
        
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFm3mYlMW1xj8YGGZ6lkbo6Vm6v94GFUUETWKCglti4hJ3BUVAEaOJRlBE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           "]], 
          PolygonBox[CompressedData["
1:eJwtmndg1kXyxr8ppEMwCSHJm7cmEASpelZQsFME6S1Big1QQIJIUcB2Foqi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           "]]}]}, {
        EdgeForm[], 
        RGBColor[
        0.8160154443040549, 0.5904846609375273, 0.33937111261359076`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJw1mgmUlcWxxz9nmLn3zoozc/d17sjigkFRxAg+3MU17gqIKFE0KhgTF7LI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           "]], 
          PolygonBox[CompressedData["
1:eJwtmneYlUWyxj+GSWcSMOHMmTlp5hwGiQqysqAgKJLNAVeRsGBCCSoosCAD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           "]], 
          
          PolygonBox[{{7019, 2138, 7018, 9072, 9073}, {8192, 3076, 8191, 9496,
            9497}, {9138, 9137, 7018, 2138, 7024}, {6587, 1856, 5491, 9185, 
           9186}, {9059, 9058, 5491, 1856, 6582}, {9489, 9488, 8191, 3076, 
           8197}}]}]}, {
        EdgeForm[], 
        RGBColor[0.9113926266861624, 0.648481566715406, 0.3253171427271035], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFmgeUldW1xz9hZu7MMDPozO3lu3eKBbAhIopPMDpCLFgwBEvUxGiMoPB8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           "]], 
          PolygonBox[CompressedData["
1:eJwtmnl8lcXVxx8wISvYJvcm9yY392atK1hURLBiWYMsvkJFFASsgCtL7QcE
KSBrAF8R2RQCitaVRSyoRcUliICASl1Qq2KVRaCC7KsK/f4+v+ePk8w8c5aZ
M2fOnHPmlt02tPuQ+kEQXMOfNP5fHQmC0bQvyw6Cc5NBMKGI/+lB0BD4sCAI
JvJtKmMZGUHQPBoEfwAuoP/PzCA4WhwEHUqC4ImsIPgPPE4WBsGM8iD4EtyV
0N9Nvz7QOycIegE3poLgs9IgeCM3CGrBP54IghL4j6HdEp5J2l+WBcEq0TO5
wcg/D5wa+qfo/4725cibg7ze5wTBm8gfDbzD2FHoD0HfjPmV0y4DjoL7NvLe
YS7/OpfvFUEwKD8IHq1nnOOMfwjPsdB/Q38b9FXQ3wbvS+hn0j/OHMoaBUFp
gyB4j7VkIi/G2iegu0GxIPgFHr8DdyLfesP7HeQ9lWuZkn0CfXRD9lTm/Drt
VtC3A3cnNH3gfT3yrqDdFMhF3rVRy9b8j8G7nG+t61k/FbQbFVsXNchflMf/
Uuv6GWQUsb4uUe+l+OWAfzBp3VSiw24aC/X3FTqfx96P49sD2tOqILgQOMR4
CvyzjG9m/F34P816bqa/HF43MP6C9ptvrWmnJz1X6TSNdr2kaUv4Vp/2kALv
5W9+EwTnM7+/oKN59bzmCON3YRN9mNt81nAF+h3Nt0mMVfPtk3gQ/MocqtiP
nuj/CeR9j32sZmwDPGvhPQF9DECfdfS3Qf8Z+Fngl9L/gP05h7VdTP9m6BvB
Lx95L4D/HHPIo10H/jHmGwf/GfCXIf+qLPNYSnt4zLYmnUl3+5H3EvRLoR/L
WiaG8rVHV9MfQ/+2TNukbHMnc9pI+1rG2zF+rNhn52X64+mX0y+H/xfwnw3/
mdhjJu0E+ujCWTwe8Xh/eDRg/jPg9wtjKXTQmbXNBj8b/J3gzKL9AzaWwBb2
gTMO3GV8SzGeBv1S2n9nfBj2/BfgPsbvAf5M+2v4TS/yN40NBRaBOwsdzGY/
PmLOEeiL0cemcD1FtF9g/hMYew17iNJ+CpoN6ZbxNO3G4AxE98vg34v9el48
mE8TcPqwng7Ia699B3cMUI/2edDeiL/oxv7Mj9hW28BjBLx6AQ/QHgS/wzo7
4LyL/Mvhtwv++8DfkuXzVo4+M5C3lvE3mO9yaGvp5zM2ijWthP59vr0Kv2bw
u4X+Aui/QV47vl0F/YuML6bdkPGrGT8G/a3Q7wbnSeb6Nt8y0ce94ExAV0s4
k1nwzgY+hv4w347R7gH9UnAfLfFeVrJfPyOrlP4U+C1ivU9A+zI836/vNdQw
1pb1Ncuyjbah/Tnf5tP+Hh1tRl//YD4VWZ7DS7Tv49twYCIwCdgd89lYzPp3
SXfw/zHdNiJbeQt+R7Psvxazf6kSy9ecymhHE977OujXQb8ZnMcyfd7lSz+h
X5vpM62zfSk0rTO9Z01pN4SmO7rZChxjvdeC0yjX57mQsUTSvq0V0Av9HEj6
7EhnR2ifYb7L6Z8H/19pZ6GDPHSVD2TTHs+ejwMG47uGAFXgVMquK5kfcL/u
NHjF0X8H+DdC/llou9D/Iu4zobMxHpyR4D6Kv7sQ/fzakLWjn3djvgtXIb+O
9pX4sOZAAF494Dr5gzTzPMp8BiJ7APAustcCeczpt0A6uA2AeZyxvcheAc0g
5n2Ib1/n2uZqI74TdDfMQj9/Q94nJbYl+SD5ov0l9q3y0Zexnr8x54w0+8wx
tG8F7qb9W2Rcw/iOpOf3A9920T4AfdN65nGQ9hvM9cVQvw3Rzc6kcUV/h84n
6+uU6Ttfd//t0DQG/wTzXcN870taf9LxKNojktZlP+jfBP+bpO/W69FPJ/Tz
K2sYy1qKgYPQb2O9F6DfM+i7AH3Ppn882z51PLJnFth+9e2o7jL09W2uz99Y
eC0EZ2SmffwC2s3A+YL+etZzOe35zPcbbPl96DfRfx1+9XPsw/eB/yDrP4n8
O9D3bcxnMvhNkBeB3276G0N7XyOAPh/52ch/n/l+x100t9hnWTYdY6wAyM21
jbZFnxelvLam9BvT3hKelw+ADtA/Rn9Ypu+4R2k3Yn4NFRdgM92Amczn8yzf
Abor5pT4rlA/L2YZkqUY4zj6G4p9paVbZ9KdeIq3dFAL7ZusN8Fa67E/l7I/
FSX2lTrzOvsLQn1tRF9NoF9Ofxf9i+BRC6+uyIvm+j6NI79+eL8OlP8pMY5w
hZNEFwPBmQTuFuAA+hxPfzK4O5H3DP2zBfb1PYDr0c/foz6bu5H/A/r+Lm7f
qTu1ObIHcPb6A//k+yqgTcTxYxNwauNek9b2BPJmx3zGxU9rPhf67nGPq78a
Xfyb/nX0L2ONlRH7aMm7mPEvGJ/HeGP6Z9DpHPzztLhjqfXs6bYyx1Tq647U
Xak7pFlI/yX01fSLNS7/w94Mj9sX6U6ORuyT1G/B+pux/k70kxm+43XXPxs3
P91Rn4J/c9Rr1XzmMt6H/pX01zG+n/Uuibt/Kf3vRR/1+nYDc4vsQ3XWO9L/
NO4YqzrE/yP66R/3Xac7b13EPlS+dAm0S4u859p7nbnrwH9Z8SfQlj1pB1yK
zTYFRiB3JPAsNCcy7POOsdcXQj+gge/zI4rXGE/P9J2uu70nPG4E3uT7W8AO
2tsrHKMqVh3OXIYBLzP2CrCS9grgFukC6IaMF0J9/AS/6xVz0G+Nfq9K2afJ
tylmCiL2kervYf/2KP5GVkfgPfDWxX3nSx9l8NsA/+lR66sG/HHgrwGnDtgI
bAKmsvYpVb4DdBf0jjt30h0diziHUn8y9GOTvgN1F8oHdEKfi7GxboF1spX1
/QTNRw18hnSWruDbpAz7GPmaZMy+TjFZivbJmGNTxZynYtahdDkZHdUAW5Hx
GfAY7XnA54W2VdmYbE0xlWKr8Xzrq71iPv2Bk+CeAh6E13vYXiZnbhrtgiLj
a/8mMddW+Y6F5b8Vm2+ivxF4GNoZwEu0l+d7D7WXN7An65nrTfIBtHcz9oP0
IJvTPrMXK5U3wOteYDbtWUAvxnpX2iZlm/1pD6i0D5Ev6QkErG07a+qZYZ8t
330/9jASGM4e3Qccg9dRoDO0XSodMyt2HgjNuUW+w/qF+7+esevA7Qrsg+/+
uGN6xcLKYXbTX1Hou+1j8M+iv59j9n3av2noZ0Gec8fPFFOynjMx49YA/8/4
0YjHFDMpdhrHHB8AboBvD2BozLmfbOI07Z0R27rOvM6+fOyWkN9djFez1lrG
WqGPK9FNV771SbMNNWd9RfCOVzlmUuykGHx0GEMqltwetS5qoH8A+uNx62MA
/u9h/N9e+nuAQ7IdoAbdTAbO0T0EnOXbGSCbdo6+xR0Lan3VEeeYyhcfgWdb
xsewB6OBi5lLY+DqAo8tBX9FzD5UvjQBdGRuS4jf6uS/2LPFtBcwx1rgUuZw
WYVtTra3Drr1RZ6j5qo91F7Kh8iXSKZkS6ZkK2ZT7PZ01LlVS+T347x2wobG
099Gv3MYAyoWlA6ly02hL5APkS+RT5Jv0h5qLxuy3lh95yC1pbZx2Xpf5t4v
YZ8u36475ybdHWF83Bx994g6plRseQe4dwJL4LEYqIZ3xyrnsMplK+G/gvFB
2Ng9OjvM5a8VviNkL4qRyhmfCryMrBgyp2gO4PYFbgZ6AXkJxyofAvm096Cr
3cB2+WagLd/aADcAPYA56H42MB14OGUfI1/TmbEuwE9h/HoR0J719EUf89BH
H+b7E+P/RebyTNecVHvSHaK7RHe+7v5TEcdbyqEy0PPvy0yrHKZpmXM+xTOK
iZQr/BvaL4E/opvWVa45qfbUD5wTtJ/j/D4LjIb3GCDCXPMr7WPka2Qzsh3d
SbqbZNOybdm0bPvHmHMrzflH5n4ceC3T96dyR9m8bP8CeF4I7Cj0Xas7RHfJ
Q9qfTMekik1157wX3im6W6ahg1fqmeeDtKeBM7XAPlG+8Qz0b2c65lfsPzfm
XEXfzjL2CTI+jvpM6mzKxmRrujN1dy4ocC1FPvIk9FH6EWC17uAK5+zK3XVn
XwTvUTHnJjPhfyd6m0D/sQa+L2rYm3tY66sZrmGcyXdOptxMPle+Vzm/cn/l
AC2irnGo1qGYsEOBY17Fvg1oZxQ4ZlHs0hV4BvwXCx07SuZEZPcDt2+VY2bF
zrJx2bpyQuWGj8cc3/fgmC6MOeZQ7KEctYHqMYXO9VWTy8h3DUy1sBZAyyrn
bMrdlPMp9/t9zLmCeE6DdmXEsaZiSsWWulN0t2iPtFeDmX81uF2Z8yDaLcsd
a+rbIc2Xb29nuCaSB68hMcfSiscfidhmZDuyYdnyTfDuWeU90l4pxpV81bR2
FHvOLcIYTLHYBWH9SmesH/zeZI6r446pFFupRqZaWRPk12EXk2KOP66BZjLt
bGRnyYdyb80Avox7L6TPnsq/4LFA8Rlj4/J8xjuHPkG+QT5Jvkk2KFtsj42t
wz63Kv+h/VaYjyhGV+x/Z8x3l85Ee/bjdmgHhnusvZ4Rt39UzD89bpsbH9aD
FIvoDq0J8w3dvX1iHlcOm5XvmohqI6o5qfbUjzn3zfMatJaHilwLUw37G/Sb
Sniuir9VK5LPle99A52sVvwEzVagDe22wHfAf4DNwAeVjokVG8tHy1fLB8kX
KWZW7FyqmCDXOYRyi3dUr0vzt1WMV8i+ch3DK1fZwHi7dH9bXeqcVrmtcrRl
yu/4tijXNaONCducbE/f3mLsYML2rxrSrfC+hDVuCulfhL5FyrHCVch4JeGa
r2q/z4HzEu15gmzPR7lFYblraaqZfAuvIGnfrhpDDH33LnMtWvWhXmXOmZU7
X4O8eeAvAL+W8fXQ16p2kHRsrZrGcuQfjDlemgHNq9BW6VzTXgvOBnAfSDqW
Fr5qIadKXI9WDf8E7VeTtm3l9HuZ79mI81Ot+YOka5aqXapm968S8xRv1fgz
GDuAzr7Kdf1Xbw9tdd+c45pNuzLXAFWL2EH/NLinSt1WjfxP4C+K+G1ENQvV
Lgaj32E5ril9VOgaumrpekNpX+KamWpnknkQ/GvQb6cc3wGtyv2GobeMrtCf
RBeXxOy/dKf9GVkFwJxc55TKNaVD6WYu3xbCr3GB7UU5vnL9FxOunYpmAeOF
Se+X3oSiyk8iplXOolxGbwx6a6iE5/fos125Y3ed6ba0u6cceyumn4+sZ1Ou
bcqn5UJfP+LcYSI8pyFvern1IXt5iHZl0rVAnW/l9o+V2fYUMz1K+wJ4jDvH
Pup82ktKnI9qTwPm80LCsWBzeF6O7MPFjtVEc0i1+pRz35nglBS6xqdan2pQ
qkUlGa+E9nn2fzv4C/ENj+e4BvMIsgoqXHuVDUQVY6YsSzmncs+ahGMp8Uil
nNMrt1cNugFjJ8Dpqvoj0JGxi1OuDcmmZdunge6q5wiHsc4pt/UmsUXxV8S1
Kb2p9VSslXRsJp+xLeoam2pteoM6D9wnWd+9jZyzDVddMuLaneZwLbixlGNb
vfltQXaHlGuTsrnqlGMsxVrSwTP0bylzLKocT7me9lR7qxpQPeTvTTqXVs1R
tVHZiGxlMDRzoV1UaFtVDV219N1J13qEr1ql3oj0VqQa9T76m5OuRamG9Yvs
IWle8kHzaeekXAv+Gfrz4dco5Vq8amAbWc8Z9uy8bMfsR5jPK0nHxqph7ok6
p1FuIx+0g/63Za7tqAatWrR8jnyP3ggPxRzTTg9zDOUaM8qcC6kGqlqofJ5s
WTats/6HlGsPbZjPWuZ3PesfnuPxQYyNAMbleM+198pZlLsohlYsnRV3fUAx
72nWf53erNJNMzLlN1r5EvEcInsr9FuacqI76VcX2z9J30cTftPR245sYkSh
cyrlVudjQ4lix3SK7fRmczFjreA/Ks01rHaKY4vsW/XtQtr7mOuPFY6ZFTvr
DUFvCdL5ryW+E3U3tgBaVjpn3hfmjMod9WYqfL0hPQ/tWcW0YU6u3Hy/ZBS5
BqFaxHBgWJ5jEsUmy8L3GeW4ynWP8O1wpWsOqj18EN7Fqnmo9qEaiGohdbTX
qB+3r1O9bQrtUXluqwY3Ou4cSLlQf/kO4Fn5v3COmuuOMBfSHDXXqaX2bXpT
09vat8jYJtmKFYDLVFNMd8x3O/uzIXx/Uo1Ktape4I7P9Juy3pYfp79Qa0HW
ZkGe83/l8M/D66sSv22pRv017XeSfptRv472wzG/darGP4P22UK/PepNJYg5
Z1Pu9iRzewpIS7jWrTe1dNrdSn229AbfnfbYuN8epTP9dmBKzLGi5vxcsWNE
xYqyCdnGQeZ+IN8xkmKlo+joSJFjOsV2ihkVO0qn0u39cef2sjG9xf8M7mng
LnDuzvMeaC+K4Fms/CJ8T1ZNvTnz+77Eb1Xqby9xDqFcQjGzYmf5dPl2xcxz
Yo55doXvA7obu6Z8t+qM6axtD/M11VdUa92LjvYAq5D7GvCnPMfCism+ZZ6v
l/qs6436DcVipY6l9JuGJ2kfTjj31J2t3EM8xEs2K9uVTco2JUOytEatVTm5
cnPZgGxBNTTV0kYWOnbSm+v9KdfoVKtTjq5cPWDNZyutc+leOa5yXdmUbCsJ
/ax052wDod8Vdz1LNvpD3Da7NYxpFdtujbt+LJrPtVeFvktVQ+ifck1Otbk6
9LImzzU51eaUYyvXro67FiYb7hB3TUu1LdVMVTtVDU61uBXQrgSGxu2fVCMa
HLcPky/Tb0g+LbWMutAnDA9tRLaiNWvtitEVq8sGZYviuSKM+RX7X5nv+qdq
/nprUM6r3Fc2J9uL5Lv2p5qXal/bilzrVPzxf9A/FPP+Z/JtOu21hf6tiGre
qn0/Vegx5Yt6a2oZ+kLVOFXrXFdo/qoxq/a+LM++WGv+B/w+TThW1m8w1pT6
NzT6LY3eyPVWrhhCsYR+o6LfqugM6yzL58j3fBS+vyqG/pD2/wCElSeC
           "]], 
          
          PolygonBox[{{9179, 309, 6581, 6587, 6588}, {6583, 6582, 6581, 309, 
           9052}, {6519, 1819, 6520, 6339, 6340}, {7492, 2462, 7494, 5174, 
           5175}, {5194, 5193, 6405, 1749, 6404}, {6524, 1822, 6525, 4695, 
           4696}, {7025, 7024, 4896, 308, 9131}, {5175, 5174, 6193, 1639, 
           6192}, {6340, 6339, 6553, 1837, 6552}, {4696, 4695, 6941, 2088, 
           4780}, {7570, 2519, 7572, 5193, 5194}, {9066, 308, 4896, 7019, 
           7020}}]}]}, {
        EdgeForm[], 
        RGBColor[
        0.9362013165825397, 0.7105032914563492, 0.40222408140587296`], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFmXu8lWMWx9+ovTudhHPevfe79zn73aeTUqQoSbnX6ULRHWMyHwzGUOSS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           "]], 
          PolygonBox[CompressedData["
1:eJwtmXu8zVUaxn/E2ThSc87eZ++z7+ccx5TEROXSNJHjltMI6apBc5gupBhU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           "]], 
          PolygonBox[CompressedData["
1:eJwtkjssZGEUx88S70cUM+Ne9tpMDIKNR0hkI2FRj12jF1FoBB2FTsEm4xkS
ChRiBdvRyBarJBgJwkomGvRLRWHD7+Tc4pfz3XP+53HP94X7hmNDKSISgTRo
D4oEM0QGXJFdR2QPYvjK8cXxLRSKLMIUxGGV+Hq6yJ+AyC9P5CGLIuh/ct4E
p1ikEK4552eL/MW+QCnnZ7VoI1BPfh08fhTpocY/bAX+AnRJdIfUOIJGNA1Q
S99++tZgq3RmdHfoEmjOYIhZQ8w8iD1Fn4BOiEIWvhtyM7FlaCPwH/8tfVep
seLZec0zveZ1wXfY8f9xG5tHfpI6+a7FVDPCPHP4Rh37H/2vGeIVzDKN/cp3
G8yzuzkYxxcmFg3avnRvb8Tv6bHlmVZzvBKRZv7xE/bJ31FvwHarO77m/Ju+
l/TNgVzH7knva9bv302Pb1DKedK1/jpHK7ktMOFa7IdrO9RdXsBKpsg5dpl5
kvR9DdjOyvw70bs50Ti642Lbte78A7N+ZuZU7Bdyl8ht9uz+9B5z/VnPYJ/Z
rwL23vTdDfv31+G/D30nlUUiY/iqsSFqNlE7WGKz6z8cwAZ11h17m/pG3wEV
Q2I6
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.961010006478917, 0.7725250161972923, 0.4791310200846425], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJxFmHvY1+Mdx7+dHvWk5Ol3+v6Ozy8lktJhPZXpIC6VJvW4NhM60VyXpHSa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           "]], 
          PolygonBox[CompressedData["
1:eJwtmXd0VVUWxi8JRAiIGN5L3n1576UCKghIkSI2ykgTlLhsoIBKdJQmRayM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           "]], 
          PolygonBox[CompressedData["
1:eJwtkMFKAlEUhn+FUZLcpKZjjCQ2r5FQPkGPILgayUW0jVzVG1SuFOkBhGoi
fYB8AlNcintdF/Qd7iw+7p3//Oc/50693bu6Tks6Ag/WRWl+IN0HUgA1yFSp
gaDL0W9I9RPpFDzqXfw9+r5glJEGFemhLD2WXb/l3ME3vhWeDffjnLQNXIZl
mdd6XugdkvGJ75nvJ2ih3aDdohW5F2ABU7QF2iU5F9CBD2bM0GIeFLFrxJkK
pTRM0d+ptxO/9Y3Jz5HzmsyymeGZe6e99xDysEffwZsvNbPUS9If+m/VzbBZ
Mf9lyYwZeT/JnrZvhPecnonvMizrH8FyMzc=
           "]]}]}, {
        EdgeForm[], 
        RGBColor[0.9858186963752943, 0.8345467409382357, 0.5560379587634121], 
        
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtmHmQ1NURxx/n7s6yHDszO/Oba2fYXdESCMeC4dRACARRNwQTxGNRwrUI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           "]], 
          PolygonBox[CompressedData["
1:eJwtmXd0VVUWxq+hhAQCgbyXV/LykkcSkRGkCOhAsCFliaKUpQwOfehdQbA7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           "]], 
          PolygonBox[CompressedData["
1:eJwtk1tI1FEQxj9X1Ipab7ubu6bmbj52oSI3fKseIumiBCXdV7AyKgofujzk
k0tGEBT2UK1SYQZFQhRIl80MCitQiEKiQJTCgvQhC3W7/IazDx9z/vOf8803
c2bKY0drj3gkRUEWuFwmtYELYA+O7AopXiwdnCW1YPuLpNcgEJT84E8h92ZL
5xfgK5d+zZWGfVIB50LQzZ04d+9hO7l3Cwj/v4XSA+K+EZ/F937+N4AS+FZk
SLcj0ilyd6Fh/XzpTFhqBh3cbwd3iW2B9w72akBKzZGmS6UB/g2CiZA0DhoK
pEZSBhdJx0ukY2CAvH1obuJcT2wMfICnHb4hrJfYJjT0Ud8b8BbkocuD1in6
MoWeabDSj/YcqY7/lSAK2ujDPLgzyZEBrwc8TGswLTNwp8ASYn9k0wo4KomJ
pnWb/lY0NKLlLLaa7w2gmvgZ4hcTf85iwDJ84/jC+DbSg+to2UHNa/GvAz3E
dPP/EfYTuT8XON2mvwbuWnLkU9dUxPXcer8PfwzUwbMdrIEnyb9tIfee9q4j
1PabXhRxfkbsJXieFztNpm059R2m3u/c/QkmQSaxY9y573NvbzMQxl8OvPh8
9OwKvdtCnh7yPYanhnNtyPXGevSEHBfJlcS+4t7LoHsje6sD1BBnPlrCbl5s
bk4zP61wZsKdKnTzanPbYbOKL4+82fDmGCrcvNvcXwOJMtcv65snrT0DO0rs
CNiLrpv0ezN9n7B3CLp6re4I9X9F4xewCl8X+k6Sf4i6e+H5iPXCkZveB9uL
PN5wlLcqIf4Ec/kCfYM+N682tzvJ1wvPMLG7OO8OOd2mP5+4IuJvUFcC+Dnn
+lxvrcc2gzaLq8EhclRhk+Ap2ApPgjqqA26vbb/HuNtP3CTnTbbjnJf63Z7Y
vryjrgTv8L44PZvpWqymZnz1/Kui3k44/7KXqVK3s7a7/wH62KQT
           "]]}]}, {
        EdgeForm[], 
        RGBColor[1., 0.95, 0.75], 
        GraphicsGroupBox[{
          PolygonBox[CompressedData["
1:eJwtl3uMVdUVxjcDwwzPOefcuXPvuXcedzBpqgIKohLBdlCsNoRq0WhMja0P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           "]], 
          PolygonBox[CompressedData["
1:eJwtmXm81lMawH9t3tv+/t663bV7e+veJIVW25iKhBg1acZSSDOkyLWUdiJm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           "]], 
          PolygonBox[CompressedData["
1:eJwllEtIVHEUxs9Y5jvvvc6MZunMaC6Sgh47mdQWUYES2SpskZFpUDNGLYqs
RU1JBEFBLaIXBCHRY9ek0tvooVbYKtMJgyJSC0otev8OZ3GG//nOd973TGRz
vCGWJiJRJB2pr+DHE5mJ9OaK7PSLNIdFtvAec0U+IfPhfAmJPOX9GCn1ieQU
iGwrF1mKvg6JZohcmyOSHxAJ5okEiDcKHsZ3mHgPiPcX/YwDF7868N/o/1yz
xch7oFhkgDgdYBfhnSBHNdxu3lNgp+GdI1YC3iC842Bnse2DN1koEkG/7ljt
W+EtxzeJ/g28DWwvWFER/aDfQmJZIhklIq/Ba+jpF9gfZAh9l9/sXehJJJ16
I8g73nPprZEeD0ZEUmGb2wzP6tR6Z4N/BRuGO4K4cHLwfcE7H94EttvE38B7
Oz5LwD36aWV+ZfDeowexFZKjgHm24t+Mzw3HetRej5JjE/YSeB/AyvFzmMMC
+niO/hL5yc7amVUfsQ+jn8e/A84QNa5Gv6R5M+nTs53obj6CVZErGra6tf43
SC1xo/gGmV85ug+fh/BG4Fyl7ipy1LvWj/aleTTfHbCV2SKLStkX2AWwI2D9
8PcX24511/fBGuDVlNo+da/3wNaALQNrpL6F6HVIJb6nyPmD/nzUkIBbBj7N
XIbA12Jv0p2Dxz0TfbeArceWgtPmt/rTPPv+9Q4Wk2cV+e66VqfWm2DOG5nz
PDivwPPgTZFX8O1Df4ZkgXURbxwsD14/WDZYLjLI2wH7jK3Xb7ekN1UEVkvc
HQHjqs+Aa/18J77DXDN5n3Rs3jp37U/7PORY/umQ7U53eBm8HbzHszvUe2wA
q0auMLtOco/iMwv7E7BMcsbIvYIaisHGwSrA9pA3Du+mY3ei96Lfvt5ADxLn
Jnb7jas+E659my1ab4nZu127O70/nY3OKIccY/CS+IbA3ur/CFgT+Y/pHYFP
YnfBUmqD84h3Jb11urZ7/Qb+A5MJph4=
           "]]}]}}, {{}, 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1FlI11kYxvFTjViNZqajluZaEYy2W0F7VAQt01hMRNEwhVlG2iIttEEp
Ula0UF2UIe0MUcFAZhCOUBdRQcUMtExKFMxlN2WhBX0OXXx9znnP+7znPed3
/hasqi6r6hFC+NWf/QUhZA8M4VBOCIeRYXyQZtKmn0JIp89yQ0ij17BsQAhr
aXZ2COtoziBjTJdbiceF4rQuLYQf1E5AQC/0QDt/S1YIdzAvI4RWWsa/CLtQ
z1divxHoqY9Vam22z0actraf1mK1eIr10fJG4Yi13fxLsQyz5CxQfwadhrf2
3TI4hBpsxnZ063Ur/UI/8D+V/8b4Gc3HaHXGYKZxrvM254VwG3PFOtTMQ4J4
Pv1LP0X0jJ4K6TnaiGHxPp37AIqGWkOa3AnmLzLt6/wf8RD1aj2gZ9Ufhwbz
A3gaY3rYazxJnynmL/JDeIn56lWlh/Cf8eQi0CS1n4v1pSnm/ZHB85puFF/A
s4m2m0/laYxxuUf0VU23mW9HFk+i+9kiN4GnhvY2n8KzI9aV+0osmfZDauxB
f9nGs3nnoETNefQfvf+LZPeXhFLn+yOeQ2w1XRi/F667k9T4TtTNtWceGswP
4bW88+70AhKNm2hvessex/lO+Mb3sVx/J9U6hRuxJn6TswaPfN/ymK/PTDWz
kIYMpGNx3FvNDvzizt/RlXpdgT04xjfNe5uOLPvXxlrqH8VI68UowRPe4bQO
tdjJN5ZnB/3fmSfKH8dbSseiQ9+V7nY91qHYGappIt1AE9zHI/nP9f+YXkEX
Xzde4SWq1WinS2hj/E24kwq+Xs4wCT1xSs8n8adxnbPWItkdJ+Ge3D7mbXw5
6gzGFXk39XuJrtD7Nme5bn4NTWKXnXORcaq1Lr7+UX3fH9W7G9+Lel/1mkhb
4psU/2T9Mzrld9KP6CPebP2ivC/yf3fmevHJztFtfkG8ig6VV+GdrcUH/jW0
HEPEN1ivkNdFO8Wuxv3F38d+9DXGWl/awlcop0H/f+u9DcX2+RmV1seLt8Zv
REe4gxKUqzU+/p748tUswL6C7/8/vwGdHbeK
           "]], 
          
          LineBox[{9577, 6903, 9475, 4792, 9298, 9079, 9220, 9157, 4742, 9144,
            6910, 9151, 5656, 9563, 5642, 9556, 5649, 9570, 9577}], 
          
          LineBox[{9593, 5756, 9585, 5764, 9077, 7023, 9069, 4900, 9246, 9250,
            9155, 4904, 9134, 7028, 9142, 5772, 9593}], 
          
          LineBox[{9611, 5976, 9603, 5984, 9397, 7266, 9389, 5098, 9277, 9286,
            9177, 5107, 9406, 7275, 9414, 5992, 9611}], 
          
          LineBox[{9130, 6573, 9065, 9296, 4790, 9468, 6891, 6886, 6896, 9241,
            4740, 9130}], 
          
          LineBox[{6586, 9063, 5499, 9525, 9533, 9517, 5507, 9190, 6591, 9182,
            4916, 9265, 4908, 9101, 4912, 9055, 6586}], 
          
          LineBox[{6600, 9036, 6605, 9230, 4959, 9267, 4957, 9252, 4958, 9064,
            6600}], 
          
          LineBox[{6640, 9041, 6645, 9266, 4745, 9178, 4718, 4795, 9301, 9251,
            6640}], 
          
          LineBox[{6663, 9097, 5589, 9547, 8365, 9031, 8374, 9540, 5596, 9261,
            6670, 9254, 4744, 9168, 4717, 4794, 9300, 9090, 6663}], 
          
          LineBox[{6830, 9327, 5928, 9501, 8196, 9019, 8201, 9493, 5936, 9344,
            6839, 9336, 5042, 9166, 5024, 9088, 5033, 9319, 6830}], 
          
          LineBox[{6848, 9050, 6857, 9362, 5069, 9462, 5051, 9452, 5060, 9353,
            6848}], 
          
          LineBox[{7010, 9209, 4894, 9240, 9268, 9242, 4895, 9129, 7015, 7005,
            7010}], 
          
          LineBox[{7247, 9371, 5080, 9423, 9443, 9433, 5089, 9380, 7256, 7238,
            7247}], 
          
          LineBox[{8087, 9014, 8094, 9479, 5899, 9434, 5897, 9424, 5898, 9478,
            8087}], 
          
          LineBox[{8832, 9594, 5961, 9453, 9476, 9463, 5962, 9595, 8839, 8825,
            8832}], 
          LineBox[{4739, 9119, 4706, 4789, 9295, 9208, 9218, 9128, 4739}], 
          LineBox[{4754, 9229, 4728, 4804, 9310, 9110, 9239, 9199, 4754}]}, 
         "1.8`"], Annotation[#, 1.8, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1F9sjmcYx/HLtjRZZFWd4q23eNUmlk2xYloTQ2Ip2dZyYBNtV10PNtHU
VkuWbNmJKgllDkiITjVKRMSq1VAOiC7rkrGQoqsgmCzOdkLHMp8nO/j5Pr/r
vv7cf97K1NRXbBgREbX+SWUi7o2JyMW7mIdz8yLujI+4zVflR1TTPX4t3sWd
r0a8jOPSEWPpvYkRq9TsSkUUjI2YIW9ALO27yXc+TsNZ1r9ROxf/nBAxDz+m
1fS6+mLsnxSxviCiz+w3CiN+xg38dv12UAv1mnlwckQbDanp4U9TF/2qT5VY
JR2Qe5/fjw+wFev0y7GX0VTiDPNpBL0ofhSP0UP7/cH6RbEjfPeUiAr7vTBO
rT6HxU7wJ2mh/b5Lk+UfED8u1orPzHpKH/LlNKx2WN5T7NV3iTOdxXXYLL5X
TQ/fbP0M7uPnYLX1bnwHK2ktledGlOp9KpmNKf3r7Wuh79lyO519Pf+3Xl/g
T3yT3I/UdlivwKP42P09oWJv/ja9IrdHzWkqUjOTttnHBf2bscAZ1+B5/lzy
fr4zauZgMY2Xn803y7vhDvP5FP3rzfPwGW71Rrvktsq7ar+l8jrNLsG09+6y
z27K13+B2DU5T+TOU/cYe/nP9SrlS6iY6tR/RrWURV3O9p9zdeIL/C33ddbM
3/iV9raKzvPl2ItN9nUq+R3oFVRkxlKzGsyZzm/GD/jZ4tl8Dr0kv0Xd4uT3
q88SXIOf0HS5i/jLztHorq+Y24C/49eYSs5HE6hBr6+okWaqvWRGxrk38VPw
oD6T3MWPeEh+G2XxU631Jb+B5H2xk/aryTYjI3cUvobT6JHc3Xrnyp3Kz7fv
NvmD3vkvef3JHSRvTEfEO2ixnMvi28Su4D9iw/Qd/z1li/3hjnOwPpkpdt/Z
HtCb5gyIj3T3162N8X0Tb+IKzJKzEQvVNOl5zpl+8UZbfJfRcmqX06LPiuRv
KPl7UduIe+35ELXTTuvfyhtlzqC1ib6HMM0XUK79PeKXqd2EZc6+nMr4AbPf
xy+dsw5v8NepxneRvif0f2hPg/wttS3u7457HErOTaOTc2AOtrr3tO8udfvU
7VF32JwOqhV7y/qn9lJDe8RmJW9NM6jaPquoMvP//8XPATuWy7o=
           "]], 
          
          LineBox[{9576, 6902, 9474, 4791, 9297, 9078, 9219, 9156, 4741, 9143,
            6909, 9150, 5655, 9562, 5641, 9555, 5648, 9569, 9576}], 
          
          LineBox[{9592, 5755, 9584, 5763, 9076, 7022, 9068, 4899, 9245, 9249,
            9154, 4903, 9133, 7027, 9141, 5771, 9592}], 
          
          LineBox[{9610, 5975, 9602, 5983, 9396, 7265, 9388, 5097, 9276, 9285,
            9176, 5106, 9405, 7274, 9413, 5991, 9610}], 
          
          LineBox[{6585, 9062, 5498, 9524, 9532, 9516, 5506, 9189, 6590, 9181,
            4915, 9264, 4907, 9100, 4911, 9054, 6585}], 
          LineBox[{6599, 9035, 6604, 6595, 6599}], 
          LineBox[{6639, 9040, 6644, 6635, 6639}], 
          
          LineBox[{6662, 9096, 5588, 9546, 8364, 9030, 8373, 9539, 5595, 9260,
            6669, 9253, 4743, 9167, 4716, 4793, 9299, 9089, 6662}], 
          
          LineBox[{6829, 9326, 5927, 9500, 8195, 9018, 8200, 9492, 5935, 9343,
            6838, 9335, 5041, 9165, 5023, 9087, 5032, 9318, 6829}], 
          
          LineBox[{6847, 9049, 6856, 9361, 5068, 9461, 5050, 9451, 5059, 9352,
            6847}], 
          LineBox[{9467, 4710, 6895, 6885, 6890, 9467}], 
          LineBox[{7009, 4893, 7014, 7004, 7009}], 
          
          LineBox[{7246, 9370, 5079, 9422, 9442, 9432, 5088, 9379, 7255, 7237,
            7246}], 
          LineBox[{8086, 9013, 8093, 8080, 8086}], 
          LineBox[{8831, 5960, 8838, 8824, 8831}], 
          LineBox[{4738, 9118, 4705, 4788, 9294, 9207, 9217, 9127, 4738}], 
          LineBox[{4753, 9228, 4727, 4803, 9309, 9109, 9238, 9198, 4753}]}, 
         "1.6`"], Annotation[#, 1.6, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1WtM1XUcx/GfU7fW6oFyCTTgHIpqpZCWgqxNMV1YqAkP2poPlOyyZUhe
8EkrWzMTGIMiKMwWcQmkLQjK28TVA3e0skkQ6tw0bEgmlbVYt7Ve//Xgzef/
vX1+3////M8hXr6ltGJaCGGvP8NpIXybHMJNdIT+Sn/DEHbPDaE7M4QrKSF8
eWsIpzElf1Vfp/y4fBvtQDsOoDAphJbsEPZhe1YIlbeEsINeSw2hcU4Ih2Ih
fM5nUlwo/5z687TXbB/OqA3hLmdcTg/hPjPv0zbsc92CSTMP6S3GTr07eFah
Xc828VZUosZ+K/RU0xEzw6jWM8T7hPtYY4fLGSHcrX7avZ5Bmv50rNQ3i8dM
fanipWZek1urt4HPavqyeCPdTJfTfr0P0grxV/qnm/tEbjqfY3R7tF9UM/+K
+/haz2fyD9ujiQ6In1IfVD+OIl6FPJ6hi3g84R43oUzPEnEBFiPF80vGlL56
PnN4p6OX37DePvq6fI3eHH3nnVfnuh579I2Kb5M/R2M0G/Eonh3CLnPn6Yf2
ifGfx283v/Xyf4r30iwemeiQn6XeSV+Vn2/XRfEQcukBz7YHqVjnmffxX0sf
5d0b7YjrzhigeearzC+gP9vxOtLMjervN9dj5mN6VnwO+SjEEtxvJjd6d3m1
0D30bdqMUnMb9ZRjOZ7EJhSYaVM/Tmv1D9K4+8lGq/y/7nOp837xfE7YJYHM
6P2Qv+rzeVa+zH7L9Bz03s/2HShynUTrxQ3YKq7gvY2O62/g/a7n0s9rQpwv
v1m9kr7HsxWn1L7AHfZ5wB45dEP0zqHZfBN+NFOjtxaf6j2MIyjXMym3hffR
6PtAfxJ32fmkmQSq9CR4fsS7RP2CZ3GnesK9nMJf4r+j56pvQryQ/iG+Xc89
zp5rZiUd8Bkvcz3Cv4iO0mn6a/WX6m10VhmtExc5L0v9Rmem22uMNsq/gQvR
/fO7pGdc/gce1+iY+HH1i+qX8BivKR5vOiuPRyP9XdwT/V6IF2Ie8uUWI+46
xqdbvQstPL6PduObId8azXjuY3zaXXeizh4XxQvkv6O59F7kYb3Zf8xNRO8u
r1z7lMhV83ta/ht7r6Kr5Iqj74OeAn471Uvkk33uKXjJszzk3dhFM/AiXsDq
6LPn3WGuGSvMNNGbea3j0a2nB53owgfYr7+ZDtrvLZpjh/30Hawxc4PZR+hZ
XkkYjX7vcUU9YfZo9F66jpmbSWegOPn//w//AT5L8oY=
           "]], 
          
          LineBox[{9575, 6901, 9473, 4715, 6908, 9149, 5654, 9561, 5640, 9554,
            5647, 9568, 9575}], 
          
          LineBox[{9591, 5754, 9583, 5762, 9075, 7021, 9067, 4898, 9244, 9248,
            9153, 4902, 9132, 7026, 9140, 5770, 9591}], 
          
          LineBox[{9609, 5974, 9601, 5982, 9395, 7264, 9387, 5096, 9275, 9284,
            9175, 5105, 9404, 7273, 9412, 5990, 9609}], 
          
          LineBox[{6584, 9061, 5497, 9523, 9531, 9515, 5505, 9188, 6589, 9180,
            4914, 9263, 4906, 9099, 4910, 9053, 6584}], 
          LineBox[{6598, 9034, 6603, 6594, 6598}], 
          LineBox[{6638, 9039, 6643, 6634, 6638}], 
          
          LineBox[{6661, 9095, 5587, 9545, 8363, 9029, 8372, 9538, 5594, 9259,
            6668, 6656, 6661}], 
          
          LineBox[{6828, 9325, 5926, 9499, 8194, 9017, 8199, 9491, 5934, 9342,
            6837, 9334, 5040, 9164, 5022, 9086, 5031, 9317, 6828}], 
          
          LineBox[{6846, 9048, 6855, 9360, 5067, 9460, 5049, 9450, 5058, 9351,
            6846}], 
          LineBox[{9466, 4709, 6894, 6884, 6889, 9466}], 
          LineBox[{7008, 4892, 7013, 7003, 7008}], 
          LineBox[{7245, 9369, 5078, 9421, 9441, 9431, 5087, 9378, 7254, 7236,
            7245}], 
          LineBox[{8085, 9012, 8092, 8079, 8085}], 
          LineBox[{8830, 5959, 8837, 8823, 8830}], 
          LineBox[{4737, 9117, 4704, 4787, 9293, 9206, 9216, 9126, 4737}], 
          LineBox[{4752, 9227, 4726, 4802, 9308, 9108, 9237, 9197, 4752}]}, 
         "1.4`"], Annotation[#, 1.4, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1X1MllUYx/GDtVyLbENA0uR9tdpMFxJWCygeoEwK33rVzVq5NSFbW1GG
tTBx5hIE3UCNWoNopk1d/lFRodmoAVZW9mI0s0ysVeAUghT63OuPL7/7Oue6
ftd1zv3wPBkPrVzwWFwIYbc/VSkhNCeGMDAlhCaaMz2EJ60dpl9iR4K8tBC+
8Jw0LYQ30Y4HJodwztr99A3xOjXxSSGspS/iLnV9U0O4L4r5JnuupTXiNdil
X6v4Bc8z1GfrUZIcwjx5m64IYYzvCs+PWE+VW2ctjR65PIRvcKn998SPqqnj
sREp8hPkT8avPH9Bo/XrzNUh9zI136qdRM/IudP+qdQQ+lEgZxkdszaOLdEZ
+HXSAzikzyEelepS1Ae5xWr+cgcTPMehx3kq+a/EXjUr6G66013ci2rxKlpD
63mto7XIV5ekfgriUc43kT6uz2Gz9OK4Pj9HWP+EZ5L7SESDeL78ATqIarmr
kaf2GO859Du9lsj5VF2amnSURPNjs/2izBBiWOhsi7EIzc67gAa15XRcPJ/G
ie+mE+g9tN/s+/mdpGvNd0qffXwzxJ3We/T82nOvuzyq5i17O/G5vTvUz8Mo
7yr6dPROUIYRa4Vm+odmZoXwYXoIH+EqXnPt/8ijD718YnIG9dmX4R5ob/S+
cAm+QqmaC93FXNpgxkZkuqNNtINXPd3uvbR6nihvJHof6kbpxeIy2iLnPM1W
d452632tvtusz6C76EzaY33cfps4uIsdtFw8ic8F4mZ3EEfjxW36teibLicD
acjCu849jCEUeT/Jzn29+8tDmbmu1KedT7faEj6leNj6en3+pRvoGB3HHnkD
4vOe5+hbz+MGulRNu7tLsPeEteVmyZHbZm02/c3+CUxVNw0teqbRVGwx02zn
zEWW/Ez8aX0p3+NqC6PPrdpq+6vxLJ7Hc8iTs4b+7h7/iFBXLf8EPYkGffp4
1NjLt77EO12sZpqaVExHoZlf5l+HRrkb6GZ30UQP8qiiMWfK51VKC+g19Gpk
8Rp2xyM4g1zxEK3Qq1vPLhwV/4Bjer3Nb6LzXYTc6DtK/jPWV+Ep1JlvI4b0
TOTRZZ6b5exSN8RrGC/JW48a+/neaQGKeZVGfqgwX5PZztI2+jGPgxgS32Z/
mN5ODzj3XnPsp8vN16/PO9G9iPdYb9Wz03NP9L2l/lY1RfjMXofP0AeosFeJ
0zxj9gbpjebJVve9M2TR9+V1qfnb3k9yF7rb7bxfiT5bfF+PPmt0Fs2THzNL
MW7BIiyM7pfHKF6Td5bXq7QWD8qfqS6H3iRvGz0tbysdpDF3WYRUZ0vyf5+M
bvMdkTvFXS6Lfqv4zUr8/7frP7XKCOQ=
           "]], 
          
          LineBox[{9574, 6900, 9472, 4714, 6907, 9148, 5653, 9560, 5639, 9553,
            5646, 9567, 9574}], 
          
          LineBox[{9590, 5753, 9582, 5761, 9074, 7020, 9066, 4897, 9243, 9247,
            9152, 4901, 9131, 7025, 9139, 5769, 9590}], 
          
          LineBox[{9608, 5973, 9600, 5981, 9394, 7263, 9386, 5095, 9274, 9283,
            9174, 5104, 9403, 7272, 9411, 5989, 9608}], 
          
          LineBox[{6583, 9060, 5496, 9522, 9530, 9514, 5504, 9187, 6588, 9179,
            4913, 9262, 4905, 9098, 4909, 9052, 6583}], 
          LineBox[{6597, 9033, 6602, 6593, 6597}], 
          LineBox[{6637, 9038, 6642, 6633, 6637}], 
          
          LineBox[{6660, 9094, 5586, 9544, 8362, 9028, 8371, 9537, 5593, 9258,
            6667, 6655, 6660}], 
          
          LineBox[{6827, 9324, 5925, 9498, 8193, 9016, 8198, 9490, 5933, 9341,
            6836, 9333, 5039, 9163, 5021, 9085, 5030, 9316, 6827}], 
          
          LineBox[{6845, 9047, 6854, 9359, 5066, 9459, 5048, 9449, 5057, 9350,
            6845}], 
          LineBox[{9465, 4708, 6893, 6883, 6888, 9465}], 
          LineBox[{7007, 4891, 7012, 7002, 7007}], 
          
          LineBox[{7244, 9368, 5077, 9420, 9440, 9430, 5086, 9377, 7253, 7235,
            7244}], 
          LineBox[{8084, 9011, 8091, 8078, 8084}], 
          LineBox[{8829, 5958, 8836, 8822, 8829}], 
          LineBox[{4736, 9116, 4703, 4786, 9292, 9205, 9215, 9125, 4736}], 
          LineBox[{4751, 9226, 4725, 4801, 9307, 9107, 9236, 9196, 4751}]}, 
         "1.2`"], Annotation[#, 1.2, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1XtM11UYx/Gjec3UJilo4DULBbdIozSJrQuIVkP+yMIJm9m8Iaw1E2op
2vJSOCtuAjpMM8MLlrU5SzNz5qw1/8CKP9SJePkjBRVQq2m9vuuPt59znvM8
n+c55/fj56i5RTmF3UIIzf65mxBCx4MhTB8ZwgzcPzSEG/bXcQ1TBocwTiwR
DYNC+G1YCKeQGyfPWR6dg74xIWTInyrWSbuwUmyFs1L6b6yG1ouG6Gl9B008
N8ufNyKEBPu5NJ6+RhfpsTY+hDVYjRFiw3GebwWfu2bd90AIOTy+U3MIW3ld
Gh7CZbTiIi5gvpwgt5zPJ9gmL1/8ipo4nifNlCa+mOcqfX+1LxTPdl5A148O
oQzz+MS6S7s3u4armMjrOv2F/7Nq09R+Zb54cyZgljd7V910eRv4zaDL7dPk
DzTDC/b96OxR3hRF/NPVF9InzHOSR4Z4Js7pM8icMShXc0btYev98kbyW8f3
jLyzaHfegRvYJe8PvX/HdjlNco/rkW3Wp9xvKo7yOcDnW7zhHi08ap3fUl9H
b9O9fM6rj5FzzvlG8dPepUntEbEf0RjlYQ+q5VThPv1a1PWntXJq5e/jFav2
LI9KsWpUYbDYGbEhNMlcE5CMsWLHefb2Hn1QYP46b9vf+h7enbz7i3XRnvZZ
tCJ6L7EKOSesb4r1cpbMq8r+H/tKZ3H6ZnnvWLnTabVYFWrl1OBnfXfTRtSK
D5f/oryh8l+im8Tq0N2d9sp5NPr+OPuIf7Z+X3v31eJX7EfTvu5zL/oh0VvM
5JeDyd79EfuHMTZ6Uz4D+Na7ZxG/v9HG43XaThfSBXjeDGXyDsi/Qq9iudgU
flm4LecvbHZ+wSzPObtsrv3mXWiGVLH59HG6gL6pZqf+DfgCk8QmYqb6Nj7D
fKYX9N/Jo0VNK9bzKvVOK9GoZpP7xMqZLSeOfim2F9/LWyWnQGwAzxM8x4vn
yS/S92P7TufldKV7vIc089bzSaejnY1BPHJ5PUSfib5Xzl+1rzTLK7TG/qhZ
i2mmfQbvabTEfiztoy6Ldvk8elr3wBL++WoOW/+AE3ofoTvc93P0MGdPpJr7
ovn2WNeZe4j+S/kOprvFdqFY3TIc1OMnMx2LftfkHIty9MhU/ySfyfhGfj2f
LSg0Z7NeS5z/qb6QJo7xuVqXyt3h72IFr0u0lA6UP875eX1WOG+ldXJrUey8
RKyEfip/G7biLft6uoxuoUvpB3zWoZv5PqTdo98T86zF4ujzFSvDafNsULNI
7H1na7Aaw8zQEr2/2av1rsFGbI9i6j6jze4/y93LsB5bo7mi3tFvv34pYqk0
w2dyWyzd+79sXS/Wqcdy59PEMtHpzZrETuGm9S104Aa61Pb2WT4tb45531H3
dvS3IpZMJyBXPImOR4f8Xs7avNUUNY/pmRL9xvNuxyTrg+Kp1uPk55snyV3y
aFv0nY7+5t07BYesG+TeSfj//9b/AMM4Il8=
           "]], 
          
          LineBox[{9573, 6899, 9471, 4713, 6906, 9147, 5652, 9559, 5638, 9552,
            5645, 9566, 9573}], 
          
          LineBox[{9589, 5752, 9581, 5760, 9073, 7019, 4896, 7024, 9138, 5768,
            9589}], 
          
          LineBox[{9607, 5972, 9599, 5980, 9393, 7262, 9385, 5094, 9273, 9282,
            9173, 5103, 9402, 7271, 9410, 5988, 9607}], 
          
          LineBox[{6582, 9059, 5495, 9521, 9529, 9513, 5503, 9186, 6587, 6581,
            6582}], 
          LineBox[{9032, 6596, 6592, 6601, 9032}], 
          LineBox[{9037, 6636, 6632, 6641, 9037}], 
          
          LineBox[{6659, 9093, 5585, 9543, 8361, 9027, 8370, 9536, 5592, 9257,
            6666, 6654, 6659}], 
          LineBox[{6826, 9323, 5924, 9497, 8192, 9015, 8197, 9489, 5932, 9340,
            6835, 9332, 5038, 9162, 5020, 9084, 5029, 9315, 6826}], 
          
          LineBox[{6844, 9046, 6853, 9358, 5065, 9458, 5047, 9448, 5056, 9349,
            6844}], 
          LineBox[{4707, 9464, 6887, 6882, 6892, 4707}], 
          LineBox[{4890, 7006, 7001, 7011, 4890}], 
          
          LineBox[{7243, 9367, 5076, 9419, 9439, 9429, 5085, 9376, 7252, 7234,
            7243}], 
          LineBox[{8083, 9010, 8090, 8077, 8083}], 
          LineBox[{8828, 5957, 8835, 8821, 8828}], 
          LineBox[{4735, 9115, 4702, 4785, 9291, 9204, 9214, 9124, 4735}], 
          LineBox[{4750, 9225, 4724, 4800, 9306, 9106, 9235, 9195, 4750}]}, 
         "1"], Annotation[#, 1, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1XlM13Ucx/EPgpyKF4kgoAgCSopHmga4LtLN0tXUWeCRTU3NzNZKOlaZ
Lc3SlViw5VH9V6t1LZvHdFpWm1tuRSV4VFgL0vKoLFHp8Vl/PHl9Pp/38Xm/
39/v70vhghV33J8QQvjNn3sKQmjIC2H14BCewZgBIayhY+mfV4XwXW4I3+MI
uuxrB4WQmh3CwzSFFjkP/UOoHsKfVtLztIomZYVwNR2BclRgJNrZN9NX8DIa
sAmtfUM4TX/HKSzOVyO9l2YUhdADPdELmciSv5B9CAajGEVIkL+G3oJ16nwe
s+ROpvV0G+2OMDCEHL77zWCtXDWFIczX9yHnyc5SUJkTwnWYqc/SmKtfCGnm
lYp09jR8ZQ6DaSFynZfx2xN74jvM+m6x7fJ2YKtcW3BczFD+tWY6UEweevHt
jXLreZ7BfDwp9incyn8Z21S6Vu6D+tiM151txxRnk2P/+hlGh6MEZSjFX2rp
osHcrtCnzfQyXU075GmWo53mOMvFAORhINrkLKCDkI+T9v3MK12uteLT6Dr6
HAaZ4Wm2ArpXzn0oNc8SpKNU7IPmsBIb7TfgRbwgdj0+0t/t5vOSHA/wGR3f
Lf3vpylyHaCpdAbd7Y49OGLfgrPqvyDmDG2Xq1hdHfRXjDLn4eY9j5bRuXQY
fchcjrr/GHry+9nMe9B692fQbH5b2bbgPfsS9w1FMVqdVfP/1ExarH+ybsNJ
pPNdJUca7S9HE3sjttkXit0ee7X/EPPVME3d05HF9wu2iXwmYApbH+eTaba8
m/hvZN+AL9Vfbg7L2Te4q96cPjC/+5wvR5P3qFFME5byaaDL6LvuyJDnHbqE
3/t0uvldkuuwmH0xRq5O+xv1doXeQC/TDPeMt74W4zARE+Jvlm0L3YrXsFId
v3gO5+L3AGdxBn/gUbWXezb1dARNxWPW6XKPZh+DUbgGY9EhdyNtwqtYIXeu
uo+JOY5ueinTwwnrpXJcr8fD8XnyycQk71M1ZumpRJ/rzTIj/n7Rh703qsSd
E38+vgNiFznb7a5VfBdbP0J3yPsJZso1A4fU0cV/krsviulEf/mzUSX3kjh3
FLt3KBL1cYL+gB+xUI4e7uiJDPRCZvwOxt8XzUJv9EUfdKmhu1klIwm17k6k
dbSUjkQFTtnnqyFJTHckIgXJaJY7jaYjFd/ad8rbTdwaNSfQZ2mL+tpoKz2K
Sj1OlfcNc5pM36Sz4ixQo++bcROmsd2GOvbh+ptDS/nsZNuFve5LjN8FmkRr
6Mfe8x34zP4gmr03fcWWiftGriI1NdOvY1/qSIjfV3Fd8RnRYL/TuiL+zuNv
J95Fd8dvE/8DctfF7zytpQv1c5fncidm46Czv9lGqvUC/dy+1nkd5mAR/7lm
leN5z4nfRzovzlDuandVoRLj3TcOu9TyuNqfwFtyznR2SZ5OpJr1BfH/mu1F
/INL6MRZfZzBbHGrxS1279t8FxT8/3/6P7lkDcc=
           "]], 
          
          LineBox[{9572, 6898, 9470, 4712, 6905, 9146, 5651, 9558, 5637, 9551,
            5644, 9565, 9572}], 
          LineBox[{9588, 5751, 9580, 5759, 9072, 7018, 9137, 5767, 9588}], 
          
          LineBox[{9606, 5971, 9598, 5979, 9392, 7261, 9384, 5093, 9272, 9281,
            9172, 5102, 9401, 7270, 9409, 5987, 9606}], 
          LineBox[{5491, 9058, 5494, 9520, 9528, 9512, 5502, 9185, 5491}], 
          
          LineBox[{6658, 9092, 5584, 9542, 8360, 9026, 8369, 9535, 5591, 9256,
            6665, 6653, 6658}], 
          
          LineBox[{6825, 9322, 5923, 9496, 8191, 9488, 5931, 9339, 6834, 9331,
            5037, 9161, 5019, 9083, 5028, 9314, 6825}], 
          
          LineBox[{6843, 9045, 6852, 9357, 5064, 9457, 5046, 9447, 5055, 9348,
            6843}], 
          
          LineBox[{7242, 9366, 5075, 9418, 9438, 9428, 5084, 9375, 7251, 7233,
            7242}], 
          LineBox[{8082, 9009, 8089, 8076, 8082}], 
          LineBox[{8827, 5956, 8834, 8820, 8827}], 
          LineBox[{4734, 9114, 4701, 4784, 9290, 9203, 9213, 9123, 4734}], 
          LineBox[{4749, 9224, 4723, 4799, 9305, 9105, 9234, 9194, 4749}]}, 
         "0.8`"], Annotation[#, 0.8, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1WtM1mUYx/GbcpVltRVoFIJWo5Z47EWHqaCVE8UTZ0hdYrWWG1KicRKw
XrS1NLXVG5FSK0stFEMx1+GFxxJQc75LDkvAtcGInG6B9PmvF9/nd1/3fZ3u
6//8n2di0drM4pgQwo8+lieG8F5CCMX0wqMhrKXxj4VwMC6Ei+wS9s/0pdgQ
Tk4IYR7t5b/Juha3OYtBQlIIYx4J4amxIZwRs5nfdPab1oed9z0Qwhrrfvo1
n96JIXxDr9G9tOzhEKbK1yjmFr9h3JBjgvOb9JPxIUxz3uS8nXaiA0+yTznr
UaNF7tPWd8eHcA/2yXvE+VGsejCEVDWK6G4+e7AL+/W9D7vFNrIP4xCa8D1W
858pbgWflVge3XOcO6BVzBJ15li/pf5c+jY9oW6lmGz9Der/JDvL+pg+mtFt
3YsK9+qhf6kzn186rkT3wwrrVzyDHOef6mERezp7Ac3AQvyt/gdiB+nTYmZg
u5wtZjdDzdHs+/EP3+vIlSsvemZ6HuBXqsduPfegWe7tfLdhs5xbaT/6UKN+
EBODZ/hexTx7xXJ+KC5dvV/cO0vOU/Jn02u+I0utH6dPOE/GVfubopq0/6EQ
xjtLRJG91Rgn70Xz/R2X0MvnT3e7YH0eH8u3HaPF79BLHba45zt6LEM5ztu7
gTbcx/debIjuFD0TexW4S/xW+9vwm7zn0KnONH4ddCqdgvf5lZjFr3REf2dp
gXsU4l19bxS/iZabQyWqUIF1zktx3GzW05tmVcuvBvnsPLRjGTJRYf9V+hq+
ElPOLovmx14vX2mUE9X2qtTcSHOd5WC/ni7r7QDNi76vdNj5CG5hFZ/L7tQi
vhXn8LpZtNFBtcaJHWXu+WZQiALslGNQnXqaJmeKdSqtY8+kszELGfKWeUbl
6JPrqFp18u5AnLwF7j2Z35QoB9rQigY19kbvW/TOsmPN+kt8gXwxG8Tm0Unq
7onO9FuqxjosFLdWXKqei2kaLaHH+VSISxczoP5P7Al+x+ZH33f14tSp1X8s
raHNej2Gz/jWY0D/O2mSmB/EdsjZHr3T9hKcpdI5SEOyPjLkuaSXFP1NQrWc
86PfFHpdzc/pd3wb8C2elbPL85hsv4Om0E5aL/dc8XOQhgVypOOK3gpoYTTn
6PeA3aSfMeay0nqXuIWRP9LRIF8+3+fUOaheIw5hs/kkm8vzzoesh/gOY5G9
xRhr77T5nMFZHHG3JeKWYjEysQx3iM/17uRhnRo5cuQiD3/Yi9fXBTokx7/I
t1/Kr9ZeDe4Uv8VcPkKL81Z0md9MZ7PUnI02/bRiDd8T7pgk/nZ5RmFED8H9
q8XXoMfsXuR3lb5Au+kBM3kj+t/QSxW7EtnsLHTh5cT//+/+A3bfFek=
           "]], 
          
          LineBox[{6897, 9571, 9564, 5643, 9550, 5636, 9557, 5650, 9145, 6904,
            4711, 9469, 6897}], 
          LineBox[{9587, 5750, 9579, 5758, 9071, 7017, 9136, 5766, 9587}], 
          
          LineBox[{9605, 5970, 9597, 5978, 9391, 7260, 9383, 5092, 9271, 9280,
            9171, 5101, 9400, 7269, 9408, 5986, 9605}], 
          LineBox[{5490, 9057, 5493, 9519, 9527, 9511, 5501, 9184, 5490}], 
          
          LineBox[{9091, 6657, 6652, 6664, 9255, 5590, 9534, 8368, 9025, 8359,
            9541, 5583, 9091}], 
          
          LineBox[{6824, 9321, 5922, 9495, 8190, 9487, 5930, 9338, 6833, 9330,
            5036, 9160, 5018, 9082, 5027, 9313, 6824}], 
          
          LineBox[{6842, 9044, 6851, 9356, 5063, 9456, 5045, 9446, 5054, 9347,
            6842}], 
          
          LineBox[{7241, 9365, 5074, 9417, 9437, 9427, 5083, 9374, 7250, 7232,
            7241}], 
          LineBox[{9008, 8081, 8075, 8088, 9008}], 
          LineBox[{5955, 8826, 8819, 8833, 5955}], 
          LineBox[{4733, 9113, 4700, 4783, 9289, 9202, 9212, 9122, 4733}], 
          LineBox[{4748, 9223, 4722, 4798, 9304, 9104, 9233, 9193, 4748}]}, 
         "0.6`"], Annotation[#, 0.6, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1V1M11UYwPFjaTdlKWAiIAqEkl40TQq1qHSrlLdE1KyrQAUrMC2rraBc
vpbM1BIrN1+2tkAu2lICmrUuSgPjtdLUXhRtqVnOalOXrc9ZF1++v+c55zzn
Oef///3JKF9WWjMohPChPxW3hrAYxzNDWMQf4wkcE5fzHyNCuIhG8eyEEMqS
Q6hNCuHzjBAWGv9tTAgXMDjR+pQQhvDdqSHkoXNsCB04PDqEhKwQkpCIFPU6
1EvlfHW2qXdSjVMYQIP4d+u+Rldcjx50Y7H6K+2zhNvV+EgP+0eG8I/eWu1z
jXPtPQW3i3PQkh7CBJ6Iu+TbeJ+1IdbwPIhb1Nin1p32mIJcJNmn0tgkz5Nx
Tm/ncb3cHfq+Uf998o/pt5cf53r5dvnl9mzjFVzJ5fIVmCrOw8S4Rv0+fKGX
fv6SV8mfVWuce8rGMDTJ36C/IRiBU+IkPuKsW9TuEm/lUdZOxV5xkbHtcvO4
WTxd/oq+X9XDKtTiFdThhDlt/LDzt/Is/p5XcIW1y3m0PtKRiuvE7xs/4Byf
4rI5V3EF6+2RzRu4xDmKsdDcR3FWz0/xGn09LV+NGvwofkudKj0eFS/l4HNJ
t88M+bVxfloIqz2vwWfxfs17BsuwLo6re079Mp6HB+UfQq0+NuhnuM/tmLXH
cRQz4xl5Gy8x3sA/WTeX27mUP+Hz7maAT+MUfsEZ7DReZt08zEWCvQ/HO8cO
zy+hwGc6Gznmzo/7xfn8lzm7+QfxHt6FKs/51lTyvdyERhSKh/IsLojvYJyn
5hznGueOxuM2bHVn2dzsnN3Olatmsz4Hu5sM95CJLCSLp8s/Yv1Y8RjkiMdj
L6arPVNuBh5Aizql3vk56FS/xLpd3qGdOImfsVJueHzHcTOG4RZ0oNDYr/rf
r06+evfh/oh9ip0l055ZSJMbjQLzp4lH6DNVnIJR+Nf5muSnqNPlfI3O+QFG
+j5ujt+H+H1FibFiLDD/oHXz42+VfdL0cpA3iYdb86S1U/U1IDeN83APTsd3
hS/4jN5Tt0e8g6/q613uFr/Dh/A2ktXaFntV9wX7v4jn0SB3Ro0TnjfF31d+
M/7WWj9Z/UU8ifvRhx73Uct1+qqL3x+uxcvYaO8JXM9DvQc3IdEZE9BrbrXa
G+JvjfM+i+dwQFxjXjVmmrdevN1zvbEGbhSvjT0Z24wu8UZjb+B1NInXGe9U
fz4vQKF8EVbr45r4Nb7s87+CInwrd0mff6LKeZaiypm/k6/kI9zKF7kXfejB
N+jH3/bczXuwWo01KHaHl8SH8BUOxp7QkfH//67/AB/hBe0=
           "]], 
          LineBox[{5749, 9586, 5765, 9135, 7016, 9070, 5757, 9578, 5749}], 
          
          LineBox[{5969, 9604, 5985, 9407, 7268, 9399, 5100, 9170, 9279, 9270,
            5091, 9382, 7259, 9390, 5977, 9596, 5969}], 
          LineBox[{9056, 5489, 9183, 5500, 9510, 9526, 9518, 5492, 9056}], 
          
          LineBox[{6823, 9320, 5921, 9494, 8189, 9486, 5929, 9337, 6832, 9329,
            5035, 9159, 5017, 9081, 5026, 9312, 6823}], 
          
          LineBox[{6841, 9043, 6850, 9355, 5062, 9455, 5044, 9445, 5053, 9346,
            6841}], 
          
          LineBox[{7240, 9364, 5073, 9416, 9436, 9426, 5082, 9373, 7249, 7231,
            7240}], 
          LineBox[{8358, 9024, 8367, 8356, 8358}], 
          LineBox[{4732, 9112, 4699, 4782, 9288, 9201, 9211, 9121, 4732}], 
          LineBox[{4747, 9222, 4721, 4797, 9303, 9103, 9232, 9192, 4747}]}, 
         "0.4`"], Annotation[#, 0.4, "Tooltip"]& ], 
       TagBox[
        TooltipBox[{
          Directive[
           GrayLevel[0], 
           Opacity[0.5], 
           CapForm["Butt"]], 
          LineBox[CompressedData["
1:eJwl1UtQl2UUx/FHnS5jTSr/vAAagVqC1abJ7gucrFykhjcsR8FxEZpRZi2g
jcLCqaapRCedUUGUaArUFjXVhMifPwI2isktL+BCU7nojKWBlvV5p8WX33ue
c57fc57zvkD6qsKct0aEELb4MTA+hFhKCEnIxmw8OSGEtgdCmEVP0L30YnoI
I2MhXE4L4RIGH7QXWfeH0Dk5hG504d8k9Txu04vqfsfyjBBew+vYNDGEOXIb
6TLxUuTivLoLuCVXaf9N2s6vA43OiSPTWcuQi7v1Paxmq+ervK7gIJ8DaEAc
5/j1YkjdHp5/0R7xWUxSv0TNB/YvnBTCS3Il1orFh+Ub0Gat37nH6WW1fbiE
U3r6DbVqalAl/yKq5UbxGNRbvXnlmlsdXUoP0ZNqEnSluJHm0Sa6gubbuwp5
SOVRrXYuJk7RKyagRG+1aFZTQ//R22raQbvQiXJ+zfwKvKuf1KXppZXfeHF9
5EP/tH7I86JUfSCOtdYTtAlFKMYT1uLqZtE2HmW8ipxRjBvWNjvrfPR+kEAh
tvpetqFX7Tms098PZvQjjrjPNgwnh7Cd1ugjU69T1LSq7RK30AG5BtoevUea
Ib84urt4h9wGvVTQ/eIxnu/Du7ggXk+vy+3yvveJq7A3es/Wp3rPGfhEXCAu
1FP6VO9FD7fdpZ3mWcvHSoxV80q0n99Oz5XyOe79LV1I79Db9+bTbB4t2GNm
FVgkt9v5a+xdG52FdXgT78u9oHYOpmE6FlsrV1/kzAEzHEQSnxgy9ZWFh9Q9
jCVqnxMnOzsr+p3ADNwp3qXHfXp9RP4u8Uz6GB7Favt2OmOBHl7FfIxTnxO9
A+dkYZrZTEeZWZ/Wyxnc4Pe8/TH37NNXP8aqHYdKue+s15pHD5/9tAZX1R+k
g/QAvUIX8O2nX4v76Dd0gD5Oq+lXqHLelyjnO8Y3km5PCv9UJONjff2BFmdd
o91qu9AXffv0afoU3nHXfH7r6bPiZzDTPGbzy0aCV7bcdT6NnkvdpTT6/ULc
tzuSjsIINOAwRvO4F/fgFO/37Kkzi5+RFn2/ZnsU8820ju9x/sfc4Ri9qf4W
hvGL+/5Nj9Ki6PvCh+rn0Y+ivzH6/EK+n26nb9M36BoUYAeG+H5GP8enKMMW
pER/u9Sf5FNPu82xiXaKj9DJ8gnaEd2bbnbXM/o/i9PoRQ9+ta/CXU7QRnON
I6a/UrxsbchZrfovsb4JG9P+/z/yH/YADpM=
           "]], 
          
          LineBox[{5920, 6822, 9311, 5025, 9080, 5016, 9158, 5034, 9328, 6831,
            5920}], 
          
          LineBox[{9042, 6840, 9345, 5052, 9444, 5043, 9454, 5061, 9354, 6849,
            9042}], 
          
          LineBox[{9363, 7239, 7230, 7248, 9372, 5081, 9425, 9435, 9415, 5072,
            9363}], 
          
          LineBox[{9381, 7258, 7257, 7267, 9398, 5099, 9169, 9278, 9269, 5090,
            9381}], 
          LineBox[{9023, 8357, 8355, 8366, 9023}], 
          LineBox[{9111, 4731, 9120, 9210, 9200, 9287, 4781, 4698, 9111}], 
          LineBox[{9221, 4746, 9191, 9231, 9102, 9302, 4796, 4720, 9221}]}, 
         "0.2`"], Annotation[#, 0.2, "Tooltip"]& ], {}, {}}}], {
    DisplayFunction -> Identity, AspectRatio -> 1, DisplayFunction :> 
     Identity, Epilog -> {
       GraphicsComplexBox[CompressedData["
1:eJxF03lI02EYB/BpmqVRUKlJimc2LUcYHvNg4VGu1JlZqavpZnlSmV0qlDMP
DCwZmujmspozjzkTLHNsTScy0UXpbM7UNeeB2y81c0VaYAX2vC+8vHx4vu/3
v8eZcS32sikOh4v6e/+9BJKNYWNjWYrbPKJt9Ktpb5fABe9UWC99Eazn29n6
2X8Be36O2L5rygBu2MMzjt/Xg/uogw+lpAWwfb29U830PPhUKDVP+WAO7Pgr
lelBngV7CbnMnEUdWHvzGUHVNA3OqGPx6jK14Ph7Ca4CFw0Yj3lQ455MgLOi
Y0p0M2pw4g1KsK+vClwpXYiRvlaCSabqcwSTYXCmWpbNX1WAg2oL94ly5eD0
qZWJBFsZmKI93DbgJgL7SjljhmIhmPj1YoompQp8qGjZsudWJem/2+VLzQXx
7WAJedA/QNYNxlqeZ0THy8DcNgLH+EoOFtNLrY90KcD5e2s/UnYPgxUfRsNG
2Erw9SE/9wobFbjhfZh16oAaXC7oarKInACbVI6S+8w1YNvmVnlDhBasesF0
NS+bBlNbPUtzdDpwEMcisP/ALHimovuHW/EcuNO1AHOenAdreXe8zRwWwCP4
cOZqrh7syA53GpAYwNUtCWvE3xhYKQ0Zf3N2EZzVS7NyqFkCb+4D2MgLFBxN
QvsRyRTl74xEc9YKfqi2Hc0nn+7os/6G+iRJ6d4WjSifXFP/STGG8m4dPml2
/Shvls1SWeah/G0K6dEWJbIcS2TMY+h/BPEkkSNE//E/+U3lDJRnj51JLhEj
x8o9xYV65PzH/u6r31Ff4t04lws81BcQ9JIVdR7lBftp5OMdyJesfPghGuRj
RU7KHiNyXObBsrV11M+oH68Wc1F/KM1nq/A0yncGz0gaW5GveInseGpkMp9/
wnkZ2Y/OoSWvI/8BvPBPPg==
        "], {{{}, {}, {
           Directive[
            Opacity[1.], 
            RGBColor[0.368417, 0.506779, 0.709798], 
            AbsoluteThickness[10]], 
           
           LineBox[{1, 71, 65, 60, 56, 53, 51, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11,
             12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 
            28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 
            44, 45, 46, 47, 48, 49, 72, 66, 61, 57, 54, 52, 73, 67, 62, 58, 
            55, 74, 68, 63, 59, 75, 69, 64, 76, 70, 77, 50}, VertexColors -> 
            Automatic]}}}, VertexColors -> CompressedData["
1:eJx11H8w1HkYB/CNi9opu+gHqu0qJXuEWD+a9Kizd+ooIcXhKqQfGyoO19VV
qFUTofNjj8LQsEw2xHaHcHIk2ShhEsd89/d3N9XUqrXd9sc999f98cxr5v3H
85l5nmc+qw7GBUQbUCgUP30Z6qt4ZpeoclYN/zo+G8d2/6SG5eztpi4rJWhD
+3HBISoJQcd36AQBU+gJ69hPm7oUYKexrjl7dwI1qTzgwZTIQaitc2Z5jKE9
T4u5zi5y4J0y/W5T+AjqnWvflJElAw7VrHOn5xBqtndfrxtVBoIBgu64bRA9
qREZzLsihXnNUwOP+SI0+KaoL2m5FETTyS7Zc/rQdYuocavaJFBkGNNe/rAb
9fU6Fe1+SAIWvIWUrK0P0OePquW9VhKITyf3F37ZgTJ6zbsXDIuh5M7BnCGb
VtT0pOU3ujwxSBf43gum30MvnxN+e3u/GCa4zdwtNg1oQ3od289ODPSZWy26
gVp0tN9nhvaJAMGDrBAGUYkygri+y0YJuPbQJ9M+pgx1TystPt1EQNu7CH5l
Bg/NCehqtywi4Nzd1b8YhGejHsaBd8pSCaAYBmqXZKWht2P9e1rj9fnWCk/2
0UR0yMJ2Q1GkPtcFvpyzOvw/TSr2OIbqc/80ZqfWFu2YbFON79HnlJKWvGob
dM+bNbmDn/MwBqvvjwiUlu5clvC5Tyu3L68nAT0rcKY5fX53vZMR1zodZSnr
qBdPELD/flPeC2E2qpNll+anETCh2Ux/ZslDC8rOXVXz9HN4TfgYXy1DFyY6
/MwWEuCVHlM+p7gS7Rrg1POG9X1cxtN/TaxFrXav7F4xS4Bj007XN5p69H1R
QdIPTP0eLUYOfzwlRIMb61OYoWKwGExf5i1vQX/MXXv++HV9rhu/MdTfjl7g
50zufqK/nyn2/LWKTrTyTPyxAnP9fS52COHwu9Gl+bHGGZES6HyUUOqQ+Qil
m67UpDZKwKvxyFhKiQilbt/8odVKCkYUk2wjt0G0hv+846sMKTAV+4S25DN0
o03U9hdaKcRXM1xWfz2C5iyfG+F4RQYTIbpCv5EXqH8Uv9DNWg5W4us3vU5P
oPPLnFhtg3Kw+81Tq3adQqNeHqn60KwAul/Y0pwbYnRuXI/xxXEl/N+/9P30
moQxgQztqWhcd5MgQXtWXc8JkqFBzArx4y4S+KmhyZaXFGjmUPdA+AUVxPq5
JSaPStB+y5YnAz4k3P+4nufKVqDyQCE3hqMCpXnY0rhnSrTcKKGuf1oFh8/Y
J6e5StA+W9p6OzMSXANJg7VuctTsRHn1ATMVJETmx1XdUqJPei/95D6pgi3k
7/QzHSR6f0Ya+tRLDaxr9wadZGK0edRzOlqjBPtt3uOF7TKUtoSzw1lBwraC
ErsGsQJt3zhhsrlMBa5GytGQUhJtqdl5o5ulhi+06oLgoyq0RreL+1eyGg6H
Rbdk/SlG+xhJ10cVSojwcReZXZahDzvMXgmGSVi4bMvlubkKtLZ+0Ya9F1UQ
IqKFeFuSKONV7QrOPDVYS7JgMkCFNr13WPwuXg1tHsaE1d8qVNGy1zeiRA1U
VtVzrUCMGsa4F1cRStBqHDKN4mRo1SxttKafhCiP1/sSjynQVea3VtikqCCK
qWESY0o0KXJWWPpWBeXTTm+5r0nU7WP07mF/NaTQ8+1SRSp0MHRj1BBPDf8A
TlOcKA==
         "]]}, Frame -> True, 
     FrameTicks -> {{False, False}, {False, False}}, GridLinesStyle -> 
     Directive[
       GrayLevel[0.5, 0.4]], Method -> {"DefaultBoundaryStyle" -> Automatic}, 
     PlotRange -> {{-2, 2}, {-2, 2}}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           GraphicsBox[{{}, {}, 
             
             RasterBox[{{{0.148, 0.33, 0.54}}, {{0.35010824805008983`, 
              0.4267473076214373, 0.6132590490695958}}, {{0.5054106468014115, 
              0.4813264253934673, 0.5219630702509275}}, {{0.6607130455527332, 
              0.5359055431654973, 0.4306670914322591}}, {{0.8160154443040549, 
              0.5904846609375273, 0.33937111261359076`}}, {{
              0.9113926266861624, 0.648481566715406, 0.3253171427271035}}, {{
              0.9362013165825397, 0.7105032914563492, 
              0.40222408140587296`}}, {{0.961010006478917, 0.7725250161972922,
               0.47913102008464237`}}, {{0.9858186963752943, 
              0.8345467409382357, 0.5560379587634121}}, {{1., 0.95, 0.75}}}, {{
                Rational[-15, 2], 
                Rational[-225, 2]}, {
                Rational[15, 2], 
                Rational[225, 2]}}], {Antialiasing -> False, 
              AbsoluteThickness[0.1], 
              Directive[
               Opacity[0.3], 
               GrayLevel[0]], 
              LineBox[
               NCache[{{
                  Rational[15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[-225, 2]}, {
                  Rational[-15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[225, 2]}, {
                  Rational[15, 2], 
                  Rational[-225, 2]}}, {{7.5, -112.5}, {-7.5, -112.5}, {-7.5, 
                112.5}, {7.5, 112.5}, {7.5, -112.5}}]]}, {
              CapForm[None], {{
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -90.}, {
                    Rational[15, 2], -90.}}, {{-7.5, -90.}, {7.5, -90.}}]]}, {
               
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -67.5}, {
                    Rational[15, 2], -67.5}}, {{-7.5, -67.5}, {
                  7.5, -67.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -45.}, {
                    Rational[15, 2], -45.}}, {{-7.5, -45.}, {7.5, -45.}}]]}, {
               
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], -22.5}, {
                    Rational[15, 2], -22.5}}, {{-7.5, -22.5}, {
                  7.5, -22.5}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 0.}, {
                    Rational[15, 2], 0.}}, {{-7.5, 0.}, {7.5, 0.}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 22.5}, {
                    Rational[15, 2], 22.5}}, {{-7.5, 22.5}, {7.5, 22.5}}]]}, {
               
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 45.}, {
                    Rational[15, 2], 45.}}, {{-7.5, 45.}, {7.5, 45.}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 67.49999999999997}, {
                    Rational[15, 2], 67.49999999999997}}, {{-7.5, 
                  67.49999999999997}, {7.5, 67.49999999999997}}]]}, {
                Directive[
                 GrayLevel[0], 
                 Opacity[0.5], 
                 CapForm["Butt"]], 
                CapForm["Butt"], 
                LineBox[
                 NCache[{{
                    Rational[-15, 2], 90.}, {
                    Rational[15, 2], 90.}}, {{-7.5, 90.}, {7.5, 90.}}]]}}}, {
             Antialiasing -> False, 
              StyleBox[
               
               LineBox[{{7.500000000000002, -112.50000000000001`}, {
                7.500000000000002, 112.50000000000001`}}], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False], 
              StyleBox[
               StyleBox[{{
                  StyleBox[
                   LineBox[{{{7.500000000000002, -90.00000000000003}, 
                    
                    Offset[{4., 0}, {
                    7.500000000000002, -90.00000000000003}]}, {{
                    7.500000000000002, -45.000000000000014`}, 
                    
                    Offset[{4., 0}, {
                    7.500000000000002, -45.000000000000014`}]}, {{
                    7.500000000000002, 0.}, 
                    Offset[{4., 0}, {7.500000000000002, 0.}]}, {{
                    7.500000000000002, 45.}, 
                    Offset[{4., 0}, {7.500000000000002, 45.}]}, {{
                    7.500000000000002, 90.00000000000001}, 
                    
                    Offset[{4., 0}, {7.500000000000002, 
                    90.00000000000001}]}}], 
                   Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], StripOnInput -> False]}, 
                 StyleBox[
                  StyleBox[{{
                    StyleBox[{
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.2\"", 0.2, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 1}]& ], TraditionalForm], 
                    
                    Offset[{7., 0.}, {
                    7.500000000000002, -90.00000000000003}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"0.6\"", 0.6, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 1}]& ], TraditionalForm], 
                    
                    Offset[{7., 0.}, {
                    7.500000000000002, -45.000000000000014`}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 1}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.500000000000002, 0.}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"1.4\"", 1.4, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 1}]& ], TraditionalForm], 
                    Offset[{7., 0.}, {7.500000000000002, 45.}], {-1, 0.}, 
                    Automatic, {1, 0}], 
                    InsetBox[
                    FormBox[
                    TagBox[
                    InterpretationBox["\"1.8\"", 1.8, AutoDelete -> True], 
                    NumberForm[#, {
                    DirectedInfinity[1], 1}]& ], TraditionalForm], 
                    
                    Offset[{7., 0.}, {7.500000000000002, 
                    90.00000000000001}], {-1, 0.}, Automatic, {1, 0}]}, 
                    Directive[
                    AbsoluteThickness[0.2], 
                    GrayLevel[0.4]], {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False]}, {}}, {
                    Directive[
                    Opacity[1]]}, StripOnInput -> False], "GraphicsLabel", 
                  StripOnInput -> False]}, "GraphicsTicks", StripOnInput -> 
                False], 
               Directive[
                AbsoluteThickness[0.2], 
                Opacity[0.3], 
                GrayLevel[0]], StripOnInput -> False]}}, PlotRangePadding -> 
            Scaled[0.02], PlotRange -> All, Frame -> True, 
            FrameTicks -> {{False, False}, {True, False}}, FrameStyle -> 
            Opacity[0], FrameTicksStyle -> Opacity[0], 
            ImageSize -> {Automatic, 225}, BaseStyle -> {}], Alignment -> 
           Left, AppearanceElements -> None, ImageMargins -> {{5, 5}, {5, 5}},
            ImageSizeAction -> "ResizeToFit"], LineIndent -> 0, StripOnInput -> 
          False], {FontFamily -> "Arial"}, Background -> Automatic, 
         StripOnInput -> False], TraditionalForm]}, "BarLegend", 
      DisplayFunction -> (#& ), 
      InterpretationFunction :> (RowBox[{"BarLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{
                 RowBox[{"Blend", "[", 
                   RowBox[{"\"M10DefaultDensityGradient\"", ",", "#1"}], 
                   "]"}], "&"}], ",", 
               RowBox[{"{", 
                 
                 RowBox[{
                  "0.00044474532224813077`", ",", "2.015867575340424`"}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               RowBox[{"{", 
                 RowBox[{"0.2`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.4`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.6`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"0.8`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.2`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.4`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.6`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}], ",", 
               RowBox[{"{", 
                 RowBox[{"1.8`", ",", 
                   RowBox[{"Directive", "[", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    GrayLevel[0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> GrayLevel[0.], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "GrayLevel[0]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    GrayLevel[0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["GrayLevelColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    GrayLevel[0], Editable -> False, Selectable -> False], 
                    ",", 
                    RowBox[{"Opacity", "[", "0.5`", "]"}], ",", 
                    RowBox[{"CapForm", "[", "\"Butt\"", "]"}]}], "]"}]}], 
                 "}"}]}], "}"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
           RowBox[{"Charting`TickAnnotations", "\[Rule]", "None"}], ",", 
           RowBox[{"Charting`TickSide", "\[Rule]", "Right"}], ",", 
           RowBox[{"ColorFunctionScaling", "\[Rule]", "True"}]}], "]"}]& )], 
     TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.6509291122999487`*^9},
 CellID->1215003148]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function to show field lines in 3-D ", "Subsection",
 CellChangeTimes->{{3.650907830011841*^9, 3.6509078459547787`*^9}, 
   3.650910754727253*^9},
 CellID->429072009],

Cell["\<\
The following is a function that encapsulates the artificial approach of \
plotting field lines given earlier.\
\>", "Text",
 CellChangeTimes->{{3.6509291439642076`*^9, 3.650929182265419*^9}},
 CellID->135909113],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"squareRootStreamPlot3D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nLines_Integer", ",", "plotRadius_"}], "}"}], ",", 
     "nRotations_Integer"}], "]"}], ":=", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "sqrtStreamPlot", ",", "graphicsComplex", ",", "graphicsComplex3D", ",",
        "revolutionDisk", ",", "fieldLines"}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sqrtStreamPlot", "=", "\[IndentingNewLine]", 
       RowBox[{"StreamPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ExSqrtDisk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               SqrtBox[
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
             RowBox[{"ArcTan", "[", 
              RowBox[{"z", ",", "x"}], "]"}]}], "]"}], ",", 
           RowBox[{"EzSqrtDisk", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               SqrtBox[
                RowBox[{
                 SuperscriptBox["x", "2"], "+", 
                 SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
             RowBox[{"ArcTan", "[", 
              RowBox[{"z", ",", "x"}], "]"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "plotRadius"}], ",", "plotRadius"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"-", "plotRadius"}], ",", "plotRadius"}], "}"}], ",", 
         RowBox[{"StreamPoints", "\[Rule]", 
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"n", "=", "nLines"}], "}"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"RotationMatrix", "[", " ", 
                RowBox[{"2", "\[Pi]", " ", 
                 FractionBox["i", "n"]}], "]"}], ".", 
               RowBox[{"{", 
                RowBox[{"plotRadius", ",", "0"}], "}"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "0", ",", 
                RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], "]"}]}], ",", 
         RowBox[{"StreamStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"\"\<Line\>\"", ",", 
            RowBox[{"Directive", "[", 
             RowBox[{"Red", ",", "Thick"}], "]"}]}], "}"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"graphicsComplex", "=", 
       RowBox[{"Cases", "[", 
        RowBox[{
        "sqrtStreamPlot", ",", "_GraphicsComplex", ",", "\[Infinity]"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"graphicsComplex", "=", 
       RowBox[{"First", "[", "graphicsComplex", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"graphicsComplex3D", "=", 
       RowBox[{"graphicsComplex", "/.", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x_", "?", "NumberQ"}], ",", 
           RowBox[{"z_", "?", "NumberQ"}]}], "}"}], "\[RuleDelayed]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "z"}], "}"}]}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"revolutionDisk", "=", 
       RowBox[{"RevolutionPlot3D", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"ColorFunction", "\[Rule]", 
          RowBox[{"Function", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "x", ",", "y", ",", "z", ",", "t", ",", "\[Theta]", ",", "r"}], 
             "}"}], ",", 
            RowBox[{"Blend", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"White", ",", 
                RowBox[{"Darker", "[", 
                 RowBox[{"Blue", ",", "0"}], "]"}]}], "}"}], ",", 
              RowBox[{"Rescale", "[", 
               RowBox[{
                SqrtBox[
                 RowBox[{"1", "-", 
                  SuperscriptBox["r", "2"]}]], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
         ",", 
         RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "50"}], ",", 
         RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
         RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"fieldLines", "=", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"n", "=", "nRotations"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"GeometricTransformation", "[", 
             RowBox[{"graphicsComplex3D", ",", 
              RowBox[{"RotationTransform", "[", " ", 
               RowBox[{
                RowBox[{"i", " ", 
                 FractionBox[
                  RowBox[{"2", "\[Pi]"}], "n"]}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}]}], "]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", 
              RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{"fieldLines", ",", "revolutionDisk", ",", 
        RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], "\n"}]], "Input",
 CellChangeTimes->{{3.650907875638294*^9, 3.650907982143818*^9}, {
   3.6509080385604277`*^9, 3.650908039086212*^9}, {3.650908090782148*^9, 
   3.650908193460155*^9}, 3.650908223643783*^9},
 CellID->2076185169],

Cell["\<\
An example starting with 12 field lines in 2 dimensions, plotted out to a \
distance of 4 and then rotated through 10 separate planes: \
\>", "Text",
 CellChangeTimes->{{3.650929200040847*^9, 3.6509292594070177`*^9}},
 CellID->131289048],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"squareRootStreamPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"12", ",", "4"}], "}"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.650908248054749*^9, 3.650908257332798*^9}, {
   3.650908416489297*^9, 3.65090842374293*^9}, 3.6509292081847258`*^9, {
   3.650929241751501*^9, 3.650929241815757*^9}},
 CellID->3471281],

Cell[BoxData[
 Graphics3DBox[{{
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 0.027018032709135397`},
        {-3.438774713548781, 0, 4.}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], {{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}, {0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[1, 2] 3^Rational[1, 2], Rational[-1, 2], 0}, {
        Rational[1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {0, 0, 1}}, {0, 
       0, 
       0}}, {{{0.8660254037844386, -0.5, 0}, {0.5, 0.8660254037844386, 0}, {0,
         0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {
        Rational[1, 2] 3^Rational[1, 2], Rational[1, 2], 0}, {0, 0, 1}}, {0, 
       0, 0}}, {{{0.5, -0.8660254037844386, 0}, {
        0.8660254037844386, 0.5, 0}, {0, 0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], {{{0, -1, 0}, {1, 0, 0}, {0, 0, 1}}, {0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 0.23097893450126084`},
        {-0.11059606702372894`, 0, 0.37922675664867045`}, {-0.125036421470842,
         0, 0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[-1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {
        Rational[1, 2] 3^Rational[1, 2], Rational[-1, 2], 0}, {0, 0, 1}}, {0, 
       0, 0}}, {{{-0.5, -0.8660254037844386, 0}, {
        0.8660254037844386, -0.5, 0}, {0, 0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[-1, 2] 3^Rational[1, 2], Rational[-1, 2], 0}, {
        Rational[1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {0, 0, 1}}, {0, 
       0, 0}}, {{{-0.8660254037844386, -0.5, 0}, {
        0.5, -0.8660254037844386, 0}, {0, 0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], {{{-1, 0, 0}, {0, -1, 0}, {0, 0, 1}}, {0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[-1, 2] 3^Rational[1, 2], Rational[1, 2], 0}, {
        Rational[-1, 2], Rational[-1, 2] 3^Rational[1, 2], 0}, {0, 0, 1}}, {0,
        0, 0}}, {{{-0.8660254037844386, 0.5, 0}, {-0.5, -0.8660254037844386, 
         0}, {0, 0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {
        Rational[-1, 2] 3^Rational[1, 2], Rational[-1, 2], 0}, {0, 0, 1}}, {0,
        0, 0}}, {{{-0.5, 0.8660254037844386, 0}, {-0.8660254037844386, -0.5, 
         0}, {0, 0, 1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 2.1229523694081682`},
        {-0.33648823122997684`, 0, 2.258603210375649}, {-0.35919232826669234`,
         0, 2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {3.365014131324725, 0, -2.16256326982239}
       , {3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], {{{0, 1, 0}, {-1, 0, 0}, {0, 0, 1}}, {0, 0, 0}}], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 0.23097893450126084`},
        {-0.11059606702372894`, 0, 0.37922675664867045`}, {-0.125036421470842,
         0, 0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {
        Rational[-1, 2] 3^Rational[1, 2], Rational[1, 2], 0}, {0, 0, 1}}, {0, 
       0, 0}}, {{{
        0.5, 0.8660254037844386, 0}, {-0.8660254037844386, 0.5, 0}, {0, 0, 
        1}}, {0, 0, 0}}]], 
    GeometricTransformation3DBox[
     GraphicsComplex3DBox[{{-4.174050091548382, 
        0, -4.174050091548382}, {-4.174050091548382, 0, 4.174050091548382}, {
       4.174050091548382, 0, -4.174050091548382}, {
       4.174050091548382, 0, 4.174050091548382}, {-4.174049531157045, 
        0, -3.8955697568034373`}, {
       4.17404981074222, 0, -3.8955705422417024`}, {-4.174049574893224, 
        0, -3.617089029376664}, {
       4.174049298303022, 0, -3.617090170454405}, {-4.1740497401396714`, 
        0, -3.3386090597385136`}, {
       4.174049565222938, 0, -3.3386099904776714`}, {-4.1740499018494255`, 
        0, -3.0601293774213234`}, {
       4.174049677708912, 0, -3.060129652837702}, {-4.1740496738198205`, 
        0, -2.781648620052174}, {
       4.174049927990908, 0, -2.7816498877594236`}, {-4.1740496701446075`, 
        0, -2.503168412946758}, {
       4.17404976259095, 0, -2.5031693633520637`}, {-4.174049387328748, 
        0, -2.2246883135997315`}, {
       4.174049618915261, 0, -2.224689090011101}, {-4.174049414257641, 
        0, -1.9462083429389365`}, {
       4.1740495339526875`, 0, -1.94620940890464}, {-4.174049455486521, 
        0, -1.6677284615341694`}, {
       4.1740493356202615`, 0, -1.6677293353301774`}, {-4.174049452423573, 
        0, -1.3892482981444927`}, {
       4.1740499005987, 0, -1.3892493995392285`}, {-4.174050021344357, 
        0, -1.1107679246044686`}, {
       4.174049554775888, 0, -1.1107689388858326`}, {-4.174049505108115, 
        0, -0.8322876725850498}, {
       4.174049299250206, 0, -0.8322891106528312}, {-4.174049412506576, 
        0, -0.5538075252178071}, {
       4.1740500293215534`, 0, -0.5538089037378513}, {-4.174049321369756, 
        0, -0.2753273879090166}, {
       4.174049960957723, 0, -0.27532860617869614`}, {-4.17404997913131, 0, 
        0.0031526914911777807`}, {
       4.174049598897517, 0, 0.0031515521305300704`}, {-4.174050006922345, 0, 
        0.2816323594752206}, {
       4.174049402555718, 0, 0.28163197349810165`}, {-4.174049426483442, 0, 
        0.560112453999543}, {
       4.174049986410189, 0, 0.5601123824716931}, {-4.174049341866967, 0, 
        0.8385926561301852}, {
       4.174049979568416, 0, 0.8385922709501803}, {-4.1740493941644035`, 0, 
        1.1170731809403966`}, {
       4.174049294154098, 0, 1.117072098282337}, {-4.174049487127568, 0, 
        1.3955534431727605`}, {
       4.174049782576082, 0, 1.3955526516617418`}, {-4.174049360840577, 0, 
        1.6740334214247348`}, {
       4.174049859033517, 0, 1.6740326598620305`}, {-4.174049856987635, 0, 
        1.9525138251729923`}, {
       4.174049826598079, 0, 1.9525126065456144`}, {-4.174049872998826, 0, 
        2.230993621378525}, {
       4.174049983005634, 0, 2.2309931316684466`}, {-4.174049321345516, 0, 
        2.509473545235665}, {
       4.174049618112877, 0, 2.5094728412694356`}, {-4.174049602523623, 0, 
        2.787953924912921}, {
       4.174049357399639, 0, 2.7879534734977365`}, {-4.174049346495845, 0, 
        3.0664337601788474`}, {
       4.174049701267443, 0, 3.066433125550644}, {-4.174049480604508, 0, 
        3.3449143114522615`}, {
       4.174049769365585, 0, 3.344913314513392}, {-4.174050037511889, 0, 
        3.623394631424799}, {
       4.174049955127788, 0, 3.623393654240715}, {-4.17404971907404, 0, 
        3.9018742267213997`}, {
       4.174049370927733, 0, 3.901873910163139}, {-3.895569173796738, 
        0, -4.1740497860062336`}, {-3.8955704105213624`, 0, 
        4.174049407822666}, {-3.6170894412312813`, 
        0, -4.174049298917979}, {-3.617089889851414, 0, 
        4.174049862408198}, {-3.338609102390688, 
        0, -4.17404990030926}, {-3.3386099856018236`, 0, 
        4.174049612819556}, {-3.060129371880348, 
        0, -4.174049381480671}, {-3.060129604239527, 0, 
        4.174049422226499}, {-2.781649211584993, 
        0, -4.1740498311876895`}, {-2.7816497889884007`, 0, 
        4.1740498540483575`}, {-2.5031690896699255`, 
        0, -4.174049437909363}, {-2.503169530505327, 0, 
        4.174049502058129}, {-2.224688567342583, 
        0, -4.1740498749605495`}, {-2.2246896379444405`, 0, 
        4.174050030643373}, {-1.946208668130156, 
        0, -4.174049445339704}, {-1.9462094595482382`, 0, 
        4.174049926103117}, {-1.6677281999969502`, 
        0, -4.174049500549804}, {-1.667729223327134, 0, 
        4.174049945629854}, {-1.389248465524535, 
        0, -4.174049996633362}, {-1.38924940262623, 0, 
        4.174049915460037}, {-1.1107682652862199`, 
        0, -4.174049816284037}, {-1.1107690766079337`, 0, 
        4.174049314647035}, {-0.8322876979624507, 
        0, -4.174050023414843}, {-0.8322887766068969, 0, 
        4.174049977353135}, {-0.5538079681917505, 
        0, -4.174049524239789}, {-0.5538083476645976, 0, 
        4.174049964922034}, {-0.27532764102991697`, 
        0, -4.174050064718783}, {-0.27532854263583795`, 0, 
        4.174049914222193}, {0.0031524638819671754`, 0, -4.174050024285651}, {
       0.0031517028270240575`, 0, 4.174049441406654}, {
       0.281632257844313, 0, -4.1740493375926135`}, {
       0.28163152250036105`, 0, 4.174049694340315}, {
       0.5601125180809396, 0, -4.174049702190564}, {
       0.5601122264226527, 0, 4.174049411277313}, {
       0.8385929641117309, 0, -4.1740499065150445`}, {
       0.8385917889761343, 0, 4.1740493280442905`}, {
       1.117072794382394, 0, -4.17404999719469}, {
       1.1170721106411337`, 0, 4.174049466196718}, {
       1.3955533637763187`, 0, -4.174049466092344}, {
       1.3955521935997641`, 0, 4.174049302913673}, {
       1.674033507463631, 0, -4.174049632356052}, {
       1.6740326049224936`, 0, 4.1740499646401625`}, {
       1.9525133013248848`, 0, -4.174049670967833}, {
       1.9525123618930447`, 0, 4.174049582748199}, {
       2.2309936151169305`, 0, -4.174049324126522}, {
       2.2309928118169875`, 0, 4.174049440649012}, {
       2.5094740633642116`, 0, -4.174049934248979}, {
       2.509473317086602, 0, 4.17404973826148}, {
       2.787953698601192, 0, -4.174049956489491}, {
       2.7879532563587532`, 0, 4.174049977523326}, {
       3.0664342155867077`, 0, -4.174050048458308}, {
       3.06643322815831, 0, 4.174049840962858}, {
       3.3449138990901344`, 0, -4.174049960520727}, {
       3.344913293771911, 0, 4.174049418495157}, {
       3.623394228915949, 0, -4.1740500870756865`}, {
       3.6233934666447496`, 0, 4.174049645404951}, {
       3.901874759669541, 0, -4.174049601893197}, {
       3.9018736557656295`, 0, 4.174049422482071}, {4., 0, 0.}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9904091565102782, 0, -0.00005681886055559544}, {
       0.9943002371429586, 0, -7.443851491855187*^-11}, {
       1.0199196653057956`, 0, -3.932244833634539*^-17}, {
       1.0441270251617798`, 0, -4.1881857966708305`*^-17}, {
       1.0656356343777018`, 0, -5.4802539523734833`*^-17}, {
       1.1039169547005943`, 0, -6.291355848473783*^-17}, {
       1.1377329748978307`, 0, -5.768564726528922*^-17}, {
       1.1684354112359163`, 0, -5.3449874850035874`*^-17}, {
       1.2233866892487932`, 0, -5.740898543844772*^-17}, {
       1.2718799698722487`, 0, -7.169875969936329*^-17}, {
       1.3156507378292355`, 0, -7.605557225169891*^-17}, {
       1.4627817757158563`, 0, -6.195397641957874*^-17}, {
       1.6359101241905039`, 0, -6.918896576432862*^-17}, {
       1.7418228968663718`, 0, -9.134338558355565*^-17}, {
       1.8348422064474612`, 0, -1.1016553625876332`*^-16}, {
       1.9561859590610045`, 0, -1.275016876388803*^-16}, {
       2.062918183658599, 0, -1.2852140541589376`*^-16}, {
       2.1980085193009735`, 0, -1.1889401531607432`*^-16}, {
       2.3172727734015317`, 0, -1.1054620693552902`*^-16}, {
       2.4766784141082274`, 0, -9.957537778415076*^-17}, {
       2.616957867892946, 0, -9.005579148493106*^-17}, {
       2.7838967988400123`, 0, -7.887204757512255*^-17}, {
       2.9321701035746273`, 0, -6.903823762048966*^-17}, {
       3.0443135860245762`, 0, -6.165853380675544*^-17}, {
       3.1496802999736975`, 0, -5.4750953700329167`*^-17}, {
       3.2482702454219905`, 0, -4.831549730121086*^-17}, {
       3.3400834223694553`, 0, -4.235216460940053*^-17}, {
       3.5093126446991727`, 0, -3.1414332031147237`*^-17}, {
       3.663301140900122, 0, -2.1509917649012786`*^-17}, {
       3.8042329302218385`, 0, -1.2486008105883199`*^-17}, {
       3.9352085680591986`, 0, -4.12644982310117*^-18}, {
       3.9959643887654526`, 0, -2.5686371778506697`*^-19}, {4., 0, 0.}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       0.5790240852473685, 0, 0.002065480447481141}, {
       0.5814994734035468, 0, 0.006482305179419597}, {
       0.5864299939704595, 0, 0.01517645341179089}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       0.5913331756452858, 0, 0.02368835096778804}, {
       0.5962085495579186, 0, 0.03202316938866924}, {
       0.6154171453626063, 0, 0.0636906172376373}, {
       0.6872976909326596, 0, 0.16928637566170113`}, {
       0.7664328815079947, 0, 0.266742169128484}, {
       0.8540209828379113, 0, 0.3597945329268557}, {
       0.951925055423371, 0, 0.4523212350167648}, {
       1.06212956051685, 0, 0.5475975021171873}, {
       1.1864448529114298`, 0, 0.6481545927936556}, {
       1.2604732644596965`, 0, 0.7056922035030405}, {
       1.3264899807447494`, 0, 0.7559606561820165}, {
       1.409671234971646, 0, 0.8181133153686464}, {
       1.4838120081365833`, 0, 0.872663434984493}, {
       1.5769655730440526`, 0, 0.9402346372138277}, {
       1.6600107525578949`, 0, 0.9997740809275446}, {
       1.7640214548575162`, 0, 1.0735445356658109`}, {
       1.8568016887333507`, 0, 1.1387654848120992`}, {
       1.972710476086052, 0, 1.2195753347940994`}, {
       2.0761848588435043`, 0, 1.2912226998402014`}, {
       2.2047773225198917`, 0, 1.3796981256078276`}, {
       2.319706146066483, 0, 1.4583539954094706`}, {
       2.3937813901425224`, 0, 1.5088463466286672`}, {
       2.4640242246695223`, 0, 1.5566374111493846`}, {
       2.593012665076405, 0, 1.644115680095381}, {
       2.669034997056822, 0, 1.6955119579117608`}, {
       2.7413998005517533`, 0, 1.7443679171383744`}, {
       2.8751568220851618`, 0, 1.8344588798223023`}, {
       2.9969792743462045`, 0, 1.9162929678293463`}, {
       3.109562702004454, 0, 1.9917745808416882`}, {
       3.21404784800531, 0, 2.0617007130210165`}, {
       3.312089560877171, 0, 2.1272254819065406`}, {
       3.3617156461331703`, 0, 2.160361504149783}, {
       3.365014131324725, 0, 2.16256326982239}, {
       3.4683137509402244`, 0, 2.2314351999314512`}, {
       3.5659919929879615`, 0, 2.2964942111511935`}, {
       3.6612920577262864`, 0, 2.359944882973844}, {
       3.7518357678457863`, 0, 2.4201788760023115`}, {
       3.8381336822676593`, 0, 2.4775452126286166`}, {
       3.9206963599131033`, 0, 2.53239291524478}, {
       3.9998760483390723`, 0, 2.5849619115258005`}, {
       4., 0, 2.5850441622287628`}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       0.24486853474725556`, 0, 0.0009285470749877983}, {
       0.2460703205798437, 0, 0.006964144441464508}, {
       0.2484627568537386, 0, 0.018855868993763854`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {
       0.2508402345101303, 0, 0.030514031500260577`}, {
       0.25320262948307837`, 0, 0.04194656201728638}, {
       0.2624992545846604, 0, 0.0856015936950548}, {
       0.27154742067870385`, 0, 0.12617088023553918`}, {
       0.3053253523852115, 0, 0.2655265458950435}, {
       0.34414902059907426`, 0, 0.4071320847467887}, {
       0.3884923318217594, 0, 0.5531140213861572}, {
       0.4388611301627683, 0, 0.7056891286934044}, {
       0.4958000678036376, 0, 0.8670922859187888}, {
       0.5295164933402087, 0, 0.9587659418693859}, {
       0.5599016028660492, 0, 1.039552029001494}, {
       0.5977890065599318, 0, 1.1382172336327128`}, {
       0.6318163025051393, 0, 1.2252994607494074`}, {
       0.6742418417618208, 0, 1.3321363236633021`}, {
       0.7122632179657488, 0, 1.4265955752421564`}, {
       0.7596368055738757, 0, 1.5428225797742292`}, {
       0.8020411972623271, 0, 1.6457698729254988`}, {
       0.8548169306146991, 0, 1.772653080395511}, {
       0.9020314025217675, 0, 1.8852406434130184`}, {
       0.9607416887852592, 0, 2.02418188332473}, {
       1.0132594331154077`, 0, 2.1476765907648914`}, {
       1.0783136187530094`, 0, 2.2997462429949964`}, {
       1.1365323066570807`, 0, 2.4351596426074367`}, {
       1.1739726162803445`, 0, 2.521914296249329}, {
       1.20948846558827, 0, 2.6040646208269065`}, {
       1.2747467832581065`, 0, 2.754552282789121}, {
       1.312969718388395, 0, 2.8424346837435106`}, {
       1.3493670001816565`, 0, 2.926009724762216}, {
       1.4166846037570995`, 0, 3.0802377269925785`}, {
       1.4780328895386456`, 0, 3.2204342421752257`}, {
       1.5347451530805056`, 0, 3.3497972230051754`}, {
       1.5873900395904845`, 0, 3.4696761357928185`}, {
       1.6367933375816253`, 0, 3.582027328479323}, {
       1.6601086942689862`, 0, 3.635003989581545}, {
       1.6616600520075455`, 0, 3.6385279814180738`}, {
       1.7136842635152363`, 0, 3.7565699249190225`}, {
       1.7628760233960656`, 0, 3.8680779328487316`}, {
       1.8108683778321129`, 0, 3.976826983469212}, {
       1.8211030800665156`, 0, 4.}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.5749107678694192, 0, 
        4.}, {-0.08139770123190963, 
        0, -0.0006701635194014469}, {-0.08434803469633333, 0, 
        0.044231297185984085`}, {-0.08722950973541316, 0, 
        0.08614725616455743}, {-0.09805425666731109, 0, 
        0.23097893450126084`}, {-0.11059606702372894`, 0, 
        0.37922675664867045`}, {-0.125036421470842, 0, 
        0.5330625185007294}, {-0.14156885131947572`, 0, 
        0.6947843651488326}, {-0.16040290893576908`, 0, 
        0.8667726933437201}, {-0.1716295390259131, 0, 
        0.9649173849283694}, {-0.1817683304753174, 0, 
        1.0514790397645628`}, {-0.19448633804453588`, 0, 
        1.1577037392857865`}, {-0.2059189310011923, 0, 
        1.251435441700589}, {-0.22027421289181137`, 0, 
        1.3671194309826085`}, {-0.23313614228652152`, 0, 
        1.4692757754137211`}, {-0.2492907371465582, 0, 
        1.5958684007763733`}, {-0.26373244553481234`, 0, 
        1.7077648209428806`}, {-0.2818660557201502, 0, 
        1.8467987784822102`}, {-0.298053958196879, 0, 
        1.9698248789127137`}, {-0.31836827217926406`, 0, 
        2.1229523694081682`}, {-0.33648823122997684`, 0, 
        2.258603210375649}, {-0.35919232826669234`, 0, 
        2.427490458948781}, {-0.37943807912835653`, 0, 
        2.5772855530812384`}, {-0.3924727733036537, 0, 
        2.673334956723809}, {-0.40482016825229505`, 0, 
        2.7641501262860366`}, {-0.4274530604696115, 0, 
        2.930077763169462}, {-0.44181214962407, 0, 
        3.035013784466016}, {-0.4554250202831398, 0, 
        3.1343525033102138`}, {-0.46829167244682113`, 0, 
        3.228093919702057}, {-0.4804121061151137, 0, 
        3.3162380336415445`}, {-0.5029949600551669, 0, 
        3.4801613988082467`}, {-0.5237542241929329, 0, 
        3.6305496434551117`}, {-0.5429265265209997, 0, 
        3.7691860746149675`}, {-0.5608528735796039, 0, 
        3.8986360399225166`}, {-0.5687347598379763, 0, 
        3.9555019641876994`}, {-0.5692593530931406, 0, 
        3.9592857675237307`}, {-0.5749107678694192, 0, 
        4.}, {-2.61944293578114, 0, 3.0229982974170335`}, {-2.616941147675899,
         0, 3.0200014377417284`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.421911136682303, 0, 
        2.786013985830389}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.24016178276008, 0, 
        2.567168779316083}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-0.40999811315669565`, 0, 
        0.0015409916214994645`}, {-0.41134866525921393`, 0, 
        0.005350800319608012}, {-0.4152638936559199, 0, 
        0.016296918116744285`}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-0.41915512420630907`, 0, 
        0.027018032709135397`}, {-3.438774713548781, 0, 
        4.}, {-3.23803980613164, 0, 3.761251937007238}, {-3.3018694440188323`,
         0, 3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-0.42302207969961025`, 0, 
        0.03752156732860251}, {-0.4382417957336082, 0, 
        0.07753063805012846}, {-0.453055481511507, 0, 
        0.11455264021720829`}, {-0.508274949298838, 0, 
        0.24043007900320323`}, {-0.5708807754930367, 0, 
        0.3648483672248687}, {-0.6415559665152554, 0, 
        0.4901819149134623}, {-0.7211338529393796, 0, 
        0.618957063321551}, {-0.8105554119716457, 0, 
        0.7536295934943013}, {-0.863376906114619, 0, 
        0.8297184470340888}, {-0.9108368145610453, 0, 
        0.8964934276731119}, {-0.9700214244305294, 0, 
        0.9779739260894744}, {-1.0230614625399619`, 0, 
        1.0496886245022605`}, {-1.0891999026920929`, 0, 
        1.1376337997103756`}, {-1.1483915371643805`, 0, 
        1.2152578409155759`}, {-1.2221315840523168`, 0, 
        1.3107281350940823`}, {-1.2880908002922125`, 0, 
        1.3952168520792825`}, {-1.3701413966920506`, 0, 
        1.4992823166818763`}, {-1.443534084543633, 0, 
        1.591599948287518}, {-1.5347254334191736`, 0, 
        1.7054293563894405`}, {-1.6163181093456591`, 0, 
        1.8066238396093195`}, {-1.7172572760358236`, 0, 
        1.9310675851855048`}, {-1.8076412347411757`, 0, 
        2.041940363119783}, {-1.8657683454963438`, 0, 
        2.112973029023029}, {-1.9209235387055597`, 0, 
        2.18025434543082}, {-2.022318172486133, 0, 
        2.3035629297600364`}, {-2.0809085459518823`, 0, 
        2.374604489495953}, {-2.1367459388194563`, 0, 
        2.4422193176672655`}, {-2.24016178276008, 0, 
        2.567168779316083}, {-2.3345540626127725`, 0, 
        2.680928080204464}, {-2.421911136682303, 0, 
        2.786013985830389}, {-2.5030869676017478`, 0, 
        2.8834959601975445`}, {-2.5793233167036007`, 0, 
        2.974926450145272}, {-2.616941147675899, 0, 
        3.0200014377417284`}, {-2.61944293578114, 0, 
        3.0229982974170335`}, {-2.6995699841982037`, 0, 
        3.1188721072638375`}, {-2.7753900633137967`, 0, 
        3.209504870754742}, {-2.849383484038376, 0, 
        3.29792116674691}, {-2.919723587980931, 0, 
        3.381904527741606}, {-2.9867983741336865`, 0, 
        3.4619307681908693`}, {-3.050995841488869, 0, 
        3.5384757025467404`}, {-3.1125848679555554`, 0, 
        3.6118679019503945`}, {-3.17183433144282, 0, 
        3.682435937543006}, {-3.23803980613164, 0, 
        3.761251937007238}, {-3.3018694440188323`, 0, 
        3.837208203660807}, {-3.3633232451043957`, 0, 
        3.9103047375037097`}, {-3.422401209388329, 0, 
        3.980541538535948}, {-3.438774713548781, 0, 
        4.}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-0.7524479628504781, 
        0, -0.0024370980793219418`}, {-0.7574595826574196, 0, 
        0.002519646088146447}, {-0.7810476903474675, 0, 
        0.027341450661089173`}, {-0.8040942793946679, 0, 
        0.04965357995649679}, {-0.8265312526316726, 0, 
        0.0696642197792893}, {-0.9090368185815776, 0, 
        0.13226892111729754`}, {-0.9958497151633394, 0, 
        0.18341954183196246`}, {-1.0940359095230165`, 0, 
        0.23095152402299293`}, {-1.2051544482142327`, 0, 
        0.277884743439456}, {-1.3354667601009906`, 0, 
        0.32808978360846286`}, {-1.48400336409034, 0, 
        0.38174271400813786`}, {-1.5773191646620055`, 0, 
        0.41421681982934727`}, {-1.6597374552822863`, 0, 
        0.4423562184119268}, {-1.7622553627276054`, 0, 
        0.47675323494639477`}, {-1.8532152935362554`, 0, 
        0.5068584377248067}, {-1.9713090571091842`, 0, 
        0.5454534194246343}, {-2.0759659492610028`, 0, 
        0.5793031074179551}, {-2.2083701330020413`, 0, 
        0.6217183237209467}, {-2.325890607155771, 0, 
        0.6590720207208786}, {-2.4736933933741287`, 0, 
        0.7057123201788662}, {-2.60509523948393, 0, 
        0.7469311881147722}, {-2.770376742233452, 0, 
        0.7984927242395742}, {-2.9174990439096367`, 0, 
        0.8441797854486603}, {-3.0098318037119727`, 0, 
        0.8727534717813846}, {-3.0973817785257767`, 0, 
        0.8998051367118247}, {-3.258133373187794, 0, 
        0.9493424023658539}, {-3.4034888611301213`, 0, 
        0.9940009540966732}, {-3.5371832755871946`, 0, 
        1.0349901635902088`}, {-3.6607304186742398`, 0, 
        1.0727941757992887`}, {-3.776311020441678, 0, 
        1.1081091085844395`}, {-3.8341306486148476`, 0, 
        1.1257580964161833`}, {-3.8379718944579895`, 0, 
        1.1269302273657187`}, {-3.9607251115456603`, 0, 
        1.1643403847981113`}, {-4., 0, 
        1.176297093481058}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-0.9090368185815777, 
        0, -0.13226892111729746`}, {-0.9958497151633396, 
        0, -0.1834195418319624}, {-1.0940359095230168`, 
        0, -0.23095152402299277`}, {-1.205154448214233, 
        0, -0.2778847434394558}, {-1.3354667601009913`, 
        0, -0.32808978360846275`}, {-1.4840033640903414`, 
        0, -0.3817427140081379}, {-1.5773191646620073`, 
        0, -0.41421681982934744`}, {-1.659737455282287, 
        0, -0.44235621841192657`}, {-1.7622553627276072`, 
        0, -0.4767532349463949}, {-1.8532152935362558`, 
        0, -0.5068584377248063}, {-1.9713090571091847`, 
        0, -0.545453419424634}, {-2.075965949261003, 
        0, -0.5793031074179548}, {-2.2083701330020418`, 
        0, -0.6217183237209465}, {-2.3258906071557717`, 
        0, -0.6590720207208784}, {-2.4736933933741305`, 
        0, -0.7057123201788662}, {-2.6050952394839313`, 
        0, -0.7469311881147722}, {-2.7703767422334535`, 
        0, -0.7984927242395742}, {-2.917499043909638, 
        0, -0.8441797854486603}, {-3.0098318037119736`, 
        0, -0.8727534717813844}, {-3.0973817785257776`, 
        0, -0.8998051367118247}, {-3.258133373187795, 
        0, -0.9493424023658538}, {-3.403488861130122, 
        0, -0.994000954096673}, {-3.537183275587195, 
        0, -1.0349901635902086`}, {-3.66073041867424, 
        0, -1.0727941757992885`}, {-3.776311020441678, 
        0, -1.1081091085844392`}, {-3.8341306486148476`, 
        0, -1.1257580964161833`}, {-3.8379718944579895`, 
        0, -1.1269302273657187`}, {-3.9607251115456603`, 
        0, -1.1643403847981113`}, {-4., 
        0, -1.176297093481058}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-0.45305548151150726`, 
        0, -0.11455264021720905`}, {-0.5082749492988381, 
        0, -0.2404300790032035}, {-0.570880775493037, 
        0, -0.36484836722486913`}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-0.6415559665152554, 
        0, -0.49018191491346225`}, {-3.43877471354878, 
        0, -4.}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-0.7211338529393796, 
        0, -0.618957063321551}, {-0.8105554119716456, 
        0, -0.7536295934943013}, {-0.863376906114619, 
        0, -0.8297184470340888}, {-0.9108368145610451, 
        0, -0.8964934276731119}, {-0.9700214244305292, 
        0, -0.9779739260894744}, {-1.0230614625399617`, 
        0, -1.0496886245022607`}, {-1.0891999026920924`, 
        0, -1.1376337997103754`}, {-1.1483915371643802`, 
        0, -1.215257840915576}, {-1.2221315840523168`, 
        0, -1.3107281350940827`}, {-1.288090800292212, 
        0, -1.3952168520792825`}, {-1.3701413966920497`, 
        0, -1.499282316681876}, {-1.4435340845436324`, 
        0, -1.591599948287518}, {-1.5347254334191733`, 
        0, -1.705429356389441}, {-1.6163181093456587`, 
        0, -1.8066238396093197`}, {-1.7172572760358231`, 
        0, -1.931067585185505}, {-1.8076412347411754`, 
        0, -2.0419403631197834`}, {-1.8657683454963438`, 
        0, -2.1129730290230295`}, {-1.9209235387055592`, 
        0, -2.18025434543082}, {-2.0223181724861328`, 
        0, -2.3035629297600364`}, {-2.080908545951882, 
        0, -2.374604489495953}, {-2.1367459388194563`, 
        0, -2.4422193176672655`}, {-2.2401617827600795`, 
        0, -2.567168779316083}, {-2.3345540626127717`, 
        0, -2.680928080204464}, {-2.4219111366823025`, 
        0, -2.786013985830389}, {-2.5030869676017473`, 
        0, -2.8834959601975445`}, {-2.5793233167036007`, 
        0, -2.974926450145272}, {-2.616941147675899, 
        0, -3.0200014377417284`}, {-2.61944293578114, 
        0, -3.0229982974170335`}, {-2.6995699841982037`, 
        0, -3.1188721072638375`}, {-2.7753900633137962`, 
        0, -3.209504870754742}, {-2.849383484038376, 
        0, -3.29792116674691}, {-2.9197235879809305`, 
        0, -3.381904527741606}, {-2.986798374133686, 
        0, -3.4619307681908693`}, {-3.0509958414888687`, 
        0, -3.5384757025467404`}, {-3.1125848679555546`, 
        0, -3.6118679019503945`}, {-3.1718343314428195`, 
        0, -3.682435937543006}, {-3.2380398061316407`, 
        0, -3.7612519370072386`}, {-3.3018694440188323`, 
        0, -3.837208203660807}, {-3.3633232451043957`, 
        0, -3.9103047375037105`}, {-3.42240120938833, 
        0, -3.9805415385359497`}, {-3.43877471354878, 
        0, -4.}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.5749107678694193, 
        0, -4.}, {-0.08139770123191005, 0, 
        0.000670163519406717}, {-0.08434803469633347, 
        0, -0.04423129718598363}, {-0.08722950973541328, 
        0, -0.08614725616455698}, {-0.09805425666731123, 
        0, -0.2309789345012604}, {-0.11059606702372908`, 
        0, -0.3792267566486703}, {-0.12503642147084212`, 
        0, -0.5330625185007292}, {-0.14156885131947589`, 
        0, -0.6947843651488325}, {-0.16040290893576942`, 
        0, -0.8667726933437204}, {-0.1716295390259135, 
        0, -0.9649173849283698}, {-0.18176833047531782`, 
        0, -1.051479039764563}, {-0.19448633804453633`, 
        0, -1.157703739285787}, {-0.20591893100119274`, 
        0, -1.2514354417005893`}, {-0.22027421289181182`, 
        0, -1.367119430982609}, {-0.23313614228652196`, 
        0, -1.4692757754137216`}, {-0.24929073714655864`, 
        0, -1.5958684007763737`}, {-0.2637324455348128, 
        0, -1.7077648209428813`}, {-0.2818660557201507, 
        0, -1.8467987784822113`}, {-0.2980539581968794, 
        0, -1.9698248789127142`}, {-0.3183682721792645, 
        0, -2.122952369408169}, {-0.3364882312299771, 
        0, -2.2586032103756493`}, {-0.3591923282666927, 
        0, -2.427490458948782}, {-0.37943807912835675`, 
        0, -2.577285553081239}, {-0.3924727733036538, 
        0, -2.67333495672381}, {-0.4048201682522954, 
        0, -2.7641501262860375`}, {-0.42745306046961185`, 
        0, -2.930077763169463}, {-0.44181214962407034`, 
        0, -3.0350137844660163`}, {-0.45542502028314014`, 
        0, -3.1343525033102146`}, {-0.46829167244682135`, 
        0, -3.228093919702057}, {-0.4804121061151139, 
        0, -3.316238033641545}, {-0.502994960055167, 
        0, -3.4801613988082467`}, {-0.523754224192933, 
        0, -3.6305496434551117`}, {-0.5429265265209998, 
        0, -3.7691860746149675`}, {-0.560852873579604, 
        0, -3.8986360399225166`}, {-0.5687347598379763, 
        0, -3.9555019641876994`}, {-0.5692593530931406, 
        0, -3.9592857675237307`}, {-0.5749107678694193, 0, -4.}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       0.2624992545846606, 0, -0.08560159369505477}, {
       0.2715474206787041, 0, -0.12617088023553924`}, {
       0.30532535238521175`, 0, -0.2655265458950439}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       0.3441490205990745, 0, -0.407132084746789}, {
       0.38849233182175963`, 0, -0.5531140213861574}, {
       0.4388611301627686, 0, -0.7056891286934046}, {
       0.49580006780363806`, 0, -0.8670922859187892}, {
       0.5295164933402094, 0, -0.9587659418693871}, {
       0.5599016028660496, 0, -1.039552029001494}, {
       0.5977890065599321, 0, -1.138217233632712}, {
       0.6318163025051399, 0, -1.2252994607494077`}, {
       0.674241841761822, 0, -1.332136323663304}, {
       0.7122632179657494, 0, -1.4265955752421569`}, {
       0.7596368055738768, 0, -1.5428225797742305`}, {
       0.8020411972623279, 0, -1.6457698729254995`}, {
       0.8548169306146998, 0, -1.7726530803955116`}, {
       0.9020314025217682, 0, -1.8852406434130187`}, {
       0.96074168878526, 0, -2.0241818833247303`}, {
       1.0132594331154083`, 0, -2.147676590764892}, {
       1.0783136187530098`, 0, -2.2997462429949964`}, {
       1.136532306657081, 0, -2.4351596426074362`}, {
       1.1739726162803448`, 0, -2.5219142962493284`}, {
       1.20948846558827, 0, -2.6040646208269065`}, {
       1.2747467832581068`, 0, -2.7545522827891205`}, {
       1.312969718388395, 0, -2.8424346837435097`}, {
       1.3493670001816565`, 0, -2.926009724762215}, {
       1.4166846037570995`, 0, -3.080237726992578}, {
       1.4780328895386456`, 0, -3.220434242175225}, {
       1.5347451530805056`, 0, -3.349797223005175}, {
       1.5873900395904845`, 0, -3.469676135792818}, {
       1.6367933375816253`, 0, -3.5820273284793225`}, {
       1.6601086942689862`, 0, -3.635003989581545}, {
       1.6616600520075455`, 0, -3.6385279814180738`}, {
       1.7136842635152363`, 0, -3.756569924919023}, {
       1.7628760233960656`, 0, -3.868077932848732}, {
       1.8108683778321129`, 0, -3.9768269834692127`}, {
       1.8211030800665151`, 0, -4.}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.186444852911429, 0, -0.648154592793655}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       0.6872976909326596, 0, -0.16928637566170146`}, {
       0.7664328815079938, 0, -0.26674216912848314`}, {
       0.8540209828379108, 0, -0.35979453292685526`}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}, {
       0.9519250554233707, 0, -0.45232123501676447`}, {
       1.0621295605168495`, 0, -0.5475975021171868}, {
       1.186444852911429, 0, -0.648154592793655}, {
       1.260473264459696, 0, -0.70569220350304}, {
       1.326489980744749, 0, -0.755960656182016}, {
       1.4096712349716458`, 0, -0.8181133153686461}, {
       1.483812008136583, 0, -0.8726634349844926}, {
       1.5769655730440515`, 0, -0.9402346372138268}, {
       1.6600107525578944`, 0, -0.9997740809275443}, {
       1.764021454857515, 0, -1.0735445356658102`}, {
       1.8568016887333505`, 0, -1.1387654848120992`}, {
       1.9727104760860514`, 0, -1.2195753347940992`}, {
       2.0761848588435035`, 0, -1.2912226998402012`}, {
       2.204777322519891, 0, -1.3796981256078273`}, {
       2.319706146066482, 0, -1.4583539954094704`}, {
       2.393781390142522, 0, -1.5088463466286672`}, {
       2.464024224669522, 0, -1.5566374111493846`}, {
       2.5930126650764045`, 0, -1.644115680095381}, {
       2.669034997056821, 0, -1.6955119579117608`}, {
       2.741399800551753, 0, -1.7443679171383746`}, {
       2.8751568220851618`, 0, -1.8344588798223023`}, {
       2.9969792743462045`, 0, -1.9162929678293463`}, {
       3.109562702004454, 0, -1.9917745808416882`}, {
       3.2140478480053103`, 0, -2.0617007130210165`}, {
       3.3120895608771717`, 0, -2.1272254819065406`}, {
       3.3617156461331703`, 0, -2.160361504149783}, {
       3.365014131324725, 0, -2.16256326982239}, {
       3.4683137509402244`, 0, -2.2314351999314517`}, {
       3.5659919929879615`, 0, -2.296494211151194}, {
       3.661292057726286, 0, -2.3599448829738443`}, {
       3.7518357678457868`, 0, -2.420178876002312}, {
       3.83813368226766, 0, -2.477545212628617}, {
       3.920696359913104, 0, -2.532392915244781}, {
       3.999876048339073, 0, -2.5849619115258013`}, {
       4., 0, -2.585044162228763}}, {{{}, {}, {}, {}, {}}, {{}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, 
        {RGBColor[1, 0, 0], Thickness[Large], 
         Line3DBox[{154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
          165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 
          178, 179, 180, 181, 182, 183, 184, 185, 186}], 
         Line3DBox[{225, 226, 227, 234, 235, 236, 237, 238, 239, 240, 241, 
          242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 
          255, 256, 257, 258, 259, 260, 261, 262, 263, 264, 265, 266, 267, 
          268, 269, 270, 271, 272, 273, 274}], 
         Line3DBox[{315, 316, 317, 320, 321, 322, 323, 324, 325, 326, 327, 
          328, 329, 330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 
          341, 342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
          354, 355, 356, 357, 358}], 
         Line3DBox[{395, 396, 397, 398, 399, 400, 401, 402, 403, 404, 405, 
          406, 407, 408, 409, 410, 411, 412, 413, 414, 415, 416, 417, 418, 
          419, 420, 421, 422, 423, 424, 425, 426, 427, 428, 429, 430}], 
         Line3DBox[{471, 472, 473, 480, 486, 487, 488, 489, 490, 491, 492, 
          493, 494, 495, 496, 497, 498, 499, 500, 501, 502, 503, 504, 505, 
          506, 507, 508, 509, 510, 511, 512, 513, 514, 515, 516, 517, 518, 
          519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 
          532}], Line3DBox[{567, 568, 569, 570, 571, 572, 573, 574, 575, 576, 
          577, 578, 579, 580, 581, 582, 583, 584, 585, 586, 587, 588, 589, 
          590, 591, 592, 593, 594, 595, 596, 597, 598, 599, 600}], 
         Line3DBox[{630, 631, 632, 633, 634, 635, 636, 637, 638, 639, 640, 
          641, 642, 643, 644, 645, 646, 647, 648, 649, 650, 651, 652, 653, 
          654, 655, 656, 657, 658}], 
         Line3DBox[{693, 694, 695, 702, 708, 709, 710, 711, 712, 713, 714, 
          715, 716, 717, 718, 719, 720, 721, 722, 723, 724, 725, 726, 727, 
          728, 729, 730, 731, 732, 733, 734, 735, 736, 737, 738, 739, 740, 
          741, 742, 743, 744, 745, 746, 747, 748}], 
         Line3DBox[{785, 786, 787, 788, 789, 790, 791, 792, 793, 794, 795, 
          796, 797, 798, 799, 800, 801, 802, 803, 804, 805, 806, 807, 808, 
          809, 810, 811, 812, 813, 814, 815, 816, 817, 818, 819, 820}], 
         Line3DBox[{856, 857, 858, 861, 862, 863, 864, 865, 866, 867, 868, 
          869, 870, 871, 872, 873, 874, 875, 876, 877, 878, 879, 880, 881, 
          882, 883, 884, 885, 886, 887, 888, 889, 890, 891, 892, 893, 894}], 
         Line3DBox[{927, 928, 929, 936, 937, 938, 939, 940, 941, 942, 943, 
          944, 945, 946, 947, 948, 949, 950, 951, 952, 953, 954, 955, 956, 
          957, 958, 959, 960, 961, 962, 963, 964, 965, 966, 967, 968, 969, 
          970}]}}}], 
     NCache[{{{Rational[1, 2] 3^Rational[1, 2], Rational[1, 2], 0}, {
        Rational[-1, 2], Rational[1, 2] 3^Rational[1, 2], 0}, {0, 0, 1}}, {0, 
       0, 0}}, {{{
        0.8660254037844386, 0.5, 0}, {-0.5, 0.8660254037844386, 0}, {0, 0, 
        1}}, {0, 0, 0}}]]}, GraphicsComplex3DBox[CompressedData["
1:eJxM3Hc01+//+HEjK5E9iyRFO6slly0ZRRkpKxmRBkWpkIaZnWSPkOy9XVb2
3vNl7+wkFb7v3zm/z+uhfzrnfvzh8LpuHtf1HHx3HmqYkJGQkAzQkJCQ//c/
u8l0a+mMpmSqkNrxY35TEiT//x+594v1kYkAtAvv5omxPyz5v/7E9cTlkYkv
KNrkuVG0vTixmyqFBbTqpKKR7F+fN/qliP34u/dLwxNZaCnvNHm0vQKxx5qU
sN3kLUAkRRb3r3CqEDuPwi+JVh2MXA3aLDb6rxG7CvOn9ENK5YjB6GGEauJ1
Ynclz6wcnqhEQXf2dETZaxF75WpTd6hzNeK9m0D9S+kmsZOMz87q8NahOBOF
S1c4bxO7RAflFktRAzppNvY4fFqf2J9VHmRs1WlGuqJS1zf6DYldV5fXr+pP
C+LJ9rKKkb0DX6+RHHJIqQ2Nig26qCYaE3vglYuxzp/aUWzOseh1JhNiz5Kp
TRme6ED3ztoXRdmbEnvbBe08SdEudCKvpkt51IzYl4QnykKdu9HSOfblNaV7
xE5/zKb+T0sPyso3oY1Mt4CfPz9ppw5vH3p2IUvgCud9Yr/C7U3IsepHFwvJ
pH46WRG7OfP+aZaiAbR9UV03fPoBsb+nTVy23k1ARoSrFw4JPiL2L+Tn/7bo
DKEKHjvFjX7oI6+MnT9dH0aHDcJvNHk/Jvbl50ddqv4MI9eI70Yxstbwe7Fd
9liLGkGzQz8ePFuHzmCd53NIaRSpHmB5qZpoQ+y8Dxw/Xl8aRamGF90OGjwh
9lMWCsHOn8YQY9SdwHWmp8QuaUoXkS45jp6MuMU0VEFXu9MRMzwxjrr40tOi
7G2JXU8/5OveDxPo/J2eYtuTdsRupXsnWVJ0EoVEb9cpj0J/qSWUYdU/iTZH
D/ccCHxG7J4aSzmhzlPIkF9tYk3pObGHqOUW1gtNo3Ljpyt1m9ATrziU/mmZ
Roe+hG5HpNsTe4GC/HehZzPIZbxiz1OTF8ReJ7OnTod3Fs0cmuO8wvmS2Hsl
25tcqmaRsgnTEd5G6DMXgttzrOZQSux50Z9Or4j9t7hRzwTLD8QwaShdK+pA
7NQigoMsRT+QzWFXtfBp6OynFkdkjedRp2nqLZtQR2I/cixn0nr3Agq9bil6
SNCJ2MWPvJqLSl9AjatbBfTO0BX45ZZadBbRlr+f9EY/dFVe2rXt7UV0TPRw
zZjYa1hHc7q2GYWakhu0HpdHLMClexSP69fyA5Dd7wEOKiMT9L+e89h//1r+
FySy8M6E0ugpsecZPtBcZEtFrGlqEZXUTsQ+GP+l6md+FmK410dLafSO2PV4
/UYfT+ejPQdNnynmuxM7IdBxa4ENo7fzz6wrqX2I/bSLOF3OwXJEVlciOJHl
R+xLMidCfuZXIse4XUMURh+JPXWLX0hEvRr9c77y8TBdELE/LODKfTxdi54b
+Cgr5gcT+ylbRvk0xwa0frGL1NwkjNgXz1C3L7A1owt76G9XUkcSe7etYxpb
dwt6/ud0bod+FLHndtivZx9sQ7nT15kmsqKJ/ZOwraTmg3b0q8vWam33F2K3
83n87md+BxL9/rmGwiiW2LUX7jf4U3Qhm8wifrbcOGI/q2LOLKLejTKihhwO
030ldvZvxrptoT1oyZusT9w4gdjXqQyiHk/3olMOAmKK+d/g+zfRnWYQ7UdW
9y/7aO9Ngu+/QvNUmuMAStK1nDMzSYbvn0/d9mr9IJq77KXwrDAFvn9HleIF
tiH0MaTnWiV1GrEnLfCTKZ4ZRllMFg4NmdBDw6Ji2bqHUYfb38QO/XRi/6DC
qzT5cgT9JPnQO0CTQeyv/ob+yD44ilie8VBNZEF/8I3L513NKBJdTBWdN8gk
dv2bQSKaD8bQdVPpO2u7s4hdjZqt+xDLOLIZbPPezIaOcv3tf+aPI/8bd4sp
jLLh82DKyFNpMIEy69dm6fbkEPsBVu8yf4pJ1C7jwsGWC52hco+JceIkWsnn
UOC5k0vspDbu1CLqU4jpzDebw3R5xL7MR51Etj6FhL9ejDqZB3205d3VttBp
pMHb2CRunE/sbY7kq1EyM8g6UP+fJH0BsVecfB34eHoG+dEtCSnmQ88c3Dov
7TWL0t++1r56t5DYv3i+HGQQnUOtf5neae8tIvaAi3+chnvn0LL1lwyDAuhv
Z+0OpTn+QIyzYsNmJsXE/vTzWrWjwDw6Y1RN94ihhNhNLttYXq2fR9d6dC4+
K4Sutb5Ez/t4AT26OmvuZIqJXSHuQcYC2yK6PHZJuZK6FH7+mj80S4oWUUc4
5Z3L+tCNkxOplYQ1JRsutLWWX4R56Utu5+qMeAAS3wy6zy4KLhk8lL0yI/4F
xU8WFLCJgj9zZKHBehopKFNNCPM1eRO7hLL92rR4FjLsrzdiEwVPyD7G7Y+R
y0eme8nHuV+DGzWENnk9jRJ0X/aCKV9TBLFfDtjOoU0rQ/mF5574fwAHjuaz
1k+LV6IizRtibKKw3ukIx4a+F1ehksWHv4L64sEfMpnVaLlaVObmkcv9GtZv
2xEdKqf6elTBH/8s/Ais02yVB9x6Gk2oqrj8PF9TKrE3nCtnD7vfgsaPPdxU
vwDr7pJyYxRtWiua+P1Pz/8DrK8UvZ5j9qttaOq7e0nHMKyvA4/GsqfFO9C0
HwcvmyisF1/nBaRt34lmDOIctV1ydvzcNmq/F3eh2eOiw0F9sC5s4nfdECXt
QT82yqT6TsDnfCJ/LyFarhfNV12N4n4Nn2etBi5zRtc+tOA/SKrXAZ/naoLA
imN9P1o0tLwTfgQ+n+eXT79coB9Eyyc2yofs4XP4jVyCUk+DgFb+vOfna4LP
4T42RZ/6j0Poj/FumXQf+LwpsgjRhd0fRi+uqK+oXygjdqewkxo36EfQv9NB
0Stj0AsOi36iTRtBr9iHNPw/lBP7aur5gXL1UbS9KUAueraC2I+fR3z2q6PI
afx+ZscwdJNyOdMzH8cQaX2m8VP3SmIPV76SOC0+jpzT/zCziX4HzzuuLkX0
jCPyIOnKnEHoDPqaYtr2E+itg+sTbZcqYlea0rWn3zeJKEyaD/0+XU3sbx4Z
4u/Fk+i9MltnUB/0og2TXa8MphC1sN67829riH3N2VJJlHQauXF8Ees7UUvs
J/c89pqLnka7t2cn7Luhm320bY+Wm0EeE2cCuV/XEXskz0sO3ckZtKfhmULR
0Xpi741/rcfoOos+ZOBftzugM59xia4RmkP0nynjN181ELtKgeeUY/0c8nFU
1Q4/0kjs72T9jp+1+s8x0wAq1Aq9pOHT4wX6eeSn0p87ZN8Efzc1w3Ji0+YR
s8hBc6dDzTCHDEX/va2xgAI473HwNUG/Y/5ViuXnAqIi0RkfvthC7LMk4QJV
V29IXv0x1njVGvZxB5weKU/o+yPPE4XIXd8RPidqK1/H9WNQyunAc2764FKX
3vEkLfrk/+bP+K+T7z/BHCWeqT2un4lQBnm2qz7403Tp2s0w8Tz0eTvVkDUk
htil5Od1teiLEfNhgunke3Dm5mH5FKrVUuSlsscq1zqR2Bm/MZ8a169AVDYX
bFz1wZPaE6OppXXfUalKVtHxWPDEOT3tdJh4Ddo0qEesIeDGBTHH9OfRdei8
zWj5pg+4sZKnKqxF34hs32/IT74HHxIl9mUK2zejjM8MtU0vwYczhmufqVZb
0GLSEZVca3CAPvp235pgGzpWKtkcYQ4OzI5VcI3rtyPzdk0NV31Y71UCx261
BXQgDZsci3PfYL1Hm/mFlNZ1ouV/0knHY2FdOyRs9KeQdCPv943zByJhXevO
Ge4LE+9BJxhunmINgfUrfqLmtsf9XlT/efwRTSCsX6aHp8KeR/chC/5HGZs+
sE4X0wIHzXr6EXXy39VlD1in9Sub+7X+cyxO3EVs8j2sx6+iJvpycgQkX8pk
1/ca1uM724ZwYfshNK4Untf0EtbdmYHPDxl0htGbdqE/5Xaw7nhfNXpTrQ6j
g3rZF3OtYX3R85CmbX0YQWWTUq8SrWB9bZaItqwJjiLDRw0lEeawjuYMzJd+
VPzn24Y2SYAxrKM+klCGcf0xFP5mTNpVH9ZLTVTz6f6NMRTxPle65Disl1wZ
cvW2gHH0QPnVnXPfoMeOiT+uPTWBJBlk32QcaYW55a2Fb2ndBKLrpP5yPBa6
s0B4eq7JJBr83FQZ9988/r/+uKq1NYVkCiXpB0wciIRuYEaxEhsyhV7y61KG
7G/fMTeeZwoTn0bK07xHWEOgSyTcFw5onUbcyROK3hwdxH7sSqSGx/0ZNPs4
0ZwmEDrnXLu1M9UsKhB/7PaGuZPYqT2p/J9HzyK3v+LfNn2g/zp+MfPRpTl0
s/RfnR19F/x9bHzQbtYzhwTflc8te0DveBC9qm/zA/1Wct1zn6ab2Mv3djFr
/edbDb3aicn30BPSaERVE+aRbzuzmuGuHmL/mNu4PMJ+XVI6LJ0z9LU80av+
fXL9NmJ+yFzQUcXH+S3x61Xp3snYiEWjEEXrSG/nAPi7tsf80/FriYj07xeu
7opw+Hy+E/hlLZaBRLotr3g7wz5obdenyObyHDR1+h2VSAzsX+6+pVY+fq0Q
BbuHV3ZVwL6jk9x+zXUQoyMr/VKXVsCf6LK1Zmux/9ZnhDmvtzPM+TdfnxTg
e1mJepXXNoeZwBkGaTP75vIqlPH79YBwDDhTTRLZ/IqmFnnE0he+FYF52LG0
59Dxa/XorkbI564KmCvEnRjt+wIbUcQ2swTLDk/m0ZVm18FmRKule+zSCnjS
5ijtx83Uip4lRXKZXgA3UoYGi6zF2tA42RSNtzO44Y7sp2p12pH6zRMbuXXg
hkkEGxPfyw5UnGozPcwEPkhvZ0g8i+hERykLumlugQ/7Da6aNZd3ocDbJNXC
MeDD75I538OT3Yg8UyHn1hz40MHjWvSKphc9pPkQ+1YEHEh1ODTVcbwPDRi0
ByS/AAc8CKWMx6/1o8s5nG+7KsABc0k9iTc2A+gWZVr+NgWsa7nwDdO+wEHk
d+b6GZYd651v66PvmQICqrn966ugGqzrTT3hItfBIbTt8vnApRXo8/pmqw+d
hpF4pkSQeiCs636vbFduphFkRRjaa3oB1m9tCTlPdcwIiqF542JPgJ63oJ5p
LTaK+kQPb3s5w/qN44m8zFM9ihgNa21jDsM6DVBbGKzVGUOXPe4v5NZBd3aQ
sHk6O4YccvaaNjyAdfo4xZ2a7+U4yh7JGBxmgvVoQOgJa6CbQD/2aGmu5UBX
pT8i8ixiAvGf22iguQXr9KLk0xr+M5PopnGoHM829KMPKvSayyeRjxcqEo7p
JXaOcMZV+xtTqDp/VERRsY/YKZsMXA9PTqGt8XeJt+ag/9xM3t9mN41EGYT4
H3n3E/vYiX8Zr2hmkOXFhuC3IgPE3qp35bJQyAyKNn3I9LkbOv4QNNhxfBb1
+jK5J78YhM958aS1U8ks2lucTVrOSyD20HlR6uPX5pDCtM7zrgrob/a/Cese
mUNPmf8tzZoNgZ9VWnaF3uqSBdY8jq/FrxC9MjwbsWyHfZBP+NeEL9uu8Hu8
xWdihyNRkN/P7phtOBcK4bZpFeZNQKsW7skFGPZrNVajPHY4DYV4cj2M2Ybz
lgpV2s4bi1lIJuXbaU8Ec1HxCVEPYd58tGa2/3kBhv1UPp2eNMPVYlT7bKI3
ZQjmn95f5X9tcSkKdUu+ELMN5wBdpt1dJt3l6GHw05BPvOBPe9dc+o3FSiST
eOmfB4J5pkWB5IMsVTWiJTifLD0FzjTmsJgL89aiJ5OT+gUY5pa6w0KyfGfr
EWHhinfWVXCmOvASD8PVRqS4noJThsCZSkqNjS3TZpS+zbT09SE4Y3hRZNYW
tyBuarsDMdvgjIFNsfaD+lb0lqH/Wpg3eKKXqPjdpLsNLXCg1594wZPbY63C
emPtSJsvJt03FTzR5b4deWOxA5UJUY16IJgfbl6fpFP524lYP4vRVJiBG9oe
j17IUnWjK2FmfKWnwAetij/TF5h7kGPU5/PF69Bv/H2rJczbi7Ji69ULMLhx
XWRvpdCxPjSTsHkv1wV80LD8fIbvbD/iSTnlnHUVfNCI4Y/gkB1ANzKMgtPZ
wQH1/uQ9DFcHkVuOf0bKEPRrzOfsqW4RUEnB97rEePDhmnL51JbpEPpZsj76
9SE4EC8dd/TF+WEkVCH0N/YsrPd4PcsRWzyMDKpvMcfscCD++ekga/kRFFD/
4VhkNTgQ93FN7UH9CKptxrJh3rDe49ILKCz+3/60fflWsDas97hGxyKT7lEk
2sP/5BMvrOvYGTkbI70xdG9A0zNgaken2H1Ub+y/uW7Y5YtvKqz3L3zNwzr3
xlHHeH6Rlx2s6y+XAj7dWBxHu2fmOjwQrOsvN2+qXXs6gSJ+edlWkg8Te8xT
HgqVvxOo4Hc8WYXZju47Vqj4ehJ1/in1Kqvf0ZO/WstSTaGlf71cpadGYE6o
tRJCH6b+25+uxJX47+gTwsMXmKeRAOkekeJ16FGkvwPFP08jKXIBXHhrFPr+
YlVh3hmkSyGpXIChB5933nUydgY9otLuzuMfg3nSOP/S+xdXJdcuPRQ++0qN
6FWGGUH0GKUXuqSEab8wf4B1J0Z2/ihlOPrm3ckewwzn0j0hdZYRb+OQbvEE
S0ETnCM17mMpFKJMQUMZw2HRzHAuNNJ0kqKvIgMJd1j5yx8Hl257tx+PeJuD
1tTmuvObwKXuq89u3JUvQHm15vtOPoa5SJ1h/0shyhJkLzdpGM0M+yzT6WF1
u7FSFD6UrkF7C+afmMuZE70V5Wg7dOmJ/HHwZ/jru+cSXyqRoe6pT46bMP/s
p9Ghi3hbhcrYH+TnN4E/uveORpGa1KCDnUn9qxHgz6faf6J35evQG7+5zROP
YZ7pEGquqRJoQONXjx4wl4F9DaN71G0hyiYkT3dPJpoZnFGbtVnymGxGcXXx
dwfGYW6RF+CXsRtrQeRyNrK0t8CZu5p7PL+2t6KsaL8bX2V37DverXX2VrSh
u6QZJvLHwZOobAIvbVY7YjVstR1lAU/wRPU9iS8d6HvJkovjJnQCa3qmVUAn
st3P8HnfJDjzTz54M/xtFzr88tS3/CbwhNv2jWLLk27U06dWqJULnlyMu+9L
atKD3M4/aFiNAE90uzT7hTV70YWgD4M+ruDGc0okcFe+D839Slo48RjcCBIX
fPhRrB+FajZs190EN/JMGfOrBAaQatYcg7kMuNEd+IfsN+sg2maiPUhxDHz4
VTWmIkRJQGmPj4pEM4MPrOsNgbq/CMioRUkO/YMueiRn2GNyCDGduqc5MA5u
fEu8+lHfchhVfHA1fd4IbuTLyl2wGxtGF361X6S9BQ7U9p8b8r41gvxjjStv
NkPvtTnx9mv7CJq7saryVRbW+zTtQaEy5VEkt+tN569c6L9j2Jp6/9vnhmUy
6csfh/VOJUFrs3JxDK3diZ70j4TO3rHNTps1htSYhB+OsoADR+7/LOI/Po7i
ysrWT7tBF981YyTxZRxtP1J3ctyErhA6SKm5bwLpHBihbno8Tuyaom2JVgET
KK35ke++SegmDVXX3u+ZRDSOJFyWuhPE/vRu4Vr420lkdNInOr8JuuO/1ODc
f5Moa5D3GLXsJMzbJgQJdF1Zspvra+0InzrRKxEhufAze93R78ejW1lacJ1O
5dS3itN7g1GicfvTLC24XrZ9iPP2XY8YpOsldp/eGeYoHWE9rdN7v6G3A8pn
srTgOlFvxDVBB6U01L/88rjRfdjHvYuzFrjrkYlEqFKO0DvDvCScHHDwSmMO
8tg3dLDwE8xLhMwc3tN7C9AyB/XeLC1wyb2gZx+bejEKjYn0dDcCl0IMN/c4
KJUixZPndxvdh7lo2diL9vFsGVrJa3U5awfnM4pmvLvvelSgcFkLCnpnmH/C
LNKotY9/R0pNZG/GPWH+WbWSprrSWIV+6oSQFH6C+UfpcRvFpQc1KHJMxME3
GvyJeGK86/TeOiRwdnIzUwv8WbP7ScafVo9evMyQ4L0N/ii/eEfKpt6IWssc
Xrgb7fDHgY2EZqUJHaZSLlgzBWf+ll7ffqXUgl6qsG8Y3t+x35EJdVjnbEVt
vmNnGx7vmGcqxzcfzbaiI92ptmftwJl/8idezRa0oVf7XmZHv9wxt1Q//Wfs
0Y7ajC7/pHMGZ64rlbwYvNWBhOJZRJ67gDPbdZR/tY53Iscfw4/HPcGZbypX
7Vv+daKuM8lpV/3AGa2mTxtKjV3ouN3zxYJP4AzpteFnFWHd6E2R/MnDYeBJ
cqvgb4kHPaiXlMnKNxo8uXn9sV2OZC86pUhI/BcPnuzqzP91am8fklXQXMvU
AjfStMhsE4b60IJ5YcC9Xui3eq6sHUzrR589+ER5b4MbVLr+T0KdBpBcikt7
BwF6Zn//Kqv6IFpqmbd2NwI39PUO2XjzEVDI6nUmqXHou4fur1CvEJACW0H6
min4kG2Y/di5fAgtnzugnjgD/cyyw+9XSsMo7Nb7JcP74AOlMH9eQfowuuzw
w5ttEfqAdbXdOucIWo3UONXwGHzIyLQ8K+o8gsIr8ppe/4Tu+nPv+qPZEaQ0
yfPgrB24oS+WlZOsMYrWqN/RzW9AF7HVsZ0tGEWRx+aSol9OETtN7j+xI//N
Scpq6io629CH1iPXjD3G0K9HuXN0ztPw8z8nnx25OoZC/Pd7VOyaIfbjigKR
3HkKkvVZM4P8xRpEr5qdznxM/vYOeRnwT88QfIlf3xTzaCjp20cUIXVBY4YA
1/GDZQ/Zk0pFItvWO2l6TXDdTVXM523St1h0JF2eaoYA504kR/55abMmIr+N
m+IxWnD96+aeLBVSqTS0Jf3ARK8JrmeJUsy2aq1lIEt35wB2BdjH0W3xaid9
y0aW9+pHpgmwj5v4pTlAapiHIj9obnznApdKFj2MtFkLUVf6EEOMFrj0abps
MqmuGNF23RN08gOX8pb+ipFKlSKpP6tIrwlcEpgP/J0YXIZseRy0L+yGuch3
5kyh1lo5SpShfsiuAPuvrYmGV6TXKtEjESXZP6XgksWomVTSt+/IQ56+eZoA
LnUTyMi1KapRnHa7bvc/cEm2P+w7qWENKr0XNPmdC/xJ6z7nmlRQi/pf6Fln
nQN/9nW0X9FmrUe/PhzcitYCf9xaHtCRPWpAjJFTbr5PwJ+1BpqWpLpGdCwj
idXJD/y5U/vFT1ugGSlUPo56kAb+TI1GHCWVakFGXeIn9JrAHx6jeQ+t+f+c
nP6bp/wD/NEcujCfGNyKgv6Uyl3YDc546LmqkV5uQ5l73rcICoIz5f2dqVpr
baiZR/k2uwI4s3GTnzEpuh095aD+SSYMnpzueWRNeq0DvYmaPf+nFLqpVkm7
1mYH8j3a6Lh8FTwJ66AVS/rWiSIyU79P73CmQ+NmIKlOF0qS8KMdtgJPaFvj
1rUoulHB9yfq3f+gS1/9qZOU0Y1q1LQ/NXmAJ88apQtIDXtQV/f5we9c4Eaq
sje3Nl0vGjPcx1+cAH2yduBlUkEvWp7ZMs86B27sv3yUQGreh7atR1ISq6Ff
r7JD2qz9iO5fxc9oLXDDXe57ZFJ5P+J+F3cheAJ6WTkTGdmjASRI7+bk+wTc
+C1laKy9fxCJf7KsciUHN07i5MqkukEkd0Btj5MfdJNLfwXInhGQRsJpDTs+
8CS08LKLtsAQMhRmDnqQBr39fOB0UtsQsipcGzRBs8ROMbB8iFRqGL2Q6+HX
a4K+LySoMzFwGDk3Fty7oTcHnphcXLArlpYcPvyYO4rmBtEry9JTu9jmnNC9
luv7SPb5w+eERM6Wdc4HeVVTvtzmhut6RXyPZiMMP6OpuLGZrQS4n0eKT+0U
61wkOiA7fGybG67HRZ+5e69PIBY1ZDSNbo3CeTi5jH1MhGECen6w+PNWAsxR
pho+g3dDkhFzraagY96O+zHOtNOyzqWhGZJG8m1u2McFnCd8taPORCXn5IYc
HHecI0nPyPcJZKOAR4UFW6Owj1tT+jkqIZuLLL4KBzoo7HBJY9sxwjAfSQ0n
PN5KgHlJU3f3fjKHQsTKwafqQAcuvb/DWnA3pBj9OqLC4pgHLuVYHNCuzsNo
uIKKDM2CSzb5rH9Y5kpRvUHF4hY3zEWel0IuV22UoZy/DoMlquDSl7IDn+yo
K1DUpwv1Do7gUpF83IQgeyXyFPmVJ5m+47pM7THRPoHvyK45PW5rFFz6oZru
7CFahe5YWgWUsIA/FG3irRKy1UiVSsjZQQH82a9VxLugXoPOxow/lHwG/oj1
ST+IMKxFB1Gk3lYCzD9q+tVF1x7WIfr+W8ol/eCS2agKLZlDPfpjy37egQ78
cTJtu5np2YBs3O4xR/CCM59ntb/eDWlE97QVdzvmQc94MPiL9VsTMhAQIDVQ
B2fqV+7IV+c1I81Vst+Ss9CtL/5UKjJuQVfKhhd43oAzjpviyyxzLUjKu2Ri
ixuc8cDPg6ysW5G4XugAIQt60OsiVLXRio4fs28vUQVnvshuT/K8bkMHN7Tr
wnfsg9IpZLzsqNsRR7VYmYMjOFNc/Vasxbsd0X9kztPnAE/q3KoHBNk70C7j
5RTJdOhdyrvfvg7vQH9ON8fyXAFnxuhUj/UJdKLFraTQrVHoi83ebcLJnWii
wd2f8AKc+efb9txDtAv1B5u7l7CAJ9Q3WPnGC7tQq7nC6/Bk6KxsOjUSst2o
WvzQMwcF8ISvJ/jhx7puVLyL7KH+EPSTwYNsC+o9KLNtyETyGThz4faBEoXe
HpQQWXybh/EHsSvyGJtEGPaiiAch17cSoKsOx+75PdWLPkg8v0KQmYe/10PS
F98unZM88bRvdIxUk+hV92TrzbIaO3RE/ltBOTVcB9yqVPUrrXFBDIdDmMqp
4XrfZeXeiz5dvshTaKT6IB1c12PI8jhZWvMJvQ30Lymjhn1f7z5JvqWCMCQb
JM65shvOo1plftP4dEUh0uBem4N0O67H2amTf23+goZVJc0SXGCOCk789g/X
xKOSJu+AMmqYozaHyH91l31DYVdHynrdYI4yYtFbXCxIRi9bhBeXd8P50p1D
t36S66YhXfW3+3Z7wvlSQAnVsndXOjrf1ql0kA72cVU6WfPc1zORZ4L/xf2K
4NLvFcPZ+OYs9PeehEaCC7h09APdlIhKDrI4OmEuVgPz0u0jBWO4Jhf1zX5w
LKMGl7zKTIeV5fORUqJ4oKoSuFR6i3mwu6wA5VkOJfW6gUsra7jXWLIICR53
rTCpA5f4fe53LRYUo08/Tvct7waXNI9ytr84ixFlcu/SK2VwSW50dIpctxQ9
tXKm2u0JLumdOj+pxFGGJk4c4wlsAJdsX3qPe3eVoRsL7aIH6WAu8q6dGO0M
KEeVKS+VU1TBpQQ2iRHu6xUoOJfpzH5F8Kfc2G/IiLEStbGbSRhPQR9Imx6M
b65EtM8KFRNcwJ+1TcmB+Q/fkWzP3uuLR8Cfvcof+0RUqtCLc3f1xWqgCwbN
9TzfXY0yg/LuvTAHf2QmpLtxTTWa+73naRk1OHNLOKiTwqUG8d80cqLaMf88
dVxoV5avRbfysz1UlcAfrwa5Nl/yOuTPufuT/wz0r5whLd1ldajhuX50r9uO
Ocd0uWm/Uz3a1ZeRzHsUnOnPVGw0lmxAEheo8k3qoP8kCa9P+NeAngTfqky0
AH/o1X7WLhY0oqQ/qc3Lu8GZIyFXasSeN6Fx3V39ZxOhS09HVr0424z2FepM
vlIGZ3TF1ivL1prRDe7k5Yo56BfK4kbIdVvQhxekmzSe4E/1VOvw4fwW9L1f
k/racXDmOv3mkBJHK9q8+I05sAH6sKjg0H27ViQWusUzcB/8sbp1neDd1Yqs
/mkcPUi3AL/f1w6DGWJtKPx2vJh5MnSr9oB77/8ck1Rw74zuiQKvmlzmduWn
WCAXi3g3tSjw6vUNdoG8FHv0ODZoQDUKvPKyHhijIX+Lwj7qPfm5DF71XTiR
nZvijiZkGN+rRoFXAaSoQjjZB/0tWG2NrAWvCkymEmnIAxCTSNf+n8vg1Uit
d8CwzicUoDmQxU8H51FUJ8+9yk0JRhG+jbqqUeDVCb9hE69d4ehbYwmJnRjM
UUIv5OKFkyNRFk1aXGQteCWRHMTNoxONsHyUSp0ezFFXh35405B/QXWv/VZW
l8GrO4zSu9aSY9EsQbqBvgK8eir78dmwTjxaenkhgp8OXHJ9OvOjnjwBrXGJ
WJ/ThjkqJP6SUW7KN/Qn75i8ahR4ldLr2xl98785VfsQx5058KqMdlLJa1cK
oljbN2crBi51XLpQ8jw1Fe32Zy3xcIR93OpZxc/CyWmI4Qy9b2QteLV57fH1
r87piLWZ8m42M7hEaRFCx6OTgbistsXr9MAlhjffq/1PZKIDtL9phuJhXuIM
XXxNQ56FBBKWBlaXwSv+bE4Jx54sFBjzU3sXD/hzokn218/kbPR55VEZfQX0
s1NWaRZvclCo9PxRTnNwSZokyGJYJxdF+NwL4KcDf1Q4yw9pncxD0UMTmycy
oGsJ/yDUk+ej2JN3zM5pg0uGymyfpXvzUcIrQovMP+gWd6Wu56YUoKQG3Quq
UeDSk1cWdCfeFqJU7u4YbQXwxyEwoDr6ZhHKsLhOd2duxzlPaslrjlPFKDu/
2fa+D7jkVzN90WtXCcqjVhm2FQN/QkeYfpH3laAi7Rql133Q4/5IpD1PxQjH
yWV6OIJLPW4i2XYypah8rXRf4CHwRy/wsp9wcin6LnfpfWQt9NFovYfz7GWo
xj9/8dsD8Mcs1Vrlq3MZqh8Vu5nNDP78KHQRMp4vQ01nMspxHvTHNaGUPDrl
qM3p5PE6PfDnV0f6WE95Oeps/vaxgwz8eTlSVep/ogL18BzZJsRDJ13oD1ML
qkD9VjHmMyrgz/s/S/Y05JWIUMTbtroMnZKKUqfSqhL10YZe3ApcJHZCDPfd
6OeUkgvvG/4QJsGrMI4TFzkfyqOyN+/VDo6BVy8pDF04HmqiOY+rEXxj4JUm
DjinwWyI1jpvsWfcgPsT5l48P8Hx0AT9N2gp8o2BV87n9A8S6iwQhVjBmxlu
OKfytI+i1WB+hHbrluL0G3BO1dPDTClWZo1c0dhmkQJ4xX/2PQnHw6dot8Yk
N98YePXg4+8/f/Y9Q553Z86/cwSv8lYt1gbr7BG93Q/tGW7Y95FrDC6WPnuF
fNwWn6rmgVdHeo6sqTM7IabQFf/0G7DvU6Eyspa1eI2udP/pcf8NXlmLBy+K
ljkjD8N/U0UK4NUnk/b7hzneooaZzV8LAeBVccCeWfaH7xCdzTYF3xh4NVoh
b0ZT9R6p/SNhvX4G5iiqVYfxP/tckfc7skPvHMGrEwfzjH7YuKEW+l0iuY3g
lYb6MmGwzh0xBlHIzHDDHPXM6ejtZj5PpMFHpc5tAV6FpRr3lj77gPy/URuq
5oFX5YRQrYxmL9QhsvuhIyW49JNybkad2QexFtM6pN+AOcol3OVrXYkPOh7z
vuqxOrjEJX7ITNbCFzWaUTW5/4ae3FgqUMTqhx4cd+2MidjhlYneuGiZH9q7
TD1YpAAudfzbiE6+74/Sst3GO+ehmwUEGh3mCEDq9rt/LASAS3+OiRyIqAhA
K5Ieq1QS4JJXRTOB/eFH5E++5++BMeh8t+6H+XAFItEaT7IL7uBS1gr1bZqq
QNTpSbf7+hlwSdE9lsv58Sdkq+7FeL8Heh+fTO+ffUGInW0v5ztHcOlBPuGT
TU0QyuvzPhB+GFwiVX+h9cPmM7oZwSCY2wg9YJqd1YQ3GP0x9j3V8mTHHOWU
1T5YF4xCBJnOznCDSwXs6n5atiFIYt5PkqwCulrq/LVmvlA0mM6swG0BLo0o
uO+93BiKHGwDVEV37NeeEA43lT4LQ7wXWTVV86BT2VZ4nj8Ujkq3P942NQCX
gukMlTOaw5FRJdtdR0rw52TsP5pjLyIQmdsny6Ad85JhuMq4OnMkilHlsEm/
AS4dng2Wpb8XiSSYPtvX/YWubzL68XrngZLkBxLfO5rBq7qO1aQMOkM8t+fr
DaFG8Ir7nNLhDLpHuNxUKE6wEbxqfcfxy53lGaar3ooqEgGvKmZWR9PpnHAS
86yaYCN4Fe7Tf4WH8S1uq+hQsSYBr56frchwZ3HFv23wlSIR8EqT8I1rnd0T
72XSPPRGBLz6JKNUlk7ngw9aXOEXbASvdrFdWjPb64dFy9HBRlPw6vHMaSEe
xgCswCXGZ00CXhGKDul1MAXim9ZHD7AH73gewYfD150lCFvW8fIWiYBX+cZ7
vkuxBWPku9s7bRK8OnyWZOMXeyi+fOkd/RsR8Mp/98/jyZzhWH1m+4OmE3hF
smiTlk4XiXU/2tMJNoJXOT1WdZ70Ufiu9JrnH07wyqrcbNxsbzS2mn+4p9F0
x74vyWhLhiEG236e9YjIBK/6Pt7i4GH8gh3lTWitScArH0dN4Q3GWOy6POQu
pwpeKd67qtLBFIf9wnR3sweDV1saSqapzPE4RKnTbWYS5qssCVknd5av+Mva
VZoiEfDK8vClYBPWBNx9zUROUQpc4mc4myXF9g0PxB18mzYJvW/jdBM3eyIe
+TdUwfkBvPIdOzr9iz0JT2qEkb8RAZeUGg+RtXEk47mvurI/eqGT5PLsS+ZM
wctb7G80ncCr3EgOcVeuVPzrRmd5yWFw6aw8zdd0ujT895sfmWAjdOYLlGK8
XmmYhPSajK8NeLVwkrzckz4dU2jTOf/h3HHuxE9y9Y9XOt6dXFdmXAo9jmOz
32xvBt5L7kraaApevab7Y97pnYFZbspLi9OBS3pk62syDJmYM5XsdUQm9PPr
q85pPpmYh6K0lFoXvGL5sbSXhzEL8996RWJNAi4tDc+HevhmYaH0C1L9cdAb
OmeFNhiz8Umq345yquBVfN1UjqlfNhbRy8bJq9Df4HHZDqYcfC7TepstGLwy
yBppkfbPwZdoTiMnKfDqQgJBL5U5F8sYzDvMTEJnC++f3ReQixWzv5VofACv
Vvx67NxZ8rAKrflWoQi4VO3Suet3QB5WMhKQFOiDXvditeDwa5GS86Ha/Vx6
4JX7yrpkz2drPKqX9RsbgFeZRQvR3Z+dMbVLvSo2AK8OOBkdrpj0wDxDEhHh
3rAfrOabvdH92Q8Hc2v/LjEAr169iWFTlfqEY6v3RqXYwX5QdOJ2T/lkCE63
qVEK94b9oC0/rWqoQiQmeEttVLXD+ZV6x9SJ7s/ReGwitLHEALw69q6Snmn+
C56+uBGVMwfnV5TiUYsqUvF4wVfTNsUO9oMjk69aXPwT8OpU+pU4cvCq6JNu
evlkIv59iZ433Bv2g58un/XbPJ+Ct5SyN+o+gFf5/9zOhyqkYdKnY2NV7XB+
dVjzd8L5R+mYPJKxqZwTvApINuXq/pyBKetRXokBeEVK2en+pCIT0/yyii6I
hf3gQ33Zv4zzWZiWL9QzZw4cG8hJt0xly8H0KnW2GWfAK6W9BwZUpHIxg91v
wxQ72A/mmnmpzN7Lw8zRh5W/FYNjh0r/Fbn452PWxhticeTglR+H5QmB4gLM
8duZN1oJvNp+1BtWPlmIufjTacK9Ye6yqlWkN2QoxjxqQ6ufO8GxAb4ch83z
Jdi3iHKx7gN4dcX+0GKwMcZMbfvHa06DV7fv1Z4KVSjFAVOivVXt0P0/kkxb
9Jditk3lpkpb8Kq+7Gzk+UdlOIjJuKKcE7wiW3igQ01RjjkF7fNKi6Cf54pj
6P5cjkMu+SaXGIBXjxQGa2JPVuD9179GF5GBV/HWLK+fVFTgCHP8qSAWOiFc
+bysTiU+4NDlmXcZvGKrd15mnK/E0f7zr3PmoKuu5ycMv/6ODyXsssvyAsfe
8i8bpbJV4bgS7vsZZ8CrwquCXA6JVViwQ9gorQP6yguDNhWpapwwo6SVYgeO
CX0NdOfurMbHtg2Vk7jAK8OORpnZezU4meWZ1Ldi6EEkFH/ztmrwqaPeYl8N
wavm4xKZLv61OA3FHY0jB68ob9pYagnWYWHNYt4vcdAvvfvGL1Bch7MsOlii
lcCrJ+kj/avq9VjcaY4m8gf0xEGOgPLJepz7kWw7zBsc66e5puL7ogGfSeT8
GSK8Y+6qx+Nx8pIlTZfmXvn7wPXBSDOWlDjCS5y2R+9QRihcH3xxeqowluCJ
yx71OKaHwvVBP7Y7DP/iPmKhW87zNJZwX+hUQItMLCEU1x4MPJEeCtcHw90i
Lhyhjcab7JZ3B9/AfVY1NV3tf+Ni8Rk6qRAaS7j/8ycVvVWLTAIWeb17hksI
vNqvKE8ZS0jCjX+f7EoPheuDh2RLmiUupWFT2yFeRQbwKm/05r4jtBmYZFnp
4uAbuG9B1XnNnLE3EwdbZmnZrMPcNcrnm/037r+/O5M81jSWcN+CXdlxsskn
ubjR0O1DBAHmrj1GNWotMvk4c/55B5cQeBVFcjekgKEQkxw7NTpxB+Yu8cjt
qS+EIqxqPr6YFgqO1aMQUe+kEhwc+3nzRdeO+xYehpRKXCrFk6NqtIoM4JU9
mpk8c6gMixzYxcl0BeYu+b1n6Y7QlmMnvfzDg2/Asb1Db0X2rZTjxuAHol+L
wbHelLabjL0VmKuHX8ZmHRz74nDAibK0Epux9l6VPAOOPVB7EPc37jvO1PDS
o7EEx87zFDUsfajCpD6ylh1fwDGKBZrViSfV+Grj72cRBHCspVibs/9WDVaj
0JYV8wTHQj7EohaZWrwWc6aOSwi8MtVbNfkuVIdDZfaok1RBP3NC2rOAoR7L
jkx2T9wBx/7988pIXa/Hs45l+vXb0KsbBnq+EBqwL0/oRFooOOYfenT78/dG
fK7Y9n7geXBM//4zAe+kJky4pb76ogu6kESV8lv/ZvzuzzF7ox3z2B+K3fkS
l1rw8c+UpIoM4NXw/GmV3LQW3H52xOV4MvTvndpDZw61YvuuQnqmHdcBE4sd
rJM+tWK+p4Ef1yeh+8TGUhyhbcM1zI/3Db4Bx2w/NARFObThhxnKMeUHwLFb
T1eP7Vtpw6zqh49+Ld5xDq/HhQNN2nHRIkn6B11w7LC8tAZjbzs29uo/a7MO
fc8J8wkPlQ68+0ROiU4A+LbC4v2MsrQDp9f7yEueAce6/2XTvhbpxDoWlg38
TdCLxwfC/8Z14m1qhes0luBYWAO5sC1XFw6PP9C3QAWOLTMyx9nIy5UY7j9r
EWwF75XyKYgXo9N8gwXo9peJuMD7Wwz2v/Tfo+mP28+nCYi4wHM3tnqHPP22
QzHLfKtFQx08j1ytZiqzRzMGH23Z6BZ2gfvY2x4USF49+hXXJbjbbwvC/QwE
L/qLfttJ2OIN9/6GOnhe+Kl2eojFbBp+f7LLQEUc7mewN+vn3KOZiTVDeNKF
XWCf6GRHEZSMs7EAtRkZZw/MXe9cTrFdPZqH156kXt8WhH2i+6ebAUsBBbhy
ZP3LxHOYu7zj3zD5bRfhADWpX/V1cN3wY26yj4gFxncLXRUzuGHuahyzdLGY
LcVcAeYqKuIwd7XMOSkU8pZj57o9T7E+ONa2+pFij2YFniFJDxN2Acc6/36r
vO1eidXPalbFpoJjPeSlb5Lxd5xvtbHA0QOO9dF2ymz9rMJ8X8LYPUnAsUHm
WdKrR2uwW5+01LYgODbMvV0aYVCLlxgmza3VwbFRfhanpYA6rKPo7jvxHByb
OCaEpOvqcemrkwU60eDYlIjklu92AxbMahutr4N95dzF68Wjok3Yd9aWFq2C
b4uy5i9FLJrxxgFu0QxucGwjtmR/+dUWfEcb3xaQA8f+Cim9sphtwRNV6TIq
4uDYZnL7ANO7Vsw1St79rg761hl9iULeNqy2qWmJ9cExkpzpEOOCNuzM8XX7
9wp0sgs2f2k123GuyB9/YRdwbFfJpm7WYjueU1MRvL/jPgdKGdeC2+4d+IBF
eFFsKnSqKiYuCoFOfOPd0rUhWXCM5krY82TciV0jZSY4eqDTNh3p1dTtwsWF
Ac817oNvdBoZ57Z+duHlrkk6TxJwjL5LIijOuxsLrJyL/h4AnUG3el3taA/W
pfMQ3xYEx5gI6trrlT3YS3Cw7lwxdJY7AzkRBr24XPaUgbU6+MY2acp2+U8v
Xtd/vZo4AZ3dYvnpUkAfPmbf7jLxHHzjXHjRGXSqHxt+FNjHSw+OcVtTiknX
9eOANLs0nWjo+3/5BMzcHcA19bVyfuLgG68990/f7QG8OcndW18HnXMr9vqF
4EF8lOyBFYUB+EY2WftjkEmpJGeUpOjXb7i/PSUtM/nNjAte2MyWbueH+0Uv
l+2bcJ75hPdeXkhv44f7Rfd1pm7wLUbhw76kFYXZ8PxygFKrk/NMPOax2m3R
xg/3i+4pWaEaG0vG3xgDVqruw3M3Mpzu1XyL6VgsZ/+LwmzYJzq2c9Fq/MjC
5brx5GlbMHcVfEhUc57JxXGOHApt/DB3/VKU8MuYLMBz6nruKpdh7jpD1tg5
OlaMzxyKbqq6D/dliRNSPN0elWLbX5NM0r7g2I2Ldil8i2W4qOaYdmE2OGYd
hFryrSowacijELE+cMxnjWpF/UclVrDKHkrdgnksWaOFedaiClfxbjJ+ZATH
6lODxJxnqvG0K69oGz84NrPHSJvLvBbTrkhr7RUHx6gshJ5nTNbhk7fuPlO5
DI4dql4OvmLSgK9Vvg920wXHZA4VFI2ONWKbEwlFVfdhX2n42plgf6cZBwbW
E8gdwTf0UMDJ7VELztueJ5H2Bd+awmh8O0+14n5zBn6HGPBNr2E+im+xFW+1
CssXZoNvP/60ZliltGG+i5pmv6vBtxdCORX5Vu1Y/oudm1gf+EarE9xBcaID
m9MFJ1r/AN+C3ztMqP/owJ62RY2pWzC/Hc2+8ysssROnDhEWfzDseP5lTIFq
1qIL3/tCQvORERxTYjrGIX60G//tYQzODIbeI7VXyHmmG3+g4z/Wxg+OmT9c
Pd/0tQfzyogWLSVBXw/rvsJl3ovTbOVV94qDb+8bCm+ZHunDMolahBM7noNj
+xtxP2OyD3cMmT1UuQy+xQq9fbUV249NWZ6TWLZCF9Mx97piMoDXL7v7uumC
b5XvVSICDw1it1chB7/uuC5wI/t02ujYIObOSMqs2uHe2BhL2ckYAk6eLJab
WINuw7TRan9nCEtyN3eSO4J7ryMfPB5jGMYtV4dND1KDb7W5w8/dHg3jO2+X
16V8oTM0azifahnGP/PI3Ay4wDedyUr3zlMj+N08M5dDDPTITXH/F94jmP2g
QGLocXBvmiUhhG9xBCdoiUsUZkM/dpz7S7XaKBb1UGzslQT3XF923xu1VS05
sXm+p+ocvM/T4cn0ZVtOT0x5YtevhiUv4tefNjqj95QzFDtju5X6JXgPA4Pc
eh07cyyWzvqVFSQK74Fx7dacesKZhEtd0x/VL8G5lpNYH+mMdzqOPCnO5qgF
+0QJRxofduZsPBTE/CRIFOaujZpzPAqBefgA+XJrOhPMXVlM5klPOIuwgVXT
qfolOO96ePvThZhQjJvnOhWszcAx1uvG49PeZXghsnLNQQscW123P+akXoHp
tTK/eMiDY62hftbszN/xCdro60Gi4FiK9Lf8lI4qrFrqQxbLD455TpaRKATW
4PtPHdPTmcAxC49exUHtOux59IFhCSk4pnh62esJZwNOHLq9t34J5jSBTuou
2v5GbFInMDT3EHwjtz+wPya0Ga8dChO3NgPfHu3dJ7w/tQW/c2Tx+q0Pvg2N
xHdOe7di1j6PCQetHe8hyRJ5nvWoDX8RJb9EoQa+Fb/H+5zU27Got32Ahzz4
duymcqmycAeunFmeY7wEvgUf6zZmZ/5vrpC7JxskCr7t3rpDNbbaicfDh4N5
ju94HrBl4VtKRxd+sqG98oUffJuJtlezz+7GFDealY7tuI6p85RyRT6wB39M
UYhKZwLfahT9PjLa9eLDNCW/z+4G385y8Zwf1O7DOcZi10pIwbf4HwkDX8/1
Y8WSpHi5DehsWMzpCecA7uY4tF23BPPee98yfqk/A9jcJkRLfRo8XDNWrabt
H8T/TGm65x6CeybivRbdhQQsx/KdLHUOege1CX1M6BD+UOZ00tpsx3PBVr91
ciWHcecDCV2xMeh9WiVH96cO4/37fr/7rQ/uMUq9/efMO4JNajPTC/t2XHcQ
utI0/Z8DKbYPBx20wL3XTAyRaiSj+Bf/MRqZNuj5fzsfZz0axZKtk6IUauDe
0niILNfIKH7vEG1YUwtdsMmI1Ul9DDcf0/f0kAf3DHOPTE2UjWH2Xs48tTLo
QZHzecrC49jgfecY4yXwsNkt0z09ehzHi/ju7cyDTmXz/DY78wReGla5GCQK
Hl64jU6+ejOBhb2ozW6lQdfqsRR4n3qtJHdM8V6jObyXWKZYjFW53RvP+V84
P87uAXO+7qXdV9ojcJTgT80x9hBiD5lblLMjxOO4N7GKs+pwDl8qVPZWqT0V
/125Nj7KDvvEFRGlUbrxTCx4xqF0fgGeK6RoP0NmR8jF7dPt9LPqcD7PYc11
cLinEDtGCulNZoFjRxnJZZTaMRbScUwcZQfHeHrWTvdOluH2vZ0bhB3vl4s7
MltKN16BS4xZv8wv7HifoR3hmszId+yPpOotd7w/Kq+qbdiWUI3NuS1XZtRh
XynNVv0osb8WS65/5DQnh/OxOpNCkuGeeszcXio1mQW+Xc9O9WHpasTTKXNm
d03Bt4FdXw4otTfjYnc271F28E34qEqP5HQL9jOVzjGshfP/dXWFA72TrdhM
5v4gYcf70AqfS5nbTLRhHm9l55Ns4Jtj1IU0uvF2TL05/HF+Ycd7XWpFf8eP
duBVC9uEpGpwj3r5pJTMSCce7KEtttzx/qVGDiHXgaEuXKMQ1XL0ObjnK8Xf
YkvoxhlZ4uMz6uCelvl+DsbBHhx+sGH969Edz0H7sBsm9vdiNx8jWnNycG8k
l/GrfF8ffrL1i+fIAPS4IdqloZ5+bHDfU3gyCzy0pKI8Z989gK/08SnEfgAP
T58icWLpGsRil3Nv3jUFD9e0/lSndBAwX46KFT8CDwsdfu5Vah/Cew6NOo2y
g4dS19cTl82H8bqvXUDUEvSDZj+bJaeH8ej2nq+GteAkxYvlVQ+zEdxoFV3I
Gw0eTnstsPdOjuC8/rPNBHvwsC567uJh01H8RalxNOw6eJicM21gMzGKq2+d
eXGSDdzzrpt4U3p3DBcz/dvl5QzdmjAaTzc+hjNrq7zmF6BrrgzV6xqP469O
vhyqt8DDs5SDi/Gj4zj87O3opGroXFx9zGtGE9h/4fDxPaI7zv1OdJ+VGZnA
brHL2ZY7npseku645W04iR1uF6H6PeBhuWar48DQJH7C7FJ79Dn0L/eaYoQM
prBFnfp19wnoLq/qq20JU9jg9b7BGXVw0ti3Zq5CbxpfOzdlqlSy43kBbrkU
Oz2NEpeNA61R04pEr2S9qq4lvfHFtY2kRhyN72HeaOkrTnwThaVwURR7YyDM
S7oa11/Lf8NNyi/dWjlhn8ixcvdJ4pt0/Pcslwx7I7zXdzHnAAocz8ZCh/L+
3HaC53eqXwzQvJYvwMeoE2+2csL+MUIqqMMyrgTLbm2IPVmFeayQ7NvVxDdl
+ObPy0zsjfAc4uEJquwDWRX44eynhfw42Ff6VZtwBY5/x++GJ+tuO8HzPpsJ
FY60rDU4tEssfvsm3Edh7sk34SRfh2+alku3csKc1vHA8cqvpw347shMavR7
8A2pD6ZaxjXhh7cZeZ6swvzW+TnM/ZFlC7bvPucpbwjzG62HyqXEN634vYbh
H7ZGcE/65d/FiZA27NvoYj59Hq4L2Fp9iz6Q1Y5DL6d25ceBe0n6NzVvNXTg
+IouOQ9mcG/0KjV14HgnzpDcyrjtBO6xS+cWtPzrwsX5Anwn52HeUxU2taJl
7cE1oqre2zfhOsIbftYDCid68ax2gYO5MbiXx1LZ5iTfhx+yNom1coJ7ixQ2
7wr1+vFa28iP8y3QBdb5zv16OoBf+qzFRL/fcZ//dMvsaa9BTKZGc4v2Enjo
1+sYZhlHwK60+5merO54n1XdyWtxJUOYvvZ07UACOElCePD6keUwDngv5yRv
CE6GaFX1fVgfxlxyOmdT2MBD8eb9oolvRnAk6f0FtkborYpPP9TsHcWHsWOs
4xtw0qq0YXIiZBQnvfS/PX0enKQ+f0iKXHAMi1yIZ1Zfgh6T/uLzgawxnL9e
UJcfB35KHm1fuSQ1jlF20+uDeuBnX/RRlVsN4/i79eg5jx338T7ldo59pjOB
lU//Wlythc4Q0Lv1cXwCt87TxN92Aj8T95zRyXw0ibUT9+t/Fwc/Fd+5prf8
m8SD5mdYT85DH90c2r3gOoWND8s3BMaAq69sz96lZZ3Gs2M6b7Zvgquci17F
glHTOO+a+H5RanAyy2ySTeHEDH5xqvSZuTH0q8OXHhnnz2BJ+isdoSXQZ3U+
1jrJz2LS+fZTrZzgp2Prj4PhrbO4tF7Pg+IpdLWQIDfxkuslqfqejL/IZYle
nXZqnmHu8MM23oIXnxx0Jn79eP2gMnNHNJ4iUMfYHIRz+NTu9uh9kkmYxfaV
YLIIzF3Fy+P/mDoycBTlhpbNQTifj143+MrulovPamRyMiSCY66bfdf3SRbh
pjCrgSQRmMdySRMdfZ6XYpOZIxFKRXB/V8Jb806mjnL8imv5tM1BOM8PpTp8
7OPJ7/iylJpfmSnMaV7uY07sbtWY2TRxdW8i+OZEF9X1eawWEzyoNfUX4Xql
jY/+8X2SDTgh3SQnSQTmNxPmfc7hQU3Ypruc/a8dnKcdr/9h6fO8BUtu8j5X
KgL3Yj3rA1vjWvE7X8l5ZRJwj0ftWxlTRxu2ODS/3+bgjvvK9rr9uE7aga/m
hqgFy4F7DK1m7B9PdmKxK1ccy0xh3nPzU5DputWFuQZ/p067gofkNwSs2N26
Mcmj+OG9ieDhS9ZdQTo5PXiCTIvxbOOO5yi7Rss/j/Xiuo+7ZPQXwckHQWXz
fQz9OE0w0/odI1w/nboZybFPcgB/LDSKSRIBJ424HWX1LAfxSzWGjnZNcLJ/
QO9BeBAB3xkp2fXXDpzUDJf4PPR9CF9+YiV2MBjmxulUujs+z4fxSap9pkpF
4Gcsw6v10wwjeLeqifK5HfvlO49/eLbGjeBXgUVjyiTgJG/brYPWl0bx8hDz
SwNf6APC9blMHaP4rpAli82O93x+9r+gmmkxhruty5PeZ0LX+pkwep10HF8p
4pQPlgM/mTU5n/38NI6LKR4PJndCb8l2pft4cgKfvlrztMwUXP3A9jta7PsE
jgnipe9ch37Fzuxc161JzD5qGzftCt5S9XQ12q5M/l9X5x1P9fvG/yihUKk0
JZVKaJgNuVsUDQ2jktGgRWVEJCLtoSEqRWnJKEpk5J1RsvfeW4iWpIzf53eu
+3tffr9/n4/zOJ2Oc173fV3nul4v7pJclkbvoHm85MVaeydcbOb67GSKRwUj
d7v79k+UVAt3LN756Ex11FuNv7OubY9s4eoFCwTVMpH/2+k1s2fDF85gi9xD
HRPU23exQ6Pv1n/hUu+5LzbpRH58qu2mpU6t3PKG0hzr06jDiqfq6stGt3Fh
CosOnh2DOtxZucXx5PM2bqbDBb67g36vCdFIEJuq0c55f6i+G6KEOrzHf+GT
uIJ2jn+EmuKHZOSuXmo/utP14gP3HL4R5beM6VXN88YVBoW3uJQXG77NM3RC
nWw5e0+/8DGn/tVg7DxDzIkI7b0zbsiHUC4tcbWhaQLOP5wVMlirX/iG+y1W
8UTWEH3a39409QhKe8fdUFja42iPvjQNUw8mDHDvuefbhk83TcB5iUvblrgG
7Uzg4h3ztNaIYH/s0cR4Sf3CJC7f389K1hB9Id5Vroob0P3EtXw85CUWgPMV
2QEpO4PSPnMDx30rHe2xDm3av6FHTzOdE77IZ90+BXWvTz7XZ4DL5Mbd3z/M
NAHvdSN65k3Rl8zhpF5l+uRa4O8F3kZWh4J25nLzEpXk1ohg3Sod/yp6wCeP
Uy68Gx8ZjnoYOv2HkH5hPkdaBrbIGuLc7OIzytuDxAs5nX/mjb69qJPJjfbP
B3SLOD2xjBNiAaiTuuuif+tdLeZMpRVF3NaiTpYH/dMMSivhVCZnZDvaY/1r
Iapxe0CwjIuZ6TpJSRv188fR0w16muUcUVDc2z4F9fNUXqJSkHsF91G1MeRp
B3JhFYEzA1wlp7Pizm+TBNTV2z5r8/T6qrgc7fUrJnqhro7pSx6tL1nDGWzr
v5hrgbpqON/i3UBsDVexKzz/0hLU1QemgmZBO2u5PRb7JNeIoK42XA8U1O+p
5VqOTtjfV4V8XqL2qwGfOu6IY1pYZDjq7bGfrQZBqvXcL/dTf4964L00ctaV
fr3Ces7pysI1soaow336Cs8GbBu4Id71V+tkUYdXn8/aGCTeyJ3z9y727UV+
8d3RLr3wRk7khba0fjbqc/aX0Q8GdJu4m697D4kFoD5LTHm9JqijiZsY9yoi
xQ71edeGbe16V5s5v497+k+vRX0OOPXr1oBcC3ezecQsSVHU55aXt5cFpbVw
+pYNnx3tkS+oUa3XO/iFm/j9vVVR9aB9sTEllwYEW7ny4z7iStqo27GrHBWD
nrVyfn+PRXm+Rs5nN7lMT7ON2+2qs6t9Cur22qexbgP1bdysYbP4tM8iv1a0
SzbIvZ1rvtD39GkH8gLB/hw96a9ckGixDv921PPJS/xPDHBfOaubYZ0mCch3
HFoxPcikg5ObcMkrdh7queRe696N7vrxMlf9Zx9MWMj0qutUyPclZ7y4muen
Sg90HWWPFxe7p7nkzBPOYfz+zP1d6OsuW2l8szD5JecSLOgj+uc849OLrncu
PhPBrcwwWru/C/3eg9//GC/4JJpz/1180qwH9U3tqZ56YXI8Vz+cX0/0D/rA
79EyCs/9kcBpTZCXj/mN97c5S68kLz6TzD2bYzBsfxf6w7crvC/2H5vCDZ26
okP4L9an4dIdrcOfpHLKs/R3mvWgHjqMl+q3Uv6vvpM/9CnyD/oNqgtvHlOY
nMV5Kbsqiv5BnTztskLcLyiH+6ju5be3G38P3funxDf3Ry7XtebFiJjfeD/U
srGWEViWz8lsjLcf/Rv1c2678KvFZwo4A/38OosuvDeOtAhYbJleyCXNt3tu
8hd1taN6aaL/2GKu/LVLpfBfrJdzduSvzzcq4X6qXhz7tgf19k3+4cLhT0o5
kdhb2mY9qLe3Nw4zXdpexs0ifq4je/D+eSLlfouVcgWnnhT4NvIP6rDRShWb
R86VnN7aN227/+C9dHls5r+C5CrOMv29tOgf1Ofrk9+s8hhew53V/Wz4rhv1
2d3QVdAvqIbzy8+7urcb63Q7r/UZUZtquSjDyiSxbtRti9wJN3J/1HI55c09
0b9Rt7eLNei3eddxX0x/LDD/jXW99vqwyQLL6jn+hl7z0b9Rz5ddcK6eVl3P
TTkgeD+2C/uZCh/XPVl8poFTbh+TZ9GFOi/FP/7g1jmN3OzFYsMuOqHOjyG1
CpbpjZyS01h/k7/I+Z1Df5w92sSRuIlLlZ1Q/3+9c4zyH9vMbeiXLBT+i7yp
S9M5OqqZ275i5rFqR9T/EkXxlflGLZy5+9yRb3sG+dkerRL4OtDCWScrPLvk
iOdCbEhQ2vAnXziX4UorzXqQh36x95y+rpW7tG5xhYojnhf+s1frLW1v5Xwu
LXcY2YP8xt5Rk/Sut3GPM1aJ157Ac+TMw/JKK+V27pXYutDIP8jtKp8HnC9p
5+I2b1x35QSeLxaT7fY/cv7Kfb65tX73H+TbDVfIx07v4AoLDF3UTuD5ouMl
8r0guYOrlTCeJPoHuXJuyduOA51cy/Y9EXUOeO4UPLqsvLRKP97r35gbYfYS
TK9+Ta8Rbijz4roESrfpWOqzx2/W7dhZX/aEs3Sb+VDbEnO+Zl9rD9Nb94rr
JAoj1cYcY9zF4vjQ+rIIbi63TkvbEnN2Ws7avfQdE8OZaexzM0rB+9u2p7Y7
9NZxXGYVqVIdg7lgpnuWuJ8jidxBv8x/XDzWp+N+vCuuK0vmBEyMJmlbYl5P
qttiBWKfwj2S/KKaNwn9nF3GvHP3HZPGLa+01zNKwfuh0iO1ku6QDK70/jCb
Bjv0U21ZGKWgty6bWzo/NUV1DPoWbjLzXVnyPYcTErtu8G8/znvIzjWyPEfy
uKKvBo1cPNbLQ79N9lG+ms89yZS08xiP+wJVUWUJdWUFnE1oA7+2JeYHvXO9
1359bhG34mrwDdEk7BPeWrtzArEv5sSsbKbnTUI/aqtRk1d9TSrhKjYseeV9
7C7j64pLLX3HlHFB8kM0jFLwfjvD/66Ptmk5d0IkJUNq2n3Gey12JHaHVHBa
7VeNGuzQP7Z4/qSvT/9WcuMy9FoD0/F34fDfJRP01lVz3wuvxqmOwXuylukG
ab71NVyJ5vehd+OQK68OUS35XsN9eKu3/t9+PEdmzBHZ8OpOLfdc5t1N47HY
Nxg90nL3OVLHed6eUsbFI+/rSLc3bqrj7AVcpWccwnOnLU/uivLVes7keN0B
j/H4u09p5OVHI5UbOM1GzbCmD8g/3WuLrCtr4BT0X3Svs8RzKsJlfUa0WyM3
7qMICZ6A/YqAPcG11+c2cf+Uj50TTUJ+XWtk9/7sJq7+SX7m0SN4rp2ad1iE
2DdzaePUxudNQh/Lw2Lp0hKSLdxrj3u7lD8i3/FjntrXpBbu7q++x97H8BzU
Krq0IfnQF85t3+62P1OwjlCOad3tO6aVO1CQrGiUgnyGn46DzbtWbvOauU7v
B+WzjHYPuqJt2sapRVxOkJqGfeM+8xEB04e3c1KzOoXcU5G3aR+K6g5p54Z7
bd3cYIfnbKlCWkbWtq9cx9BIH63pg/ZZxsyre/r3K1doO6k6MB15RNfFbudH
Hdz7eufZIx3wXA4o/SKit66Ty5P9Fqk6Bs/lC++1Z8h1dnKJtY/Kmi2Q51O9
Kuvl6VX8//hPqldygjy94v7HdalePXbn6RXjs6helazg6RXjzlSvTD7w9Irx
ZqpXjYSnV4xvoXoVWc3TK8ZNqF45+vP0ivGxVK/UTXl6xfhnqlcD03h6xfgp
qleJVTy9YnwR1SsPP55eMd5E9WrmAp5eMb6R6pXAKJ5eMT6X6lVTB0+vGOen
evU5i6dXjFdQvXrxkqdXjEdRvbp0jadXjN+gemV5hKdXjFtSvdq4iadXjGtR
vZo/n6dXjE+nejVajKdXjP+jevX9K0+vGC+kepWXydMrxl9RvSor4ukV45pU
r9K1eHrFuBLVq7hInl4xLk31KnQ2T68YF6N65e/N0yvGe6leXR/O0yvGW6le
udnz9IrxYqpXNk08vWL8I9WrvQY8vWL8DdUr/U88vWL8IdUrLVWeXjF+jeqV
2jOeXuHnn+rVXAmeXjF+iOrVpHM8vWLckOrVyN88vcL3k+pVrzlPr/D9pHr1
tZCnV/j3pXpVpcnTK3w/qV5lv+XpFb6fVK8+yPD0ivEvVK9e3+bpFb6fVK8e
C/D0Ct9Pqldex3l6xfhrqldnG3l6he8n1avYeTy9Yvwc1auwOp5eMT6R1oPH
oR5kevWd1oOOgbx6EP+/tB4cJcGrBxmfSevB71APMj6V1oNlUA8y/ozWg7VQ
D6Ju0HrQQJBXD6Je0XowHepB/HdpPUjm8upBxltoPbgD6kHGQ2g9eAvqQcat
aT2YCfUg46q0HhRU4dWDqHu0Hly5nFcPMm5G68GTmrx6kPFVtB58C/Ug6jyt
BzuhHmRckNaD4xbw6kH8/NB6cNEbXj3IeAatBzep8epBxl/SevAw1IOMX6f1
4AWoBxm3pfXgU6gHGden9WAi1IOMq9F6sBrqQcav0nqwD+pBxl1pPTi5gFcP
4vtP68HF23n1ION7aD1oUMGrBxnXo/WgrRmvHkR9pvXgDagH8XXSevAV1IOM
y9J6MBPqQcan0HrwONSDjIvQetAD6kHG+09CPXgL6kHGv9F6MADqQcZraT0Y
DvUg4/m0HuSgHkQdoPVgFtSDeK7RerAS6kHGA2k92A71IOP3aD34D+pBxq/Q
enBEJq8exM85rQcnjeLVg4wfpfXgnC28epDx3bQeVL3FqwcZ30rrQc1CXj3I
+BpaD+pN4NWDjM+n9aDxDl49yPgJ2m//Df12pldltN8uHsTrt7PHa9N++3no
tzP+hPbb+ZN4/XbGT9N++4pRvH4746G03/4B+u2Ml9N+ezX02xk/S/vtA9Bv
Z9yX9tslH/L67YyH0367+idevx3vXbTfrmDP67czXkX77cuh3874L9pv3wD9
dsYFaL/dCPrtqAO0334Y+u2o27Tf7gT9dsaf0377Rei3M65I++13od/O+Hva
bw+Efjvj62i/PQr67fj5p/32vdBvZ9yU9tvboN+O9xPab7eFfjvjx2m//S/0
2xkfQvvt7tBvx88/7beP0OH12/H7Tvvtt6Dfjp9n2m+fYszrtzN+h/bbH0O/
Hf9etN8ud4zXb0f9p/32COi3432G9tvVz/D67YyH0X57MvTbGe+m/faN0G9n
fDnttxdCv53xM7Tfbgz9dsZTab+9EfrtjI+i/fYj0G/Hc4H2239Dvx0/57Tf
zkG/HXWP9tvPQL+d8Tm0374W+u2MW9F+u4g9r9+O90nab8+BfjvjPbbQb/eC
fjvjhPbbt0O/Hb+ntN8+9SKv3854Ou2310C/nfExtN/+FPrtjG+m/fZ90G/H
eyadZ8iHeQamV3PpPIM3zDOgntB5hhHVvHkGxgPoPMM6mGdgPILOMyTBPAN+
Duk8wx6YZ2D8JJ1n4PfjzTPg54rOMwTAPAPjj+g8w0OYZ2D8Jp1nOArzDIx7
0HkGDZhnwO8jnWcQvcKbZ2Dcgs4zVMI8A97b6TxDCMwz4PeFzjOchHkGxh/Q
eYanMM/AuASdZ7gK8wyMX6PzDHYwz4D3LjrPsAvmGfDeQucZVsM8A+N/tsE8
gxzMMwy6T8I8g/hQ3jwD3t/oPMNfmGfAew6dZ6iDeQb8PNB5hlSYZ8D7D51n
eA3zDIxn0XmGezDPwPhaOs9wBuYZGK+h8wyHYZ4B3086zzAP5hkY30nnGfxg
noHxCXSeQbyGN88w6D4D8wznYJ4Bzx06z/AP5hkY30jnGY7CPAPjI+g8Qz3M
MzD+ic4zGMI8A+obnWdIh3kGxlfQeYYVMM/AeF8xzDNEwDwD49F0nmHucd48
A+P2dJ7hPswzMK5E5xnGCPHmGfAeSOcZzsI8A94r6DxDD8wzMH6QzjNYwTwD
47PpPEMtzDMwXk/nGQxgnoHxh3SeIQ3mGVC36TyDGswzMP6Mzou+gHlRpleL
6bxoK8yL4vtP50V3w7wo48fovGgTzIsyLkrnRacu5s2LMl5H50W3wrwo3m/p
vOgamBdl/CqdFzWFeVHUMTov6gTzooxPpvOiXjAvinpF50Vfwrwo4510XjQV
5kUZ30HnRW1gXpTxJDov6grzoowr0HnRKzAviucLnRe9C/OieD+h86LPYF6U
cRU6L/oG5kXxnkDnRRNgXpRxfzovmgXzoowX0HnRcpgXZVyYzou2wLwonpt0
XrQL5kUZt6PzonzbefOijL+g86IXYF4U7z90XnRUPm9elPFxdF7UG+ZFGdeh
86KSMC+K93M6L/oE5kUZj6TzonIwL8r470qYF30D86KM36DzokthXpRxeTov
mgDzooyn0HnRdTAvirpN50WzYV4U9WQxzIsawLwo4z50XrQS5kXx/kznRc1h
XpTxTDov2g7zoowfoPOitjAvyvhQOi/6F+ZFGfej86JuMC/K+BI6Lyp0kDcv
ip8TOi/qCfOijB+l86ISDbx5UdRnOi+aDfOijD+l86I3YV4UdZjOixrAvCie
d3RedBLMi+K/S+dFS2FelPF1dB+nCPZx8H5F93GEvXj7OOzxuXQfh4N9HMbP
032cONjHwddP93Em/eTt46Be0X2cZbCPw/j3PNjHaYV9HMb56D7OXdjHwXs1
3cdZC/s4yOk+zi/Yx2Hcm+7j5MI+DuOSdB8nEPZx8PXTfRxX2MfBzzndxzGA
fRy8V9N9HAXYx2F8Kd3HGfaKt4/DeALdxymHfRy8p9F9nNewj8N4C93HuQj7
OIyH0H2chbCPg393uo8zBfZx8Jyl+ziCh3n7OPh9/wb7OD9gH4fxGLqPUwX7
OIy70H2cVNjHYXwV3cd5C/s4jA+n+ziPYB8H9Zzu41yFfRzGPek+jiPs4zC+
je7jWMA+DuMT6T7OVtjHYbyC7uNowD4Onu90H2ce7OOgntB9HImbvH0cxsfT
fRz+IaL/dx+H8W4n2MfpgH0cxkvpPk4Z7OMwHkv3cT7BPg7eG+k+Tins46Bu
032cbNjHQf2k+zgfYR+H8TV0HycW9nHw/kP3ccJhH4dxIbqPEwj7OIy30n0c
P9jHQV2l+zhesI/D+Cu6j3MJ9nHwvKD7OKdhH4dxW7qPYw/7OIzr0n2c/bCP
g+c13XdeBvvOTK92033n6bDvzB4/lu4734d9Z8b/roZ9Zz3Yd2b8MN13LoN9
Z8aP0H3nMNh3xveT7jv/hH1nxqvpvrMa7Dvj+UX3nR1h3xn/v3TfuQr2nfE8
ovvOA7DvjM9P952nw74zfq7ovvNK2HfGf5fuO++BfWd8/+m+8xnYd8bXQ/ed
n8C+M+Pz6L7zR9h3xu813Xe2hX1n1HlH2HceJsPbd2bclO47e8G+M36u6L6z
DOw7M76M7ju/hX1nvC/RfWct2HdmfALddy6GfWfGz9J95/2w78z4zz7Yd/4D
+874/aL7zpdg35nxHLrvPAX2nfG+R/edQ2DfmfGXdN9ZA/adGZ9K952zYd+Z
8ct039kM9p3xcxsP+84/YN8Z7zN03/kM7DszXkz3nUfs5+07M65J9523wb4z
4xF039kX9p3x+0v3nRtg35nxVLrvrAD7zngPp/vOx2HfmXE1uu8cD/vO+P2i
+86Cs3j7zow/o/vOurDvzHgl3Xe+A/vOeB+m+861sO/M+Aa67ywL+86Mn6H7
zjaw74znHd13joF9Z8Z/2MC+89Ba3r4zntd031kL9p0Zr20EP5kE8JNhenWN
+sn8BT8Z9vi51E9mMvjJMD6M+smogp8M48epn4ws+Mkw3vge/GTegZ8M43LU
T0YL/GQY30v9ZArBT4ZxX+onEw5+MoznUz+ZP+Ang/dY6idDwE+GcWnqJ3MW
/GQYX079ZDLAT4bx7dRPZiz4yTBuR/1kdoKfDOPXqZ9MDvjJ4L2I+sn8Aj8Z
xj9TP5kJ4CfDeP1B8JNZCn4yjA98Aj8ZE/CTYXwK9ZNxAz8Z/JxTP5kn4CfD
uCz1k/kMfjKMR1E/mTbwk8HvKfWTEcvj+ckwXkD9ZJTATwb1ivrJGIKfDOPf
DMFP5iT4yTDuSv1k/MFPhnFR6ieTBH4yjN+nfjJ24CeD5wL1kxleyvOTYTya
+sncAT8ZxtdSP5l54CfDeBH1k4kDPxnG91E/mU3gJ4O6/Rf8ZGrAT4ZxN+on
YwN+MoyPpn4yAto8PxnG/aifjA/4yTCuQP1kZMFPBs9Z6icTC34yjGtTP5mN
4CfDuCX1k6kGPxmsF6ifjDX4yaDOZ4GfzNBonp8M3qupn8xt8JNh/CL1k5kD
fjJ4TlE/mWjwk8F7EfWT0QQ/GTx/qV/fQfDrY3plRf36FMCvD7+/1K+vAvz6
8HVSv77p4NfH+BPq16cIfn2MP6d+fYXg18d4EPXrcwC/PsYNqV/fVfDrQ92g
fn0m4NfH+A7q17cA/PoY30n9+gbAr49xI+rXlwN+fYzvon59j8CvDzn167MB
vz68D1O/Pmnw60NO/fougl8f42HUr+8H+PUhp359O8Gvj/Fw6teXBH59yKlf
nxz49TH+mvr13QK/PuTUr68X/Prw80n9+vaBXx9y6teXAX59eH+gfn0q4NfH
+Fvq1+cHfn2MR1K/PkFpnl8f4xXUr+8Y+PXhuU/9+r6CXx9y6tcnDX59jFdR
vz4D8OvD+/Nb8Ou7DH59yJeAXx8Hfn2M17wHv75f4NeH5/tK8OuTBb8+5B/B
r88Y/PrwPqwNfn03wa8Pz51M8Ov7BH59jDdsAb++f+DXh7wQ/PoWgl8fnvs7
wK9vH/j1Md5UCX59d8GvD/lu8OvLAr8+xpsbwa+P35Tn18d4y0Hw61MDvz7G
v3wFv77D4NeH3Br8+h6CXx/jrV3g11cIfn2MtzmCX59wM8+vD/+/feDXpwZ+
fXhepIEfchH4ITO92kb9kKPAD5k9fj71Q/4MfsioG9QPWRn8kBm/R/2Qc8AP
Ge+r1A95+ESeHzLjntQPWR38kPH7S/2Ql4AfMuqzFvghF4AfMuN/VoEf8hHw
Q2b8AvVDFgY/ZMYnUj/kx+CHzHgg9UPWAD9kxhdTP+QS8EPG+7wZ+CHHgB8y
6if1QxYEP2T8+/qDH7Ie+CEz7kj9kB+BHzLjHtQPuRP8kPF+Tv2Q1cEPGe/z
1A/5Ivghoz5UgR9yEfghM/6U+iHPAj9kxq2oH7I1+CEzrkL9kOPBD5nxPknw
QxYBP2TGP30FP+Sd4IeMf3fqh6wHfsh4TlE/5H/gh8z4dOqH/Bj8kPH9lAc/
ZB3wQ0Z9pn7I38EPmXEn6od8B/yQGV9N/ZAJ+CEzLkL9kJvAD5nxwmXgh3wV
/JAZz6Z+yMrgh4z6T/2Qy8EPmXEf6ofsDn7IjDtTP+R54IfMuBn1Q84FP2TG
11A/5BPgh4z3Z+qHLAV+yHhfpX7In8APmfEfa8AP2Qr8kFE35MEPeRz4ITMe
Q/2QY8EPmXF/6oe8B/yQGT9D/ZCFhXl+yHgPp37IL8APmfGjNG9CA/ImmF4p
07yJZsibYI83pnkTopA3ga/HFfImZCBvgvFjNG/CH/ImGB9D8yaCIW8C/44N
kDcRBXkTeJ+neRN1kDeB99J8yJtogbwJxtM8IG+iA/ImGPdVgbyJn5A3wfhh
mjfRA3kTjC+jeRMDkDfB+EiaN8Gvw8ubwO81zZsQgLwJ/DzrQd6EEORNMK5B
8yZGQt4E488EIG9CFPImGBejeROjIW+CcXuaNzEW8ibwviEGeRMSkDfBuBbN
m5gEeROMv+Qgb2Iq5E0wLkHzJqZB3gTjLjRvQhryJvC8/gx5EzKQN8H4Zpo3
4QV5E4xHO0LehATkTeDnhOZN3IG8CcY1ad7EZMibQP2heRP3IW8C/19fIW9i
GuRN4D1nEuRNPIS8CcYn0LyJGZA3gecCzZt4AnkTjJ+meRMykDeB98w0yJt4
DnkTqKu/IW9CFvImGJekeRPBkDfB+FaaN6EAeROMn6N5E68gb4Lx2OeQN7EI
8iYY78yHvIk3kDfB+CyaN6ECeRN4D6F5E1GQN8H41e2QN7EY8iYYT/CAvIkY
yJtg/HcY5E2oQ94Efq9p3kQ85E3gOUXzJhZD3gR+f/dBntcryPNiejWa5nl9
hTwv9vjdapDnlQx5XqirHpDnNRryvBgXpnleLyHPC/+OnpDnVQh5XqirqpDn
9Q/yvBgfVQl5XmMgzwvrgpWQ5zUL8rwYVxoPeV6qkOfF+MUWyPPShjwvrAti
Ic9rF+R5Ma7sCXleRyDPi/FLeyDPawXkeWEdoQJ5XjqQ58W4qjDkeW2DPC/U
jQ7I89oFeV6Mfy+GPC8LyPNi/H4C5HkdhTwvfJ5gyPM6AXle+DxekOflDnle
+DwukOd1GfK8GF97APK8vCDPC8/ZLZDn5Qd5Xow/WAZ5Xs8hz4txbRnI8yqF
PC/Gf4lBnlcV5Hkx/vAP5HnVQ54X6kMd5Hm1QJ4X493pkOf1FfK8GH/8FvK8
fkCeF+Ob/CHP6w/keTF+ag3kefVBnhfj25ZAnhc/5Hnh/YTmeQlCnhfjAzMg
z0sE8rwYL5gAeV5jIM+L8SARyPOSgDwv1D0+yPOaCnlejBv8hjwvacjzYly+
DfK8ZkOeF+P8NM9LDvK8GC8ugDyvhZDnxXhoKuR5qUCeF95/4iHPaxnkeWG9
8AbyvFZAnhfjCwIhz0sT8rwYF3gAeV46kOfFeNkNyPPShTwvfH/OQZ7XBsjz
YnzS8/8nL5Xp1esp/09eKnv8DaH/Jy+V8ScJkJf6C/JSGR/iCnmpA6N4eamM
71KHvNRhkJfKeIUz5KUKQ14q6kM55KWeh7xUxhcvhbxUYchLZbzxDuSlXoa8
VMZvdUNeqijkpTK+wgDyUj0hL5VxhzLISx0DeamMZwpDXqo25KXiObUE8lIv
QV4q4ycPQF5qOuSlMp7rA3mpIpCXyvjcFMhL3Qh5qYy7/oa81GuQl4r3cxnI
S82GvFT8POtDXupoyEvFz6EH5KVugbxU/Py8gbzUm5CXyvjCeshLzYe8VMbX
CENe6jjIS8Vz/CHkpcpBXiqej4shLzUD8lJRJ3MgL9UK8lIZ/7kf8lLFIC8V
7/MDkJf6CvJSGV/vA3mpmyEvFfVtPuSlfoe8VMYDPkFe6k3IS0V9M4G8VCXI
S8X7fBfkpRZAXireh69CXupxyEvFe5EM5KVKQF4q4/1xkJcaBXmp+D3Vg7zU
7ZCXyrh+O+Sl9kBeKuN8HpCXeg/yUlF/pkBe6jLISx2kM5CXWgF5qagn6yEv
9RTkpTIeXgd5qdMgL5VxYyfIS+UgLxXvJ+KQl2oGeamMR7yAvFQ+yEtlPOwh
5KUGQF4q4+7tkJe6DPJS8fNWAHn0qyCPnumV7wXIoz8DefT4d9SHPHoryKNn
fI4t5NH7QB4944HLII++FvLoGR/HD3n0vyGPnnE9C8ijF4E8esZvp0Ee/Q3I
o8fzi+bR+0IePT7/Lcijfwp59Ph5oHn0YZBHz3gqzaOPgTx6vLfTPPpkyKMf
9HeBPPpmyKNHnVkDefTtkEfP+Dp7yKP/Dnn0jB8IhDz635BHz/iFMsij/2fA
y6Nn/LkI5NEPgTx6xlM0II9+OOTRM267GPLoR0IePerVFsijHw159KjnNI9+
POTR472F5tFPhjx6xt/QPHopyKNnPInm0d+CPHr8e9E8em/Io2e8gebR34U8
esa7aB79fcijx+/XZMij94c8esYllCCPPgDy6BmfvQHy6J9CHj3jauaQRx8I
efSony6QRx8MefSMb/eBPPqXkEePf8cwyKMPhzx6xh1TIY8+AvLo8Z5fB3n0
UZBHz/i9f5BHHwN59KhXlyCP/j3k0TNeSfPoP0AePeMWjyGPPgny6BnvoHn0
nyCPnnH7OMijT4U8etRVmkefAXn0jJ8vhDz6bMijZ3xUHeTR50EePeM+NI++
EPLoGZf6B3n0JZBHj583mkdfAHn0qG/VK5d5fFusIXO8rK6eD/VqRXPujoTP
DkRKMygmUQj1yuLjxpsfPp8nQrN9xROFUK+815cuu150g7jJ1qbMEEW9coy4
PP/DZx9yyvtWfILQoPuVpIb0t5gHZMkd1Uk/RqBeSa3+I3y96BHpultqO0MU
9eqGw5ahgdlPSOlGjf0vzmP/ij8kqJf7/JxEZXl6JQihXtnWDP1dnBBEvHRr
E0ovYv+qYZxxZ2dMKLHJUez8PgL1KmiW0a+hO8OI7haPqSOu4O+A9fGC3z2L
wolCXqH2DFHUqyk7Ir5O2faGnH1xa5nkWtQrvZ9mrc+zI8ivg+pbX5zH/tWV
q6LNShsiyd55jQdUPqOOJc+Jqec+R5G81quuCUKoV30JFjXrNaPJymBV743a
qFcqu8ZWFifEkFeHq0NKL+K968hvrnSvRhyZJn8hyTwNdezZdcuizpj35Gr7
wrLvI1CvqudNyj+pxpHekNJvp9bjvetyXV3z0J0fyGErd8ERV1DHAhcsadKe
mEBKFeSmeWegjiU7ezZ4FiWQdR35yjNEUa9qUxvrCr0SybuXzutfbsR7V5+E
eu2UbUnEK0p8keRa1KvJ+25W7x6TTDIm7Fff24xcLbyl8nl2Mhl2Inbti/Oo
Y3r9GhVfr34k6iWjtnXOQb2yXn+7TGnDJ2K7eJ+JymfkV++0lTiOSCHBd94d
PHkA9SqocWUx9zmF1P8ROZ4ghHqVoninUOD8ZzJlx+7Tgi+QN7h25K/XTCXb
ot9e3qiNejUkc03ejaFp5PKkET63viCXnOybU5yQRpIcTQJKL6KOLd3/PUvy
dDr5V/o6VGoe6pVhxNrMvRoZRHGpYLR5GnI7Pr/0F70Z5NA9o+TgQ6hj1zf9
Su2MySQBf19lfx+BehXqq/NZxTGLlO0cVq4WjDyt5eGnk2rZRDx2e9Op9ahj
zSrdyQld2URnSuj3pDbk7gnPaofuzCHuJ/n6hK+gjo1uya2ZHZ1DYsr1hTbL
D+qri/VVa0/MJT+WBY31zkCuoDK32tIhl8je759WYYk6Fmu0rcqzKJfs7t06
b4Yo6pWmu0vla5U8cnPXc5UDg+5jHubLOhzer9QomG095ZEw/j7o/2HBMIm2
08QkZ9vUIVPx90EFvjX249uukzMpw50HpuDvgyNnHGv1N7tLip7Vf+l/gfs1
dtKbFoxve0jGr66RG5iCvw/WL9p3sEzmKYl/nVXXX4fzDFtXOT32N3tBDsx4
f7f/Be7LJGy9XrnPN5QIp+rPdX2H8wx3FuWPHN8WRqqGZA4dmIK/D2YtqQp0
EHpDXi9eU+3iinNW/1VFmmUyb8m5Y7Ex/XV471LX+VWnvjqKGAUqertoYZ1o
u3XA1d8smiyoeWHd/wLvXUE7R0jyu8SSoROlN7qIYp1Yu2d8zD7f96R9zoZx
ru9QxyYenm6Y8o4jRUmC/KQVdSwwevzfcW3/nY+mSZ39U/DelbTcd92nngQS
9M+lMn4j6lh1wnQfB6EkcttnabqLK+rYX81njXMnJBNXpd/vNMJRxyTS5JTL
ZD6Sg9nhz/rrUMcWbQp3v6z8iWw7bOUVPw51bEOeaq766hSyXFDW3UULdeyA
QZxUx5bPZO7jhqMaJ1DHzpStPOJvlkrEyUPj/heoYw9NUuI2H00jfWVG6+PL
8T4WV7dhJL9LOmmxn7DERRR1rMQib8ebKxnk4MWDY/2lUK+6Wg0D9/lmElPD
tSNc3yEfc7Ty9/igLKIvI8NnugV1TOHnHs2Ud/99737y/9FoRf502S/tuL05
ZEVCTce0M6hjb/pUv49ryyEqnvGN/YPmFhI4xztWNrlEzvh+RVUE8my3OPKp
J5dMl3PKj984aN5y9UDTNLc8ItFjmObXhLxNYNU1B6F8MjJFJcHFdVBdmeKh
kuOZT/huj31nMhF1TOhSSsXcCQWke8/3lxrhyCU2jPBw8ysg7Quzn04b9Lvh
LLGNcmUyhaSuP+R+fx1yxRzPPMXQQlKccelW1UnUtxU38xwvKxeRzHsHLsWP
Qx3bpDdeuiG2iCQe0HLzC0VuLLH9s/rqYvJOddYJFy3UscMl947eTismocP4
j5pUI3e8VynRsaWEPM6rNtc4gfp2ftf0eK3SEnLn4ftd0wbVm7en7TX3Nysl
1474but/gfxBzVORP82lxFndUadq1aDfDdfKPJzyTksjNuJL5cz3W5le8bst
uh0adJa4mM5s+VKF86J8T45VhwTdJp4rlm79UoXzoh9Wz3LiW/GQmObuCTPO
Qp+E0yrXPUKCnpIJ4ZqCX6pwXnTFnN5rhuODiWvPDtXHBrj3d1okYgPfijDS
vPKIuXEW9rXMBFpzDbpeE91L7l4TtLCvRfqlDEOC3hKjg+m1LVV475Lq1q/g
M3tHrl3V7/k4Ge9d/Z2XdxuOjyWJ4dWjHxvgvauyJaEpJO096So8OPf0TZxz
qPr2T4VvxQci+/cnMc5CHdv01ftP8L0Esmuai+HSETjnEP9lUaxBVyK5vkro
6AQt1DGFpoxTfJuTyR4l7dV/P6COPajbvyIk6CM5qSmW3VKFOiZazT/UUCCF
3DbM31nci/cx5/IHH/nMPpNXB+80fZyMOtZevPhCSEwqST1pbBOxGHVsV0G+
juH4dFJ3dUZ/gAHqWEbOEVH+Yxmk17/54g071LFlmcI5IWmZROJ1yPjTN7Gu
DE59ctNQJpssSLZ+dCQM9U203n8e34ocol2kqmCchfqmtfvrZYOvOWRfy793
69tR31yql34NvpdLXP5+WLN0BOpYpPGFTXzr8shdkXM5c+fiPa2zvPCVQVce
eTNt/a4JWqhvc3bOHBMSkE/2TxT6xa+IOmZacsyGb3MBsXvUuuTvB+R3DOLz
DfoKiPu8TNfvuqhjOQUjVUKCConnm1cfW6oG7ads2+HNt72I3Fe/ObLGCvVt
Ze6zbgOBYvLio92W4l7kjrq/toe8LiZRmwx9si6jvr3OXBnDZ1ZCkouXVH6c
jDrWut5ziqFoKck1mzrz/aD724y0CueQmFJS/aX/QMRi1DejdfOq+A6UkXab
2pfBKchvfXIghuPLSc+/pF8BBqhv6Ws+PgxJLCeCZ58tvdeIfFiSOD//sQoy
Tuzi6Rt2qG/qK832GkpWEmmfw58uDEV9s+NCk0PSKsn86ZtETt9EHrr8nwz/
iSqi/mLhVgdp1LfG2HXnDWWqibbi2DtHwpBLLvVuCcmrJgaxXZXmBPVNruL7
LL4VNWTfmpKZxlnIV/veKQz2riGHMmMO6hmj7i2wqFIn29ZrJE0OTK2Vxvn2
vbJr/BaNukQarev6IwzQp+7UgqCkhaPuEZ+9+ccjDNAHZpbMpF37Lj8m6tdU
LMXc0X/soqKxwcJRQcS6Yv2iCAPcE+z23zzXRTuMJH13lt9tiXVi0DMbmX2X
35Dxgi/niLnjXJZxqNcMncxIcnBq9YxYH7x3jYqIlFo4KoZUThQaFWGA966E
mJKpElvek3OPH165tBv7XdFmfSIu2h/IgvlLRuy2RB0T33dtpHVrAil5l3te
zQF17PB+qRH7LieR06sPCYi5o44lHwoTMpT/SGSz+M80XEEdkzyyUlAn8xPJ
2+47JNYH72P21nkCy498JifrlVxuBGBdmW23d9jCUWlEXK2p743BoD7YiV/8
M8PSiYXza3WpXahjbifP8klsySSxCS4nL+1GHStzkRgi/COLjBJcH9Nlgfe0
yQnbBk5p55C9Gyb0mFmivn1add+le1IueXejXi3DGvXNNrmh71hrLhEpfmWv
5oD6JqWlcKo1Jo/snur8NsAZ9S0j5Xjv3sv55O3udb9E3VHfHLXjT1YaFZAR
z8cpOZ4ftL+fPvyfgXwhMW2vsW64gvqWv0HXKae3kLxdFBqmexP17XSWT492
ZhEZ4eDYGeOD9zeFzTUnkh4UE9M4zfmzH6DuleXO/aN+pIRE8Ilb3QhA3Tu/
zdohUqOUCK+tCu59jrqnUhj9e8GoMrJAS7/rjQHqW50Bv/2L6jJSdiDW62Ap
cs8Sna4ZYeXE47K0stQu1Df1nbfs7p+uIAtens8vGKR7X8rLf47fUknKcr7a
XNqN+uZtPMvWU7qKePzcJr6iAfnqassfQj+qyAKJmPAuC9S9b2Zvrd0Tq0np
4ulbgr8g1/3u8ueUdg3xMDr3zcwSdU9Gcea7mPAassCl3VOiE3mvTYpD96Ra
Uvpw64IMa9S9vDeH1ZTda4lH0rsst1/IX/wa1X2stZbMb5p2RM0Bde+0SkRk
6NY6Uip0VvRrD3ID++32rTF1xEOuLSTAGfVQIapXZc7MejJ/05YN2weQD/3z
sGvv5XpSeiyqTdQd9bBwsebbhz/ryalbkpeThqHundobvfzcSV2Nj8uPKqqd
2sT0qmp/lbLc8GtklDY38slY9Nv8rsK/ZN5wP+LsWTjh8Vj0n+zxTTvs7/GM
LH7fOC4mC/3ueqaOi5Ud/pK8fl3zIGAszpH2Zc0XKEt6TSQKrG5pyuPc+ynP
fHl/j0iSv6mtODoL93T6dU/o7dOMIddTD0ydb439LpfRks6yw+PJxjVNZgFj
cb7UtaVmi0P9B+JRHb51pBHqWPy6N42lSYmk7v43O0151LH+wLOO6k+Sycqd
C3xc+7Cu1BDeLurv8Yn4TzgSHZ2FdaXLwXmP+Mw/k76CkPKf/lhXvk/tVd6n
mUaMbrb1KVhjf6xPNvvzJ5kMEq07b/qBVYP8lC492iU7PItMED24KmAs3tNO
tdp+u9yUTY6nPd9X0YD6ZiIzc5VDfQ5pXW27eqQR6puLvsiVwPxccjfgpl7g
atQ3v7NdhaVJeWQd32tzTXnUt/i3VVIjI/JJt2mufd041LeqxpSD6k8KyLP4
b+dd+5D3jw9/Y+VVSPQlR9+d2oS6N03rXp+fRxEZ5rwgKDoLdU/D/szaHLti
ElG2KdYgCnXP9JnlDT7zErJvyZGMn/6oe65F+uWK+qVk7J2rldcvoO49HE5k
9mmWkaTfIR0K1qh7Capzj95WKSe2+hkDaTtQ92otxkR/kqkgMyPaRh9YhbrH
7/OX/8/4SpInPnKGgBzq3oyU+g2yw6uIu/U8pYCxqHuruzO8d/6uIoo52mtI
L/J9cyJrLjdVk7r5B/UrGlAPE4N1b5scriE3rl6wcMxEPcxbvWapQ30Nkf6d
v2ykEepeffniak+jWnLi6d7kHdnIf9oqeATm15IcvZ8bAlej7g0VmSGbsL6O
zB12pvB3FPJxTySySpPqyOk34iaa8qh7s9RH2v5YVk9K9gQ03Rq0p6xcMDBh
ZEQ9WSiueLRuHOreGstfcTPlG8iFhITuhReR6w/7slv9SQOpObbltGsfcvP7
lcP1pzYStem1QlnWqIfHlfOCrbwaiWf2sRtTB9XF5zI+bT4n0kSaXYZMPrwT
9dB7X2yXn0cTIfOvB0RnIX/U++peVG8TuVEpJSe0GvVQ8pOBQ6znFg13m2mu
bqo6TK+Oq/l/d+CuEyO/wBdPBtBPOMZI2tyBe0j23PxV/HgA/Xijp9jmKkq9
IOmHLoXGcLinU2FVN82BCyPmVyYffTyA966KjSML9TojyEBo0MIrBOcfKhSU
LytKRZPM/ZKOMRzqWIWo8crRuu/JvRONpS+rUcc6fif+s+c+kP0XQ5c+HsD7
2FeL4iLz4kSidO+4r48U3sfai9rC9TqTyUDQ8t7LBOvKdq0hV1cLppCmSvf5
HxZgXdkWOe6AolQq2dDUZBLDob61zZZdLa2WTl536HhG6OI9rdV7+bTRuplk
UvdL7mU16lvr8K09/RbZxHVA/FvgUdS348uUWu25HNIo6DD98QDe3+xs3xse
Sc8l60eXb37gifc3u+C1H82L80j4ROLmI4X3N7v6XEXj+nwyUfpx+I1XqHu2
U3Y91OssIC6ygnWXCdanttuaRDf8KyQ/7qgIJ+1H3bO9fOzkasFiIvNgv/SH
Bah7tkl/W5aOLSHbH91d8r4buc0/DwNFqVJy+Wn6lhgO9dBWaVSyrFwZ4V70
HYw6j7pne/juImm1cvIzdIF7hC7qnt3jmf4TV1eQ2a933wufgLpnVx4qMlq3
kuyMvPX6ZTXy42MXOwkaVZFrMR/Tgp+jHh5fn9jcb1FNEuO76wKPoh7Grnw2
7+SSGtKVKPvvqRrqYazx4Vp7robIphiNfTyAPM5x4R0bzVpinH5V7mEK6mTc
7a5NR9JryfVsbvUDT9TJuPAYgUNb6khy/neje4aok3GZrnHmxXXkT/FMOx8p
1Mn3X9bY7jauJ/IV+le8mgdxgRHzjOvriWnN+Sc3XqFOvpfOrtl+sIHcaoiO
u+aAOvl+uZePXmcDSWlpK7hMUCfjd+zYtPl4Izn1+5p98lDUw/jj0wQ2/Gsk
Pn+e8yftH8Rv1MeudWsi4X8/XEtIH8RDA21WCzaT9N7SyR8WoE5yqVay5Goz
aez/8Sz+1iDeqFizdGwL6R8iovS+exDn++OtereFTBwqw8UaoX5yku83Kkp9
IYoCGutjBu1dRi9xHzb/6ReyVtCw+N1M1MnAqMzvtRO2afA9CJ90302T6dXX
qWvKbVVuErm5rhuuu3vg+Sh6dpWtSgAxWWvz0NMdfzfUEjngI785mDz7+2Ry
cRL6Nviclflto/KadBcd1vF0x98TRwr4PMxOjCS+C88KKj3G/WhXD6H18ptj
icYlv+SiJPyd8edQp64LlRz58b18xfIf2Ad7k9CVbaOSSJL8Dkh5umNdaeU2
X0baOZncXt/VVyOO/fzZK/c7ZSd+IhZ/3CoUH+M9rWbIw+xTwqlE7alYrIcS
6tvdDyWz5DenE+GtvneLkvD3ym2nxziVeWcSq4Gx6uOCBvnlrtDJvlCZTYr0
d8ot/4G6V++68uYU8VxCQh5OtliK97cP1ZVxNip55Dl/s7CnO+refeLUnLo9
n4zeodATlYa65+gvIS7tXEAcX9m21Iij7hkMvFY/4V9I6gRiioWNUPeUTHX3
ZycWEZ1dQ1IUH+N9bxTXdmN2UzF581or0qgN9bB92oW4U8KlZKrw1aceSoN8
Ml1mNRfIlxEP03yv0JOoh8+qPoyR31xOvr6d5FGUhPfAMxrG6mdsK4jc8LDo
AQHUw91+PRZl3pXEbNG2ReOCkGv0376xKKaK3N71O3DuJtTDqSaKcRcqq0na
+bvTl/9A3mey/+fR0zXkv//2nS3eqJPt195emCJeS5SrqkdZLEWdLIsfOi3l
cS05KHzmvFMV8tSOLW9sVOrIA+XZA9fcUT/fTXu4blpKHckzTbV/PHvQPMmm
jsrU7fVE8LJlR1Qacm8XddvjrfVEPXKURcaRQf4VLy8JSTs3EOva15U14qif
tlUlDzJEG8kzEQP9rshB/lpic5RO+DeScrWeDGEj1M8tGsc/z1zUREbtvb9m
2iBdXXEkyTg7sYmsuUbiFB+jri7wG/PTSa+ZOEbXKa1di7oqmWV6YXZTM3nZ
cDbYqA25SH+oZJ5DC6kfJTvzmCfq7T+F3tenhL+Qicsy7nkooa62Guusk/X9
QjZaHBW/W4y89OqdygL5VuJ2Q/xS6EnU25T3TTan41tJZNxbvkQp1NvIr8pC
8pvbSFvzdseiJOR+kmceFNe2kYlje7+17kcd/jPET+aTrp6GcHt9pq7NCqZX
808fW99ocosMV4gll0zQp51P90dgg8ljMneh9+KLJujH3mYsH2IgFkqa9j0P
bDqHvuuHVN8YNpi8Ie/Ch769YIL+6tXLN+94oPqOaA68Mhvvi78z6ml+3Wkg
9p68lKmyaDqHvjTmszVfCv78QCZuELGKGuSfLxU0dkGDSRI5bbPU9oIJ3tNK
FepefUj7SOw2RMTJP0V9uxUetvCB6mcSaJpOxvvi75UbVVzDHQPSSKVNXWLf
dby/CUZvVDQQyyRjzvVoNp1D3UtQn/pG0SmbaN4dnZrljLq33KzrruDPHOIY
MmdDlA3ua08O2FXWNTePhHIa2f4HsG7trk+a3GCST2rz9LdeMMH7XoGMnFGe
VwEZaRt5aPEgPQzff9P3Q1ohedq7MkT+KerhtRc95S+HFBNyLvPr9EH+XYfb
zKY+UC0hpaN2LBjvizq5TuHzrsuWpcT2bsMxYW/USZmjCx44BpQR0ZnHXvdd
R53kD/eu3F9STp6H/Pv5/TL296p/9EkaiFWSlarnVZrODaqLlc1N1qypIhWc
uEOZG+qnr32Gn6JTNXHQ9nuX5Yz6ubzi7tHR22uIeL7s30QH1E+5U5megj9r
SOiut8uibLCOnjyNL6z/ai1Z27TiVLDVIB9CTjmna24dqTuaEe9/AHX1j+mB
b+3/1U2negyHeO1FXW0ecn90g0k9mXimfuUFE7x/Fj3KXljeU092nItaGS+P
uvpx1dAteV4NZM76U3sWD9LbiHpV69QFjeTXqNVnXs9BXX3scejGh7RGklgg
9ET+KfKbMn7hUeZNxPNuVvKzQb6mbp9yc18OaSa7TLwapw/yHzu2X+DHU99m
Mm/mzuG+kqi3pkJLxB+otpDuZqk5432Rb3phqeiV20I+hjSu9ZyIOrxc5+HW
y5ZfyE3r4APC3sjl2/Jt3AVbiZmq9cUzY1GHp1wRvOUY0EoU/qkG9V1HPkJh
2Ztjy9vIX643zUEM9bkn80j+/pI28tkjse37ZeQtRwJ+mti2k9vaF0QshVGf
i0cVjTUQ+0r2im1SaDqHPD5MWHnji69kXv7YTWbDUJ+tQoOFtBX1NZSW5uUm
LlNlevUyqvDnF1Uv8rj3juUEZcy1OXh0tc4X1SdkfFNMjIQy5tH85b9/z3jr
S1KyUZaTzkId01rv1NWiGkEyy9J3Syhj/ovY7WeSj9dEk1diQxumuKGve3FV
nqbx1nhyfdVSC+ks1LfNXgORI8MSyJLYxXa3rmK9qRw9Pr1FNZnM09dTkVDG
vtnEKrnqj+8/kcmdR3/fKUPd6+Vf9TNgTSoZcfFy1BQ3/B2zZs52wdPp6eTv
jOcn/OZgny1pw5EpxluzSGtc4hLpLNTDgsWJEx5Y5hAruaN9W5aGD/r/Zj4a
GZZLzP/0Gt+6ivVslHGJnNPPPGL88VJ8QQ3qpOyx+rctqgXE4OZEKQll1Elf
9w5i6FRINpk+czU8j7+fit7uSf34vohoySvX3ClD/XR9PkxPma+EaPQkrChT
QP38Hj2qKmBNKVH9pPtoihv+3ro3Y/KBMRfKyPxblXzGBairhVUyP1zTy8ls
s8N7/Oagrq79vtC54z9dmqbQk1g9yP8weqj6cOOtVUTi77mZ0lmot/ISa6+n
364mF/aOWBV+HfVWd5ys6APLGjJMZ8uPLUtRby8+mL9VT6yWuC28E/CjHnni
bGWfkWG1pE+ieuutq6jDva+WVCT+V3859ckMVVZDHVZZQqSdftaR7nrLNwU1
yI8krrFYdLue2Ka92Xv8Eupz4Hqd4BbVBvIt7O9YCWXU59oC3W/+JQ3E0mdl
cmQl8ikm+iqGTo3ky6kLdobnUbf1mnc6iU1tIub7smf9WYi6fe2YGffxfROp
05EovFOGPKXHfNgp02Zissj47BIP1HO+M4e1lflaSPmEJyplCqjnS0Wsr7UF
tJDt/a2NTsWD/NZu2+cHrPlCChoWeU9xQ50PneY8cWfTF7Il/YRW3DzU+abn
bsZjLrSSzHDu964C5NMXnQ/4LNtGdO4Mf953CvV/R8yVZtf0NvLJZaOh3xzU
/1urb8qrWbWT1eZegiQXeUaGj3XHf/rDrS+Pqh7kJylg8CDyadhXoq4448Dp
WXgukOqAf7u2dpDoiQcnSmchtz4QuGLcrw7iM2DYULMMz4X7bTvtX8fqa0SM
uLyu9tBspldHBKzTu6K9yIruiomCuzG3K876lmRX9BPS237WfPhu1DHO7Ih+
p8QrIv9qk3+yEOZw1T1/8ulXdAQp3V82cvhu1Ld9UjfrrFuiyfnpFifWRmNu
RZO3a3+HBEfutZ+wSRbC3yWVz6uKRs5IJD8+x89tjEB/m65VCr6/opPJuqfD
qgV2ox6+7Z8pq7Qlhfi56dyeLYp9NvuYyVHWLamky/j6+rXRqJOq9mM0w1wz
yPqlRXwHzPF3hO5FQvkdEtlky0ixXclC+Htohb1rmERxDnHuWRhVYIJzHXEF
Tt1vZ/xX3zVvE2+MQF29r2ivoX8kn+QV2lt1jcC62Pm69dlf0QWkL+nuZ4Hd
qLfGHZYZtwSKiOzruJkSUegjvXzDgbFKW4qJ3sNql9mi2A+UDNq7M+9+CXG9
xl+muhfr6z5B00fWLaUkyFlGZW006nOV+c6W0crlpPDQuuuGo3BeLj5Jf0GY
awUZsuNw235z1G0/6S32uumVRH7tNa0TsVinu7hueN8hUU2C75VsThbC33/D
Ombyr11UQxLHHHLJeIP84YNHTyWKa0jJhX/BBSao8zc2SGk3OdeSjoErpRXC
qPPu/+63v51RR4Y5TBNsjEBuEzT5+tnPdWRyxyvlr6ao/3t33FHSP1JPFpqv
3NM1AvsDekISxbPGNRCtijzPvrfI10TdcvoV3UB2bdv3XmA3nhcqFmOmJZs2
Epu0rlZRETwvZMZ7JtwSaCIXVp6fKBGFXCJZxHxvcBPxezdRa9oePEcEbS8J
KW1pJm8XBNnOFsX+are0UAh/dzNJf7bs0fx3yFtyzurm3W8htZKZWap78dwp
dR3689GqL6Tby6RXQwzPndT5bt7WLV+IqMg32bXRyGMq+5esvNZKZp5xM9Td
h+dR0BXnytHKbWTJX/GzhqOw7+G77O/pmtI2omv95LVpDPIrrQ6zwlzbiXmL
Ss1+czy/nO92pbjKfCUnTVNEj43G88tqne1h3fSv5GbR9mUnYpEbd38Tk7Lu
IIEbWw+ctsBzbdOzI687JDqJad3y9clCeK6p6bfrx8d1kqYHw/esM0E+wbwl
98MXfY1NuUMU5G42x/2PD/U82V3b6EV+SL2d9tgJdczugsK62sYn5NKnmXsC
nPA+ZqH9wCt3+ytyzcX+Xk851pXyZ899q2mMIEWTyocGOGkx/tQ8XmKHVAyR
ekusdCahD/M0rd/quds5ojR36+GecvQ73TDWJ3yWdiIpOT7s4cZg9Om6MPRN
ck1jMnFOiix45GTAePLPrOL77ilk+piDwr+1dzA+pKG1dbtUGkkymaKhM2kX
4+oFw/vHxWWQ/SGZNn4tJoyfSJ4xJnd7NhHo47b1lJsxvnOn1M1Pf3NI8cxJ
Rx6v3oOP3xrqO0s7j7zQsbmwMXgv4946y566++STk9bpAd3i5oxHrEp9WdNY
QDbemfX+kZMF43lLDd9pKBeRadyp4vV1+xn/ptiYcN+9mHxrLPrepX2QcTE5
2/S/OSUkUWShyMPwQ/j+z+Qr3C5VRryULs7WmWTJuM4Uz6pIq3JisbNuxa/T
VowfGCvZMi6ugix2W2bk13KE8XMjg7/bjKgiAnppS2fNPcb4k6FL/uVsryZH
mn+v7SlHXntqr7vPthpS7DRTP8vTGnPiHOed//S3hqwU27zn8Wob/LvYf7/c
9aiWBD1yPnqiG/lom3fXZ2nXkbEqL5w3BtsyLnXE9fa2b//Vd58LL84wtWN8
wSGte+4+9aTJiN+nW/w44xoWov7hGg1kc+f8JxmfkG/aU/C4prGBRLsbhT9y
smfc2MQ3cNTVRjJT4kK8/XwH9IXbuSdUQ7mJXHkRkb6+Drmzgexrq/Im8lu9
tmS69wnGr2z9FnnfvZmY5og2dWk74r7bpqjYdNkWkrp36c+0PuTBOi4f/ua0
EMVuiyEPw50Yj9HS/Ch74gvxvXRL9Lj5ScbTVomkbZdqJQLTPkzWmeTMeKlG
ftb5T63kSHj7HKlM5F+W3suPtGojJWsmqfw6fYrxP6q7SxrHtZOVJZqrUpVd
GBdSmls5Lq6dBB+20fVrQT5hQWft6r1fybgBv122910ZnyMX2WQzooOQ1Ebl
WXNPM64651Tbo/AO8kvcOVbMHbnWzDXfcrZ3ksBd4qt6ypFvlBrZNTDQSXY8
C/xcr+LG+HDjun2NZR7k29ppFzdZapL/cbGD5xYtrdLX2PUsze3NoNznt3Lq
tzjfTrJz2ucDY9Qxd1X0To2kXGcnEXqpPqR1UB6rIH3+BC3e8zOdHE2ff9pT
3vOz1xNFn99Okvf87PHaj57bHAjpJKfdjM92COHrn3F/gkF9owdJs1bweeKE
r/N/jx+3r8Ljv8dr/P+PT8or/r+PZ88zir7+6aG814/1S++z/bPr7cjUC1VV
Mkdl2P9LucVKZVheJ1l2I9L76TbML/7f41+d4z2e+/8fP/s67/HYb9l84U9V
k77GBuXEJcGOw9nr1DErVVIu6iRSG9xmH5TC128aqTu2qdGO7F0seem503D2
+l990nZI+9dJqoZ2R447iM//v8dvK7a5+N/jNf7/x3cN4z2evf7/vZ4sRd7r
QX2jr6d97NA5/70exv8PNm8dWw==
    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxVnXXYldXzd0+H3S12t4JISAlIiKiIghgoNiIiWJggiKAYKCgiiIWCiAEq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         "]]],
       Lighting->"Neutral"]}, {}, {}, {}, {}},
    VertexColors->{
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143381, 0.4523915157143381, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977495`, 0.20933181110977495`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.3443927181955512, 0.3443927181955512, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.899113673809771, 0.899113673809771, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.]},
    VertexNormals->CompressedData["
1:eJztzrsJgEAQBNBBI8uwEnuwBMHYFizUIizBwEjksvMTvEkG3sIy/bSMc5Nk
65I2t6xn7QPnnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeec
v+zhnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc84555xz
zjnnnHPOOeecc84555xzzjnnnHPOOeecc875b33lnHPOOeecc84555xzzjnn
nHPOOeecc84555xzzjnnnHPOOeec848813t1r7Wz5E/v8b/gB/iCRMo=
     "],
    VertexTextureCoordinates->CompressedData["
1:eJxl3UHILeddx/FBcKGIoZCFuClCNy7ERaVYWnrBrrpx0W5cSWloMaAIkoUb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     "]]},
  Boxed->True,
  ImageSize->{500., 542.6623270057133},
  ViewAngle->0.4703007239436897,
  ViewPoint->{1.3374965292852, -2.170177805239737, 2.2251811898798},
  ViewVertical->{-0.02657207481306163, 0.08344568150009217, 
   0.9961579910230678}]], "Output",
 CellChangeTimes->{3.650908457715815*^9},
 CellID->465618857]
}, Open  ]],

Cell["\<\
This is not a terribly enlightening graphic and also it does not have the \
field lines going through a uniform distribution of points at the sphere at \
infinity.\
\>", "Text",
 CellChangeTimes->{{3.650972954934391*^9, 3.650972988891527*^9}, {
  3.650973176786695*^9, 3.650973181612431*^9}},
 CellID->2005123308]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function to show vector field in 3-D", "Subsection",
 CellChangeTimes->{{3.650914938581542*^9, 3.6509149492853823`*^9}, {
  3.650928972322557*^9, 3.650928973128921*^9}},
 CellID->2101273939],

Cell["\<\
Note that the z component of the filed does not depend on the azimuthal angle \
while the x- and y-components are projections of the radial component:\
\>", "Text",
 CellChangeTimes->{{3.650914951925569*^9, 3.650914953173148*^9}, {
   3.650915016684587*^9, 3.650915055481248*^9}, {3.6509293784867697`*^9, 
   3.650929392074183*^9}, 3.650973183332099*^9},
 CellID->470166689],

Cell[BoxData[
 RowBox[{
  RowBox[{"SqrtDiskVector3D", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xyRadial", "=", 
      RowBox[{"ExSqrtDisk", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"], "+", 
            SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"z", ",", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}]]}], "]"}]}], "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"xyRadial", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ",", 
      RowBox[{"xyRadial", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"x", ",", "y"}], "]"}], "]"}]}], ",", 
      RowBox[{"EzSqrtDisk", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SqrtBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"], "+", 
            SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
        RowBox[{"ArcTan", "[", 
         RowBox[{"z", ",", 
          SqrtBox[
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"]}]]}], "]"}]}], "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.6509149631288033`*^9, 3.6509150060955677`*^9}, 
   3.650973020258469*^9},
 CellID->707930719],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"VectorPlot3D", "[", 
  RowBox[{
   RowBox[{"SqrtDiskVector3D", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"VectorPoints", "\[Rule]", "5"}], ",", 
   RowBox[{"VectorScale", "\[Rule]", ".3"}], ",", 
   RowBox[{"Axes", "->", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.65091506204598*^9, 3.650915138730537*^9}, {
  3.650915197240396*^9, 3.6509152100283623`*^9}, {3.650915266741164*^9, 
  3.6509152847781553`*^9}, {3.6509730241621447`*^9, 3.650973024650051*^9}},
 CellID->105700983],

Cell[BoxData[
 Graphics3DBox[{{}, 
   {RGBColor[0.2947336, 0.4054232, 0.5678384000000001], 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.9368590405649564`, -2.9368590405649564`, \
-2.9354331040461883`}, {-3.063140959435044, -3.063140959435044, \
-3.0645668959538117`}}]}, 
    {Arrowheads[{{0.009766188676615536, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.901401063804138, -2.901401063804138, \
-1.4491907491068186`}, {-3.098598936195862, -3.098598936195862, \
-1.5508092508931812`}}]}, 
    {Arrowheads[{{0.01106587413722738, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8810938357869946`, -2.8810938357869946`, \
-1.0655409455074406`*^-17}, {-3.1189061642130054`, -3.1189061642130054`, 
      1.0655409455074406`*^-17}}]}, 
    {Arrowheads[{{0.009766188676615538, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.901401063804138, -2.901401063804138, 
      1.4491907491068186`}, {-3.098598936195862, -3.098598936195862, 
      1.5508092508931814`}}]}, 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.9368590405649564`, -2.9368590405649564`, 
      2.9354331040461883`}, {-3.063140959435044, -3.063140959435044, 
      3.0645668959538117`}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.903847390560824, -1.451923695280412, \
-2.900953054415358}, {-3.096152609439176, -1.548076304719588, \
-3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8194857053704463`, -1.4097428526852231`, \
-1.4055454686262072`}, {-3.1805142946295537`, -1.5902571473147769`, \
-1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.756787840277389, -1.3783939201386946`, \
-1.7604116186635318`*^-17}, {-3.2432121597226113`, -1.6216060798613057`, 
      1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8194857053704463`, -1.4097428526852231`, 
      1.4055454686262072`}, {-3.1805142946295537`, -1.5902571473147769`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.903847390560824, -1.451923695280412, 
      2.900953054415358}, {-3.0961526094391765`, -1.5480763047195882`, 
      3.099046945584642}}]}, 
    {Arrowheads[{{0.010784046955165022`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8860649848488413`, 
      0., -2.882211364436433}, {-3.1139350151511587`, 
      0., -3.117788635563567}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.7637239365339648`, 
      0., -1.3752303398010315`}, {-3.236276063466035, 
      0., -1.6247696601989685`}}]}, 
    {Arrowheads[{{0.02252973259680277, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.657634749416163, 
      0., -2.2493631727565517`*^-17}, {-3.3423652505838373`, 0., 
      2.2493631727565517`*^-17}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.7637239365339648`, 0., 
      1.3752303398010315`}, {-3.236276063466035, 0., 
      1.6247696601989685`}}]}, 
    {Arrowheads[{{0.010784046955165034`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8860649848488413`, 0., 
      2.8822113644364324`}, {-3.1139350151511587`, 0., 
      3.117788635563567}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.903847390560824, 
      1.451923695280412, -2.900953054415358}, {-3.096152609439176, 
      1.548076304719588, -3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8194857053704463`, 
      1.4097428526852231`, -1.4055454686262072`}, {-3.1805142946295537`, 
      1.5902571473147769`, -1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.756787840277389, 
      1.3783939201386946`, -1.7604116186635318`*^-17}, {-3.2432121597226113`, 
      1.6216060798613057`, 1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8194857053704463`, 1.4097428526852231`, 
      1.4055454686262072`}, {-3.1805142946295537`, 1.5902571473147769`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.903847390560824, 1.451923695280412, 
      2.900953054415358}, {-3.0961526094391765`, 1.5480763047195882`, 
      3.099046945584642}}]}, 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.9368590405649564`, 
      2.9368590405649564`, -2.9354331040461883`}, {-3.063140959435044, 
      3.063140959435044, -3.0645668959538117`}}]}, 
    {Arrowheads[{{0.009766188676615536, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.901401063804138, 
      2.901401063804138, -1.4491907491068186`}, {-3.098598936195862, 
      3.098598936195862, -1.5508092508931812`}}]}, 
    {Arrowheads[{{0.01106587413722738, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.8810938357869946`, 
      2.8810938357869946`, -1.0655409455074406`*^-17}, {-3.1189061642130054`, 
      3.1189061642130054`, 1.0655409455074406`*^-17}}]}, 
    {Arrowheads[{{0.009766188676615538, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.901401063804138, 2.901401063804138, 
      1.4491907491068186`}, {-3.098598936195862, 3.098598936195862, 
      1.5508092508931814`}}]}, 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-2.9368590405649564`, 2.9368590405649564`, 
      2.9354331040461883`}, {-3.063140959435044, 3.063140959435044, 
      3.0645668959538117`}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.451923695280412, -2.903847390560824, \
-2.900953054415358}, {-1.548076304719588, -3.096152609439176, \
-3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.4097428526852231`, -2.8194857053704463`, \
-1.4055454686262072`}, {-1.5902571473147769`, -3.1805142946295537`, \
-1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.3783939201386946`, -2.756787840277389, \
-1.7604116186635318`*^-17}, {-1.6216060798613057`, -3.2432121597226113`, 
      1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.4097428526852231`, -2.8194857053704463`, 
      1.4055454686262072`}, {-1.5902571473147769`, -3.1805142946295537`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.451923695280412, -2.903847390560824, 
      2.900953054415358}, {-1.5480763047195882`, -3.0961526094391765`, 
      3.099046945584642}}]}, 
    {Arrowheads[{{0.01418054661973218, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.414593200090414, -1.414593200090414, \
-2.821542194074324}, {-1.5854067999095862`, -1.5854067999095862`, \
-3.178457805925676}}]}, 
    {Arrowheads[{{0.028925190520947153`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.25421761988601, -1.25421761988601, -1.230950458389814}, \
{-1.74578238011399, -1.74578238011399, -1.769049541610186}}]}, 
    {Arrowheads[{{0.046821543656151196`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-0.9968883533606092, -0.9968883533606092, \
-5.060398037430624*^-17}, {-2.0031116466393906`, -2.0031116466393906`, 
      5.060398037430624*^-17}}]}, 
    {Arrowheads[{{0.02892519052094716, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.25421761988601, -1.25421761988601, 
      1.2309504583898139`}, {-1.74578238011399, -1.74578238011399, 
      1.7690495416101861`}}]}, 
    {Arrowheads[{{0.014180546619732172`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.414593200090414, -1.414593200090414, 
      2.821542194074324}, {-1.585406799909586, -1.585406799909586, 
      3.178457805925676}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.390695501954445, 
      0., -2.769770429290188}, {-1.609304498045555, 
      0., -3.230229570709812}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.0810994939314778`, 
      0., -1.0222572123802651`}, {-1.9189005060685222`, 
      0., -1.9777427876197349`}}]}, 
    {Arrowheads[{{0.10258160641260129`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0.05884572681198952, 
      0., -1.3504522928659417`*^-16}, {-3.0588457268119895`, 0., 
      1.3504522928659417`*^-16}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.081099493931478, 0., 
      1.0222572123802651`}, {-1.918900506068522, 0., 
      1.9777427876197349`}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.390695501954445, 0., 
      2.769770429290188}, {-1.609304498045555, 0., 3.230229570709812}}]}, 
    {Arrowheads[{{0.01418054661973218, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.414593200090414, 
      1.414593200090414, -2.821542194074324}, {-1.5854067999095862`, 
      1.5854067999095862`, -3.178457805925676}}]}, 
    {Arrowheads[{{0.028925190520947153`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.25421761988601, 
      1.25421761988601, -1.230950458389814}, {-1.74578238011399, 
      1.74578238011399, -1.769049541610186}}]}, 
    {Arrowheads[{{0.046821543656151196`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-0.9968883533606092, 
      0.9968883533606092, -5.060398037430624*^-17}, {-2.0031116466393906`, 
      2.0031116466393906`, 5.060398037430624*^-17}}]}, 
    {Arrowheads[{{0.02892519052094716, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.25421761988601, 1.25421761988601, 
      1.2309504583898139`}, {-1.74578238011399, 1.74578238011399, 
      1.7690495416101861`}}]}, 
    {Arrowheads[{{0.014180546619732172`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.414593200090414, 1.414593200090414, 
      2.821542194074324}, {-1.585406799909586, 1.585406799909586, 
      3.178457805925676}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.451923695280412, 
      2.903847390560824, -2.900953054415358}, {-1.548076304719588, 
      3.096152609439176, -3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.4097428526852231`, 
      2.8194857053704463`, -1.4055454686262072`}, {-1.5902571473147769`, 
      3.1805142946295537`, -1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.3783939201386946`, 
      2.756787840277389, -1.7604116186635318`*^-17}, {-1.6216060798613057`, 
      3.2432121597226113`, 1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.4097428526852231`, 2.8194857053704463`, 
      1.4055454686262072`}, {-1.5902571473147769`, 3.1805142946295537`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-1.451923695280412, 2.903847390560824, 
      2.900953054415358}, {-1.5480763047195882`, 3.0961526094391765`, 
      3.099046945584642}}]}, 
    {Arrowheads[{{0.010784046955165022`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -2.8860649848488413`, -2.882211364436433}, {
      0., -3.1139350151511587`, -3.117788635563567}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -2.7637239365339648`, -1.3752303398010315`}, {
      0., -3.236276063466035, -1.6247696601989685`}}]}, 
    {Arrowheads[{{0.02252973259680277, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -2.657634749416163, -2.2493631727565517`*^-17}, {
      0., -3.3423652505838373`, 2.2493631727565517`*^-17}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -2.7637239365339648`, 1.3752303398010315`}, {
      0., -3.236276063466035, 1.6247696601989685`}}]}, 
    {Arrowheads[{{0.010784046955165034`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -2.8860649848488413`, 2.8822113644364324`}, {
      0., -3.1139350151511587`, 3.117788635563567}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -1.390695501954445, -2.769770429290188}, {
      0., -1.609304498045555, -3.230229570709812}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -1.0810994939314778`, -1.0222572123802651`}, {
      0., -1.9189005060685222`, -1.9777427876197349`}}]}, 
    {Arrowheads[{{0.10258160641260129`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 0.05884572681198952, -1.3504522928659417`*^-16}, {
      0., -3.0588457268119895`, 1.3504522928659417`*^-16}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -1.081099493931478, 1.0222572123802651`}, {
      0., -1.918900506068522, 1.9777427876197349`}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -1.390695501954445, 2.769770429290188}, {
      0., -1.609304498045555, 3.230229570709812}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 0.10930449804555507`, -3.230229570709812}, {
      0., -0.10930449804555507`, -2.769770429290188}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 0.10930449804555507`, -1.7302295707098119`}, {
      0., -0.10930449804555507`, -1.2697704292901881`}}]}, 
    {Arrowheads[{{0.016771287197067195`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 0.10930449804555507`, -0.23022957070981193`}, {
      0., -0.10930449804555507`, 0.23022957070981193`}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 0.10930449804555507`, 1.2697704292901881`}, {
      0., -0.10930449804555507`, 1.7302295707098119`}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 0.10930449804555507`, 2.769770429290188}, {
      0., -0.10930449804555507`, 3.230229570709812}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 1.390695501954445, -2.769770429290188}, {0., 
      1.609304498045555, -3.230229570709812}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 1.0810994939314778`, -1.0222572123802651`}, {0., 
      1.9189005060685222`, -1.9777427876197349`}}]}, 
    {Arrowheads[{{0.10258160641260129`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., -0.05884572681198952, -1.3504522928659417`*^-16}, {0., 
      3.0588457268119895`, 1.3504522928659417`*^-16}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 1.081099493931478, 1.0222572123802651`}, {0., 
      1.918900506068522, 1.9777427876197349`}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 1.390695501954445, 2.769770429290188}, {0., 
      1.609304498045555, 3.230229570709812}}]}, 
    {Arrowheads[{{0.010784046955165022`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 2.8860649848488413`, -2.882211364436433}, {0., 
      3.1139350151511587`, -3.117788635563567}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 2.7637239365339648`, -1.3752303398010315`}, {0., 
      3.236276063466035, -1.6247696601989685`}}]}, 
    {Arrowheads[{{0.02252973259680277, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 2.657634749416163, -2.2493631727565517`*^-17}, {0., 
      3.3423652505838373`, 2.2493631727565517`*^-17}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 2.7637239365339648`, 1.3752303398010315`}, {0., 
      3.236276063466035, 1.6247696601989685`}}]}, 
    {Arrowheads[{{0.010784046955165034`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0., 2.8860649848488413`, 2.8822113644364324`}, {0., 
      3.1139350151511587`, 3.117788635563567}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      1.451923695280412, -2.903847390560824, -2.900953054415358}, {
      1.548076304719588, -3.096152609439176, -3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      1.4097428526852231`, -2.8194857053704463`, -1.4055454686262072`}, {
      1.5902571473147769`, -3.1805142946295537`, -1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      1.3783939201386946`, -2.756787840277389, -1.7604116186635318`*^-17}, {
      1.6216060798613057`, -3.2432121597226113`, 1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.4097428526852231`, -2.8194857053704463`, 
      1.4055454686262072`}, {1.5902571473147769`, -3.1805142946295537`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.451923695280412, -2.903847390560824, 2.900953054415358}, {
      1.5480763047195882`, -3.0961526094391765`, 3.099046945584642}}]}, 
    {Arrowheads[{{0.01418054661973218, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      1.414593200090414, -1.414593200090414, -2.821542194074324}, {
      1.5854067999095862`, -1.5854067999095862`, -3.178457805925676}}]}, 
    {Arrowheads[{{0.028925190520947153`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.25421761988601, -1.25421761988601, -1.230950458389814}, {
      1.74578238011399, -1.74578238011399, -1.769049541610186}}]}, 
    {Arrowheads[{{0.046821543656151196`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      0.9968883533606092, -0.9968883533606092, -5.060398037430624*^-17}, {
      2.0031116466393906`, -2.0031116466393906`, 5.060398037430624*^-17}}]}, 
    {Arrowheads[{{0.02892519052094716, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.25421761988601, -1.25421761988601, 1.2309504583898139`}, {
      1.74578238011399, -1.74578238011399, 1.7690495416101861`}}]}, 
    {Arrowheads[{{0.014180546619732172`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.414593200090414, -1.414593200090414, 2.821542194074324}, {
      1.585406799909586, -1.585406799909586, 3.178457805925676}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.390695501954445, 0., -2.769770429290188}, {
      1.609304498045555, 0., -3.230229570709812}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.0810994939314778`, 0., -1.0222572123802651`}, {
      1.9189005060685222`, 0., -1.9777427876197349`}}]}, 
    {Arrowheads[{{0.10258160641260129`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{-0.05884572681198952, 0., -1.3504522928659417`*^-16}, {
      3.0588457268119895`, 0., 1.3504522928659417`*^-16}}]}, 
    {Arrowheads[{{0.04181231705971007, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.081099493931478, 0., 1.0222572123802651`}, {
      1.918900506068522, 0., 1.9777427876197349`}}]}, 
    {Arrowheads[{{0.01677128719706719, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.390695501954445, 0., 2.769770429290188}, {
      1.609304498045555, 0., 3.230229570709812}}]}, 
    {Arrowheads[{{0.01418054661973218, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.414593200090414, 1.414593200090414, -2.821542194074324}, {
      1.5854067999095862`, 1.5854067999095862`, -3.178457805925676}}]}, 
    {Arrowheads[{{0.028925190520947153`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.25421761988601, 1.25421761988601, -1.230950458389814}, {
      1.74578238011399, 1.74578238011399, -1.769049541610186}}]}, 
    {Arrowheads[{{0.046821543656151196`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{0.9968883533606092, 
      0.9968883533606092, -5.060398037430624*^-17}, {2.0031116466393906`, 
      2.0031116466393906`, 5.060398037430624*^-17}}]}, 
    {Arrowheads[{{0.02892519052094716, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.25421761988601, 1.25421761988601, 1.2309504583898139`}, {
      1.74578238011399, 1.74578238011399, 1.7690495416101861`}}]}, 
    {Arrowheads[{{0.014180546619732172`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.414593200090414, 1.414593200090414, 2.821542194074324}, {
      1.585406799909586, 1.585406799909586, 3.178457805925676}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.451923695280412, 2.903847390560824, -2.900953054415358}, {
      1.548076304719588, 3.096152609439176, -3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.4097428526852231`, 
      2.8194857053704463`, -1.4055454686262072`}, {1.5902571473147769`, 
      3.1805142946295537`, -1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.3783939201386946`, 
      2.756787840277389, -1.7604116186635318`*^-17}, {1.6216060798613057`, 
      3.2432121597226113`, 1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.4097428526852231`, 2.8194857053704463`, 
      1.4055454686262072`}, {1.5902571473147769`, 3.1805142946295537`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{1.451923695280412, 2.903847390560824, 2.900953054415358}, {
      1.5480763047195882`, 3.0961526094391765`, 3.099046945584642}}]}, 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      2.9368590405649564`, -2.9368590405649564`, -2.9354331040461883`}, {
      3.063140959435044, -3.063140959435044, -3.0645668959538117`}}]}, 
    {Arrowheads[{{0.009766188676615536, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      2.901401063804138, -2.901401063804138, -1.4491907491068186`}, {
      3.098598936195862, -3.098598936195862, -1.5508092508931812`}}]}, 
    {Arrowheads[{{0.01106587413722738, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      2.8810938357869946`, -2.8810938357869946`, -1.0655409455074406`*^-17}, {
      3.1189061642130054`, -3.1189061642130054`, 1.0655409455074406`*^-17}}]}, 
    {Arrowheads[{{0.009766188676615538, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.901401063804138, -2.901401063804138, 
      1.4491907491068186`}, {3.098598936195862, -3.098598936195862, 
      1.5508092508931814`}}]}, 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.9368590405649564`, -2.9368590405649564`, 
      2.9354331040461883`}, {3.063140959435044, -3.063140959435044, 
      3.0645668959538117`}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      2.903847390560824, -1.451923695280412, -2.900953054415358}, {
      3.096152609439176, -1.548076304719588, -3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      2.8194857053704463`, -1.4097428526852231`, -1.4055454686262072`}, {
      3.1805142946295537`, -1.5902571473147769`, -1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{
      2.756787840277389, -1.3783939201386946`, -1.7604116186635318`*^-17}, {
      3.2432121597226113`, -1.6216060798613057`, 1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.8194857053704463`, -1.4097428526852231`, 
      1.4055454686262072`}, {3.1805142946295537`, -1.5902571473147769`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.903847390560824, -1.451923695280412, 2.900953054415358}, {
      3.0961526094391765`, -1.5480763047195882`, 3.099046945584642}}]}, 
    {Arrowheads[{{0.010784046955165022`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.8860649848488413`, 0., -2.882211364436433}, {
      3.1139350151511587`, 0., -3.117788635563567}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.7637239365339648`, 0., -1.3752303398010315`}, {
      3.236276063466035, 0., -1.6247696601989685`}}]}, 
    {Arrowheads[{{0.02252973259680277, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.657634749416163, 0., -2.2493631727565517`*^-17}, {
      3.3423652505838373`, 0., 2.2493631727565517`*^-17}}]}, 
    {Arrowheads[{{0.017583152745852284`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.7637239365339648`, 0., 1.3752303398010315`}, {
      3.236276063466035, 0., 1.6247696601989685`}}]}, 
    {Arrowheads[{{0.010784046955165034`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.8860649848488413`, 0., 2.8822113644364324`}, {
      3.1139350151511587`, 0., 3.117788635563567}}]}, 
    {Arrowheads[{{0.009619171201781102, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.903847390560824, 1.451923695280412, -2.900953054415358}, {
      3.096152609439176, 1.548076304719588, -3.0990469455846426`}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.8194857053704463`, 
      1.4097428526852231`, -1.4055454686262072`}, {3.1805142946295537`, 
      1.5902571473147769`, -1.5944545313737928`}}]}, 
    {Arrowheads[{{0.01789396772835969, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.756787840277389, 
      1.3783939201386946`, -1.7604116186635318`*^-17}, {3.2432121597226113`, 
      1.6216060798613057`, 1.7604116186635318`*^-17}}]}, 
    {Arrowheads[{{0.014663611636960637`, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.8194857053704463`, 1.4097428526852231`, 
      1.4055454686262072`}, {3.1805142946295537`, 1.5902571473147769`, 
      1.5944545313737928`}}]}, 
    {Arrowheads[{{0.009619171201781103, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.903847390560824, 1.451923695280412, 2.900953054415358}, {
      3.0961526094391765`, 1.5480763047195882`, 3.099046945584642}}]}, 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.9368590405649564`, 
      2.9368590405649564`, -2.9354331040461883`}, {3.063140959435044, 
      3.063140959435044, -3.0645668959538117`}}]}, 
    {Arrowheads[{{0.009766188676615536, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.901401063804138, 
      2.901401063804138, -1.4491907491068186`}, {3.098598936195862, 
      3.098598936195862, -1.5508092508931812`}}]}, 
    {Arrowheads[{{0.01106587413722738, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.8810938357869946`, 
      2.8810938357869946`, -1.0655409455074406`*^-17}, {3.1189061642130054`, 
      3.1189061642130054`, 1.0655409455074406`*^-17}}]}, 
    {Arrowheads[{{0.009766188676615538, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.901401063804138, 2.901401063804138, 
      1.4491907491068186`}, {3.098598936195862, 3.098598936195862, 
      1.5508092508931814`}}]}, 
    {Arrowheads[{{0.007251359583717527, 1.}}, Appearance -> "Projected"], 
     Arrow3DBox[{{2.9368590405649564`, 2.9368590405649564`, 
      2.9354331040461883`}, {3.063140959435044, 3.063140959435044, 
      3.0645668959538117`}}]}}},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->{360., 390.69293666342895`},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "TransparentPolygonMesh" -> True},
  PlotRange->{{-4.55884572681199, 4.55884572681199}, {-4.55884572681199, 
   4.55884572681199}, {-4.55884572681199, 4.55884572681199}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewAngle->0.47030072394368955`,
  ViewPoint->{1.0733622208638498`, -2.6117529588202526`, 1.8645750252848179`},
  
  ViewVertical->{-0.0546395452414203, -0.07752592705102475, 
   0.995491964171831}]], "Output",
 CellChangeTimes->{3.65092899886583*^9},
 CellID->1070057912]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electric Potential for a ring and disks", "Section",
 CellChangeTimes->{{3.650893659576766*^9, 3.650893663967044*^9}, {
  3.6509699216475573`*^9, 3.6509699294116917`*^9}},
 CellID->19044002],

Cell[CellGroupData[{

Cell["Ring charge", "Subsection",
 CellChangeTimes->{{3.650893699078713*^9, 3.6508937010416822`*^9}},
 CellID->97478211],

Cell[TextData[{
 "The potential of a ring charge is the integral from 0 to 2\[Pi] of ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"radialChargeFactor", "[", 
     RowBox[{"a", ",", "\[Rho]"}], "]"}]}], TraditionalForm]]],
 " times the following expression:"
}], "Text",
 CellChangeTimes->{{3.650894927832683*^9, 3.650894979613872*^9}, {
  3.650898709428299*^9, 3.650898709428329*^9}, {3.650970490048403*^9, 
  3.6509704900484343`*^9}},
 CellID->1083191080],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["a", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["\[Xi]", "2"], "-", 
      RowBox[{"2", "\[Xi]", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], 
       RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}], ")"}], 
    RowBox[{"1", "/", "2"}]]], "/.", 
  RowBox[{"\[Xi]", "\[Rule]", 
   RowBox[{"r", "/", "a"}]}]}]], "Input",
 CellChangeTimes->{{3.6508937300194283`*^9, 3.650893786184125*^9}, 
   3.6508988919743633`*^9},
 CellID->1933753263],

Cell[BoxData[
 FractionBox["a", 
  SqrtBox[
   RowBox[{"1", "+", 
    FractionBox[
     SuperscriptBox["r", "2"], 
     SuperscriptBox["a", "2"]], "-", 
    FractionBox[
     RowBox[{"2", " ", "r", " ", 
      RowBox[{"Cos", "[", "\[Alpha]", "]"}], " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "a"]}]]]], "Output",
 CellChangeTimes->{
  3.650893787912819*^9, {3.6508988967621593`*^9, 3.650898922007564*^9}},
 CellID->1143599798]
}, Open  ]],

Cell["\<\
Note the additional factor of a which fixes the scaling from that of a field \
to a potential.\
\>", "Text",
 CellChangeTimes->{{3.650898898741172*^9, 3.65089891970109*^9}},
 CellID->1184459662],

Cell["Which is the same as:", "Text",
 CellChangeTimes->{{3.650893983096575*^9, 3.650893986398883*^9}, 
   3.650894988405045*^9},
 CellID->690800992],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["a", 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        SuperscriptBox["r", "2"], 
        SuperscriptBox["a", "2"]]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"Cos", "[", "\[Alpha]", "]"}], " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox[
            SuperscriptBox["r", "2"], 
            SuperscriptBox["a", "2"]]}], ")"}], "a"}]]}]]}]], "//", 
   "FullSimplify"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.650893938194059*^9, 3.650893958845242*^9}, 
   3.650898927175426*^9},
 CellID->1133530922],

Cell[BoxData[
 FractionBox["a", 
  RowBox[{
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]], " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Cos", "[", "\[Alpha]", "]"}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["r", "2"]}]]}]]}]]], "Output",
 CellChangeTimes->{3.650893962292564*^9, 3.650898928602203*^9},
 CellID->2039876913]
}, Open  ]],

Cell[TextData[{
 "because of the symmetry of this with respect to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", "=", "\[Pi]"}], TraditionalForm]]],
 " the integration from 0 to 2 \[Pi] can be done from 0 to \[Pi] by \
compensating with an corresponding factor of 2."
}], "Text",
 CellChangeTimes->{{3.6508946936307173`*^9, 3.650894741850998*^9}, {
  3.6509294143695*^9, 3.650929442584301*^9}},
 CellID->1905330897],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", "a"}], 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]]], 
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox["1", 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"]}]], " ", 
        RowBox[{"Cos", "[", "\[Alpha]", "]"}]}]}]]], ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
    RowBox[{"Assumptions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", ">", "0"}], ",", 
       RowBox[{"a", ">", "0"}], ",", 
       RowBox[{"0", "<=", "\[Theta]", "\[LessEqual]", "\[Pi]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.6508938419144707`*^9, 3.6508938887133417`*^9}, {
   3.6508939739143543`*^9, 3.6508940026087017`*^9}, {3.650894610978334*^9, 
   3.650894614304225*^9}, {3.650894650241281*^9, 3.6508946704385643`*^9}, 
   3.6508989347727213`*^9},
 CellID->1322339561],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", "a", " ", 
   RowBox[{"EllipticK", "[", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["r", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
  RowBox[{
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["r", "2"]}]]}]]}]]], "Output",
 CellChangeTimes->{3.650894677573627*^9, 3.6508989418247843`*^9},
 CellID->473154978]
}, Open  ]],

Cell["Thus the potential for a ring of radius a becomes", "Text",
 CellChangeTimes->{{3.650894853649828*^9, 3.650894862585609*^9}},
 CellID->610290968],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialRing", "[", 
   RowBox[{"a_", ",", "r_", ",", "\[Theta]_", ",", "\[Rho]_"}], "]"}], ":=", 
  " ", 
  RowBox[{
   RowBox[{
    StyleBox["radialChargeFactor", "MB"], "[", 
    RowBox[{"a", ",", "\[Rho]"}], "]"}], 
   FractionBox[
    RowBox[{"4", " ", "a", " ", 
     RowBox[{"EllipticK", "[", 
      FractionBox[
       RowBox[{"4", " ", "a", " ", "r", " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["r", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        SuperscriptBox["r", "2"], 
        SuperscriptBox["a", "2"]]}]], " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        RowBox[{"2", " ", "a", " ", "r", " ", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["r", "2"]}]]}]]}]]}]}]], "Input",
 CellChangeTimes->{{3.650894868622616*^9, 3.650894893009386*^9}, 
   3.650898710761579*^9, 3.6508989458408527`*^9, 3.650970492188671*^9},
 CellID->116977404],

Cell["\<\
Note that this is valid at any point, as it does not depend on the azimuthal \
angle.\
\>", "Text",
 CellChangeTimes->{{3.650895232723847*^9, 3.650895255803205*^9}, 
   3.650895823518426*^9},
 CellID->493377353]
}, Open  ]],

Cell[CellGroupData[{

Cell["The potential of a uniform disk", "Subsection",
 CellChangeTimes->{{3.650895047790646*^9, 3.650895064813553*^9}},
 CellID->1197875539],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialRing", "[", 
   RowBox[{"a", ",", "r", ",", "\[Theta]", ",", 
    FractionBox["1", 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox["r0", "2"]}]]}], "]"}], "//", "FullSimplify"}]], "Input",\

 CellChangeTimes->{3.650895087553069*^9},
 CellID->183153390],

Cell[BoxData[
 FractionBox[
  RowBox[{"8", " ", 
   RowBox[{"EllipticK", "[", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["r", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
  RowBox[{"\[Pi]", " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]], " ", 
   SuperscriptBox["r0", "2"], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["r", "2"]}]]}]]}]]], "Output",
 CellChangeTimes->{
  3.650895094167395*^9, {3.650898952611135*^9, 3.650899010952408*^9}, 
   3.650910472334413*^9},
 CellID->533729327]
}, Open  ]],

Cell["Thus define", "Text",
 CellChangeTimes->{{3.650895099058648*^9, 3.650895102414392*^9}, {
  3.65089517262731*^9, 3.650895175313768*^9}},
 CellID->1043090698],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"8", " ", 
       RowBox[{"EllipticK", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650895087553069*^9, 3.6508951665150642`*^9}, 
   3.6508990189751797`*^9, 3.650971555259779*^9},
 CellID->1316350825],

Cell[TextData[{
 "This can be expressed in terms of the Cartesian coordinates as (for the \
scaled case of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r0", "=", "1"}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.6508952108699713`*^9, 3.650895218836524*^9}, {
   3.650895272260508*^9, 3.650895289978009*^9}, {3.650895854773468*^9, 
   3.650895871451096*^9}, 3.650973185032197*^9},
 CellID->1029497776],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialUniformDisk", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
  RowBox[{"PotentialUniformDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"z", ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650895883511196*^9, 3.650895930537702*^9}},
 CellID->1562829634]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform disk on the z-axis", "Subsection",
 CellChangeTimes->{{3.650898175735496*^9, 3.650898179605671*^9}, {
  3.650910380443143*^9, 3.650910383432521*^9}},
 CellID->290970972],

Cell["On the z-axis here\[CloseCurlyQuote]s the plot:", "Text",
 CellChangeTimes->{{3.6508990417458277`*^9, 3.65089905431994*^9}},
 CellID->1059647592],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PotentialUniformDisk", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6508963913423023`*^9, 3.65089641260744*^9}, {
  3.6508973521646*^9, 3.650897356052438*^9}, {3.650903181357485*^9, 
  3.6509031813970127`*^9}},
 CellID->413977081],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1l3k01PsfxseYsc98u5JySyEhlK7spfcnJLqWikpkrRsl2RUhRYuyFHLt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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.30000000000000004`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650896413950876*^9, 3.650897357241055*^9, 
  3.65089902636733*^9, 3.650903183350218*^9},
 CellID->2068177289]
}, Open  ]],

Cell["\<\
But let\[CloseCurlyQuote]s confirm that the analytic expression is the same \
as the textbook one\
\>", "Text",
 CellChangeTimes->{{3.650899072624196*^9, 3.650899087375005*^9}},
 CellID->1853633507],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialRing", "[", 
   RowBox[{"a", ",", "z", ",", "0", ",", 
    FractionBox["1", 
     RowBox[{"\[Pi]", " ", 
      SuperscriptBox["r0", "2"]}]]}], "]"}], "//", "FullSimplify"}]], "Input",\

 CellChangeTimes->{{3.650898198775017*^9, 3.6508982024690104`*^9}},
 CellID->1489697098],

Cell[BoxData[
 FractionBox["4", 
  RowBox[{
   SuperscriptBox["r0", "2"], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["z", "2"], 
      SuperscriptBox["a", "2"]]}]]}]]], "Output",
 CellChangeTimes->{3.650898203178259*^9, 3.650899092751276*^9},
 CellID->93232348]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   FractionBox["4", 
    RowBox[{
     SuperscriptBox["r0", "2"], " ", 
     SqrtBox[
      RowBox[{"1", "+", 
       FractionBox[
        SuperscriptBox["z", "2"], 
        SuperscriptBox["a", "2"]]}]]}]], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", "0", ",", "r0"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"z", ">", "0"}], ",", 
      RowBox[{"r0", ">", "0"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.650898241192086*^9, 3.6508982916401653`*^9, {3.650899097441058*^9, 
   3.650899100232891*^9}},
 CellID->980608506],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "z"}], "+", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["r0", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], ")"}]}], 
  SuperscriptBox["r0", "2"]]], "Output",
 CellChangeTimes->{3.650898293821534*^9, 3.6508991025521708`*^9},
 CellID->1802412980]
}, Open  ]],

Cell["Which is the standard textbook result.", "Text",
 CellChangeTimes->{{3.6508991124308147`*^9, 3.6508991194618473`*^9}},
 CellID->750630278]
}, Open  ]],

Cell[CellGroupData[{

Cell["Uniform disk ContourPlot", "Subsection",
 CellChangeTimes->{{3.650899155346607*^9, 3.650899157384924*^9}, {
   3.65091039326333*^9, 3.650910394560217*^9}, 3.650969975267105*^9},
 CellID->1033820060],

Cell["From the graph of ", "Text",
 CellChangeTimes->{{3.650899173258073*^9, 3.6508991759366503`*^9}},
 CellID->123560543],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PotentialUniformDisk", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650899267374898*^9, 3.6508992708618383`*^9}},
 CellID->815671893],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1l3k01PsfxseYsc98u5JySyEhlK7spfcnJLqWikpkrRsl2RUhRYuyFHLt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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.30000000000000004`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6508992726580963`*^9, 3.6509031965763187`*^9},
 CellID->178219459]
}, Open  ]],

Cell["Here are a couple of examples of visualizing the behavior:", "Text",
 CellChangeTimes->{{3.650929539197625*^9, 3.650929560820067*^9}, {
  3.650929680824822*^9, 3.650929686294819*^9}},
 CellID->657213787],

Cell[BoxData[
 RowBox[{"SliceContourPlot3D", "[", 
  RowBox[{
   RowBox[{"PotentialUniformDisk", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\"\<ZStackedPlanes\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", ".5"}], ",", ".5", ",", "1", ",", "2"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{
       RowBox[{"x", "<", "0"}], "||", 
       RowBox[{"y", ">", "0"}]}]}], "]"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650901046695985*^9, 3.650901075830052*^9}, {
   3.650901153994342*^9, 3.650901186440036*^9}, {3.6509295798677883`*^9, 
   3.6509296017308807`*^9}, 3.6509298257329397`*^9, {3.650930001423623*^9, 
   3.650930006604678*^9}},
 CellID->266775360],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx03WecVtX5vn06tog1GntHjL0rhsGuWGOU2GMv6M8eNVYUNBbsJUaNvWvs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   "], {{
     {RGBColor[0.2625454545454546, 0.3936363636363637, 0.6472727272727273], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV1GtM12UUwPGjARqCYqgoZaYBzjums16V5PKSU1wrXbVu5sjmxNLykrcM
t7ILmZaZLRf5osRJahRUVvNSKRhekiAtq5WuZqHmJaxsfX4vzr7nOffn/J//
r/fUWbeVto2IcnIZSe0ZUZwdkYKHu0Xc2CaiEUf0iChrH3ErfpETcVNqxJd4
/1URuzpF3Id7xFWoUYunyBG5p7FAzli5fXEomUu/Dkd2j9iRFlGER8U9LP47
7KTWgY4RWbiaNGVFrMKJ+p0w5ARc7HwN+yJcRgbQn8RJfKfEFONy58HsZTj3
yoiWjIjHcTTfdjG3YLN+9+r7LV7tfNYyemJ/OYXuNQDHqDGaLOwq3nnBFeLx
MJlOb8Qp7nDBXSZjU27Epx3EYjnfM3JfwP2kl/gDyVzuX2IPQ7C9uBnpEe3w
Vb6fxa/BM+SC+NP4LHmUfQWeNGuDmX/Hpc792JfgEfm79W3BUvc86r4zsV5c
ivg6nON8kn02DtN7sRmGYxf5v9l5V8whF+nd8SDpY4ZDeIe7tbjj7fiI/GPq
zMKHyG56Cd6t92Puko4vySk320rMS35vvfJxvP1+Zf9jcBJ/cfIb2W0jX/Xl
9orP8VWkRDyPH+YkDzPiI5xPxrLPwxryL70WW91tuN/uIuY4/0TvhofU2qzm
QUzeuTXE0973Puc32OvRysLI8SL7GfnfC/oTu8ivlpSN+8VVim/Ac3zXsp/H
3XwjzPY5diZb2bNwBylg34nF9rLcfibidudM9k+wI3ldfCa22NGP9vwHNtpd
jaG+wQ1ytmVGvIV1eq8zw16cIy7F3mYn7yqZx8wNON+5B/s8HKXuFnu+GdfL
X6nOOvwl2YULH8c+fGliemM+Safn4QJx5808H59QK1fNBUltvl/N3D3Zv37r
7e0DTOf7zJvpgEV8m9QZmVCPUWauxF3JN4S+E4fwLRFTmOzDewrvKgMr9Nto
zjcxI/m2qJmJ9c4d6HX4nn6rpGzDY87T2H9I9mNfK+ytHnvIaev/m5vkkmy7
3Ye1ZENnbyr5fuhXpG8vfDf5L7NX4X/mm2A/l3CNunPM8wp+zFclZjtOlZPf
LuIBrCHD6CU4jfSnP4jnkv+RvmeTb5h7zvS7N2MT33ExzfgXX4F3dyGJTfai
byu+rF+pvqvxKVJEL8OL4gaJb03mJDfQL+E75ITfaC3mqzvZvfJwqx2Ns6st
2NY3fbz4NngXX4YZ7sSBpET8APxH7+vN8Dfuscdl9rkXq+SPUmczHnJ+m/1r
rHQeyL4Rq/Uus5/3cSFfgZhF+Jq5l5p/LQ7WY7peg3AomUEvxDRxJfqm4ib5
49SpxP5894jph33JFHoB/g+vGfoX
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNm3ecVsX1h9/dZekLW+Iu5d0gVXqRKn1BsaBGwYomAaMISO9KhwVRLMSW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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJw11nlslkUewPHpXQotFZa2b/vuYintVuUUQRfYVfFAFw9cj/VORIVyFFRc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         "],
         VertexColors->None]}]}, 
     {RGBColor[0.4020454545454546, 0.445, 0.5827272727272728], EdgeForm[None],
       GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwl1ne4yNcZwPFju+a11xV7JzLaPNqmVEgaMUOsmg31UCsD0YgRM5G6JEZp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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxdnXm4jlX3x8/gOIbjOMdwnjM8h1RvGqSkMkQJzSHVGzJVpkJFIgrNk0oD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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJw12Xncz1Xex/Hv5cp1cVm6uHbXL4NEIdluSjLSZitTMaPGkiRKUXaaFlpm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         "],
         VertexColors->None]}]}, 
     {RGBColor[0.5443181818181818, 0.495, 0.49909090909090914`], EdgeForm[
      None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwl1nlwltUVx/EbkASSViAbSBIEoVpU2k5dsBR0xClEFmWzhEACKIyAFaUt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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNW3d8lEXXfRKSDWmkZ3ezuyDS1E9siPqK5UWK9BZCly4I2FARuyAKCgQS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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtmHl4zVcax08isltu7k3uvbmxjw6K9pmiWlUdu8aaWCqLrXZFq2ifWGOp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         "],
         VertexColors->None]}]}, 
     {RGBColor[0.6865909090909091, 0.545, 0.4154545454545454], EdgeForm[None],
       GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt1Hto11UYx/GTW+ZtKls6S3+GNXMmUca8hGYO2sxVNreZZi2xUPzDCjIj
mqlByuYldDolu2CLXNrmlluBmJCFSlbSzFKaoygjJ2jhTHKr1uvw7Y+H93PO
+TyX83zP7zfqyWdLnukVQtjE0tjMESGsGBTCQ7jrxhAW9A+hDs8OD+HRgSG0
Yxer5Xfjw8Oc9Q6hGB8Qs1zsYpzFVvEfxIXZIWSmh7AM69lZ/gf4j/id8lzF
jIwQstmYISG0WH/HP4LH6M7T78Xd7Gd+Ew53PpSNo99Nd5Bfh4dTydkK/kt0
c+grsMe6Tq1/8S42bUAI47FUf4v0OQOX0A2kX4Cj3XlDP+f42g167RPCRhwr
/5d9Q2jEA+5cc53aWMtK+VX4SpwFvxEniRkjtj9ulneb/OtwQEZy55H6/zSV
rCv0c4C18vfhelbO34x72Vf8RnxHrhw91GKdXD/K+T5usO5Saz1+SHecvml4
Mqch7Fa1ZvrIRexSVggv669AnxXYzFbwW3C7fubRjI3fiB2+1twwW64ccxuK
9eyonA3xXThL18N87Kv2aD0MwLVyFcm5GgdZj7OfwkfouuQvwxfNd5g3thEf
i/HyPI4rxdwvdhU+Yd3ffnmcm95KxG7FZXL9IudzmG29zjt86//eS1mPO04Q
s5U/EbvZJ+5yFXuJGSk2Dd9l3fxNuMdZu1q78Gt3G+bNHMdF3sdR7+QprE4l
c8zNTurEfrrUupdulvncE98zTZn9mlQy7+h309zmnuu9qxzcIf6IWm/iFbZf
b114QXyVur/jUvdvc68iXKO/Tn2+ipPpdsg5Dd+wzvAeXseq3skc5lxPp0ae
2a7Gqank9/U5/iVmn1pZch7rm7zn/fQT1MvX/0ScK+agPudhJ30z/SXcokaP
HlqwVXyrb/QN3m1daX8yFptRpVnNxoti9oi9gKvkGq+flbiZLqhbjQ3Wi+03
xT7j/4XYKXjS+bfskN4y1Uh3r8G4nC6T/nncYq+aldO0W39h/wz+7Q7vmWGa
PE1qFMnTHN+mdbb8Odihp7f1di7OI5XUOx1/42LzzCEXC+K35xdim7xL5G/E
SdbT7c/Dyjgvs62KvwVWY38+jqJba4Y3Yb/4mzWfPlgWf9s0c7FQHy/opwAL
6bbS346D2Qj+RfqUswZ3uQbvFDNF7B3YGe9DcxnvY9vkz8cZzqbS5MX/DXkW
6bkeT7hnmfu24k/m2OnbncFzzk7R/Iod4rPkPB+/J91G73MNLnD2vf2F2CZv
sX5O40fxPub2MTY7WyrPIfzTOpf+Ct5sXcW/BXemkm+WF981+0MPP8T/IXbC
fiHOZr/xS/AkO0XTgVNSyf/YZxjif667XNZbvrk8bYbT8T/4ZPiQ
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxFmHmQVdURxq/yZsaRWVSYue+9+x4xFWUQK1HUJCIoKWW1ElAWAWVSCqKJ
Cy4YFyBoquKwGJMqZdhkEUtNlSxGAdkcFS0xonHBQVBZNFoKqBUVUDQL+X1+
bfnHV7fvWfv06dP9nfPDsdcNnXBkkiSTjkiSHN/1tUkyBowGa8A5nZMk35gk
vfj+iQa3lJPkiIYkqe2YJDcWk2QDbZqjj/qOrEiSr2n3JRiO/FqaJAeR94HN
yO1gVIXbvZF6bM2xgfqz+Q5j/J58h3ZIkhrkbzolSRrzD+vgr/oc7uT/4+uS
pAvYz9wHwZBSkrTUJ8l0cAHyKxnto83rmb/6/7TWfaTLNznr/J1O+kr3LcgD
Ckly31FJMh/0Rx7B/E3MP5nvjEr6Ix8Z9pBdpGvvsJV03cScW5nnY/Ay8vaj
k+RNsBVsA48xz6NgGVhR4bVrDK1bNugd/yq/izHPQocZ6DId9ES+rOjxNO5Y
5GOw2X76lWk/BPlV5n0R/B28Umu7yD6XgGZwBX3epW//GsZGv4E1lvuBAeDM
zPJu2lxO20uL1lv6/xr5/Gr6gH5gAHi84G9/8BjyOHRYiC4vVzF/PklOw055
kIIeHd1GbWVj2XplwWN+N9YcylvBLDAb9IsyyX1jb+aBubFH80NWH7V7KLMf
PwH6lL2H86NOY42gfhrr24EuH7Oe4WX7ofyxlf3vBgZhzwJlg6m7iPbTa9xH
fbX38oHD1B/NGNfQZgD/u/jvgTySNnfVuI/67mHcf4L3wEfgbWzyGbZ5E7yR
d5nqdoEPQEPZ+94zzsbLtFmA/DPmGFu2L5wMuodPaK4ZoCXmPBh+/gU4ELJ8
/5MoG4D+VzPWQK2D/8exwdVaB1iJfAbz3VvpPdReTuL/Q/7fAdcgL0+ts3Rd
lvpc6nzKhqOw2+esa1usT+u8inkmU38l3yGcw4czxw3tkfZqO/O+CbaCbeAF
fPQGcD3YBHbSZjT9RoIdmctU18Z/xvdJdJrNPLPAeuS9RY+psfYg/5E934+d
/gf+Il/gzM0Fc8A80IRfnwiKoATeod9boZPGkZ+8HWWq64YOZ2DnPuD0zGOd
hi165DxmT2LQxfW2/bPUT8RGx1HXDdyGfBb1Y+rdRm33FT2u5pLuDzDG/WAx
WFJhH90Rc6vtLNaQ46wsYr3PsN5LGHcE6A5OzXmvPgBvxZ7NpP3XrP19MBF5
auo+zeB25Mmp+6tMdc0hayyt6zXmeJ25XgL/QN7NPg9kP9/lW4+9NofvyIde
BGezprH1XqPWOpc5a9C3ErQifwoK9GsEHyP/BBudhS1PACnyzTpDjP8M428r
OIZ8G0vAq3nnlv05nyvlmF0RCxWjdoLW2Bvt0Uwwruhy1SuWaQyN1Q62IF+c
uY/aDsusWydwTOi4ImL1UrBcuY429+N7i8ChzDpK1zcU/8pek/o1gNP4XwE2
U7eWNt3KtoFsoT3UXo4veg2KyYrNY0v2cfl2E3Iz/X7e6POoc6mYr/Wqj/q2
h220P9qn5aHroZzznGL47rDNuIj9u+Jf5UOZYxxzjQfDSj6rOrNTWd9vG+xj
8rUF4GnkcSWfUekoXRW3doB3wM6IZbujTHV1Bccqxaz6gmORcuO+iEnTsOFF
4hHKVZnrlD/bo43G2QSejzmUq94N3ZWnTkoddxR/FMsr0ekJdF8DqkqO04rX
G2OPjqJsPXUbQDXyHfTp12AdpMsobNTG2E+D0ci9KftV5MaeyC1l20X22cP/
JMb+TcQ2xbgrI96dzLeRMcc3uE1Xvg21bqt/lQ+mT9+yv/q/E/l40M4+/x59
R5edd+6scQxSHJBe0u8eMAv8gTaDxEMYuzdyIxhO367MMarsWK965UPFfOU0
5bZ7sdkZ2O4L4ndVo8uU97LO/lf5+fw/h83bwJ/BLHBUo7mGOEeps3Pmhmgz
OzUkq9+81JxE7YfTvrbsfXwuxpqd81lPGpxLtVeKffMjNisG7s07nyivJPjP
FezZ7/C9m8Dlpe85nnjhFuQFZfM02UC2+Hcn66x1aT2DIv81hc2a4l95sZb/
5QVzG3GcFYqXzDsFXAiGVTnHtsSeaG+W0aZv8CH1XZV3e/VbnfeZ0dlRjlKu
Oq9g/qI+6lsVurWiW5HvVaGLcnP/BvuwfFk+K99Vndp0CX1lW61P65SNu0S9
fLqm1rxVvjA8+OuuomO2YvVO8XlsvBo8Av4GtqNTe7W5rbj/KPawA/uUA6OR
H0GPB8ES8FdwfdH7p31U7J6ceV7Nr7P1YdG5U/77EfJi+swA0yOGKsYp1hVB
V+QPis696qO+WeT6J+vc5u6i+aR45YNF6/JAnceVTl9hg3lgNjgADoH5Uaa6
Nvaglb2YA55CHpq6nfxZXPpJbPBE2ES2GZa6n9qobdc4v1fG+X4qcxxTrGpD
npG3n8hfpuWt0+JYq/LGmOBy9/G9h/24LjV3OAVMSM3JFePEy3tl5rA6u/Jb
nXXx+k21voe1gV8UzH3Fgc9FXhexTzFwLdjOGBfUfR9r1kbdUrC8zvegr8CB
uMMpxg2I+4DuAj8uOs4o3pxctG1WgZVhI8Ws8RHbekmm35DI58rrSck+I185
nHmNWutJ4OrUejwUPqV2KlNdE7gK+ZzM42ncfsifpc7HukN9njpGKlbOxJap
bJU69ykH/is1lkYOV9/3i+aa8jH52hjKqmlfDy5FruFbCSpAR3CQsjX0XQe+
TJ0nlS/FcS4Hh1PHLPG2hP1+PM6R9NNdT3cvxSbxct3BpoJbwbVgIrgN3AJu
jvIpYFKUqU7cYmTcN5S/5LetwXcVU26PdrfG2L8suUzy+ch7CuYy4jR7C17H
mthD7aXi6I3guuDd4qniq8fGHtwQdROCd18fsvKnzuXSzP74AliWOTZPjDE1
dvfgvk2x558UzLXFufcjDyx5vVr3oJJ5Z/doe0pw0FND1jmZmfntQW8Qd8lX
sfnWSudM5U5x7gNx19mYGV8E19BZ7VPw3VJnRmfn69RnXmf9q9SxWPG0FDFZ
fqD4pzjyTQf7Ri7KVDcu7tVjwie2o8cW8Gql9RocZ1lnSjxCMU5xLAUnltz3
krgPaIxjwxflh3U5x2+9P0zh+0qlbSW/uyx8RG2rw2drgtOLwz/Hev6T+tsc
dtRd5fkKl82NPKu5D8ZdUToMynsN0l22/W4M9ftval4jfiMOlNXal3RPWRQ+
dV/w1eaIb7lKc2jx0g7Iq1PHG51RnVVxYnFj3aF1l96id5N4w9Bbxrq4b+je
IR5dn/c4esfR29LK1PcBxa9VqXEgYprmki6L4j1CHHoj/RciLwbPIg+v9t1Q
d8RB1ebs4u7v0fbasueVbmtj/kWxPq3zxSpz7EMxn2KpcorOqObQXA+n5sXi
rg9Jn9S5SDnpzNQcTFxsFvhpar0WBt8W7xaHU/6exHw/iLeG3XH30puD3uT0
FlUPJiLfyRh35/yGoLeE80o+vzqPfUvmeeIcxeCAJ7CmumrfD3VP3Bh8Wflf
PGCOOArfWr3ZKJbkvafaA+3F/IL7a5wlBXNqxQbFiHNLxoSIIdJFOkrXBnCz
8knBeyDbP1rw2VCuVx7TGdG8VXF/1D1S8y6PNzz5QKeIuYq1x+otgDEqoo90
FydU/FUc1luh9lR7+xL1JyHPTM1DxUdnpPY11csHdMedWvS7ld6vbkHel5qX
ip9+lPpNRvlcef30vH1KeygdpMvAvO/iupMPyVuvirj/aU19844Vihn98uZN
4m/9407Sgu53gAvjDeRHJedw5e5yybZaHzlfNvsyzoLOhO7K0m1B+Kp8VneW
qTHmXuRHM583nbuVmd/mxE3FUb99owtu2zfe+BrC12rAcR2dexWfRkQO7lL0
m4reUo5Bvqnodmp/A/IFmbmzOPSFmXlgS6xN7zy94k1ScbNPZpuOiViyuOy4
8EJwIHEhreGOGOOTzLZdHGdHNm6Lu9764JDvRTxZFz4gTipuKp2k28LghrPj
DHaNt99vY29n69wSb25DM69dNlD+UYyekjkuKj7qrtgetlUsex18mPqdSLlM
3E+cbW68aepuIJ+aF+9Tavt/2tlXtw==
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlmtQVVUUgHdyUXlcbhp677kXdUwYTGcqzbRRfDCjiDg+eJRSKWniOPbU
8pmhzRTxUkOBScbxlUpqIIqPlJimadQs1DTQGogsKY3EMlIJQ/vWrP3jm3O+
c8/ee+21197n9p/7WsqrXYwxORAM9V2NOQdnYVWkMXVcWxxjHgo1xgE/XMdv
QJR1ed6Kr/YZk9jNmCSYDO/gMwPGjAs3ZiwUQzq+36e/J8MqqMKfon1Od2MG
QSyMwPOhg/u78C/k4fFQwn0R5MJIfIXXmIEu2sLTsBJPdxszA56BhF7EwbU3
cT4IHrjM3HpxvcDYdcRwES5BHe4JM8YNXWgXyjUcUnh+lVxM6KZzzMITmEsm
cxoJcTARHxVlzByPMfNgLozG23m+JYL5QTo048MC2mYUxMOT+J+Qy+9bYQd0
4Mm0z6GfWfAipODf+TReifu8gL/l09gkxt9gJX43oP3shF3wH36G59/w3mnY
TA5q8VnkK4y8BUNHEDnDhwc0rjHhun4j8MXk+go5jwghJ/AhvsbPXMjPUBgC
q/EXaO+hrx7QE+bgGRDBfbhLx5qNb6K92/YlfZbih4kni9iKoBiq8TU+rSnJ
u8zxbfxZ2rvopyuEwHN4mlfjb4c7kIpfJ+5sm3vJbSt+lj5qYUuk5kHy8b5P
63Gyrd9s/ANHa09q0BBfIT6cPovouwQ2wQh8DJTacYOIZSa+EGJtDmTeC6Qm
yc3n1Fw9XIQMvJx4TlGbp6EWKvBrvLuFzbgdtkILfo/nZcS/HbZBJ54i9cLa
5MEweAQfDVO5nwLTZP3wRubSxpxuwl/QgPfrQ41E6j6X/T6eZ9Oh2daP1FEy
vpQYe7GuXvDBcjyB5xf4/Xv4ARLxaOrSS30eI7ZPYQC+zK/tpH1PWIL3g2zm
PhBioS9eQ36qYQzxFHBdB0Hkui95j4YYCMH3kYdmfmuCH2EvvoaxsmAhe3Ua
12RIpc8C+t4ANTADX+TXfSz72fDu6/hsv66FrEkRJOBJzKXBzkvmN0nmxvN8
fs8N1dj74x8z9k/E8DP8AnvwzXCS+0aX/laGTyAPS8nLMo+eC3H4eFjM/Rvw
CsRHadwS/wJim8p1OvRg7AOsfwW4iKUnfog83Ccf9yCNmjyMb2KcLxnvhEvH
L8XPy36g3W38FnyL7+fdSbRJhCSodLSOpZ43gp/8F3PNlRq367AWcvCdft3j
stczYDd+1K3nrJyticR9hOu4KJ3Tco/OOwHfRfsGG18JFHq1b1nrOMbMt+Ok
BrSWpabzIQ2v9Gp+r0EbVOEV0GKfXYVyfAdziQ7R74Ts2Y/wWtr/QUyt4COf
Z/DbjtZetl3Ph5nHAL/eyxpL3cTgrfS5l/wdhipow4ewZ5oi9fsh35Fr9HXc
p2eVnFmpsAMvY5waxqyG47Ab78O7g+03S75dY/GgKD2X98ER6IrPgzfJ2yI4
BZl4B2MfI4Yj8BncxR/gebltuxcMvt7RupD66IR1+FpH7+X8knOsAE/i3Sxb
f0tgMl5IjLNszCdhn+Rezkruv3LrfPbg/9A+xu5dyeMtGZN4ThBXKWyD+/gT
Af3mj7PfkKHSVtbJnmtH4ZbkNKC/x9tv4eP4FOJZRVwrYDVMxR8L6O9x9nv7
qPRnz2Gp2SjWpY1rb55H27NPzsA4/CCcJ/5zbp3PAZkbazyfOl4AL8FBqYGA
/meQmn4e8uTM9Wu9Z4bp++X4J371DLsf3sVvyv5iTpXBWjc38Eaen7b9yzgN
uHH0HJbzWM63Lnh3R885cXl+mRr626t1dyhYvwW/S38Snz3j5HxokP9Sfu17
vo2xQs45R8/MWPt/KgKv4d0W5lTn1lxU43fos9rGfBDaZW85ej7IOdFG2/fw
X+nzEn3Xw9fQhFfR/oLtrx4O4V/w/GX7jrx7BZ/I2mXa/0MrIREf7NezucDu
uUF4mKPxxtgzPxTf4Gjddtqa3oj/D2ithGE=
         "],
         VertexColors->None]}]}, 
     {RGBColor[0.8288636363636362, 0.595, 0.3318181818181819], EdgeForm[None],
       GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwl1FtsD2YYx/GnWmVoZVHn/lmlQ1udQ+kIzUi0QiJZ6rCQqKZ2sa6zimRs
aIKFosXcSB124diDTIrYEiyIZpm7ZeGGm+JCydo5rM5LfJpe/PL9Pe/7PM/7
vs//kFVRXfptn4iooGRKpEVkUv7QiE0jIub3i9iMNbSA34qfjYwo7C8XU2kc
3w/TaSI/CE+PjriiTyN2ikcPiOjCHeoX6/MjnqCv+GNYb++l2r1YlBmxenDE
bGwQ37O+vqeWnvFncaeaz9XW4nGq5C9hqprWdG/BUfKmy8/EJErwKT1r9pbo
X4Db1ZSo3YK77b2QswtrqZvficeHR9xOcV+86D1t3tWCH9gbKycZfxPftf4r
NtMNvhVv6Xtb/79xzChvMIex+FCcorYDPxT/YH0wXlbzUO3veI7+4s9jF9V5
138986Ra/h/spgb+BT53v6a+9nGOeNygiGFYom+L/mV4mlYNjDiJp6iMb8JH
an5W+wzrxMXW67FL3Gz9KT6mo3wHFprdUjOcgZ84Y5azJuMUmslPxRwq4Etx
gV7N7lCM08RF1guwRbzGWWfwFyrnG/E8VfKtWOKMKmfNxbXmNdM8q3Ce+Bvr
8/GNXvXm8C/u8Xm8Mts6nGOvXE4xvrN3Qs5bXKj+TmrEIsxyxi53y8YHtNG5
1zGXDljPw+16PdFzG34vHiZnA+bQPjkTcDzV8h/hVfpOzjVcbl7h+7MK+6jP
1CdwH73j92OGO2WZyRC8J+8nc27Hw9Sm9hB+SSP4NbjMj3U5/T8k4oK403or
FiW09p1pw3y9PtVzEqYnevMPYp640HouHlHzp9pjuIRey1mKDfJW8rnDe7mC
kjL8XsXZ8r/GCkriv8Dxek3V82P8I9H7P1LDl9lLk7MaG+kmfxQf0AFvvN/z
prTeO+f4z1lnFu1mUo3N9trlN+F7QqyiJA==
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJw1l2lsV1UQxS90YaltQYH3X9nRVjYFlN0iSxCEiNWikAhGCKVAQSQKIggo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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlm1MVmUYgB8BsYIXWIHnnPe8CCipmC5BAlw1tSVvc7k10upPyrRNviZL
57IvIxTREKY2W0vbCkR46UOs9bWcptn62Mp+ZG35B+hDCMG0xEq2vO7d949L
zvW8z3k+7ue+n2PBusaqjUnOuTqYCo97/JPiXBJEYA0+P+rcy7c4tw86oAhf
6+nvs6AQavAO2uNpjAFroBvvgWpzaT+CTyY7NwFXIT/buev8TY4515/h3LvQ
BZOhczsD+tzk3D8wBE/i65nHt/VNgXX4HPqWpDt3L5TDAnwCXrXxjkIS42cy
99OsPwQf0vF637mKac79nOrcT1CDx5inlPnKoBxm4H2Mdybi3Gk4Cb34s/S9
n3crIQ7P4+0Wg+UwHbbi80NdVwWUwR34bVDA80yIQQTvp28t76xP05i9g//B
mKmsIQa5MIW1XGTPhzmsHtgHv+Dbab/M75MwAbvxrFzWnq1xlnhX0e+tqI4v
89TBMTydvnN5Zybkwc34A7S/TYz6IAFxPDnQ33NtPUn4ZtqzGCcDUnKc24Sn
BNonz8ZMxccDjbvE/xnIol8/6xnjDEdhABL4vFBjtBhmQQ4+QPte9nkQDsBv
eCHv77J8lLych08LdD7ZSxFE8CFPY7R/qo4xiJcQlyHi4lkejNJvFe3/EqP/
kzX/H8G74Jyt7yIcxZ/z9bzl3BdDI35nqOstszNeiBfCQp4XQTHMDjVvPoGP
4UFidSKiOShrkLX8yprS8B3kazNspM8L/H0R7iZ/12ZSR1AN9+BLoZ7nOmiA
ZfgOy4M/4Qq0SEzYbydjf8t6z8Iga+6Nak1WW7714Y30HeCdQTgPtXg+727j
3R+tPuK8+yF7Oc/av4hoTXyAvwff8/w7XIBP8eMwbG3S/yM8n3la2WuL5cGt
+KZA5xywOt+Mt8M1y2XJ6Q58mPgfsjx4HUbwK54+y/n2wl/49FDrqsByyMPn
2h1RbGdShBeHel7ldneU4G2B3jdy78j8e/AxT8eWekvAOL6IWD9s5/EYVODL
Y3o2qzP1XCrxUuKXmqP1IXXSEtU7RmIpMW0ithvwu+i7yt6VcUvxJbDBzld+
K8N7JK52D30OCfwzxtzC2E/JfQOn8VNR9S1W5+9LvTBPFef/EKyEFnw01Hx7
CdpgHL8Ee6ytFcbwkVDzUPKxgf0M49t9HSdud2AznhvovVlqNZiJ93pa39/A
19CDn/U1FyUn3yAG3+GPenqnSw3KN2I1/gqcoO04LKXfAbzJ1zlX2l52+hrX
LLtz5e5tw1f4eq9XWK02+Jr7Mu85SGF9F/D+UGMp+Sw5fAyfE9W7Re4YydfZ
+CFP1/8lnIHX8L9DjVt7hn5vrsp3h/ZT1u8rOIjXwu32vZTv1xN4XlTroNXm
KcCXkC8rcvSOkLuim/GaiOElq2ep62b8eqjfSZlXzuo//E1P55M4y73ViY/Y
90P2Knv+Ae+Gep5roQa68F2B1to1y/1WfLflS4317fR1Xyfhvmw9EzmbBfb/
g4R9LyrxG8QjJGE=
         "],
         VertexColors->None]}]}, 
     {RGBColor[0.9113636363636364, 0.6484090909090909, 0.3252272727272727], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV00lszmEQx/FBq5QqXVLqpW1IbbUUrwgHSySa2EIiPRCJWmJtORBLD1Jq
DSWWELumSXEQEVtCQs8uImlo1C5i3x3xeQ+/fGfmmZlnnnn/b0lVzbzqjhGx
kDrRyj4RbV0ianAPfWRvxz79Ik50jmjCnn0j+nePyMadhRGTu0XsxkUaLKD0
vIhr8lq7RjxRe8nZYjnNODYRMS87IolN/ArxA3iVlrIv4z6axK7HQzSDfRjr
e0fMyXAXrtf3udl2pljgLD3iGbbTDvZTHKLmYGZEGbbQRn3uYY65i8zfC2/x
14nfxY5mOtEj4o/4UvWFafaB/fiD5SewmIayi3C0/ApvKceL6qv0uY7j+bPE
x+AF9Y/0OY9bzPrezJvxm/oGd33H184OmPkTVtrfQupkhy/5DeKvcJM3T/H2
jXiW/1DPc7iBP0G8GmtoIrsW3zrbq/YF1rrvg3u3Yp2zmXK2Y5a7+3pLLl6R
16pnI073hsv2VpH6bamBPRiHyyuTPwhn8JvFp2G1vs/0X4trqJ29GvNT+5I/
FEtpBHsglmT5fqg8P2KUHU23q5E4zFlSThmeNscD85xJ/Q5yi2ik/HHy5sqf
hLvc8ctdu7EDZbA/eNdt9c/l38Kb1M6+g1V6Fei5BKf6Ph+LT8HPajLVfsV3
9Nd+XuJ1NW1ybuAr/j/xN9jfXUn5CexMxew0XK5vQv9lmGcvm+ynB55SM1vt
DmykVewm7J76JuVk4zn+MvEz+MN9R3wbP7FO38/6b8NhZm3zn7qJv50dk/ML
c9TX6lOMCapjF2KWmgFqM3CFvkn9V+NJ87WY8zjm6pXPzsHzdNR/PCknXU2J
2l5Yqtd+PQdhLn+EeB5+cXe9GT7ifL3++m4rsZl/394u4X8wjpQM
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxFlv1r1XUUxz/Me3eX21XMu4d77z7Tba5iM61opUYq+dDKcg9QQUZIzKco
N6VEK+dTtllrKpQ2rR8Mk8AslkH+EDjKTIiCSKYbipSbxLT/oKfX23PCH958
zufzPed8zjmf8/CtfqGjbX1BCGEAJEBNDOGvVAhHMiG0Qx9lnVdm+//PtW9n
7S8M4cnJISwDj4MnwApk6vm+ku8PVITwLPsd0Pcju4b9b+CflOnSXUWlyMCf
ZH242OQkL5n30b8q2n2yoxZ6WjaEOUUhzAXToQfKQxjG8CHwBfR6eMbgfXVi
CMW5ELryIdyD7mnpEH6Ido/uOwfPyG3YFe1enW+G7gDL+H5G37O2ai+dQ/D3
YH8ztq9SLKC/5M6RhNkgW/LINBaZjbL1FfRuR34Da98k9EO3Qg9hTwvrBeR+
AT+D82AbMjfcv5qs2d7pMvIhjU/X3CbZ2gnPZXivgA3Qn2PTRmy7yH4N+wPw
PDOBmE8NYVK85ZN8+Soaj3hHwDro2aVmYzNrLm12y/77WKvZX8fHd5Pms3xv
4c2Xg8P49hHYSrxnwVsF79lob6C32ARKoG8g05c0HdLVAe829N/rMqI3eqx0
90b/Lr5dnHWjs6vM7tBdojv9200efLiOL+NgB3QdvpbAM4H1uQm2al+bsbgM
omMsbTn8YCU5hV85kAXTwPxK81G+JaEXgNbJdqZvZ6LFqV75Cz1O/FPcnQR/
QK8rN33S+xL0qWh5p/ybGe1O3a06mgNdwHke+xaxrsC+GpeVLdWeI8qVn8Cv
oM3r7jHQDHL4PIu7a0Ea+li0OlW95qLV9BGv3Ww0Gck2+TsmsOFDfO0HBZXm
s3zXmb6N4tO/KfPvOvQhdDyPnYXonAxd7fWpGqjKms+yX368DJ2AL11m76L3
UJ6tL7P4KY56l+Iyy1e9T4nzTkV+But2dP5ZZDWiWin2t/xbscpYLPWeo+lb
PUnro+5nq8dpub9hEplKdCzJmB9rs1YLqonVWavBuV7P8q0Jvuj8PyasLlUv
s70+p5Djr5Prb4Dbc/aWi+EdTNibPhXtTO9cX26+KwaDyC4vNR7Zk/T3/4wY
d6asplXbS/z+Qre3NVo8FdcG9C11+UV+p+ilbqtkP0HHiynTKd2rvf6l/0SF
9dS5Ht+tWevD6sc7vYfPj9YL1BN6oEuon3wJuQQm5g2iT+J/K/4PZ63XqH+q
N3/H2Rb67WvgDPTXoAO6E5yCXldhd+lOzZKbOeszR7OgEv13ob8BVOetZ6t3
q6YaoE+7vnYwkLO6US2XKRYJq9F6z7md0LvhWVBsM0CzYCb7fdh+DCyBbgLH
oQdAC3SfzuBdCnpzVheHwEGvmcYKm1uKm2afZuBKn2Ufs+9BZqHL781ZDBSL
u/GnJm89Qb1BM2oL9Pcer03g25zNUL1DI1gLfdblxSNe2fIe2O82LebsU/fn
EejT3HE1bTWi3nfc80s5cbTC3kmz5ZrP0Dqv1zu8BpWzBZ6bH0SrPdXoDK/B
b9B5OW136K6Dbss+cABkvT42g0zOcl/10+I1cAmMgAtgWDMyWo2rtqdE03vZ
+X5P2xvqLVU7C6P5ddW/qQcohoql/jMao82ZbT6PNc+Uoyf9fZtzJnfJ776S
ttwpBxnPoVafx20+wzWHunw+aX4pR6RLOtugx/M2n8Sj2dXgPVC9r5/9wXLr
D+oJ6g1bff6rx3VlracWes0/HW3uXkzYf4P+OfYwR7vBm+AtsDdpZ6J7QW3e
cks5olzR3H0naTqka5T7e9i/DcagM/BXwT8dlOatZ6t3i2fUZ3ev65Au/VOo
V+uN9Fa7osVH/y3695LeHrdxj9M1Psu6XZds3e06z0V7F/UY9Zph9/W8/+MV
e39Rz0nLPnJ2Hrn7EOiosFl12GtStdnm7ysZyZ7w/yPlvHJ/hv5XSixGitWd
qkHvL3XQ/wFInF1e
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlElsjVEUgC9alY46/u/9/3s6oGirxlqw0ApaVGkTrFVLCNoIUtqFtFpT
B0LM85RiZUGRiGJJJUIo6UBJDI25WBm+k3MXX9797rvDOfee/6aWVpSsH2yM
KYFQOO0Y8zjEmOfQCefxRa4xV8ONuQKtsAC/7BlzN4px8BKu4ZMCxhTEGDMP
8mEifov+t/zfB71wE+9jzRY2a4RmeIPHsOZm1q6CaojFd/qNGRhmzAfoh134
K8buZs6uUF3jNX7D07VfQCfMCjLeRz7MCYNw+IRf9zTWLuiGNjwvqHNKEo2p
TDKmLqjrSF7PbL/8n8BZ/B1izB8YlWBMPH6SNcvDOB8oguN4NTF+tPFK3Fvx
Buil3TNM89mBf/FpXCmQCqH0raEvh3WmQi17rMbD6B9px8jYofgszuYiZ7QX
WiAX3xdNGzYSbzO/ey3S3kBfHb/1kEt+RXh7lN5fq6e5Slv6Fidq3kkhmrPk
mU4sify+t2f6j/j+wjt8jo2l1dZHPr7Fr7kP2JzX47Hsm5ag5yfnuIR7C/Fr
TuH2ngbhSxkX5B4KGPuQPU8wzmXNWtausbXhx5OJOyOS84JkiMPTYDztbBgL
Qbzf07wl/0py+4h3sO4DmMse7fzek7t0dL9HIVr/p/Ap1O9C6rgQSmAqnhPQ
9iIohmn4OcY+Y85TeAJn8TrOptDWhdRHPd5K3Msj+H6gAC7gqxibypxkCMBK
R2OQWOQMJE6Jt9zR/+Ve5C7iOacV9Dm0/eBCGX6FNctYuzRC97qMr/PrPUgN
dsNa/LCjeUv+s9nnEL7dp/FK3HlQhU8I6Lc8P0a/Y/me97uaw3K7zyW8Beba
vOS/ffgyR+9a6kjiLMVj/VrLUtPZEI832rm5MBP24HFBzVNqL4p6KMZ/s/cx
7rEoRt+ZyQF9n+Sd2sNbUA+9eI+j7QbYDt14u7wvrF0JFXAHv+2qS/8WuI+f
cfQOO2xdHMOvuZpnmZ3bhqe4Wo9Sl02Qjo9xtd1iv81xsqdPz3IGTIdN+Gjy
yLQ1KrWajo91dV6TXTOAZ9CfYutb6jwTT7VzsyK1/lPwGp+un2fvrhYfoP+g
fQOk/j/jXY6ex45QrTmpvW+evhvyfhyA73iWp/tl2H3G4zs5/21J+r7I+K/0
/YIjtA9F614/8VhP45W4R8Bw/Ienax+N1vuTe/wPM5rdnQ==
         "],
         VertexColors->None], 
        Polygon3DBox[{{6507, 2269, 6512, 6511, 2266, 6504}, {6420, 2094, 6426,
          6428, 2101, 6427}, {7459, 5284, 2044, 2046, 2047, 6370}, {7477, 
         5384, 2877, 2879, 2880, 6790}, {6308, 1898, 6307, 6305, 1893, 
         6304}, {6526, 2285, 6530, 6529, 2282, 6524}, {6254, 1850, 6253, 6251,
          1845, 6250}, {6670, 2680, 2678, 2677, 5350, 6669}, {6927, 3102, 
         6932, 6931, 3099, 6924}},
         VertexColors->None]}]}, 
     {RGBColor[0.9340909090909091, 0.7052272727272727, 0.39568181818181813`], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtkktIVHEUxj/M0fE5Oo3Nw7mmjmRRoflqpaQDhSVICu1CDdOonIhBzYoB
UVTciIlCYiphSptW2kNo1aLWBQrmAxUtkB7QojaBv8u9i8Pv//i+c87/3Jt3
415DJE7SZeIIMRCQqlKkckO66ZdWnFIrdGRLnlQpHu76pDjO9+FVdIUeyQ13
2P9PlEKss/EUofHAdq+UEy+tww2izyFtwin0reinoZe6sWQpC7bg+YK3Gd4i
VlnfgQ/QhdH3w1p0C+jDcItcn8k/BwvSpHyiLEuKoqtEfx8+pafrPPA0mnn2
bZzPwFE7Zw/sQ9OIrxq67fcehwH2kwn4oMG+kPN8+JraEWa1DD8QUdbvYQZ3
BppM2ELNJsLJjJ7jnyBPhc/qpZlI5DyXfkNEKbU/GtY+hjeNXN28MR3exnOe
PiPwCfs6ak1Bl2HlnzR9eE5RNw++tDVj8A3RwXoJ/uYuSp0hw5qXObdZ2MV8
95hzJ2yzv5f53RbRrSZJa5yP4q8lzwjspI8L9NMFfxIpeP/BiP3temBJUBpP
l/5S0+G3NL9MH/4XvKsGvuNum/cuw4dovqN5BM9Q9yt138Ji8lx0SeeCls7U
F7FOYu3lvU74GM83vDEYYH+Ccz+sMqz/4RNMZe/j3AX91O6lhwD8QU9OvAc+
q1ez5z/wCnev0NTDo2ZPaDLhXWKddQd0E2dZH4Oz+NuZyRwcxBNmVsMwSPST
5yR8xkwv8c2v0U+5fW7AQy66cEk=
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlU1oVVcQxwcTfUk0T6kx7937vBqNX/EphUbjQhS/sKRJlLRqFlX8qC+2
giYan08FBX0uxI1FwYWgLlK1tChdtH5A6ca66MpuWqGKdFGNYDd1L/T3Z2Yx
zP+emTPnnJn/zJ23b+TTw5PMbBRpROaVzLqmmS1CZoO3zzI72m62A/2y1WwF
+izfVfQCvs8kZhNNZq+R0+Ac6zux/9Zm9rzZbD4xFhPr2FSzX1OzSmY2ju3a
FLM08zXZxpDH4NGi2XnsZWLsxL4SWTvV457M/Ayd1Y10gB+y5zD2Q8gD8AV8
xvCdz93WgkeRfmI90X3w70JP53spusSDv+K8npzZKuQg+BIxeom1EbkAHmbP
H5z1DPkSfBefkZyvyVbC52wLeUAK4J9Tf4ve9At4I3IH2y1kPXgL8gP4HtIP
3pC6TT6bwBNtft836BprX8T5OvO7oudAuVBul2X+Jr3tGd8/8X0q8/y34NMD
HkLX+T6J/puczGRtSby9UuB8vrdFbR9Sqx9Tz6Vyeh+8ijP34n+Veo3juzX1
u+sNg+B37LmcNztOjP/APehznFdDLyTmDvZ8zP7dDeQ983vpfnqD6iouaa9i
VOOup9Cbp/ud5/D9Cfufct/eqF0ZnTV6Dcux1oze1+BnaU9TnKk9c5UP9F6+
3/KeJvI5CfkHvIX1Dux96N8bHWutPtlsAH0Tn2Fyvx+5XvQaqBaHkG/Bc8n/
R8T6ECklzklxU2uydfLm9znnvLg/GPVvpydayNfnrNXbnIPiYn/ctzfe3Bf3
K8f7tEd7i8g05bvotVEMxWpLnYviZAJOSt7L6uk54Jmpc0scU2/kWcuwFZBm
cIm1CvbV2Icz57C4rB4uYb+Yem+oR77WWax1UOfPVLvM794fudTdTwQfqlHj
10XPvWrwLzgX71FO1BtlOLmLdy5m7yDxlmc+S8QZcfuvxLmuPhnJnJuaFfXg
aHPwQX2+p8FniOzyE5eHYp6tDH4eafcZJ/6rD4S11o3ubHW/o+Gjb+Gh6CXN
xGq8ryfm4VjMxxUxg2RTDq7kvSdaor59Uc+bBa+zOH6j4NyvR/9oT3fcR/lV
nmthH4r738l8lqpmql1T8L83+K4aqpa3+V4AfpT57FBOlVvlcCJmTSv5/77o
3BbHNetqyDrwGmRM9cI33+71UZ3ykWvNE82V8eBOJWb8N+w5EP2i2E+CexMx
s4rRP+qZJHHpjv9JLfF7K57iqo/K0Q8DMQOq+LzC9w1yAjwDWQZejnyQOC9U
//PRY11x/1zw4yA+L/D9E6mA/wcIotGV
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkM1KAmEUhl8M0UTNv8YZREFUcmEEQrUK0k3QUr0A/8iFf4hkC9t0IYqr
8IbKjVvNpd5Bz8e4eHi/58yZ882ZbHtcG3kkRcELH46090t/sIMZfpWS7KCU
hDRE8C71X55v4Ac6uD/l9pheC3z4Mim9JqSMJb2QCzyWlm44h6kVyTg+sqVH
n/QEz/CONy+kFgToaZOXZIJ77rjvFkoQxy3HdVMvg43nQlIeHq6lAnlPLpnZ
ZfYb9GCFr2F4dlP/xue8fzjvb/7DJ9533F3NzlsY4BW+u87cCXs0yCp+YucZ
5y9qU/KI/wNklydq
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkbsvQ2EYh3+RlkYplTblnFOXxS0SlwSTpEIkjTIYzAgGSYtIaLuJ/gHa
xlZhEbGYSBD+BsJaxWZwSViMnpNzhifPL+93e7/v61han0tVSWqGajgkLNdI
JZyDCXIeL7RITz4phZNQJq9hjymF6qQmHIQoOWDbYH2tZGEDdskmNhnrYk4U
W9BJNvAvHASkIqTDUgH/UGuFHua04zb3LC++gkq9NM/cV/wG19Q+6NVHb5/4
G/zkL9xvOXPsuRnWTDVIA9TKEc7w0A/MhKQ9r/RMLUGv5/Q8jSfhlBzHN5Dy
cz6+gy3yLd6HODmPi5AgF/Cg5ZyVDTt3s+84RG2csRP2jOFu962Gcclde4Yv
IUm+wJvcYYy/GIURyNHrBrWM+0dpvA0x8g5O8zfv3D2LM+7fLeI/90285CD0
kRtxJeLcfZZ9H3iLR3ihdhxxsl1LMHaPj6itgEnuDTlvZ7/hKrV/WadLXQ==

         "],
         VertexColors->None], 
        Polygon3DBox[{{7460, 5286, 2045, 6370, 6372, 2050, 6371}, {6677, 2686,
          6676, 6670, 2679, 5352, 6675}, {7478, 5386, 2878, 6790, 6792, 2883, 
         6791}},
         VertexColors->None]}]}, 
     {RGBColor[0.9568181818181818, 0.7620454545454546, 0.46613636363636357`], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV0Msr5nEUx/Hjfk0iPDxRU5SNzGaYhRLZkJWFS6iZYSXhKQ2zmJqykGaD
iFw2FDZ2LMh/YCGyUGY3Zic1O5eSl8XpfS6fz/ec3+/Dt8meifSIqBcZYrsq
or8gYgf/JjRyI2qrIx7kefJ7/FoZcSWfxV2zteyIZv0Fng7eVewzO6fpxU/q
jfyINlynG8yJWMHfolU+jXtiXH6AxTzlvI/yMfml/Asm+ee8U41LZgP02ziv
brO3yS3DdBf0Q1iVjKgr5MNlmi6aRewUh97pxgaeP3kRJ/id5453Bl/MCnmf
cUR9rT+K/+zLkP/HJ1Ehf8Wj92/2/hYm6D7ql2OLesuuzzhD1+7mH5jlplLv
12Cj2S+aBB6748Y9t7xpZsU08a41+0lThjnqMv1cTNJv+v/7WKQu0c/EM7qU
e05xyr4We1P4Bv7UPgY=
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJw1kz1oVFEQhYdEslmzSEjc9d73fIJgOn9BkhSCRK2CsbCJYqKw4gpBYhKV
iCIIshbaBFFEY7BRXAWxkYA/WFpoIYqFYEoRDDYWImLjd5ib4vDOvDszd2bO
3I310wcn28xsH1gFzgSz3SWzPWAWPpKZPVtt9hQMw7cWZu/Wmo3XzC7Cb+Jz
BN/D4EbwfzqrVM0G4CfBLuwWMX3wOXIMd3EfuAafB6PwQ2ABPkiOOr63O8we
4P8Ye5Lcp8Aj+K3MY5XjDvwP/2qdZuvAX/hPUIa3g+/wC+QoU8tS2WwLfCma
vSX/F+xF7JeFn6kn9Vbn/HOn36m7x7A/YH8Cx+BVsB2+Q3fC23Kzngr9gn/U
0yLHPLU3yLcefhSfj/i+B6PwF/hMU/sMeAU34ruJ7QXtuedU7m/gbHQf+fZx
HjifJudIzXtY6UX2j9TTIP730Oou6Id3EFOtuIbSUjpIj4d8jTvepPyq6TX8
a/Q8yjdVOMQvEd/LeT/2UJfPVLPdyb8rnF0G2+AH0r7ozhJ3P0n6aabHyV3O
fVaa2Rp4o/BaNLMc3gqutWIU2xNdW2ncDV8IvmvaufvwE9FnqxlPwOeC7652
+Dq8Se7N9HtVfZd8L7Wfqn+lD9nSX3sgzRppRtrdgeC7qDxj2Bty10qaRfj5
6LuhHTmnWjOfhWaSw2tgOWkk7WaC16KaxrH3Z/62NDPN7lfw3dUO/w4+e8Uu
Jw1mo++GdiRGn51qbaQZDmWuvXZgLzzPfXeksbTeVLjuitPs66mWZnpzqkm2
/ustqudmmt1U8Dt1t95AgC9m/nb1hp/D/wPjiYjf
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwVzj0vg1EYgOGnLdXSiJB+isFgN2DqxMTYoSWNr4ZNiEQlZn+ATr4SiUEn
q4S/YBDiJ5i7CTGIq8Od+37POc97znTroLafjIhRpPFbicjlIrKTERnkdZov
ra+MRHT4Bg19zd1SxN5QxD3foqkvuGRmxmyFyxjTCb4zs2r2kZ9xqJ/6/8bD
cMQyL/Xv0FVOmZkwO8gDGNdJ/nNHMeO7HFHArM5zx/qaN5zzCRb1GW/ae3dm
m7fwpjf4y15W9/gHBf3NdXsvepd38KFbvOBNV942z1M41XN8ZO/TmWNu41Wv
8z+j1CpJ
         "],
         VertexColors->None], 
        Polygon3DBox[{{7461, 5288, 2048, 6371, 6374, 2051, 6373}, {6260, 1855,
          6259, 6257, 1852, 5254, 6258}, {7479, 5388, 2881, 6791, 6794, 2884, 
         6793}, {6680, 2688, 6679, 6677, 2685, 5354, 6678}},
         VertexColors->None]}]}, 
     {RGBColor[0.9795454545454546, 0.8188636363636363, 0.5365909090909091], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV0E0rRAEUxvFj1GBGI4XGYEHZSpKRZGFpo2TkJcQHoGRvrSQhZlBKik+g
+AYU2SqW9kreI79ZnP7n3Od5zrn3ti8ujy0lIqJDVarLXMRMOuIED1VBX8Kt
bMRkVcQ2zjZH3FVHrOIg7SQVMYJz5nvP53HdPCybb4vYlCnIbuAi7ZpnAhMt
EfW17mKRtsBzhl0yTzURV5ikpXi+7TtQE3YeY68quduHKzJDsqt4IfMg+2j/
u7nRrR/s4dvj78YmtabP4gstw/OKp7LFZES//o+Wcfe3nDNP27+DA+X/IpvH
aTduZaewoG7047hLG/We+9hq55Gd5/gh38DzVn4vvpz+T1/hG+vcyuKXTFr/
ic9ljadT9h/txTlZ
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkk9LlFEUxo8m9jYzTASOvfNOV3ChO81F1LQwoWVggWKJfya0xeimaHBX
0FKpTUSFw9SiFMT6BCJ+gBKjbWCfIDcuRETEfg/nLh7e595z7nPOed7TO/9s
7Gm7mVVBB5gNZstdZncumjVSszp8oNvvVjvNNvgOc17k+4nzETldiVkRHMKr
qecpX1r5klmN/D3Ofy+ZvSa+EjVrxLczs5m82TTYghdjvt7d5e6M/AztCjiH
N3hzn/iu9Mpmt4LnKf9F8HvF//H9Q70+7toS77sOb6HxhNnmQBP+Lc6juPKW
Y28r0QP1qLN8uE3+GzDB/SR4C18I/l46/fDvwX2RPz3wz8z0kP4mQAs+Ts8/
Eu9BvQwF90Yzvwxeox693gyusRh7VK3nwWd7lTPrRi+tmF0uuIfycie4z9KU
9macVzXnqf0lc6+Vv5Z5TdWW79XgHspLaQzCR8hZp9ZXMAw/Qa+U+D8/ht/L
PKacUfi71L2ZAu9T93wj7so18dS9V0/q7SZvmrxtgWrmPak3zXQOPwa5guur
F+2AduEXmGaex+A3fA/MwJfKHlPOVfh+2fdAnsm7C/h1Bb0iMPh1ND/mvIcb
8EFwEHeoEb0WP4iej0Y/1FNnxWuolna0BD8lni94jXbij7j7mXiPtbLv7G7c
zW30m5nvxgPwAf4fYil2xw==
         "],
         VertexColors->None], 
        Polygon3DBox[{{6909, 3086, 3089, 3083, 6905}, {6291, 1882, 1880, 1877,
          6286}, {6807, 2895, 2901, 2902, 6810}, {6489, 2253, 2256, 2250, 
         6485}, {6387, 2062, 2068, 2069, 6390}, {6711, 2715, 2713, 2710, 
         6706}},
         VertexColors->None], 
        Polygon3DBox[{{6395, 2069, 6393, 6398, 2074, 6397}, {6904, 3083, 6907,
          6906, 3082, 6903}, {6717, 2722, 6716, 6712, 2715, 6714}, {6491, 
         2254, 6493, 6492, 2253, 6490}, {6484, 2250, 6487, 6486, 2249, 
         6483}, {6815, 2902, 6813, 6818, 2907, 6817}, {6297, 1889, 6296, 6292,
          1882, 6294}, {6911, 3087, 6913, 6912, 3086, 6910}},
         VertexColors->None], 
        Polygon3DBox[{{7480, 5390, 2882, 6793, 6805, 2895, 6804}, {6284, 1877,
          6283, 6260, 1854, 5256, 6282}, {7462, 5290, 2049, 6373, 6385, 2062, 
         6384}, {6704, 2710, 6703, 6680, 2687, 5356, 6702}},
         VertexColors->None]}]}, 
     {RGBColor[1., 0.8772727272727272, 0.6136363636363635], EdgeForm[None], 
      GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtkL1KAmAUhl8UUktxETHBIIjcUmoohS4hsjLCGhTHhhpsrQsQqyE1DUIc
K++gn7UGb0HxEiLtR8TyCc7w8rzf+c53fr75/PH2kUPSAnKir5Dkd0t9uD8r
tfEHcC4iNaakB5gMS81paR3ucvdKTgaecLcZlAqwzN3GjLSGr+JT+BqMce56
pCd4irLkn8F3+nmps4j/Jc/nlf7gOfFiQMoRH3J2Ex/DJVRhhjjcshlSsEL+
nku6hGMUIj6CH7bX4L8eSpNTgheWfwUj9Lhlx3t4Zz5BfJkeNXqtwhfiPebv
0uvRdungP222AfxGHvwPvLHdr2HC6qzAlv1nkvpxq/kMD1GLfaOwSV6Gtw24
Q4835k/DKm9yzFyHE5tbQtM=
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkbtKQ2EQhAeRmJgELFROAn/AxlK0M4r6BCJECy+gkkobBbEUe+1FVLyE
VL6Jha+g+AJJqSCR+A17iuXMXv6Z2T0z7dPWyYikBjFKDOtStSLtlqUu+C6T
DsekNvEAXqDWn5Q2pqXzJM0SlaL0Su0IvEq/Oy51iGXwWp6X4PwBr9Sj55p7
QzhrvM+Ivyw0rPVGvlmTmuSPBekK/n347/O+Pd2C95h5LwaHuc6Y6TF7A/8c
/K1acPmN3/Zy7/18ZmJKOiCv8l1n58sUuetN8CD3Z41tuD6Iz1LwWOsJjZ1y
3OsFvJiCx3wXKWru+aYD8Hc9buH9fSvv5N228HeN1hLxXIh7HttL3vcNUoob
u+eZBvg3i9vZo71a09pfeJxP8Q+tb48d8D+XAUNr
         "],
         VertexColors->None], 
        Polygon3DBox[{{7529, 5289, 2060, 5292, 7530}, {7539, 5711, 5357, 2526,
          7471}, {7520, 5258, 1876, 5257, 7519}, {6622, 2528, 5389, 5727, 
         7549}},
         VertexColors->None], 
        Polygon3DBox[{{6900, 3080, 6905, 6904, 3081, 6902}, {6908, 3085, 6910,
          6909, 3080, 6901}, {6715, 2721, 6714, 6711, 2712, 6713}, {6295, 
         1888, 6294, 6291, 1879, 6293}, {6488, 2252, 6490, 6489, 2247, 
         6481}, {6808, 2896, 6810, 6815, 2905, 6814}, {6480, 2247, 6485, 6484,
          2248, 6482}, {6388, 2063, 6390, 6395, 2072, 6394}},
         VertexColors->None], 
        Polygon3DBox[{{7463, 5292, 2060, 6384, 6387, 2063, 6386}, {7481, 5392,
          2893, 6804, 6807, 2896, 6806}, {6707, 2712, 6706, 6704, 2709, 5358, 
         6705}, {6287, 1879, 6286, 6284, 1876, 5258, 6285}},
         VertexColors->None]}]}, 
     {RGBColor[1, 0.95, 0.75], EdgeForm[None], 
      GraphicsGroup3DBox[{
        Polygon3DBox[{{6705, 2711, 6707}, {6293, 1885, 6295}, {1698, 1696, 
         5228}, {1694, 1697, 5227}, {6285, 1878, 6287}, {7549, 5326, 6622}, {
         6386, 2061, 7463}, {2527, 2530, 5327}, {6713, 2718, 6715}, {7530, 
         5694, 7529}, {6806, 2894, 7481}, {2531, 2529, 5328}, {6394, 2066, 
         6388}, {6901, 3079, 6908}, {6814, 2899, 6808}, {6481, 2246, 6488}, {
         6482, 2245, 6480}, {7471, 5324, 7539}, {6902, 3078, 6900}, {7519, 
         5678, 7520}},
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxFks1Ok2EQhSdGaUsxSvu1QZJ34Q1gXaoJPzdAaCXGhYqwQsW6ce0NVHFJ
YkIpsEMryJq4UleEHy9AA7IHJXFBWPiczCQuJmf+vplz5v2uz7xoNC+Y2W3s
IraemY1Vzd6Cqz3kB8ye4nfwPyTP16g/j/ocOELcBVeIP0b8HrycNzsGJ4hP
wIVes/vXzL6RL2PnzH6HTeXMvhI3qP2mr07/H3Cx17ls4n+h/gncj7r6DgvO
Rz2qPWJOExytug7xE/fh4CMNqm3g9+e9RxzEpYSdDTh3abiad00bMa8buc3Y
tx4zFvjmYc41SEs3+ptxj4ngKi26wZ1BszZ+BxvG34376E4/C85THOaC75Pk
/KVDb/EGvEH8DFym3mHGZNHsLtbGPyU/Q71SMVtix8vks3X7m9S/409TL1M/
Yt8e8WPifuJfBZ+tHQ/Q8zrzd65FTvtq8W/o1vOZaxP/3XiPc3bk+pyTuCX2
z1IbomcquWZp76Hn76Dr0M4W2Gb+D/6BHfwDZn1OzlN6pEt8xT0j1yh6rVRx
/lfA8aKj4r2YcSv9z79KrkMa5kPjVvK7b4tH8jtoh+6ke9Rjt26pf/I0/r/9
4CNuVb651Oc3X0uuQ5qlvRXaZ0NfFvO1p150rqXwlauG3nJobMV99Bb34PsP
F5CCLw==
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwljztOAmEUhU9IeCmE1wwBkimo7FgCa1AkVCrE0gQooIUNGNkBT0sbYQ1I
ZUhgAwShNzHa+/25xZeTe+45d/4pP3ZrnZCkNIThKy6dYO9JZ3SHXhelj5i0
hg3cMM8upAmM4YfMFK1fSjXwfDLoLcwj0gI6ZF7RNhpJWN91fLJh5l4gfbI7
8M1vtM8cTdgu79tdd/+3ZH3nu/1fyd7k3rail0FzMKSfonfk3hZ/EJjv9u/M
aTQLV/hJ9A2vmpeeAvvXZlR6gKVnt1v4FfbPzA38l4Jl7uEORp7l/wHPgCtU

         "],
         VertexColors->None], 
        Polygon3DBox[{{6388, 2066, 2064, 5294, 2061, 6386}, {6287, 1878, 5260,
          1884, 1885, 6293}, {6808, 2899, 2897, 5394, 2894, 6806}, {6707, 
         2711, 5360, 2717, 2718, 6713}},
         VertexColors->None]}]}}, {
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwt0ksrBFAUAOA73u/XeL+GJMnIjNI0NdPwFyyUnVgKyQ+QBbLwWslKVljJ
SpSklPwJZaeMYk/5PBZfp+65nXvvObd3dmlyMRJC2OA0GkKf2M8gQ6RIkyXH
PAsss8Iqa6yz+V9ni132OeGMcy4odVg5tdQzwCAjJDkoCOGQI4655Ipb7mgp
DKGNGL2kSJNjgnGyZEiSYJg4EQJf6nzywTtv5JlgnCwZkiQYJk6EwJd7fvLB
O2/keeWFZ5544J4brpljhmmmyJFhjFEe9b/CEZXsdIVQJVZTQy111NPAnnyL
2Eob7VgK3fQQo5MOmmmikejPbGwsF8t+5kEJxRT9tSdsy0f+nvr7J74BZ04z
EQ==
       "],
       VertexColors->None]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0s9L02EcwPEnbdJhx6AukXYTmrjdN3ClztkPm1pzWpmEiLjpFsQYbMyu
nVr58xZ0FA/RHxAdUjyFp+FJPEUn8RQF4Us6vHg/z/fw+T7fHz1zy7nSpRBC
i+jVEF52hjDPIktUqdF/LYSGNtlhl8984Svf+M4+exzwg0N+8otTzshcNte8
rI6RY4FFVqjQjoRwxDEn/OYP0esO2hVCB3kKzDJHlRpN3rBKgzoVypQokmaA
bvNSmiRBnD5iFzPcb5UGdSqUKdF2/qKmGSBFkgRx+ohxm15ucZMrRPjnGf/y
iY+8NW9bN2hS5zWviPkuo97bPe7zgPc3QnioYzzig31Ox8mzYT+lBTatp/UZ
29bP9QWzPGXLtRl9wrr1Y51kzXpCs4zQss/oMEO8sx/Uu6S50/n/HzoHmNBG
Kg==
       "],
       VertexColors->None]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0stLVFEcwPGfCD5wFbVIxIW4klbRSgpCAkGX/gWiO8GZ0L2Ck+Wjl1rq
OL5NzTc6gYgww+QfoeAuaBkuon2fg4sP33vuPffAPee29GV7MlURscTrRxHb
NRG7HHDEBZeU6XgcUdE/3PGXf1TVRlRTSz11NPCAh7TxhKc849w6kzrNDHPs
ccApRRrrI5pooZV2ntPBfmPEK81TYIMtLrikwhU/KVOiyBknHJNLc6wzpqOM
MMwQWTLpeZ01KFOiyBknHNPt/ZyOMcoIwwyRJcMgA/TTSxedvOQFv33rtf34
pbfcUKGU9okfaY+cy3v7/IGPrDZHfNLPzLBmPKtzrLv+otua1x1dSmeqBf2u
y+l8dU0PdV032Uhrs+/eiu7pon7TBd3S+TRXv6b5Oq0rOqWTLLue0He8pWA8
rjne1Nz/Y/8B1ABdFA==
       "],
       VertexColors->None]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0ktL1FEYwOHX0Y1ddm7MXETQMlyEHyBcZIQLcWWuhkAQKZBWmRARCH2E
dkK7yBmb0co7OGWZ5aXxknnLLkSIihcQEcYnXDz8zjmLF/7n/C8l79XfLYqI
Z+TLIv6URvxlky2OOCbORPwuj0joVaq4RjXXqeEGN6nlFvU00EIrbdzn9oWI
CZ1kljz/2GSXfRrPRTSR5A4PeMhj6ioinugSy2zwiyOOSZyPKKGYoOBsnz12
2CZHszljOsoIWTKkSVFCMUHhrBnsscM2W74jp2OMMkKWDGlSdPOC53TxlE4e
0cEV2s25rBcpJ0HBHRxy8J93+ewNvjBFujJiWmeYpcf+q+Z5ZT2nr3VJ3+h3
favL2q8rOqTrOqw/9CcbrDHobFUH9Jv26aL26oJmdV4zOqkp/aQTdFt/1A+M
89L+veZ4V3r6j50AinVvNA==
       "],
       VertexColors->None]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0j1LW2EYgOEnYNQao7Yaq43xsyJFpJEasYiQEP0Dbi2IIEK3ihTxBxQH
FReLkzhJp9KpdJJ+xKgV/A8OQjdBBd29xOHifp9zOC/nq29hafZjIiK2mchE
DKUjXjHCayaZ4nM2oqRlllhmhdWHc6yxziYbbPGFHb7xnR/8JNUUcWa/tLaS
YZgR3lBgtzlij32+csAv5rsiqnpMtiUixwCDTDJFmRmmKVGkwBij5ElSwyf7
JTS4s+ctN1wzwzQlihQYY5Rh1+U1SQ0Jgjv3fssN11xxyX8uHp6bUyr85gOL
nHsfc/qeMkXeMs4736XJe2umhadUchHPtJU2Ds0ZbSfLsblLc5xYd2sfp9b9
+pIBevnnWI++4Mi6UzuoWj/XNI38Nae0gSf8MddrHUlq04//0D337EAr
       "],
       VertexColors->None]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0rsrxWEYB/CXpJTBJaNByqZQ7JTjfr/f75J0OOIoSZ3T4Z8gmzLKIItN
yiWTTDLJJJNMwueX4dN3eHt6e7/PWza72hvPCiHsc1gSwlJBCMvEWWOHXdJk
OOWMcy644ppb7rnjgUeeeOeDT75oLwyhk34GWSHOBkmei0J44ZU3vvkhpziE
XMaZZJ5Fdtglwz57pEmRZJN1EsRopIF66qilhupo3j17pEmRZJN1EsRopIF6
6qilhmqqqKSCcvLJI5tfbzvhmCMOyJBimy0u9d+lo+6oz9IQemQvffQzwCBD
UdfOx+UEk0wxyxwLzDPDNGOMMsJwtCOznbIj2gdttNJCMzfOY7Kp4P9P/AFz
Kkkj
       "],
       VertexColors->
        None]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {GrayLevel[0.2], CapForm["Butt"], 
      Line3DBox[{5936, 5935, 5937, 5952, 5953, 5954, 5955, 5956, 5957, 5958, 
       5959, 5963, 5964, 5965, 5966, 5967, 5968, 5969, 6007, 6008},
       VertexColors->None], 
      Line3DBox[{6027, 6028, 6029, 6071, 6072, 6073, 6074, 6075, 6076, 6077, 
       6081, 6082, 6083, 6084, 6085, 6086, 6087, 6088, 6103, 6104},
       VertexColors->None], 
      Line3DBox[{6156, 6157, 6158, 6182, 6183, 6180, 6181, 6184, 6185, 6186, 
       6189, 6190, 6191, 6187, 6188, 6192, 6193, 6177, 6175, 6176},
       VertexColors->None], 
      Line3DBox[{6209, 6208, 6227, 6228, 6229, 6230, 6231, 6232, 6233, 6234, 
       6235, 6241, 6242, 6243, 6244, 6245, 6246, 6327},
       VertexColors->None], 
      Line3DBox[{6359, 6360, 6435, 6436, 6437, 6438, 6439, 6440, 6446, 6447, 
       6448, 6449, 6450, 6451, 6452, 6453, 6454, 6474},
       VertexColors->None], 
      Line3DBox[{6570, 6571, 6600, 6601, 6602, 6603, 6604, 6605, 6612, 6613, 
       6608, 6606, 6607, 6609, 6610, 6611, 6594, 6595},
       VertexColors->None], 
      Line3DBox[{6629, 6628, 6647, 6648, 6649, 6650, 6651, 6652, 6653, 6654, 
       6655, 6661, 6662, 6663, 6664, 6665, 6666, 6747},
       VertexColors->None], 
      Line3DBox[{6779, 6780, 6855, 6856, 6857, 6858, 6859, 6860, 6866, 6867, 
       6868, 6869, 6870, 6871, 6872, 6873, 6874, 6894},
       VertexColors->None], 
      Line3DBox[{6990, 6991, 7020, 7021, 7022, 7023, 7024, 7025, 7032, 7033, 
       7028, 7026, 7027, 7029, 7030, 7031, 7014, 7015},
       VertexColors->None], 
      Line3DBox[{7043, 7042, 7044, 7059, 7060, 7061, 7062, 7063, 7064, 7065, 
       7066, 7070, 7071, 7072, 7073, 7074, 7075, 7076, 7114, 7115},
       VertexColors->None], 
      Line3DBox[{7134, 7135, 7136, 7178, 7179, 7180, 7181, 7182, 7183, 7184, 
       7188, 7189, 7190, 7191, 7192, 7193, 7194, 7195, 7210, 7211},
       VertexColors->None], 
      Line3DBox[{7263, 7264, 7265, 7289, 7290, 7287, 7288, 7291, 7292, 7293, 
       7296, 7297, 7298, 7294, 7295, 7299, 7300, 7284, 7282, 7283},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0EcyAwAYhuHfypjoJdGCILmLsbO2cgBOktzCIHp3BF2Izg303rLwLJ55
l9/MlxmbGBmviohR8umIyWTEkE7pNDMUmWWOeRZYZIllVlhljXU22GSLbXbY
ZY99DjjkiBLHnJBIRdRSRz0NNNNCK2000kSGfgbIMUiWJCn6SNNDL52000E3
XVRs/vHLD9988ckH77zxygvPPPHIA/fcccsN11xxyQXnnHFKmRq/DlNNgX8T
0j4A
       "],
       VertexColors->None], 
      Line3DBox[{7567, 5798, 7498, 5817, 5818, 5819, 5820, 5821, 5822, 5823, 
       5824, 5825, 5826, 5827, 5828, 5829, 5830, 5831, 5885, 5886, 5887, 5888,
        5889, 5895, 5896, 5897, 5898, 5894, 5892, 5893, 5891, 5890, 5866, 
       5865, 5864, 5863, 5862, 5861, 5860, 5859, 5858, 5857, 5856, 5855, 5854,
        5853, 7434, 7500, 7432, 7568},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0E0vAgAcx/F/5LFrqZBNDi500MnTuqrNZr0EL4AYTtqkxg2p10NXkzpp
w5vxOXz2Pf623/rpef0sEREndAsRm9mIY93SbUrsUGaXPfY54JAKR1Sp0eCC
S6645oZbmtzR4p5kLmKGBFNMM8sc86RYYJEiG2TJsUqeZVZYIk2GNQr82fjl
hwnfjBnxxZBPPhjwzht9erzywjNPPPJAhzZpP9VJ0eMfPO8mKA==
       "],
       VertexColors->None], 
      Line3DBox[{7570, 5928, 7502, 5940, 5941, 5942, 5943, 5944, 5950, 5976, 
       5977, 5978, 5979, 5980, 5984, 5985, 6003, 6009, 6010, 6011, 6014, 6015,
        6140, 6141, 6142, 6143, 6144, 6132, 6133, 6134, 6138, 6139, 6137, 
       6135, 6136, 6163, 6161, 6162, 6160, 6159, 6100, 6099, 6098, 6097, 6096,
        6090, 6062, 6061, 6060, 6059, 6058, 6054, 6053, 6033, 6026, 6025, 
       6024, 6021, 7445, 7507, 7436, 7572},
       VertexColors->None], 
      Line3DBox[{7573, 7437, 7503, 7440, 5970, 5971, 5972, 5974, 5981, 5982, 
       5983, 5992, 5994, 5995, 5998, 5999, 6118, 6119, 6122, 6120, 6121, 6130,
        6131, 6125, 6126, 6129, 6128, 6127, 6070, 6069, 6068, 6067, 6064, 
       6057, 6056, 6055, 6044, 6042, 6041, 6038, 6037, 7508, 5929, 7575},
       VertexColors->None], 
      Line3DBox[{7574, 7438, 7504, 7441, 5973, 5975, 5986, 5987, 5988, 5993, 
       5996, 5997, 6116, 6117, 6112, 6113, 6114, 6115, 6124, 6123, 6066, 6065,
        6063, 6051, 6050, 6049, 6043, 6040, 6039, 7509, 5930, 7576},
       VertexColors->None], 
      Line3DBox[{7577, 5931, 7505, 7442, 7443, 5989, 5990, 5991, 6108, 6109, 
       6110, 6111, 6052, 6048, 6047, 6046, 6045, 7510, 7439, 7578},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0LsuAwAYhuHfXdTQoaPTYu1BogvpQdKhlqrWBXBBpQyOGwZaFI0etGYS
Q+tWPMOTd/3ypQ6OKocLEVGllYxYT0TsalozZMmxwSZ5ChQpUabGHnX2aXDL
Hfc80KHLBwOGjBhzvBhxQptTzrjhnAsuueKaAUNGjOnyxDOPdOjzzitv9Hhh
hzIlihTYZoscWTKkWWOVFZZZ4s/WOTN++eGbL6ZM+CTlvyYJ2vwDK8831Q==

       "],
       VertexColors->None], 
      Line3DBox[{7580, 7446, 7512, 7455, 6212, 6213, 6214, 6216, 6223, 6224, 
       6225, 6226, 6270, 6271, 6273, 6319, 6323, 6324, 6325, 6331, 6333, 6334,
        6337, 6338, 6550, 6551, 6555, 6553, 6554, 6561, 6562, 6563, 6544, 
       6545, 6546, 6547, 6580, 6581, 6582, 6575, 6576, 6579, 6578, 6577, 6471,
        6470, 6469, 6468, 6465, 6458, 6457, 6456, 6455, 6411, 6410, 6408, 
       6368, 6364, 6363, 6362, 6355, 6353, 6352, 6349, 6348, 7522, 6195, 7583},
       VertexColors->None], 
      Line3DBox[{7581, 7447, 7513, 7456, 6215, 6217, 6218, 6252, 6266, 6267, 
       6269, 6272, 6278, 6279, 6281, 6306, 6330, 6332, 6335, 6336, 6548, 6549,
        6552, 6514, 6515, 6538, 6539, 6540, 6541, 6542, 6543, 6532, 6533, 
       6574, 6573, 6572, 6467, 6466, 6464, 6463, 6429, 6415, 6414, 6412, 6409,
        6403, 6402, 6400, 6377, 6356, 6354, 6351, 6350, 7523, 6196, 7584},
       VertexColors->None], 
      Line3DBox[{7585, 6197, 7514, 6247, 6248, 6251, 6253, 6255, 6268, 6274, 
       6275, 6277, 6280, 6305, 6307, 6309, 6316, 6318, 6503, 6505, 6511, 6512,
        6513, 6534, 6535, 6536, 6537, 6531, 6529, 6530, 6528, 6527, 6434, 
       6433, 6430, 6428, 6426, 6413, 6407, 6406, 6404, 6401, 6378, 6376, 6375,
        6369, 7458, 7524, 7449, 7589},
       VertexColors->None], 
      Line3DBox[{7586, 6198, 7515, 6249, 6250, 6254, 6261, 6262, 6264, 6276, 
       6300, 6302, 6304, 6308, 6315, 6317, 6502, 6504, 6507, 6508, 6509, 6510,
        6521, 6522, 6523, 6524, 6526, 6525, 6432, 6431, 6427, 6420, 6419, 
       6417, 6405, 6383, 6381, 6379, 6372, 6370, 7459, 7525, 7450, 7590},
       VertexColors->None], 
      Line3DBox[{7587, 6199, 7516, 6256, 6257, 6259, 6263, 6265, 6289, 6301, 
       6303, 6310, 6312, 6314, 6499, 6500, 6501, 6506, 6496, 6497, 6520, 6517,
        6518, 6519, 6425, 6424, 6422, 6418, 6416, 6392, 6382, 6380, 6374, 
       6371, 7460, 7526, 7451, 7591},
       VertexColors->None], 
      Line3DBox[{7588, 6200, 7517, 6258, 6260, 6283, 6288, 6290, 6292, 6296, 
       6311, 6313, 6498, 6486, 6487, 6494, 6495, 6492, 6493, 6516, 6423, 6421,
        6398, 6393, 6391, 6389, 6385, 6373, 7461, 7527, 7452, 7592},
       VertexColors->None], 
      Line3DBox[{7593, 6201, 7518, 6282, 6284, 6286, 6291, 6294, 6297, 6299, 
       6483, 6484, 6485, 6489, 6490, 6491, 6399, 6397, 6395, 6390, 6387, 6384,
        7462, 7528, 7454, 7595},
       VertexColors->None], 
      Line3DBox[{7594, 7453, 7519, 7520, 6285, 6287, 6293, 6295, 6298, 6482, 
       6480, 6481, 6488, 6396, 6394, 6388, 6386, 7463, 7530, 7529, 6202, 7596},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0DlOggEUhdEHugkxFrS2bsCBQgEboxQIKqgR+BkqC00s1PWYuBEcGloG
E200TBvwFCdfeZObrfeOuqmIKPGyETFYi0h0qCPGTPjimx+mzJizIDIRKdKs
sMoxJ5QoU6HKDQ2atEjYXo/YYZc9chyyzwF5ChRp0KRFQpUzzjmlwjVX1Lmk
xgVLWwvmzJjyxy8TxowY8skH77zR55knHnngnjt6dOnQZst/t2zyyj8YrjgJ

       "],
       VertexColors->None], 
      Line3DBox[{7598, 7464, 7532, 7473, 6632, 6633, 6634, 6636, 6643, 6644, 
       6645, 6646, 6690, 6691, 6693, 6739, 6743, 6744, 6745, 6751, 6753, 6754,
        6757, 6758, 6970, 6971, 6975, 6973, 6974, 6981, 6982, 6983, 6964, 
       6965, 6966, 6967, 7000, 7001, 7002, 6995, 6996, 6999, 6998, 6997, 6891,
        6890, 6889, 6888, 6885, 6878, 6877, 6876, 6875, 6831, 6830, 6828, 
       6788, 6784, 6783, 6782, 6775, 6773, 6772, 6769, 6768, 7542, 6615, 7601},
       VertexColors->None], 
      Line3DBox[{7599, 7465, 7533, 7474, 6635, 6637, 6638, 6672, 6686, 6687, 
       6689, 6692, 6698, 6699, 6701, 6726, 6750, 6752, 6755, 6756, 6968, 6969,
        6972, 6934, 6935, 6958, 6959, 6960, 6961, 6962, 6963, 6952, 6953, 
       6994, 6993, 6992, 6887, 6886, 6884, 6883, 6849, 6835, 6834, 6832, 6829,
        6823, 6822, 6820, 6797, 6776, 6774, 6771, 6770, 7543, 6616, 7602},
       VertexColors->None], 
      Line3DBox[{7603, 6617, 7534, 6667, 6668, 6671, 6673, 6674, 6688, 6694, 
       6695, 6697, 6700, 6725, 6727, 6728, 6736, 6738, 6923, 6925, 6931, 6932,
        6933, 6954, 6955, 6956, 6957, 6951, 6949, 6950, 6948, 6947, 6854, 
       6853, 6850, 6848, 6847, 6833, 6827, 6826, 6824, 6821, 6798, 6796, 6795,
        6789, 7476, 7544, 7467, 7607},
       VertexColors->None], 
      Line3DBox[{7604, 6618, 7535, 6669, 6670, 6676, 6681, 6682, 6684, 6696, 
       6720, 6722, 6724, 6731, 6735, 6737, 6922, 6924, 6927, 6928, 6929, 6930,
        6943, 6944, 6945, 6940, 6941, 6946, 6852, 6851, 6845, 6840, 6839, 
       6837, 6825, 6803, 6801, 6799, 6792, 6790, 7477, 7545, 7468, 7608},
       VertexColors->None], 
      Line3DBox[{7605, 6619, 7536, 6675, 6677, 6679, 6683, 6685, 6709, 6721, 
       6723, 6729, 6732, 6734, 6919, 6920, 6921, 6926, 6916, 6917, 6942, 6937,
        6938, 6939, 6846, 6844, 6842, 6838, 6836, 6812, 6802, 6800, 6794, 
       6791, 7478, 7546, 7469, 7609},
       VertexColors->None], 
      Line3DBox[{7606, 6620, 7537, 6678, 6680, 6703, 6708, 6710, 6712, 6716, 
       6730, 6733, 6918, 6906, 6907, 6914, 6915, 6912, 6913, 6936, 6843, 6841,
        6818, 6813, 6811, 6809, 6805, 6793, 7479, 7547, 7470, 7610},
       VertexColors->None], 
      Line3DBox[{7611, 6621, 7538, 6702, 6704, 6706, 6711, 6714, 6717, 6719, 
       6903, 6904, 6905, 6909, 6910, 6911, 6819, 6817, 6815, 6810, 6807, 6804,
        7480, 7548, 7472, 7613},
       VertexColors->None], 
      Line3DBox[{7612, 7471, 7539, 7540, 6705, 6707, 6713, 6715, 6718, 6902, 
       6900, 6901, 6908, 6816, 6814, 6808, 6806, 7481, 7550, 7549, 6622, 7614},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwN0LsuAwAYhuHfJWBUqiYSXEDX3kDTUMcauhSlh4HBUhI1oY0V1yJCoyYS
p+hWom6jz/DkXb98qWI1VxmJiCx3kxFHExENbegxJzQ545wLLmnR5oprbrjl
gUc6PNHlmRdeeeOdD1YSEasssUyeNdbZYItNChxwyC5lquyxT4UdSmxTp8Yi
C8wzxywzpJgmyRQJxhljlH/bBvzxyw99enzzxScZP52S5p4hWwkyeg==
       "],
       VertexColors->None], 
      Line3DBox[{7616, 7035, 7552, 7047, 7048, 7049, 7050, 7051, 7057, 7083, 
       7084, 7085, 7086, 7087, 7091, 7092, 7110, 7116, 7117, 7118, 7121, 7122,
        7247, 7248, 7249, 7250, 7251, 7239, 7240, 7241, 7245, 7246, 7244, 
       7242, 7243, 7270, 7268, 7269, 7267, 7266, 7207, 7206, 7205, 7204, 7203,
        7197, 7169, 7168, 7167, 7166, 7165, 7161, 7160, 7140, 7133, 7132, 
       7131, 7128, 7492, 7557, 7483, 7618},
       VertexColors->None], 
      Line3DBox[{7619, 7484, 7553, 7487, 7077, 7078, 7079, 7081, 7088, 7089, 
       7090, 7099, 7101, 7102, 7105, 7106, 7225, 7226, 7229, 7227, 7228, 7237,
        7238, 7232, 7233, 7236, 7235, 7234, 7177, 7176, 7175, 7174, 7171, 
       7164, 7163, 7162, 7151, 7149, 7148, 7145, 7144, 7558, 7036, 7621},
       VertexColors->None], 
      Line3DBox[{7620, 7485, 7554, 7488, 7080, 7082, 7093, 7094, 7095, 7100, 
       7103, 7104, 7223, 7224, 7219, 7220, 7221, 7222, 7231, 7230, 7173, 7172,
        7170, 7158, 7157, 7156, 7150, 7147, 7146, 7559, 7037, 7622},
       VertexColors->None], 
      Line3DBox[{7623, 7038, 7555, 7489, 7490, 7096, 7097, 7098, 7215, 7216, 
       7217, 7218, 7159, 7155, 7154, 7153, 7152, 7560, 7486, 7624},
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzlk2AmAABeA/YRV6sBjHu+eeLIBVOChTpFpCZhlDGzBkKDM7MGTOGJ+H
79x7zn257d29XT2REEKc7VgIfW0hDMp+OfDfSZBkiGFGGGWMFONMkGaSDFly
5JlimhlmmWOeBRYpsMQNt9xxT40nnnnhlQceifjYRJRWmmnhzVYn6D+ywS+f
vPPBN19cc8UlF5xzxiknHFOlwhGHHLBPmT12KbHFJhsUWWeNVVZYptOnJB3s
8AeZIkuj
       "],
       VertexColors->None], 
      Line3DBox[{7627, 7302, 7562, 7321, 7322, 7323, 7324, 7325, 7326, 7327, 
       7328, 7329, 7330, 7331, 7332, 7333, 7334, 7335, 7389, 7390, 7391, 7392,
        7393, 7399, 7400, 7401, 7402, 7398, 7396, 7397, 7395, 7394, 7370, 
       7369, 7368, 7367, 7366, 7365, 7364, 7363, 7362, 7361, 7360, 7359, 7358,
        7357, 7496, 7564, 7494, 7628},
       VertexColors->None]}}},
   VertexColors->CompressedData["
1:eJx0nPk7FFwUx5VUhIRC2SNbyZIScoqyVUjIlkLZElkiJWVNZUuikERolext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    "]],
  Axes->False,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  ImageSize->{360., 390.69293666342895`},
  Lighting->{{"Ambient", 
     GrayLevel[0.6]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]]},
  PlotRange->{{-3, 3}, {-3, 3}, {-3, 3}},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, Automatic, Automatic},
  ViewAngle->0.47030072394368955`,
  ViewPoint->{1.8390060250459621`, -2.6651805475941286`, 0.9822777044046707},
  ViewVertical->{0.19548958045573017`, -0.26781857590242514`, 
   0.9434283408584032}]], "Output", "Input",
 CellChangeTimes->{{3.6509298835491953`*^9, 3.650929883571908*^9}},
 CellID->211963738],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SliceContourPlot3D", "[", 
  RowBox[{
   RowBox[{"PotentialUniformDisk", "[", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], ",", 
   "\"\<CenterPlanes\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{
       RowBox[{"x", "<", "0"}], "||", 
       RowBox[{"y", ">", "0"}]}]}], "]"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650901046695985*^9, 3.650901075830052*^9}, {
  3.650901153994342*^9, 3.650901186440036*^9}, {3.650907505442649*^9, 
  3.650907513470635*^9}, {3.650929899233596*^9, 3.650929902192123*^9}},
 CellID->2037630118],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nXmcjmX7xh9jLNlFCVEhqWwVEjJDm7RJ3pQt2UP0luSVZcZSKGN5i0I7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   "], {{
     {RGBColor[0.2913888888888889, 0.40611111111111114`, 0.6477777777777778], 
      EdgeForm[None], 
      GraphicsGroup3DBox[{
        Polygon3DBox[{{2590, 1953, 2589}, {2592, 1954, 2591}, {2502, 1614, 
         2503}, {2500, 1610, 2501}, {2138, 389, 2139}, {2054, 4, 2052}, {2142,
          393, 2141}, {2261, 781, 2260}, {2055, 7, 2056}, {2355, 1256, 
         2354}, {2332, 1121, 2333}, {2352, 1255, 2353}, {2329, 1114, 2330}, {
         2257, 770, 2258}},
         VertexColors->None], 
        Polygon3DBox[{{2141, 393, 390, 2140}, {2259, 777, 770, 2257}, {2330, 
         1114, 1120, 2331}, {2053, 1, 7, 2055}},
         VertexColors->None], 
        Polygon3DBox[{{2591, 1954, 1955, 1953, 2590}, {2354, 1256, 1257, 1255,
          2352}, {2331, 1120, 1122, 1121, 2332}, {2140, 390, 391, 389, 
         2138}, {2501, 1610, 1613, 1614, 2502}, {2260, 781, 780, 777, 2259}, {
         2052, 4, 3, 1, 2053}},
         VertexColors->None]}]}, 
     {RGBColor[0.4652777777777778, 0.4672222222222222, 0.5455555555555556], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV0L1LlXEUwPGTevXeq2n4mpiFUEKJLzhIf0LYkmJaogTqIA2aooOh4Puk
tboYt81BcGhryES0Qp2KVBoD8Q+wxanPM3z5nnM453fO8zQMjXeP5UVEG/KR
TUfM800+ykS8Low45kM8FR/wW8ynIma4FPsGy7gQOXER1+Cf+DZ/x4jZH7yM
M7MrXIUrPdWcxkdxhj/Y/d5Rm3yOh+pnXI53bqvgBX0n3lnk2mxER5Fd/ER+
VBDRyqv4o2eHJ9EjnuBq85+9U8Nt8gv97dwl77wR8Yx/ImvvLz7FffFv7sey
ngFOIfl3BVxs96VvzPJd5Nxzj2e9u2XvHK/ruza7xr0YED/nXWx4KMeN+rbd
84Dv4JW4jkuSvXbVc0vyT9Wb+ZYdKbvKuEn+Rf1RMit/rF6X3GPmk9lKrpCX
qJfztL5Bt01xRv7X/Wl+oW/YbX1ciiWzxTyGUfWX/AbfxOO8hwP3f+X/mCI+
qA==
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNmweUVcXSRu/MDTN3yJIVJSfJoCiSB2ZIKjnnHESGoBJEQJISBck5iIA8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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwt1FlsVVUUxvEDt+2550IRECxjC9GYoEhbEFHjmz4YRRkEoUjRAFI0WgpG
4xC1lWJI1KJGxRQJaFDwRSOQoMZQ5rYMVowogiMozkMIaiJx+O3s+/A/e317
r73W2tMZPX/J9MbeSZLMRSlOpEkyTce2XJJsxVT2Xn2XamdiBibgpL7p2rdz
0TfMuQQX4yKMxU4+47MkOVWSJD/iJ0zI4ljwqcJo7OD3BW5gbxRrAyYHH77b
zXkPb2EM/RW/Kca28NmEG9lfp7HOUG/oD+M78urWtuNFdNBrsYr9JJbhJfpj
XGDO+bnov5NO5VlPv4KXkac/1P9f2Cg6h8P0+nyMvRrPYB39ZRprCrWFtYQ1
DTO/Tv2zMBtD6ZGYx56LWzGCruE7rriHYS93iVWrrS72h/Hd+j6SpyB2H/TD
EXpPGs8lnM9NGB9iiNkl9i50YCzdH3vNOZCLayyjy/EGew92h5j0mzjuQkws
S5KF6KIPWn43unAAG+QcJPcW9mZsxWD6Pr7zzb0N9biXzuvvb3wAmEnqU1VQ
gxhrsQ6j6JFYw25P41glXcD3avgBy8V7SLwVOMo+VhrrfDzk4HeSTz/z+uLc
EE+eVvmmJbHOSnoJOnslyR1YjEa6BL2Lb6AsQNdjpfE2rMI8+jNjx9CDw9gk
z8BCzFeOFAPoe9QzS7CZmIFl9HL0sI+Uxtpb6WZsZh/EIbTQM+WZK98cTMEM
ui4fa12EBZhNz8pHu75X9L+Znorr2DV4IOw3fQta6Ga0hrjhbchzvYVeg6ux
J5wv7mQ3YSkO0Z2Ywp5cFv33ZXH/wzm0oBkP0t1ZvCeL0ID9dC1OuncnSuI/
oCbcR/szyUY3YA4uQ7e+y7WLi/1hvEKN76p/G97BEPoc+1rKN4/T4ZzpzjTG
CLHqMBHnyXPGPf4Tf6CCPiTG/uL9Dff4VfOyLL7vv3LRfzC9Up2tWIBv+dyu
XZrFM/yXfQDX0h+I8X4xZoj9Gt8hWcx3Fr9jUBbvSE/RN8zZyO+otYwxfmEu
/ns+oY+hhl2di2Of0qOspRLDMRLb0/i/rCr2h/EOffvSuO664j86/KvDGlZg
Ib5J43raxPzH+Z/F33gqH+9HuCf3ow0D6RestZH/L+bdrX2eHmavJ9FXhrPC
CHp4IdpXpPHdZXQ73yXm/JrGGCFWdRb3rbsk/o/G0U/Ic0YNp3vFt9hEr+Hb
ZPy3NMYIsSrErKWvCueMoXQ532a1Pozl6Ec/y/9pLMJ3/Bq0mf5HjT+SRP8C
3Scf5zyWxP9CX/pz7fHiuw7v+/U0rjms/Wf2XdrnSmP8cD/CnTiVxlz/Aw7s
4mE=
         "],
         VertexColors->None], 
        Polygon3DBox[{{2341, 1196, 1170, 1127, 2024, 2334}, {2607, 2032, 1136,
          1435, 1448, 2428}},
         VertexColors->None]}]}, 
     {RGBColor[0.6391666666666667, 0.5283333333333333, 0.44333333333333336`], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0t9Pz3EUx/F39e1b3y9FKd/8ijaxIjYbxj/gx7JhiCtbarOxEqsLXAjF
GG11Z5Rxx8JmbLbyI2NKLjD5caeNjQsmLv16vMfFa89zzvuc8z7vz/lU1Ddv
bsoOIdRSDhXmh9CJBZhKhzCeDGEWLk6F8CgRQg3O5i/PC2EmLuGPiC/FLWo2
ZYWwFUfppcZPcZDusQfwNS100Rvso27xi3iZetmX8LBeLbGn/u3sm7khHMG3
zqrVvsNi6jJnET6gx2rH4j30kH0fz1Mr+wJWxT56VmM2demTE2enRm8cxlJ5
t/QswXIaZ8/BXHO8kpPAPBpjJ7E/9mJfw73y7nh7A+bz+/TPwwkakvMNr9Av
b7mKDbSMvQF3qbmtth4P8Y+Kp/V/wk6qvY4nnX2QcwLLaMBsGUw463FXLnbG
b6S2A787axP/gb/pFPsPHnf2Qs4xPPj/rnjnDPctstMMlvJ75aewlXbKacPV
MY+9Ckvos5wyXKDvJ/PMxWnq35s5P/1vN3FHG3GtvCq1LbiNX+8tddgUd8du
xhXxW7NX4mTqUDsp7pOG7PEupqldPIX7aUR+S7RjX/0P4Bn+T/GzeIOfMs8g
7uMPi5/GWn6N/PXYTR/ZPVho7q/yp2A5f7d/pjLGqd97C3Ce+i9mqMB18f1q
12Amfnc50+Pe6Bx7Km6X1+jeHZit73P9s3A+f0KfSnwmb4/4KBY5S9pFMf4F
yQhqvA==
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNV1lPVVcUPpfLuZx91TqPpA+2KohtYis4/YPGNlGw2iaNNkabNlbbxAsi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         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlPtvz2cUx5/v7fN5no/LFqxlitXQVoOFLXP5A6hLgsRlyYJUJagwVddk
hIyZbNMWiVuLLZOsVSQuDb1QLXqNS6Pul5lLR9ZSkf1is9fJ+f7wyvd5n3Oe
85znnOfzTc5cNn1p2BgzB2LwOmRMB7TDKyj3jRnjjOmDszxqzFkYjW62xrSy
8Qa0QBN6AfYM4kbBSMhCt2K/hL8eUiLG3EQ3Wt1TBxegBj3F6Z7PYBhMRjdy
9lj8SyAbxsBEp/4UGAIZouEidV2GBhiO/oO7PIQH8AhKyFXBOefIUQGH4Td0
ldUaqsPqq0R3gc3s2QpboDv6CGetIHcneXL4/R3dzar/e9gIAXqE0xpS8afB
BHQSeT8Oa1+lvxXkOE9sDbbasPanGn0QCqSGsPrOoZuIHcd6X7wP0o98q/kk
byX+lMCY8U77MSimsxqLvmW156kwFG6jP8C+m/UmKIXu6AR4w7oQiuAjdCk5
crnHG1/vLffvjf0F/raIxieih8IJ/GegFtLRPajHY99djzlAT3Rv+BxbGqRD
H/RX8mboRw1cgqXofvCYXv5pdAZd0UlQ7OscZZ590SugmT2N0AA56GVW89RB
PXyDLoSV9GkV5EER+jR1noTF8JK82fwmYq8gdyWUQwJ6udMZpsNMyHG67ygs
ghe+5phK7Hb25MNkzp2G7gl5cZv4eqB7wSnWT4zesT/6kNXZyoybyVeA/hGu
kOcavIOf0L9AETGF8bcg+yLUs5055MPPEEIvt9qPWjgDS9DvYRv+vIjGh4n7
ElsMfxQCGI3uGl/LdyPfzxHqySX2a+4+B+bCSvQ/xK4nz07YAVFs27Cd9fU/
Q/47fkDfRU+k1jXErIYM1m+trtfCKnlHaBvoO3kEj8EFul/ytMFT2Cr1Oj1v
V0Tv8x+2TJkn/tkwA+ahs6zevSykvvnoe9QyifN/jWg9UtcM7NPwz4JMmIkO
cfY1argHreCjX3PuBdY1UA2v0KnYG3z9T5L/pj3sDbBtokcb4ClxXdADsP9F
L9ugHT5BR7HfwH/L07yd5Itgu866xdPzw/INBVrDTU/jY+jA6R3kLvc5fzf5
nNPvdj8cAIseTuwdX3su/Za++079e2AveOhZVu+eFdJvcbb8R7C3g/PaIUqO
D9F9A53NQ/gCW5Lclf1XuetpOAEb0ZXg5O6QAFXofDiFvwyeQQH6KITxW0/j
j8tsnfrfwb9QjC5xun4f0/hS9DHwpDa4jX0LOtlqf1/C3zDQ6puW9yzvupSa
k6m5idhs9i2ChdCI3uw0Twtch+/Qa+Hb+CxlpuvQ9bBA3oSn59ehB3NGJ+c9
NzrnIehPYRfrnUZ9g9D/AyvO/UE=
         "],
         VertexColors->None], 
        Polygon3DBox[{{2341, 1128, 2025, 1129, 1198, 2342}, {2429, 1449, 1138,
          2033, 1137, 2428}},
         VertexColors->None]}]}, 
     {RGBColor[0.8130555555555555, 0.5894444444444444, 0.34111111111111114`], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV0ctLVVEYhvF1zvFY5sCJUNDAjmUD8TI8HmkkhJU26Q8Qr4NAEy8zaRho
iGANQmhi0CCtCC8VeAUHaiokOHciGAXeRUsxf3vw8LzrW99a+9t7pxrbnzyL
hxDSSOAgJ4S57BCyroVQfDWEU7Uy/qX+TX2b9zAv73NS34aczQ+tS5IhPOKn
qJab+Iq9FT0xfmW9pT7IdSiTazhu76eeBBd63p7npvgODuXbfIFeQyb1t8gT
sRAauAnf5WbOsvdcz4kck/vlBPdYz+tp41bMyR18F0fuL+JOrKp38UtnNs02
wG/wWx7iEWzLr/kLEmb+zAvOrPmQK/wD6/IS38Ku+wuiu7GhvsalOFfPcIXz
N9yZ4X/WL8x8xvetU+pVfA/X5TRP2Jt0zxgP4638jmeid5RneR8d7jngj87E
zDnGX5EnT/Es8uUZ/oQgj/JutCfv8DmW5TOuRbkZHnMzHsgt/BeLek75ved9
MMN09K/wx/fs40p7N/VXc4V1rnqa6zEuN0b/Gd1mPua4vj75v3wJ5NBdKQ==

         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJw1lEtIllEQho+a9h0jJVCydhZ0ocuqQsKCFqW5CtdBUlhReClzFdJK7UZQ
BG2Cym7mKkorgrxUUJSWQWBCJImFKZJdvCBaPS8zLR7+959zZs6cmTlf/t6q
0srUEMJumAcl6SEUw3YogqoYQim/u6ACXR5tXfv2ozszQngMD+EJ3E1CaCZg
EzSjN0JGSgjjxF6GPofPAL5f4CL6GzzKsDN01mi0eIo7jh7Etxu6oA/mw49g
8RS3kz157F0CXeiXnPGOs9/A88RyLPH8K6MhrfOq0W2QhW82PEAX4ZNN3EWw
03WEBLJgc2I5yLYF3cI5bfAaOmFftLqpfmXR9ml/hsfQvXX/TzAEmxKza121
6oUPxDmTxgXxn+D/MXQxtvWZIeTDQvYugALWDrJWA7VwCKbxecFdXsEceiV7
Jgk1BavQy+FXMJvWvnoM+Q6jT0XL7SM0RrNprRrG0WPR+qx+D6PXYpsh1iys
S+xX/78H69OI91c9VW9VM9VEdVWtO7DlspYD7egpbHWcdRwmE1tTb7J8j2zH
/b6/0RvwySHXXNgYLdda91fO1T6/ykG5aEY0K93wBz3ttVBNJuASMXekWk1U
m7/R9srnWbS50nz1wXv1JLEY8l2DPgBt3K0Vyl3fh3tuu4HtNn534Cb62v+3
kmr2W9iu8rsVVtPrCv534tcOh91Xe1s8xgj2IeiHAbiSav6Kqdj1idm1fgJ9
3c9UHOWid9Xh8XXOT2xHuHsjzCUWe9DfnmLUJPYeZWtAL6W2eV7/xelmG/Sc
GtF7Eru7alCGXsGdPnuuyk09y/UYBdFmVLMqH/n2JFZn1fttYkjrjeitzEID
udbDDDqN+L30qgdCpr0hvaWzkBJtX4P/l31btDso98Jo36wmr6F68dS/L5pD
zapi9vj8aDZ6/a298DOrffY0w0fhAjEKiXVZ/dD7glHuNgan0eejfQf05vT2
1KN+r3edzk/s26JvTKv3RnFPeo+e+TwrR+X6D6qQ1IE=
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlNtLlEEUwGfdXb/vM9KCJKkHW6igkowIQ6mgwtasIPoDolSo6KrlQ4SP
pV2eKogg6PZSViZbS9vFdbtA5O5agaBBJIERWaabWlqb9Tucefix85tvZvac
mTMTqjm47UCOMWY9BGGdZ0yIxlyYA2vxMphFuzFgzLhjTDH+jt8qJh7xG3MY
wrSb6X/PuKOMm+B7CD8Hn+n7BANwFm+x4z5AP5zC98NW2tUQhj34iGvMIdZu
gHrI4FvoL+V7JVRBHV5Of5bYM+D4jKnAb9Fvco0ZDOr/t+J/6D/OOqehj3i7
8XL6i2yuknMFvoD+MaaPwyjMx/sczVFy3Q0baG9i7FLmlAR1zyrxv4xt5vtJ
OAFZ/Lyn+UscEs8FiQVeEV8PxGEYv+jpd4nbB7fxJub3ktNTSMAxvB46bV8K
GvDXxLeGmK7AZVht85M8e+EtdOFP4CbtVkhAB56bp3FIPElw8AB02tjkWxD3
E88Zm5fkl4P78nROF7yBHPwaa16ycVyF6/gy+sccrSGppRXMDUot2PNtggC+
k7H3ySkCv9iKRbKfMIAPwldoweOuxp+ENDzHv9kx/fARYvxfDf33aEfFoRZP
ujqnG3oghQ/ZtWW+rPOQuXWuzon7dL/34Xtd9Zhdcxf+z9X9kHOXfKbwDrkz
7Ec++KEdj3h6rn7bH8WXuFpnUm+/oQSv9rSmpLak1jfjU5BiThpewqTcK3hA
+xHE4IvUn6dnkbTnmcW/e3qOcp4dMOTpvsr+/oQJWIyHPb0DIVvTG/GZ5FgA
+TAD7rIvbZ7mILlIrd7Bd3h6J0tt3NvxYtYctnlJfgvxDP0JG4fE8wN/DAW0
C6EIEp7+l/znNJgObfKeMH/E3nNZd57cU2i0b5C8RaP4C1fPNm3r45m4o3dC
alJqcxUspyYnHX2v5D2SdynC2Ki9HzegHV/pahwSjwtl0sfY2cwpDGo9yxv5
H0udvwc=
         "],
         VertexColors->None]}]}, 
     {RGBColor[0.9138888888888889, 0.6547222222222222, 0.33305555555555555`], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0UEo5GEYx/EXkSkuDm6KnCwH9rBCkg0X7UXOYg9212bm5iInDlJyUezZ
1UEmE4bStsO2bZTD3tTSbnaT2VWSaYx8/pnDr+/z+/2f532ft3/D28RQvDSE
0EJl9LIyhAJ2YX8shMbyEAaxl+rVr3GE+tSjeKTvxAEZfMXXytvxM/9d/gWH
i+cM4AN9rXAHvqMB+ViU65uzQAGnaL8khAns8a1OTzfm6NDsI36gN/JJ3NGX
clcSmyhn/zH8RqfyY3xRzKPvC2bOzM7jNe05M4stvuX1NONffkt+iff8rN1y
eE1xdRY3KOn8TeykGjt3RJmZarPbuEpX7lrDFfqjXsb1Yv4JF+lCvRTdSVVm
N/GAatTp2PMborfk8R+flOfxhk/Y5z/e8Rn5LU7zP+wzg+9pVz2OrfTojW14
XjznZ/Qv+LSej/ibT8l/4RPwIlTf
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkk1L1UEUh49aMhO1UXEhirVwY9bChYu4eglTI4igL+BLxKV8uTsXUbnQ
oJVt4n6EXhBBMe8iDSpUXAjuxE0ihmagKCEoltLz48ziged//jNnzpw51/ry
D4dKzawZLsB0MJshMAkf8Z5odueiWSc8wtvhKl4HWfwFa9ZKzNZhBK8nNkyi
av634O+JTZArC42XzIrErpSbXYZZ/GXwvcrxHD+EfJnZE9jFH8Nn/s1BDi9A
B7ly/N/G70IN/2rhHv6GnFucvQsFfIHYCutXYTn4nlzK/0u5WVNBLZUwj3+L
7op9xbtS/ipoDd4T9UZ30t1Uo3Ip507wHug+G/AK743eO/WwGz+HpXSezjqC
RXwZTvGz6K7Yib7JMUbuIfiD9wfvxRcYxK/DX97tHG6qHvYUdRfYxzPEKlL9
bcHvqLNVw3H0Hqh+9fwA34u+Vzm28bfRe6mejuOnrBkt85r+Be+JcuuMW/gA
ax6w9j48xV/DD/wZM9HM+2eiz45m6Db+IfVTMzeFv0vzopj+taX8egO9dT7l
n6W+3/gNYmfmPWjCP0Gx1N/8Oz4YvRbt0d4GathM7zMWnI00v5rF6eizqRmd
wX9GP0v7dbf/qEdy7Q==
         "],
         VertexColors->None], 
        Polygon3DBox[{{2611, 2042, 1146, 1501, 2443}, {2278, 871, 581, 2007, 
         2199}, {2245, 719, 716, 694, 2233}, {2154, 445, 443, 442, 2152}, {
         2121, 1968, 284, 282, 2119}, {2286, 878, 900, 899, 2296}, {2363, 
         1302, 1142, 2038, 2336}, {2097, 254, 251, 253, 2098}, {2181, 478, 
         480, 1975, 2598}, {2601, 2000, 575, 683, 2214}},
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwt0DsohWEcx/EHEcUi2RTZlMsmORa3RRaZCSEKm4XNRowus9XiHE46GF0X
ZbApt6LcYnA5Lvm8OcO376/n+b/P83veiv6JrvHsEEIJ8vCcH8JETggv/Ipx
+ZHfC0LYN/DJH9iT33gRd7khLPEK7uVlTuPQzDd/ISFfci9azfRwByrlbm50
x4/7q7kBxVkhxPgTMzqk+Qunyh5xbbRnvopr8CvXcZOzypwZ43qUyo3R/faS
vt3gOBLyOq9mOq9xHIV6rvMoOq2P8ADa5WHeQpGZJG+jWE7xkLNSOg9yX6Zb
1HEaZ9aneAy78mT+/xuitxzzIU7kA77I/KtnfsKO/MA3SMp3fItN+ZrncK7b
LC/gSp6P+mb+bRs3o1xu4T9XA0zK
         "],
         VertexColors->None]}]}, 
     {RGBColor[0.9416666666666667, 0.7241666666666666, 0.4191666666666666], 
      EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0LkuhGEUxvGDEDqJVmNuwBKNDFEQlcoSpURhmVgaUbkDURKl4AaGKWZQ
EtFJtJYRGjHoxtLw+5K3ePJ/zvad835dc2sTq40RkaMmemqLOG6J+MUdem2O
2McDqvNH+Jh6HnCjNeK2IWIT6+IL+S9cF5/LL+Ebrfh4DRdTvoD3+or67zKK
Sw45wRnxgF3T+J1mP3Av3bOLk5TjR3Eq9c/iNlX5LRw002FXHmtpVxWfqcS/
YLfan3fP44J43GwBe1I+q4+kXWN4Lb5x5w9eJZ/l+insGsa+5Hsxb6bT7BCe
Uru9ZayoVcxe4lnyZXynZe/9xGL654f4D0ljQEw=
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkbtKg0EQhefPr2E3lSJWGohiZyWWSghoISgpfIQQJGjQMhDFQuy09RlE
UUGIiGLpG0gqEbwSsLGwsPU7zBYHvr3MmTO7U42d9e2CmVXQELoJZj02rtAl
XEXjmdkYWoQP0DPcR134NpqNFM1G0R18wt4ytc3c7A0eoI3c11/BPeV9gc7h
PfSU/PbhmZLZS+Y91OsHtXP3kNdp8Fp5nAWv6af7h8E9dV5Ds3itsJ7IfAbN
0k331bMDV8jcYfDJYbOF6Jmbqd8nvMneGmd11IaP0Cu8S808/n+sH9P8D9Hv
6G6P9Ud0D3lphu/gmZVdb3wN14K/rfItBZdYmVfhreSnDK3oezoro3rwnuqt
P7iHp6NnU8Zj+D16FnnIqxp9Vs08V/I/U71m+IX/AS5yRCo=
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkD1qQkEUhY8Gf2JlrxYRbLIDC/WBrxBJZZNSfARMlWzCUtFGVyDY2DwV
4wLcgE0alYhEQbAzvsLKb8gUH+fOvefMXObJ+6x9hCUlIQLXR+kPbjCJSj9o
D7owgBOmPvqckFYxySE8hlFcatPfMe9Yv8l50IA65Jm9ou/wQt20M+NpkV+H
pC3MuTfH/UP6AT4fncIMNuCz1xk9wBGqZH0yGbIpqMT/vSazgCT+L+On//Yg
uez7jX/A2aWf5Y0yWgLHYuoCpJkV7TvmvV+zB/ft0QssqQP7Z+bv7oASMoU=

         "],
         VertexColors->None], 
        Polygon3DBox[{{2526, 1714, 2529, 2528, 1713, 2525}, {2284, 877, 2296, 
         2297, 720, 2246}, {2111, 256, 2098, 2107, 275, 2112}, {2232, 697, 
         2233, 2227, 692, 2229}, {2099, 255, 2096, 2097, 256, 2100}, {2464, 
         1513, 2456, 2467, 1526, 2466}, {2282, 876, 2285, 2286, 877, 2283}, {
         2153, 444, 2152, 2150, 255, 2099}, {2167, 467, 2166, 2154, 444, 
         2164}, {2389, 1337, 2388, 2374, 1314, 2387}, {2246, 720, 2247, 2245, 
         697, 2235}},
         VertexColors->None]}]}, 
     {RGBColor[0.9694444444444444, 0.793611111111111, 0.5052777777777777], 
      EdgeForm[None], 
      GraphicsGroup3DBox[{
        Polygon3DBox[{{2368, 1311, 2372}, {2099, 257, 2153}, {2246, 698, 
         2284}, {2283, 875, 2282}, {2391, 1339, 2402}, {2164, 466, 2167}, {
         2525, 1712, 2526}, {2229, 695, 2232}, {2460, 1518, 2462}, {2465, 
         1525, 2470}, {2387, 1336, 2389}, {2100, 257, 2099}, {2235, 698, 
         2246}, {2484, 1527, 2468}, {2466, 1524, 2464}, {2393, 1338, 2390}, {
         2534, 1707, 2524}, {2453, 1507, 2448}, {2112, 278, 2111}, {2527, 
         1711, 2549}, {2385, 1333, 2383}, {2522, 1709, 2521}, {2519, 1706, 
         2518}},
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkb1KQ2EMhmNtD197AeLkD3V0dBOktTgpCq7iUhGEgk5iEQdxdnBw8gqs
xRZBKd6G6KKCtIqgq4igi89LMjzwfklO8iZnsr6zup0zsynIQ69o9lsw+4Fr
9DKMoZskZ0pmc/Eehwp6KfEeMpuAFfQhPKLvoYk+oeaV2j4co+eJjZAbhQX0
C2wMm23CAH0KtZzHlHtLntO7j16nR41eVVhD38JfwT3L+x41dzF/H70Y/jSv
lhxpeagk96C3arRLK/p1MrMn9CWxK/z04Abdhi66CtMln6FZ2vkIXSb2HG/d
4iLq1UO9yvQ8yPs9ztADaDGrDe9Fv4H2bcAHeqvou2rnBvo8/o88yutDfK+8
bvMN3cz9f6E74V8e5L0ZfnWj3RQ1mffTLT+Tz5YH3b5ObDbuLS+NuL9mynsv
+W00Q7P+AQzZVOc=
         "],
         VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkLtLwlEUx7+ZWafd1R64NTUEYhBIbYFRURJttefq4OTs6hIRFhGl+CDo
HwlMtBfR7mQItfj5ce7wgfs59557HitnxYOLmKQkzMGlSd8cfmAEV3g1xMpx
6X9eWsXfoJ2QOtCCIb4DS7zbgAwc4u/Q5L4BXfjA72DC/S+M4RbfM8+L8lOQ
x9cWpRfq5WiwA40F6d48L8r/gwd8YN5DN9Tp4xXeDmeoD8/8keavV/P7qJ9H
6OGf5nmtMMsXnif3iZxlclOwi58Sz1FvE7Jwgh+Zz5kN8QJ+bO6ZsId9/Np8
l+Mw8020T/48n5W2matHrRpeN38zCvuv4ev0PeG+FPe9bBGbAoNwQN4=
         "],
         VertexColors->None], 
        Polygon3DBox[{{2165, 466, 2164, 2153, 257, 2113}, {2281, 875, 2283, 
         2284, 698, 2234}, {2234, 698, 2235, 2232, 695, 2231}, {2113, 257, 
         2100, 2111, 278, 2114}},
         VertexColors->None]}]}, 
     {RGBColor[0.9972222222222222, 0.8630555555555555, 0.5913888888888887], 
      EdgeForm[None], 
      GraphicsGroup3DBox[{
        Polygon3DBox[{{2515, 1703, 2514}, {2382, 1332, 2383}, {2517, 1704, 
         2518}, {2393, 1344, 2395}, {2234, 696, 2281}, {2114, 279, 2113}, {
         2385, 1335, 2390}, {2113, 279, 2165}, {2465, 1519, 2462}, {2472, 
         1528, 2470}, {2231, 696, 2234}, {2460, 1516, 2458}, {2392, 1335, 
         2386}, {2461, 1519, 2463}, {2522, 1708, 2523}, {2519, 1703, 2521}},
         VertexColors->None], 
        Polygon3DBox[{{2396, 1346, 1344, 2394}, {2395, 1344, 1346, 2397}, {
         2177, 2176, 2168, 2169}, {2516, 1704, 1346, 2396}, {2118, 2117, 2124,
          2125}, {2471, 1529, 1708, 2520}, {2384, 1332, 1149, 2613}, {2223, 
         2222, 2219, 2220}, {2397, 1346, 1704, 2517}, {2523, 1708, 1529, 
         2473}, {2469, 1528, 1529, 2471}, {2473, 1529, 1528, 2472}, {2340, 
         1151, 1516, 2459}, {2272, 2271, 2274, 2275}},
         VertexColors->None], 
        Polygon3DBox[{{2230, 696, 2231, 2222, 2223}, {2275, 2274, 2281, 696, 
         2230}, {2220, 2219, 2604, 2003, 2195}, {2612, 2044, 1149, 1332, 
         2382}, {2605, 2004, 2196, 2271, 2272}, {2116, 279, 2114, 2117, 
         2118}, {2458, 1516, 1151, 2046, 2339}, {2125, 2124, 2127, 1971, 
         2594}, {2179, 1972, 2595, 2176, 2177}, {2169, 2168, 2165, 279, 2116}},
         VertexColors->None], 
        Polygon3DBox[{{2463, 1519, 2465, 2470, 1528, 2469}, {2520, 1708, 2522,
          2521, 1703, 2515}, {2514, 1703, 2519, 2518, 1704, 2516}, {2386, 
         1335, 2385, 2383, 1332, 2384}, {2394, 1344, 2393, 2390, 1335, 
         2392}, {2459, 1516, 2460, 2462, 1519, 2461}},
         VertexColors->None]}]}, 
     {RGBColor[1, 0.95, 0.75], EdgeForm[None], 
      GraphicsGroup3DBox[{
        Polygon3DBox[{{2516, 1701, 2514}, {2461, 1517, 2459}, {2116, 281, 
         2169}, {2515, 1702, 2520}, {2469, 1522, 2463}, {2230, 690, 2275}, {
         2118, 281, 2116}, {2050, 2051, 1155}, {2392, 1341, 2394}, {2223, 690,
          2230}, {2384, 1334, 2386}},
         VertexColors->None], 
        Polygon3DBox[{{2177, 287, 289, 2179}, {2125, 287, 281, 2118}, {1701, 
         1343, 1342, 1700}, {1523, 1521, 1520, 1522}, {2195, 578, 688, 
         2220}, {2169, 281, 287, 2177}, {1700, 1342, 1155, 1521}, {1702, 1700,
          1521, 1523}, {1343, 1341, 1340, 1342}, {2396, 1343, 1701, 2516}, {
         2594, 289, 287, 2125}, {2220, 688, 690, 2223}, {2520, 1702, 1523, 
         2471}, {2471, 1523, 1522, 2469}, {2272, 688, 578, 2605}, {2275, 690, 
         688, 2272}, {2394, 1341, 1343, 2396}},
         VertexColors->None], 
        Polygon3DBox[{{2613, 2045, 1150, 1334, 2384}, {1521, 1155, 2051, 1154,
          1520}, {2459, 1517, 1152, 2047, 2340}, {2514, 1701, 1700, 1702, 
         2515}, {1342, 1340, 1153, 2050, 1155}, {2386, 1334, 1340, 1341, 
         2392}, {1520, 1154, 2049, 1152, 1517}, {2463, 1522, 1520, 1517, 
         2461}, {1340, 1334, 1150, 2048, 1153}},
         VertexColors->None]}]}}, {
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwt0s1L03EAx/HvStwqRxsddbBfK2VU2k4VEp3zUFB4iIGHLiIyh/gHRIhJ
XSS6Bd0ym9qD2pOVq+klyCDvDuyekP+Bry90ePH+/MZ+T2PJ3fqtiVQI4QlH
6aAzg54gSzcFEkrcZpg7VBlljBr1+B0XPEuZc1ziCle5xjg1JpniHvepuu+M
zvKAh4z4bE4fs0CDN6yQPhLCMU6Sp48yA1TYSodwUTf1grb0vH7XRL9pUZta
iOcfD2HD7rG/6oF7fNF/+lkfeZZ9e93+q5/0j/Y676O9F9/b/mC37TP2e3vX
Ltnv7GnXSByfdrzm+KbjouNV+4ZdiO9mD9k99lv7up2P723n9LVmNXGNV3aX
vRyfxW+/FJ9DF+N7OK9tN+Iz6Evd0QX9rS/0l87rtj7Xn/qDFs343fg5z3jK
IJep0M8pcmTcy+kh9f9/dAgx+EOC
       "],
       VertexColors->None]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0l1rkmEAx+E7C8qRgp51oKBHq1YHWyvXy2au99LSwYhAUT9AOwx2NugT
ZC/7KGNHI2pb7+VyM2tljqBv0S7p4OL3vx/0kefBTHOh8vBACKHFq8MhTERC
eK1ndF0ndUPP6qae0zea09GREN7aU/Y7Pa/v9YJ+0CdHQrhof7Qv6Sed1uO+
99mesU/YX+y8fdJu25ftMXvLbrlHwfmU81fnp86zzh37mX3F3raf21ftHfuF
fc3u2tf1m97Q0+7Rs2/a3/WW/tDbuqvLvnfH/mkX9ZeWtK939bfe04GWdU8r
unIwhFXWeEmXHn0G5A55N+QpcJ9j0RAeaJ0mDVKu1bRKhTIlimTJkB5+jiQJ
4sSG9/A7DWpUqVCmRJEsGdKkSJIgTsdzx/QoUSK0Xfvn2f7yZ/hOhu+Mxyyx
yCPqVJlnjvHI///RPg4vRwA=
       "],
       VertexColors->None]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0ktLVGEAx+F30ixtFa1Ey7QIWnVR90K7wIRxrzBaZpZmk5aXLhoRIipq
ICLMMPoVWgTtRGkVLaIPEN0sLa1Jy+z2vLR4+P0PHGbOrTLVlexMhBAe8WZP
CC2FIbzV8/pOL+h7bdMVPVQcwkX7g92uH/WSrmqHniwJ4ZvdY29qhfN77S37
sH3DPuWc745v2jX2L/uWXWv/tm/bYW8IQ7pLCxi2E3pX/zrnqN+6Y/+xj9iD
9o5dZQ/Y1X7rp+N++7S9bffZP7TSOdftvJ3Wr3pNv2i3nnD+hn3VXtcu/ayd
+kmv6Jpe1oe7Q5ghQ47HPGGRZcqLPAOOcZw6zrDkGs5qPed46rhBkzTSRDMp
WhhngimmyZBlnoX4G66ngSSNNNFMKr5TxplgimkyZOM7ca/zukCOg47ndJZ7
DDEQn118zvHZUUYpBSTY8f/b8brc7ySjjJCmmw7aOcB+9lFMPj7z+O3E9+X+
V+J3Fb+3+I04fq2veMkLnvOMHFnmmGWMUR5wn9bC/9/yP2+UZGQ=
       "],
       VertexColors->None]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
     {GrayLevel[0.2], CapForm["Butt"], 
      Line3DBox[{2054, 2052, 2053, 2055, 2056},
       VertexColors->None], 
      Line3DBox[{2076, 2075, 2074, 2073, 2072, 2071, 2070, 2069, 2068, 2078, 
       2077, 2060, 2059, 2062, 2061, 2058, 2057, 2063, 2064, 2067, 2066, 2065,
        2128, 2129, 2130, 2131, 2132, 2133, 2134, 2135, 2136, 2137, 2158, 
       2159, 2160, 2187, 2188, 2189, 2190, 2191, 2192, 2193, 2599},
       VertexColors->None], 
      Line3DBox[{2121, 2119, 2109, 2106, 2105, 2093, 2092, 2091, 2094, 2090, 
       2089, 2145, 2149, 2151, 2155, 2157, 2171, 2173, 2175, 2181, 2598},
       VertexColors->None], 
      Line3DBox[{2122, 2120, 2110, 2108, 2107, 2098, 2097, 2096, 2095, 2150, 
       2152, 2154, 2166, 2172, 2174, 2180, 2597},
       VertexColors->None], 
      Line3DBox[{2126, 2123, 2115, 2112, 2111, 2100, 2099, 2153, 2164, 2167, 
       2170, 2178, 2596},
       VertexColors->None], 
      Line3DBox[{2127, 2124, 2117, 2114, 2113, 2165, 2168, 2176, 2595},
       VertexColors->None], Line3DBox[{2139, 2138, 2140, 2141, 2142},
       VertexColors->None], 
      Line3DBox[{2179, 2177, 2169, 2116, 2118, 2125, 2594},
       VertexColors->None], 
      Line3DBox[{2186, 2185, 2184, 2183, 2182, 2163, 2162, 2161, 2156, 2148, 
       2147, 2146, 2144, 2143, 2088, 2087, 2083, 2084, 2085, 2086, 2079, 2080,
        2081, 2082, 2101, 2102, 2103, 2104, 2593},
       VertexColors->None], 
      Line3DBox[{2194, 2209, 2210, 2211, 2212, 2213, 2236, 2237, 2238, 2243, 
       2251, 2252, 2253, 2255, 2256, 2304, 2305, 2307, 2306, 2303, 2302, 2309,
        2308, 2295, 2294, 2292, 2291, 2293, 2606},
       VertexColors->None], 
      Line3DBox[{2195, 2220, 2223, 2230, 2275, 2272, 2605},
       VertexColors->None], 
      Line3DBox[{2196, 2271, 2274, 2281, 2234, 2231, 2222, 2219, 2604},
       VertexColors->None], 
      Line3DBox[{2197, 2273, 2276, 2282, 2283, 2284, 2246, 2235, 2232, 2229, 
       2221, 2218, 2603},
       VertexColors->None], 
      Line3DBox[{2198, 2277, 2279, 2287, 2285, 2286, 2296, 2297, 2249, 2247, 
       2245, 2233, 2227, 2225, 2217, 2215, 2602},
       VertexColors->None], 
      Line3DBox[{2199, 2278, 2280, 2288, 2289, 2290, 2301, 2300, 2298, 2299, 
       2254, 2250, 2248, 2244, 2242, 2228, 2226, 2224, 2216, 2214, 2601},
       VertexColors->None], 
      Line3DBox[{2200, 2314, 2315, 2316, 2317, 2318, 2319, 2320, 2310, 2311, 
       2312, 2313, 2325, 2326, 2327, 2328, 2324, 2323, 2322, 2321, 2270, 2269,
        2268, 2267, 2266, 2265, 2264, 2263, 2262, 2241, 2240, 2239, 2208, 
       2207, 2206, 2205, 2204, 2203, 2202, 2201, 2600},
       VertexColors->None], Line3DBox[{2258, 2257, 2259, 2260, 2261},
       VertexColors->None], Line3DBox[{2329, 2330, 2331, 2332, 2333},
       VertexColors->None], 
      Line3DBox[{2334, 2341, 2342, 2343, 2344, 2345, 2346, 2347, 2348, 2349, 
       2350, 2351, 2376, 2417, 2418, 2419, 2420, 2421, 2422, 2423, 2424, 2425,
        2426, 2427, 2570, 2571, 2572, 2573, 2574, 2575, 2576, 2577, 2578, 
       2579, 2568, 2569, 2587, 2588, 2586, 2584, 2585, 2583, 2582, 2581, 2580,
        2513, 2512, 2511, 2510, 2509, 2508, 2507, 2506, 2505, 2504, 2479, 
       2438, 2437, 2436, 2435, 2434, 2433, 2432, 2431, 2430, 2429, 2428, 2607},
       VertexColors->None], 
      Line3DBox[{2335, 2358, 2359, 2364, 2369, 2370, 2373, 2379, 2398, 2400, 
       2403, 2409, 2413, 2415, 2537, 2535, 2536, 2541, 2542, 2543, 2555, 2556,
        2557, 2552, 2553, 2558, 2497, 2496, 2491, 2486, 2485, 2482, 2476, 
       2457, 2455, 2452, 2446, 2442, 2440, 2610},
       VertexColors->None], 
      Line3DBox[{2336, 2363, 2365, 2367, 2371, 2374, 2388, 2399, 2401, 2407, 
       2410, 2412, 2531, 2532, 2533, 2540, 2528, 2529, 2554, 2548, 2550, 2551,
        2492, 2490, 2488, 2483, 2481, 2467, 2456, 2454, 2447, 2445, 2443, 
       2611},
       VertexColors->None], 
      Line3DBox[{2337, 2439, 2441, 2449, 2450, 2451, 2474, 2475, 2477, 2478, 
       2480, 2493, 2494, 2495, 2498, 2499, 2559, 2560, 2563, 2562, 2561, 2567,
        2566, 2565, 2564, 2546, 2545, 2544, 2539, 2538, 2416, 2414, 2406, 
       2405, 2404, 2381, 2380, 2378, 2377, 2375, 2362, 2361, 2360, 2357, 2356,
        2608},
       VertexColors->None], 
      Line3DBox[{2338, 2444, 2448, 2453, 2464, 2466, 2468, 2484, 2487, 2489, 
       2547, 2549, 2527, 2526, 2525, 2524, 2534, 2530, 2411, 2408, 2402, 2391,
        2389, 2387, 2372, 2368, 2366, 2609},
       VertexColors->None], 
      Line3DBox[{2339, 2458, 2460, 2462, 2465, 2470, 2472, 2473, 2523, 2522, 
       2521, 2519, 2518, 2517, 2397, 2395, 2393, 2390, 2385, 2383, 2382, 2612},
       VertexColors->None], 
      Line3DBox[{2340, 2459, 2461, 2463, 2469, 2471, 2520, 2515, 2514, 2516, 
       2396, 2394, 2392, 2386, 2384, 2613},
       VertexColors->None], Line3DBox[{2353, 2352, 2354, 2355},
       VertexColors->None], Line3DBox[{2500, 2501, 2502, 2503},
       VertexColors->None], Line3DBox[{2589, 2590, 2591, 2592},
       VertexColors->None]}}},
   VertexColors->CompressedData["
1:eJx0m2k4lV/Y9s2aS0mTypyiiRJKZwOKiqSQsaSihAxFlJJKIgpFmUkyNkgo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    "]],
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  ImageSize->{360., 389.12678246347605`},
  Lighting->{{"Ambient", 
     GrayLevel[0.6]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]]},
  PlotRange->{{-3, 3}, {-3, 3}, {-3, 3}},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, Automatic, Automatic},
  ViewAngle->0.47030072394368955`,
  ViewPoint->{1.7761647996198415`, -2.5898526082052795`, 1.2601198642842348`},
  
  ViewVertical->{0.19083087708902277`, -0.17105857755599524`, 
   0.9666036102735981}]], "Output",
 CellChangeTimes->{3.650907661936936*^9},
 CellID->1778441594]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non uniform disk potential", "Subsection",
 CellChangeTimes->{{3.6509104066571407`*^9, 3.650910414015298*^9}},
 CellID->341284266],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialRing", "[", 
   RowBox[{"a", ",", "r", ",", "\[Theta]", ",", 
    RowBox[{
     FractionBox["3", 
      RowBox[{"2", "\[Pi]", " ", 
       SuperscriptBox["r0", "2"]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["a", "r0"], ")"}], "2"]}]]}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{3.650910440059661*^9},
 CellID->35837525],

Cell[BoxData[
 FractionBox[
  RowBox[{"12", " ", 
   SqrtBox[
    RowBox[{"1", "-", 
     FractionBox[
      SuperscriptBox["a", "2"], 
      SuperscriptBox["r0", "2"]]}]], " ", 
   RowBox[{"EllipticK", "[", 
    FractionBox[
     RowBox[{"4", " ", "a", " ", "r", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["r", "2"], "+", 
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
  RowBox[{"\[Pi]", " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      SuperscriptBox["a", "2"]]}]], " ", 
   SuperscriptBox["r0", "2"], " ", 
   SqrtBox[
    RowBox[{"1", "+", 
     FractionBox[
      RowBox[{"2", " ", "a", " ", "r", " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["r", "2"]}]]}]]}]]], "Output",
 CellChangeTimes->{3.650910441764195*^9, 3.650910477066299*^9},
 CellID->199229031]
}, Open  ]],

Cell["Thus define", "Text",
 CellChangeTimes->{{3.6509104799743547`*^9, 3.650910481485075*^9}},
 CellID->515318344],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"r_", ",", "r0_"}], "}"}], ",", "\[Theta]_"}], "]"}], ":=", 
  RowBox[{"Quiet", "@", 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"12", " ", 
       SqrtBox[
        RowBox[{"1", "-", 
         FractionBox[
          SuperscriptBox["a", "2"], 
          SuperscriptBox["r0", "2"]]}]], " ", 
       RowBox[{"EllipticK", "[", 
        FractionBox[
         RowBox[{"4", " ", "a", " ", "r", " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["r", "2"], "+", 
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "]"}]}], 
      RowBox[{"\[Pi]", " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          SuperscriptBox["r", "2"], 
          SuperscriptBox["a", "2"]]}]], " ", 
       SuperscriptBox["r0", "2"], " ", 
       SqrtBox[
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"2", " ", "a", " ", "r", " ", 
           RowBox[{"Sin", "[", "\[Theta]", "]"}]}], 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["r", "2"]}]]}]]}]], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "0", ",", "r0"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.650895087553069*^9, 3.6508951665150642`*^9}, 
   3.6508990189751797`*^9, {3.6509105026707363`*^9, 3.650910521736309*^9}, 
   3.6509715562358103`*^9},
 CellID->342221411],

Cell[TextData[{
 "This can be expressed in terms of the Cartesian coordinates as (for the \
scaled case of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r0", "=", "1"}], TraditionalForm]]],
 ":"
}], "Text",
 CellChangeTimes->{{3.6508952108699713`*^9, 3.650895218836524*^9}, {
   3.650895272260508*^9, 3.650895289978009*^9}, {3.650895854773468*^9, 
   3.650895871451096*^9}, 3.650973185953906*^9},
 CellID->754048011],

Cell[BoxData[
 RowBox[{
  RowBox[{"PotentialSqrtDisk", "[", 
   RowBox[{"{", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
  RowBox[{"PotentialSqrtDisk", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"], "+", 
        SuperscriptBox["z", "2"]}]], ",", "1"}], "}"}], ",", 
    RowBox[{"ArcTan", "[", 
     RowBox[{"z", ",", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["x", "2"], "+", 
        SuperscriptBox["y", "2"]}]]}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.650895883511196*^9, 3.650895930537702*^9}, {
  3.6509105069919977`*^9, 3.6509105083361177`*^9}},
 CellID->983919930]
}, Open  ]],

Cell[CellGroupData[{

Cell["Non uniform disk graphs", "Subsection",
 CellChangeTimes->{{3.65096999836693*^9, 3.650970001664119*^9}},
 CellID->759531565],

Cell["Plot it on the z-axis", "Text",
 CellChangeTimes->{{3.6509105302283077`*^9, 3.65091054091492*^9}},
 CellID->1549977545],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PotentialSqrtDisk", "[", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{3.650910556214006*^9},
 CellID->1504411512],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1mHk0FHzcxW1jN8PI9pAshRBFiUrfXyKptKFURBQekuVJ0iIiZSlZkyWJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.4},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6509105584784317`*^9},
 CellID->1601156074]
}, Open  ]],

Cell["Compare it to the uniform case:", "Text",
 CellChangeTimes->{{3.650910563027446*^9, 3.650910567825799*^9}, 
   3.650910611985907*^9},
 CellID->512555161],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"PotentialSqrtDisk", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}], ",", 
     RowBox[{"PotentialUniformDisk", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650910556214006*^9, 3.65091059931322*^9}},
 CellID->957682810],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1mHk0FHzcxW1jN8PI9pAshRBFiUrfXyKptKFURBQekuVJ0iIiZSlZkyWJ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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1l3k01PsfxseYsc98u5JySyEhlK7spfcnJLqWikpkrRsl2RUhRYuyFHLt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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.4},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650910602604644*^9},
 CellID->1417996537]
}, Open  ]],

Cell["\<\
Thus there is very little difference between the two potential \
configurations. \
\>", "Text",
 CellChangeTimes->{{3.6509303939661694`*^9, 3.650930460571165*^9}},
 CellID->753462768],

Cell["\<\
Comparing their relative difference shows a maximum of about 17% near z=0:\
\>", "Text",
 CellChangeTimes->{{3.650930463285274*^9, 3.65093048458243*^9}, {
  3.6509305198909616`*^9, 3.6509305581439753`*^9}},
 CellID->1121960919],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"PotentialSqrtDisk", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}], "-", 
     RowBox[{"PotentialUniformDisk", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}]}], 
    RowBox[{"PotentialUniformDisk", "[", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "z"}], "}"}], "]"}]], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "4"}], ",", "4"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.650930500252075*^9, 3.6509305084934397`*^9}},
 CellID->1435236552],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw1mWc4FX7Yx8/hkKzTjoysShShRMN9KlklZWUWWois8LePjLJXtqxjZq/M
/I5dEgkZ2Xuvo2Pr6bmu53l1X58X93W/vL+f68trZKH6jAaDwXhjMZj/nSJw
bPbvXzyZvk8B09hoDOqmZ95tbuHJM/xCh++3GoNjuNRpyh88eezB8cCBLmNo
mtMxmpzDk50SJOtpJozBICqhr6UbT+52bDS1ozWBkBXBb9F5eLJhwSFL3A0T
WCNdzZZ4/I+vsws0V5tABYPhqxfVrOSnm+e+2jeYgtv3X3M1hizkmh9zZ9ku
m8NMKvvxy5zM5OMnlzEtrRYgNKSwHz/ASGamhC30aVlBymHSWu+b/eRr26z3
/xOwgTrd5gAEDGS73malnMO2wJnAyRM1Qk+WUSnCXfa0hzu3dB06fOjIFkt9
ck6ajnBy+znxrCKOPO6rpt1t6QLzXS9SKm7hyHbS29dt3VygLN/4yx0ZHFn9
yXQNV6AL3H9ueuCVBI58P6euLTDLBYjt5omFXDiyhpnuydVJFxhNf02+ukpL
fiteGNb42BXS1N9g7sXSkp2rxVxXtN3gfO4HovUCDfncXUzdi3IiKHzWwBtM
05AX0n5xJdYQwaiFJV55jIZ8a9xGf/ArEaJmXSoFe2nIN3MXE836iIA784g6
WE9DPpRd0PFjmwh9Cdxmd+JoyGOhDh1V4A7eIQkPBe7QkNWFf87caXGH4ddJ
Ir8ysGRX/rTk5M034HrJVmGAhCVzPSkpfUDrAZxUBaPxeCz53EW97X0sHqBl
vxy++h5LRuV/zvryeEC7A+yyumPJD+9XTk7Ie0Ct68A3eW0s+VmrHDM2ygNS
3rGblO/Hkg/cYDq/ed0TTOJCSHGmGLJtrZZqerIXrDEo+Vx+hiHPdpWu6OV5
AdGWxuLnYwz5zh/iI64qL4i4Z3OFQQNDlt/xaavu8oJajEa7DWDIYt9N9L32
e8OJZ2x/lY5gyDo509+EbbwhXFemZNXpLwoqNXslqfIWtFy1+bP59pDg/Lts
wnkfYCJL1cew7aGMacsZ7DUfqMayPfNh3UOl/Rci2pR84JTXr7TnW7sI9+7r
62BjH1j1UxPi/bmLXmHZazJTfMA/Wlkswn0XJTjGp8qd9AVy8Q0gDu+ge93a
nQHcfmBD5Rl+9WsHSWfL3d8Q8YPTUhh3/ZYdVJd1ickK/CCgsrr2StkOYiKy
uAQY+IFO7VW5P0E7iOH+T5bXJD9Ya7ukbAo7qCZC/hD9OX8QnDurqx6/jbKx
9RFFCgFQ4vkzzDRsG+0ftY0O1guAm9xOLcR32yjnbv1vomUA6D1ouZ5jvY3C
mLtcYqMCILj0FQ+9/DYSnEvuqpwJgE2PoonSpS302E5YsjooEJo5r1ty3NhC
5ZEDd53nguDhp4kMMckt1GNPO7SBCYZxlcAReeEtJFpU3CnDHAx7b4ZUXx/d
QsEXLuXP8wWD+Iz7pe8zm6hWqam8/X4wxJQ0brmGbqIgupLF77nB8PLefa/R
sQ20HXZMcssmBPaULnQK924gfCjntAsxBELlD/Dbtm6ghaA8ZdaAEKgg/CDv
K99ABw9dfK2RFgIMEvd3zgVuoOIS7KZrbwikHb9vYy+1gXjIVZ7KN0NhdFjF
kDlgHRVgTu2qcoeB3YBovsabdZS2a6IeeC4MGPvwf+Pt19FwbWV4z5UwEOto
ixMzWkdC3kSBmIdhQGxQ6dG8vI7IxaMxHSFhwP1RRSVphIp6WPOCxfa/Bx0b
leuSklQk91+RzHlcOPj1fDCUOvePvThW1Q+HQ9X1ea8rfFTUPOy/5McXDtwM
Pq0yrFSUIbR6RPBGOIzE1T6Wn/yDVE6En+ZwCwfjxktvtCL+IHNOo/Td3XCw
Y+dscqSuoSkGVX5ZhkhIdzWdc55fQ64XRC86s0dCz1gZ3m10Dd0p9z/bKBQJ
V3I1tDxa11Bu4XmuYOVI2L0ZNOOXtoZqqhjz9sIiwdOMhvmD5ho6OXRLQFcg
CsLQ9H30iYIi/6ajz2rREO+MYZnJoqCA1h43JpNoyJBm+3ooiYJitH5tWrlG
Q3WR/I3nfhSkpnM43SczGqbT08RYDCioZu1zwxQmBmSCnx7S3U9B3Qt8Ta7F
MTBjMNxB1V1FVNElf94LcbDGtRHE82AVdU5P+7YqxMFeH/6uktwqMlQYORht
GAdHNKD+w4VVtJ0u/uxtWBzIKMYXy9KtIr/vlJ7vG3HwXkwvPDR3BblzcoUL
fv0AQNOjKYJdQQoslgLabxJg8syj6QPry6id7/pVgQ8JEKg87kCZX0b9JcdO
sZYlwGDUclxZzzIqZUw+AYsJ4Cq6f+xm/jL6+F8nB4tIIlTpXbF4+HgZmRnr
5S3EJ8LrV9J4rNMSSrO1pnsakAT15bfFG58vIQelNsxoXBIcoVPV8FNdQgIs
5+Sts5OgKNY09qjQEoJdsRPN35Jg9UvsGaHeRbQ8k5qmzZQMFvx7oHZ5EY3j
PsrgA5PBtKfWMpUyj15K3woLSyaBeYdhXfnAPJryJnod+EQCy1bMsdamecSp
UEWb/pUE9vUyldTYeWTiSZLhXSGBZ34FnYLsPPqy57p270YKxL8rjJl9P4ci
NCZ1CidToEMquV5UchZprMk2f5ZLg18SN47L8syi29S9+Er9NOgTGTbRYpxF
k+wMd3pep8GwADfefXAGPVQqH3tFSoPFAzHaP71nUGBG3o1jNOnAMBOy+Lp7
GjnNG0zbN6TDtWh3tor/ptC4Rpfz1LNMUNYJirz4ZAr1oKuVicRMeMTx4Vie
8hS6vRra7RKbCW4fyo6k8E2hZOZ0l5T2TKhNWjoQ2DKJgo4ZaGXCR5D/qL/f
iGcSTdjsYWr4skC1Unpr/5dxZJlDulxCnwNPnOUdPAvHEcNd7zOap3Pg9XWN
jb24cXS46xwPn1wOhCNLKsVqHBlV8Jy65p0DPXXpqwMc42i99rKBG0Mu6Lcc
nSuwGEMMUQwFjkfzwHhg5bf28VFkd2+62TczH4os+unkaEfRQxp/SYbKfNjD
NomKL42gs24v/8a25MP703EejE0jKKZqH/e+5XwgW8gJV9qNII49na+LlwuA
jSbWkfPXMCpbKWHlbimAYOV34tVnhxDvz1H6TvoiOG2t7x2BHULOn8h0WhxF
UBUh3veqdxClKI7cpIoWwfRQv/tJn0Ek4Oy87a5dBARrsXbi9AAyD2Om68sp
guWIPotb6f1Ib339S6ZuMagMn8v5ItCHXqc87CttKYG7T88YwGYvWnJoEPs+
WQJK07yHP33vRcRhcVt67CeQXT7mQLLrRXT94fYTlz6BFAZ72/VLDxIWSLPV
SfoEfDxd/RJm3egE71VmRbdS+PPYhTmhqBOZ4Yw8PbTKYXXMHh1914nmvj+V
trIvh+UX1tb+ep1oN0yg6V1EOcxavOhxoOtE/4k1i0p2lcOg24MU9YcdSGZK
PiBIvQK+JJy6xrjdjqSZbPRf6FaCJIrtnvVsRSFpP0/j/D7DCWbcTLxEK2Kr
jL/BnfMZdrXMtlRHvyMfQXUxo7bPUL96jasSvqP6U7uixkeqQe30oJHf1jfE
/z6a2SqxGiwDeBaFLb+il/zy16PJCDJ1U3HmuvXI9qC/77mDNeCfwXKMl7Ee
2d3ae7UrUAOWf2zPdJXVIa+g7JIJqRqQCpJTun6sDilYH+CvflIDjbVTQSzt
NWjHrilOrvAfq6lL6gVUI3/RQ291tGtBeln/yeCTYkTb6saPq6gDs4qUGfv6
IlSxfETc+kcdxHvOWRw8VYQ+0WEXNibrgJbdwVl2sgBZP3bKuH+kHqI9BIU1
2nORpvLCHyHLeiCfDg9a6EtBQ61taVHnGuBUJV8cTxwJRUsvj0bJNoCvSn6G
mn4y4mmwrC/Ua4D05QgPG5SAZI+2FkoENEBrGO0009dw9OCt0a+XSw0QVcWN
tb4ThloZQ7uvMDSC0YT0iZ7vweiZvvsKP28jzJoPRymkvkVlr/KzZNUawRUd
+3bk4xvkFe303NmsEfj4YrZq9J3QSqi2datXIyg20D/WeWGFnCyp/VcSGoGc
9J3lW50+Oi02WFRT1ggKpL/kNGFZyDhokPS8oRE8k59Pla0bw6k4XPnPrEbg
yJXDy1rbQTZL5C3t0EZwpDPv0rhIhGjPZImt/xphskiS5CPqBQnPPJ1KHjeC
mhHG6rOQL/Bf82Lxk2uEiCFF79ADoWCfQOzxPNIILZ9EzM8Fvofzd33/ZGw3
AE3gYfVGpkjYW/8hMDXaABbXBni36ONAt5jLvaCgAVLulg3m7yWDX01wnPP9
BhD2WGIk2xZBtbMkJfB3HehdPcyQw1cM/MINkefr6sCfIkkX01YM+wprr8x8
rIPFJ65/bc5+ArxLqWCpYx0UyrKsnRkoA61i0sMsjjqQohceCJKthsZDAkqj
RrWQLFvUnedTD/vv5N5epquBCp7bmqeH60GNLTcNt0KGjp1fnXGSDXDC3+2G
RD8ZcCVb7T5jDZDwwqBpsJAMz07dbHlyvQmgt8XTzJAMgvTt5OMrX+G1s9Ld
OG8EeU2LmW5abbAyXaxEL/EZBh+xuIhmtoHyvXstNQc/AytV+P7QZhsUT862
pC5XgWToRacE5R8QT76lPplbBe/JVrx/F38A765csvz5KnjANW9eLfYTbK6c
WXwiVgnNv4bpr5d2wjiyCqVolIMRn+Xy+6FOiKw6vGQtXQ6b5n975/d1wWrf
j8mjXOUgSMedE6fVBbFs51gax8vgrYSu2s5mF8y5cf9tti0D2eCuhMpr3cDC
a0C5HV8KnxWbpa7U9sK3kRc31/d9gsVLF+soC73gVJbyX+RCCXDzxSvnsPeB
oHEqVbejBFy3rIx4rPqAhz32wIOEEiBksfvT8/yGroWGgkmpEqhnNhn66dIP
gzy61ZHWxdDcts/7pfQQpJ1IyerZK4StSqsDp54Nga2s4tuP04UglPE7ZjB4
CA6+r+KJ/VkIfsS8vAfTQ3DxqsVEd1ohpEVlzcfeGYZBzjtnK+8XgrGi2rE3
W8OQb1FTivtYAHMfk03uaY3CRyZZoQCrfKD2GdM0mI/CqvnwS3icDxgm0dir
HqPw9eb5AEblfDj2srJFMHcUnsTZjs0K5sNN4U5RWtwYtBQpSCTW5UFUFh21
NG8MlB3r/nDl54JstvEb3n0T4OuZxr/6MRtU+kU4ojgnwLAkwJbFPxt0mP8U
sYpPgHTu0AtV82ywMHOf2NabgH2egjJaF7Ih5lyMwq/CCQjnLbuoXJYFy9nf
WP0eTcJGZJh+ZttH+JAjErtWMgV3ZIP9k09kwitmNp/Nr1PgvXT1sixNJsi8
xNrvDUwBM0vPYdxsBgwKdqoy0E+DisOl6oHyDOBJcWDk1JyGFIqJ0ZpOBqTE
1Dvcok7DPR3+eb/kdMh+q6MVKjkLWPb1LM1/+cN58pZcpNIseKmrpVmLpYHy
7fMX4x7NwqNnqvgMzn95gwZzIM17FsrEG5MeUVLhgmtqU/mvWeg+U0aznpQK
xa+XJUfs5sCszf1kKW0qVBl6H71QOg8MaNg8pIcEvQcGOiZa5mGH+rbieAMJ
qEgiNHZ0HhyWj0iUFpDgAvcI6z7WBaiLdj50w48EpL6rDINPF8DS95K7M5DA
V21ly+/QIgwEnPezzk4Grdt6w1PmS1DwtK3NJDIJbNcK4z94LIGlXr1Su3cS
hJL266tFL0HA59ocZbskaMGW9lbXL0HSal2+p0YS8Ay9m2lmWQbZnrSH00eS
ICx2bDTp6TI8e21z1iwyERyPRHepHFqBe9qx2jIaCfCSVnPIinMF3gjL2JRf
SQC91UMzYadX4O/r5RFVngSAH/473VdWoC1qmn14Lh5w/kR+gycrkAlc7o89
4yGQ1tjKsngFDkOeZlvFByCtSrKEaK7Cwyf7hY2v/cvPI5RjRQarICa9ZWd0
Kg68f+TzdJmuwuTmcwM71jgwzhW6yO62ClxGQ29mh2NBxJRbNyl9FV4026lh
3sZC2QhdZsHGv31mA5GG7hho+dEp+zOGAu5tlPEu32j4pKcjVZNCAS5mp5NC
9tGQND0knJ9LgemqeImwJ9Fgh5k7FFhLAeNLPi6ka9HAcwE7ojhLgYn01YLy
pSiwDTrvUiO9BhmJXDOp2lHAfc+7JL9nDcwCT79ouxoJDH1MmQmja7DQbpwS
8M93KM9C4gLn14AyJJ6u/8+HvrjEeZhh/kAGtZ0kvh4BNjmFDwQF/4CvhR5L
blEEfGEeWkiw/wN8h4Uzu0UjwOrb5dNBx6iQVxdp/vRiOLz5S3HX5KXCXUbD
8Sn+cAiVyB/gOkcFu3QtGZd/PlccKxiefYMKhg8Erw2svoeNl+y4ZjMqyApH
f7UofA+uzNsjuDoqOP22ojRffA++ytUfHC3WISDyW3P17TCIdXfcvOG4DjcS
NidUL4dBdomkxn6vdcgiRgpSBcPgO1cec1TMOlTcPtxlwhwGBxYTnEoa1oH8
kCODtjMUIgPdtZc5NmDhoIrr8rNQSGmTPfr8ywbIWe+Mi7wPAbbY0NjXPzfg
G81OqN67EPB7Pszr0b8B4lpLjuHOIWC96ySSuLwBPN4v6wSfhcAN4SL5PrZN
ODrX0dAhGQKD3ryO90w24bG/lOyF/mBgk9kblGTcglqX8+rZIsHgn12ase/u
NpySLDj5aDgATvNci1zU3AaTda92+pYAIIeRvboMt4F7QvZ6XWkAUBy/GpHs
t+HY5t6IXVAA6Cj+5gTSNqhYv6hvhAA4O7kXbLe1DcZm75zXSP7QeFLOYSJj
B7ImtKZnHfwAG9apWEe3B1ILfPrkhz6w92HWaAW/B6Tr3Z6fFXxgKwPjfPLE
HvDKelo0SfvAWvW5XCeRPWAtCtfEcvrA5KznoYsP90C97OAC08g7aLl56XdK
xh5QE5WJlubvIGo13Mz7zl/YPe7czRn0Fo5nZjWlKGAIfK+yDIwoXnBo94Ri
sjKGwPrrL+7llBcwP/BtTlDFEFYcZw67/PYCmk3j7zF6GELJgYA7n+u8YFHh
dEewJYbw6CwDR857L2icThx0jsIQ+pdFz9yU8gI7wYg/6tMYQqdsezCttyf8
Sify073DEgTZq0YPXvGAcRWm3lcBWAJJLVRRV9QDVtfDA3tCsQRjTX2tHAEP
YFXI2sz6gCX8ZetWfIn3ALnprjbVIizh9xTljfLEGygVFHZOHMQSeNzb00ih
byAqs6vz6iUawu7u8WxdijvoZgl5W4/SEP5jItLd+kaEEyf3frhN0RAC+oL4
meuI0BfazhEwT0NYuPKU43cFEXQc/ytIp9IQZj+1v/H9SAQtxcb+fkZaQlOi
SqyILxHUpwwl5CVoCfXdaTpvlYhwlz96mMOTlrB7++1mbrwbXIvdd7XhFI7A
p11n0/rDBVifUMtlhHGE58K2//XUuMCI0IRU2QUcocfd9vVCoQt4V9RKZl3F
EV7lFQtKhbtAe6+LeMgDHOG64UFDFR0XeM62dlbfBUfIx7KLOk86Q3D4MNuf
ThxB+BXR25feGcaCyqkCnnSEU1rtjvZPHKGY322Ot5+e8OGpI/FLoD0Mk+zF
cVwMhFzvL+sEZVv4KXibSPlvP+G9/HGZJHEbOBlzm+fLZ0aCVeLRhiI3K4j4
qL0pvcNEkMEJgyajJXSgm71lGiyEwOOX00XumcPLmkdMXFGshG0nB9N79C/B
KKE3ouoDKyEmaD+hYscUdFzU+fRIrATzeVUuYYopKEgrScfmshJ0SEIjHMOm
IFBw6QV7AysBPb51XrrCFPoTmeuOrrIStBS0fz+2MIW7xApH1rt4Au+zPDm5
ARO49egSfe4DPOH+C6bAu50mcOVafojyQzzBm6Jt8/CbCQhupGb4G+EJi4+U
mZzKTQBnGfKL0QFPmM9/z74ZbgKfHxuL70vDE+LGNDGtKiZQfH3sc1oWnnCC
ylDCKW8C2RyPFOUK8AS5tvZfFjImENOtZuBVhSdk0HzV4D9vAnYq/15MB57g
hkWL1YwmYH6+gp3UgydkE9+WX6AxgadMl1JvDv67nzDdm7ZpDKpNQlXuM3iC
rdMYPnHaGBRTU+V5l/CEd4kVJ/mHjYHgwdNBXsMTKOypDh+7jeGyYewjgy08
ofpd0wnJNmP4vz6B8P99wv8ANbshvA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.650930514546719*^9},
 CellID->1100165321]
}, Open  ]],

Cell["\<\
And a visualization corresponding to those in the uniform case but with the \
representation of the charged disk inserted (the charged disk has some \
transparency here so that the contours can be seen through it:\
\>", "Text",
 CellChangeTimes->{{3.650930015181098*^9, 3.650930055114554*^9}, {
  3.650973945797256*^9, 3.65097397640189*^9}},
 CellID->846380207],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", "disk", "}"}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"disk", "=", 
     RowBox[{"revolutionDisk", "[", 
      RowBox[{".05", ",", ".5"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"Show", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SliceContourPlot3D", "[", 
       RowBox[{
        RowBox[{"PotentialSqrtDisk", "[", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], ",", 
        "\"\<CenterPlanes\>\"", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", 
          RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
        RowBox[{"RegionFunction", "\[Rule]", 
         RowBox[{"Function", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
           RowBox[{
            RowBox[{"x", "<", "0"}], "||", 
            RowBox[{"y", ">", "0"}]}]}], "]"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "disk"}], "\[IndentingNewLine]", "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.650901046695985*^9, 3.650901075830052*^9}, {
   3.650901153994342*^9, 3.650901186440036*^9}, {3.650907505442649*^9, 
   3.650907513470635*^9}, {3.650929899233596*^9, 3.650929902192123*^9}, {
   3.650930309330007*^9, 3.650930309481834*^9}, {3.650930367137465*^9, 
   3.650930370502963*^9}, {3.650930596121159*^9, 3.6509306190060377`*^9}, 
   3.650930656568931*^9, {3.650930887823114*^9, 3.650930926851273*^9}, {
   3.650931495176671*^9, 3.6509314999823112`*^9}, {3.650931810054625*^9, 
   3.650931811243556*^9}, {3.650931960440609*^9, 3.6509319685819273`*^9}},
 CellID->766512483],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJy1vWeUVWXWRksGc0BBMKOiIm3CnAoBUTGjiDmBiIIJFJDGBBIExEAyYUAF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    "], {{
      {RGBColor[0.2913888888888889, 0.40611111111111114`, 0.6477777777777778],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV0ltoyGEYx/HXjk6z5YaJIse2XBA3ciw3NJvNYYu4GMbOsTk0xxyK6yXR
nJrEMjeUZTZkihw3w5yJnGnOlMznf/Hr+zzv83uf9/m//3dIfnlOWUwIYQnF
UnNSCAcETXgwOYSu7nKsoNniStxO9eIdWExjxSW4luaI1+E+6hTvxdLeIdTo
XYyFKSGc6hlCEb50xoq4EF7jSr4p/KsiP00Ql+FTtb48T3C1PNv6Gvwg32z9
Pcb3URcnYh8K8SEk4XGanhBCHT7kS+Z5gGXyDzzluEuvZj134lu1NTyfMcN8
GeachcvohLgAX6gN5XmOi+z5mxjCYsxUy+LJwnK1Py51I1apLdV/fXR/vn+y
8bJxnrM3mmE+ZlOJOAcr1M7zVOL+qL+9NTiIVjlrIObybeXPw1z5M+t5mOa8
fOem4wAaIU7F1Og/8fTHftHdinvgYLVJPENwhrknm38mJqqN40nAIzS6Rwi1
uIkvzdvYjIflw6wfwplmHWXmOVii9k3PUlxuvgZzrojmlY+xdxvGRv/e3jh8
Z/9O8Vv8SdXij/iLLop/R2+Kr8psc3E2VYqz8a7z6rqF0I6f9C30X15hCzU6
6xI2q03jacIieYfZivGq/RW9QriCHfJ//Pej90jXeArxodoxngd4n46K72Gb
2hf+Vjyn70T9GzGDRrqHGRhv7lR3GIenfP9y7/A0tkdvw9472KDXVD3P4Bl7
0vVpwFh7etsbgzfla63fwBt8W/ivY0p0j+ZMjr5b3yb3XIRz+cabIRPbaI+9
rXhZrdYMLVhMHfwleFttA88tvK1vtf63ojev7wX9C/A71bjbH5jHN1z/Wbgw
kngBflGr5unE+fIc67l4V68aPdsx+J5uvqvLuY/5UvgfYZvabp5WbFTbZM6z
eFI+1Ho9vuEr4P+K/wHQRKdA
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNmWd0lVUWhm/azb0hNwkoqIADSAug0lF6UEcRRTBIV5qUiBACoSgGEsAZ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          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwl1VlsVFUAgOHTdloKnekUNVHwARcWMZAYBRKQVmpMFEGWQqlBjYiWlq2g
QhsLbYEXUR9RkQBFEVEBxQcXoLQgqA8iCLKVLSAIEUEEjEYSoH6T8/CF8997
zp1z79wOd0+eVVaTHUKYRG5GUQjnOodQ3CWEEobrEckQejrXgz6M1AccX1EQ
wkqWsl8PT8bzvbmPJ/URxz9x/lOWsFfv4x3j93iUzfpwKoSbOSF0cI0Depfj
Tc4vYgG79ZbCEBrzQmigls36mLlFiRC6kuaozjb3mPs4zRlydLn9lNvXOMqY
oC+bu8Sat3mXv/QhbthDSMQ9tes8n3NSH+cEufqq41OMX0zEa1zRe3zOQnvd
wFoO63Y+Nl5XEJ/FUV1l7g4P/kd2Ua27km+cRw5Fuon77aEf/Vmgv7F+mOuU
8jBf6wbHr1nTkR3nN+rx9ljvS22kgXI9xdwNvtfP2UiVvtPcvtb1oTfddSvN
rrOKZWzVI8wtteYJRmbop4rieBSjM//qHuYOdJ2hFHOXnk678VX+Zoaemor3
vjs7npumfy6K70lzQXy/DuqdjrfYQxub2KFnpuJ1/uE/ajL3a269PSxgIeV6
LHOMa6mjTI8uinut6hLPjdF9rZ/oOi8wOfMMdT8qjbeynUr9W2bfvusqqjmj
v/Rcq7yL1UzjK/1a2ufnh/AMY3hVH/K+fZYVwnrWcVDvZ43xapbyiz7tmj1d
uxf38qs+lYrj3on4rh/PPFNzV3hNl9PMDN3d59R08nyYTje9jMv2cJHtvKnz
GOD8Q5k55Oo70nHNMIZwu85nsPGgTnF+J51IxzWFJMnR51LxeUyikrP6PHXG
c6nl98z3a4/z3Wc9dezRrZQalzCUrbolGcfFDGaL3peMz6ghK15jr77omo2u
PY8mLujdyXjtWdTwk55gj0ft9RQnqdBjHS/x3IZQnPlN0KMYaDyAQYzWz5p7
zZoOrvOcnuP4Nufb+Ja5Ou17z/Z31pGIP6aFujbzOZ55FS9Rr+el43gKlczX
1eZusqaFVqbqS6n43CYm4jv3p+5wPMsebnjP1vKDnkG7NWc4y0x9JBV/C7tz
Gyf1tMJ47bbcOH+6/o4PXWc1y9mp1/GY8eMMZ72exQVrLnKJ2XpCYfxdaWIR
FZnfFzYaf5Eb76dKj0vG/w+6hfhsx+v33XNPv8uFdHgGq/Tz3HRv4/U46vQK
rhv/yxWW68W0GW+jhdd1djq+iwWZ95EsfcI93+Leb6XV78b3ek46/j2W5cfv
Za7+iAft4wH6sybzN8QQ54fxCC/r1fRxvlfnuPcPdHM67v9GftznSv1KOq4p
pYTZ+g/esuYNFnNeVyTj/0P30Iun9f/ciAAz
          "],
          VertexColors->None]}]}, 
      {RGBColor[0.4652777777777778, 0.4672222222222222, 0.5455555555555556], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwl1Wls1kUQx/GlpVBaaBExCL7wCBFRookvRI1GY4gJhy1HaVFAbmhpgVLO
iggEEIMIauSKIGogUcALQdIKkV5cpQdyFjEihwqIgC8QhKKfTV/88p3ZnZmd
nf/26f0jJ/WfmBBC2EyJVNE2hJzUEMqxd3oIpS1D6IOF9ExyCEX4R5sQZjYP
4Txm8MvEZGJemvikEHLxur1KMTdxCxUr/g0WUTJ7CpbSEnYJbqO57K1YSIns
yXicbrKP4mG6zj6GZ52xpUUIe3EMP9cluuGjNJndC8fTUXYenqN8/fyGWa1D
eMFdB2AmdWdnYD2taBbCQexDD1vvjdmUxR6IvagruyeeiWeoeRYHxTjrOXib
X229ETvRQ3q4J/ZIFexxOMC8aswtC6/QqlYhXMYJ7nPCDAtwMv8pM5+ILX2P
y2KSsYZm+0bV2IquW0/BVLrJfhzPyJnKPo0X1DpnVuexxN5zcg9iBr2UQtiT
fhefhH2oh/XeOMx9FrjXbLxIueZTjefUnSH+LOare0zP43GEvfniX8Vq96z1
vfZH0iF2DY6yt1jM6Dh//noz6YsD5Rerk4WFdIk9Ce+z94SYe7E+vgN16rA8
vht2BQ5Va66awzFRTx3Mtjmep8X6vIDNqLn1BOwv7nnx/TDNGYnOSsd3zXsZ
1ZnRj/ZWu++h+BacMVgPXfEAf7r1GjzJb+Nbn8Ik+afYLbDcXoaYMlzETzH/
t3Eav9y5U3EUf71zR+NF+fPk/on/Uhn7H3xNrxn6mY4jxK0VPzK+efqcvTDO
Sdx88X/hG9TZTGbj175fF/f4CndRX/YPONfeI2LmYI78eepkY3v+LT2nxb/v
+HbFFOO3crrJ3YJ5+rhLP+NxNKWzx+D+eB+5+3Acv731XPxV/gN6O4177Q0R
swer1BqkZiW+Lm6U+FlYa69YTB22jTM18ztwgf35VCmngN9gPR8XWnuTdlt/
B5fQgdSmtUW0J7UpL8ZVsVs6o7s3kIxJ1IndAlOpBzsFjzh7sx6O4tLkpro1
ctvY6ymmNf7i7Fbu1YAT6Zp+JuBVWmn9b7xMy9lXcJz5bjfnsVig7jpvIB+n
qNVL/WJ8MP42qdMFZ/AbnTUMT/DT1PkJq2iH7/IzdrA3Rszd2JEK2J1wsDOW
OWsIbjLftnrfiNPsZTprKt4Z48S3S2967/GeteJ2x3flrf6HOfYaxGTjUqqP
s8AKe2vEVOJQ/jUxQ+LfVDzD70Y/XBd78nf3MbYT16j/1ljkzjvcfWakO6xy
l53x917OSfEJ+EmcBftT7Mt/Rc1MLJE/w7mleIT/nn7rcDitETMivilaxH4Z
S53xpO/4fXyT/C+sj8W16t52l49wm1p5am7FxfFu1ldjCV1kr8Jb8e76acQU
cdfcpSPuiL8h6u/ElfH/ovgVeJW/z/olPOG8Dfo8jpvkvOisjfgd/2nr2/FD
OTfkrsHP7D0r5kscaG+WnrOwnt4X34Bz1N1mhoV4LMZYr8UyOcvl7sJs/gK5
OXEe8f+4+m/hIf4K8YdxPf8x99oQfy/lVLnXjfhm4/sW/wH+DxDFJyk=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJxdnAe01kWSxb+XeOlLRJWoMCoIYkAExTEBJiSIzoAMQTJIMpDBMYMwCojj
7JhQcs4ZxYAI6hhAFFdFzBKNgHGd3Xunfu/4zp7DPf961dXV1VWduz9O6jWs
49DcRCIxJT+R0L/EymwiUb80kagkLBHdokIicYFwofBHoVo6kahdkEjUFKqK
7qrMrYRLhM7CDcrXRegkdBNuFK+D0FroJuxVvk+EZtJ1jjAslUj8KP4PwlDR
V+h7mXCe0EJogty5QlO+5wkXYdf7svltYbvwprBXOgpVkWLhI9E9ZcNfsMm2
uexPheYVwoYxyURil/K9I4xNRp1ct2pClXSU3YwyXfap0nmdbRVOF30T9CBh
SG7osK4PhHHJSLP8NeVk/LVfBueGjGU/FMaLvlK8y/GBfTFHNk8RegtjSiPP
jfiyh7AnET5w3XcmIq91mX8Z9AfImDcIWzqgZ0peInGfcK/wt7yQfQefOk8z
8U4SThTOFT4siBjaL47NVrWRzrLremFb9vcYOTYt8J19fT4+nJ8OvtvSAtET
rFt21BLuzoty3xJeIqa2ZRc8p7lNum1mhcXZiNF/YiVUFr2oIGy0bUUVom19
aD/RxgYoX0ehvdBX2FSSSGwQ1grrhXXCGmGhsFgYKF2DhKHCEKFvQfBMDxBe
lMwLwvPCFmG52l1v8fsLq6D7ImveJarjRcKFwsVCP/FuRKflaopXXcgIFYmN
fXQ3MaornUnhE9E/5oVP7duL6ROl4hUI+UKJkMoLnulkXthoWzcLzwl9CsIG
l21bV+QHz7Tr0kJ5mgrnCOcLw8S/SbhFuLkg9JT57ZmS8NM44W5hODB9rzAS
+h5hArwN+aHTujaJ7k+77i70yw2fDaBMy9l35wnN8eEYyYwSRgqjc8Pn/ZG1
7j/mRR1s+wV5EaunSyLu9sOF6GqK3BrlWS9sFNYJJ0jncUI14Xjh01TEwL7f
lYo6r6OtrCyJftVOaMmY5z79If2ynuTXqM02VrtrJKzORlubITxEm+tB3+6K
D9xX26PTugdmo5wVwgDRf0jFmGGZk1PRlmcJT9Km10LPoF2vh7cGu7thZ6ty
ZXZlLP9LbrQbt6V3RH8gTBI9kTbpttmDcb6r0L006ui62ibb1h76CuowMDdi
7NgOEHJVhz3FicR7Qk42fGxfVxaqCgXi7VPa50J+Nso+KTfGDNvgWG6kD2/C
J/bNUqF/NtJm4xPL3KnY3SV86j6UH7507Bbh03bY2oIY9pWOeeKPE/4kekI6
xpUSYaLow6nQaV2F6dBhXfOx4becROJX4Rfhf3JiHNsgLGWMmyufTWWM91i/
QO32A8awRdB7GHPN2y28J3wE/4h0PiE8LnwvvC3eu8hY9h2+e9A1jnlktDBW
mIWM01z25bLpdKGR5w9hsmTuE+4VJgo3eU4X+gtDSDtbOAOZSUITeE47Rzad
LZwhnJUTY96F9DX3zQfQO0G4XxgljBCGCyOB6YHCoNKox0esIeyTm+HfiG23
8LVtw0pD9mPmfOf5Hl8NFLbnhG6322sp4yh+dNorOWFLD2Qsu6sgfFzm2x8k
8xQxcCyO8bUO63Ic3scG2zJZ2FgQep4Cu9A1i7RNlGF+C9ZCzYXzhb/hY/t2
Mn67h/nX65x/qY3epu944VXR0/WdVhp+djvrxTqoG/V6sDR0TkZuGvRE8txG
TEai8+/ChcTYdvTV+DZa7WSE0CsZcRjA3Oo2MljoVxr91GPvUHimPXc6rU9p
9FPLDCIOA4jpQGLTsZxez93tyDeRdncPvvgHNk6iXl439aTOvWj3vai7Y/tG
NvqE+8Jr2fiOJs31/qvqtFp1Wyvcnoyy3NYbU+YYyijTPRW/uS1P4TuB2PTE
hyNpszdTB9dlNuPYEPzWDz+9lY36uF67stGmh5A2lBiPR9fL2d/L7IldJ2hM
+kFj01Hh+HSMOR57lghbhUtpV82EC72WFW+YMEQYLGyTjtNU7/32c1Ei8bPa
9I850e5/Ymw7Rlv3GNcA2QWS3eeYScdAob/QLxFplnkJffVUZkpICnWFf6P3
GLq3Sq6+5L+wv4uC/lL0HNGf63sQ+2znBPEGJaJMl3UjdRiCDeZ7Lsv13J0b
c5rnkdpCDdagDT2Peu4STssNOxtQ5t1FEZu+xM0x+u9sjOEeu3dnI2896mId
XrtuZMz32F85FfW1zAmi9wmDFZtBwheiG1FundyY53aytn9D2JEI2+fkxrrH
dbiRunYRuiUir8s9AR2nUyfzrTupNvCbyvpVKE2HbF3WOM6zg7JeFV5PhI4T
WPvYT/+bE23AMXKsXkf2FeG1RPjJMdqKv86jDtbrMexMoTE22bZzckOH8zbx
fKtvb48lQh+hhnxSnzw1U9FOncey5+ZGG3ZbXig8n4i23ByZZqxrLqVte4+6
jXZv2RcTsfZpiUwr6Bb0CfPc1mcyxrvNN8dHtvkcbGpMvWqlYs+1h73Yedhd
nzbVkJjWwZdue69ixxZ8+Cb7nm3E4Q3oF/FzbWJRlTbbB1/1EHomIpbuSznE
NN9rLOrhuG1n3bEVvT9Rr7K5a7dityQn8mRS0S7dPocKQ/Jjb5FHH3JfyqFN
uC0kcgP/pu/+hp4l+NA2eG8wnj2A9wKniFc3J8admxOx1xrFHsJ7iQKhglAk
FHptozLvFO4Qdgs7hTeFN4QdQrHa9EHZmSPZlOi14q0WVnltb9vFzxdKhZKC
2DvcnBv7eO8hnlOdnyDPC6ITGdWhUHmEHNGZdOhw3ixlfZUfdrrMH0X/JPwi
/Cx8Lxyjv5n/gdfS3ucK79uP4i2hTq7bf1OvXcjl4INC7HZZX+eHT8z/Cd2/
UaZ1LRJuR2eeeEvzgu+ynlWdHsuLOrquY72OFSYJ46HvEybDW646Xqfvn4UV
6ZAxf6pwj795sSfwXsBnCRUk87HK2ScUpZERHhQmkNe6p8FvzrlCE/Zgl4h3
qdBZ6OTzmQpho8sdJ9xNudZ1r1BJPqhVEHZbzrTPp+6jLreTx7J3oWM8Ou7m
XOsSynI9n05HHss+I3p0uXLNbyNcLbQT2gp7iOObtMXFwlyP0cShotpNJeF4
4bjCaFNuW26XW7x/1HeTsFxYKVQuiLMMn2lUFbamIt1yL4nOileDOleiX1SF
l4V23prwNtHuF1JGDdJqo8PtqDL5rKuybKwiVBOqChkhSx1cl1x4FekTa+WD
dRVCxvxFFYKXQfZr+kFlyspgp22vSD/MQKe9x8mLPmKf2reF2JVFrhJ21cCn
yySzAJ8vxoeup/kr6Mdu64+XGwP8nY9PVpH2ILwV5LWupWAxsXQfeo9+upu+
Olxjxi25saf13nY5ehegp4Q6um6pgrDdvq1JHUYoz63osK7j4dcSqhfGmOSx
aQhyt0IPJo/HoBJ0V0zHGFGIr1xuDcqqjU7HqTI+tC9H0Mfcxt3Wp+fFOsHz
lPfaa8RbL2wkzsuElfCc9pSwVFjt8zzSVgkbkFlKnjXILPGYgtwy8qymzSyC
XkNZ5j1JGZabL+Tnxzj2LrEoyI8xzjynVciPGC5l7HtU378zRnms8llkS6E1
52YvaM12TWmcX2wX/YR4MyjTZXvf+FVB5GlOnVy3TfjkM5XxuXBYOCS8lA47
Fwrb0tG2HqVst7FqzJGeG33GcS9jmct02Y/wddmPCyXUy3X9KC/O+dow9nic
LKLOrqt9kc4PnulSYYHqVKq6FQvzszGm3UU5W9Lhg9botG6fmxei03pS6Cnh
3NFjusd2z3uea0spK7+cjL+21WeULuMR6vIiZd9bvq55MR89Sj/03PEZvnQ5
tu0yxlzb6DWW11r/kOzToqeL9zBtym1rMd9ltL1POOv5HL2eV3oLfYUuQleh
h9BT6E5aH6EfMk67QeiFzCBhsDBUGEIM2pKvM3Q7dJjnOc5zne18EJ390GFd
12PHDZT1z7yo20PCw7SZqcyt00g7k7WzZSoylnrucz9OM5aaHoHeQdjai7L6
wnPacOTc90fRDhfju6ewdaAwDJs7Uc8u2H4ca023abdtx8Q2uh7PpMJm2+67
hQeI9cP0Scd8An5ZTNkewzyW2a4N6UibXi627lseCxbRxwZj283EZGU6YupY
rkrHuuV6fGt+irF4RIXfyxhO3Tem4wx5JOOsx+brqLN1WNfDxGY6dVhBGV0p
+++kTWTMsezp7L3M/5l1WhXmXY8hHkuqMC573DOvMmP1k5wR+WxopjBaee8V
/ibcAT1BuB9eVmWk8+LM32f/lRSD0tzYc3rveQdyD3AOep90rufcyWdTFSVT
kBt5nNe6ivJi3W+d8wvinNBnkwuFSeSzjbb1HumcKEzCrpnY7jzOO4S9xH3I
+Y4jg822/Ub2GU6zrsfRaz0zCoLvvJMpYwZp1j1HWJ0fZ/g+u18rHEiFz1zv
g6L7paO+rndn0U+JP1uYK8wS5gsLvY4WFguLhGVeQ8M37TuS5eV4/q4kj3XN
EeahczF827SatNXYNo9YOHZTiMkCylyILROo51TkUsSmhH1eEtp7sBzSCtj3
lQDT3vtZ5m78OoG28xjl2M4Z+XEvMwmf2/dLqNt66vAEcnOoq9N857IBmQaK
4anCKUJ9jwHiPSe8IDyLT1zv5+GfkRd5LNtYuDMV34bCHamI82bhRWFafqRZ
9mRkvHfw3WStvNhD3JUKnWW6msI/Oy/usHx31Ix83nt4L3qn2xV7Ut81+W7v
1oK4cxrCPnQ4PO9NxxREvnHImD+iIO7Erk2HjPexHdNRV8f6X9T5VnSNJM91
6dA3iry+o/Odi+9afG85C5/ZV/ZlE+pakzpNwzcvCdPzw+9Z+n69vOhrM4Wn
6TfriZXv2nzHdTJydYU/CJuzcR7pM9ZnsxHLiugsi+kp5HHezcR1K3Y8x92i
78WeLYl7t3OI8RnYXBOdp5J2NrRlnqaezxL3+7B9M31+Jv30GfjPycYOpbGG
81quHnVPUqe60Pal74Jn0NbL+uI9xN5tfgL0fYxp5h1T3iPC98JRYY/K2KGy
LkgmEt9mg+e0fcIB4SfhB/I47y/kc9o3pH2cF/scy9zCWr4He4hfyXeUvEeQ
3UM5vnf8BB3WNZt59X5hVl7sg2ZDew/6JvOY9xZvgOHsVV7IjXXRd/lxbuE1
7IO0I58XHxG+Eb7Nj3OM76DNPwbvCLI/wNuvMr8UPhO+EHanok6uyzupiIPb
9vu5cSd/UPzP6Ze+2/06L3Q47yHhcF7IOO0SeF+Qx/yv4B1E9ht8vR9dh6mb
513vRffmxb7NZysfYNMv5NuZijv0i1nX+VzgALH9Ep3fE4ud8A/hN+v22YzX
rIegvUa+i3HdfvwUfIMv7fs9+OJd4b3ckJ2Cny1nX/mc+m3krkrFeZXPrdql
Qo/j8BP1XETcx+TFGZDP7p6k33gsOKI8j+j7sPWL/i99/5kf86DlHmFOmMFY
/zC8J5B7EtlZ6PRdqN9a+N2H70T97uMifOezlW+JwyFidTQV+h/BFo+Dfgfw
mDCtIOZSz62eUzy3jGCsdNrUgrDBtszGjqnMC9Npu/fDexA/PsY85nXCE5Q1
AZ7TJjGuTCOf+9Ve2ob7nX3vc/a3iMHb0O5XO3Njn/Mebcr5plD2EWK4gz7n
vvZibpwxeE3vdfG8vDgnmEefnUvbdt/5lDbus4T5/092Gn1+NjKWbUYfcjv1
Oejr6NmJrbbBtnjs+AhbXVfXZTRjxJvUdQw8p/XJxt2U5wTPDS7rtbx4E+Qy
38UP1r07N8p8HRnLvo/PdtLG99F3dmDr89zbr2femCLc73cJfgvBXfoCYS53
6qO0Jh4tjBXGCMMLg2d6pHCjzzSEccJNnGW1FFpz7mK6lXBZOZ6/bTgn8Vr8
iwohVwX+1UI7oa3wT62h/iE8JDwsXJdRfcX/TOgi+jH4fxce9X28+O8K7wm7
C2OP4r2KeU57B/4e4QNgeq/wYWHosK6eQn9hBzJOewub22BbbepyGTabXySb
munbXCgWPRAf2TfDhH6FwTM92GdCkvmLvh2EtOgnVeYjOVHvGUJH8bsJtwoD
oLsTB/NmIGsf2Bft0eV812BXe2j7dFcy9Luct5Px5sBvDxoILYUreIdgurVw
ZSLeKFxGWi3q7fq5nm2QayVc5TsTfGyf2XdXkdZMuCgRvroSm2ybY/mG8Dkx
/Qz6S+EL4XnhkPCVsEV4E72OxU7hlcIocwdpvdh77xL9cmGcIZhnert9Ix9v
1XebfZKJNuy2fLswvjD2sc5jWcsNYZ/rtmOdr1HOTuzehg1vkvZIsdb8wl3C
P4VFRVr/CPOFeUVxX+f7zX3cqXZWH+sotBbaloRN29DVMRP9ynb9VbgNm7ZT
5jbol/GBeT3tg8Los+6nT9AuHuUdxnjqeic636Au+/D7F/j+MH7fBO9QuVg4
7WtickA4KHwrfEPeA9CHgenvyLOT2O0vV+Y+8nwJvR+dB7D1DuEubPYZg2O0
lVi+TFzewQdXZ8Jm29o2E2PTSHw4jliPRad1P45v+vNGxboc693oPCQd0xTH
6cLhTNxLzsCn9q37pPuhy3E/X5eO8xGf4az13jcd4495TvO40kPoLtyQE2+h
FjLmeuxdko6zN5/BLRbdD7luQm9haTrOuyxj2f6MVZax7GlqU02FFsKZQnvx
mubEu6B2lH2lcAU2/EVoLbQSugjPJ+Pd0JnCc8ngtUJHe8opy2ebvuD+2W8D
5qq8F5Mh57K2iK4rXluht9C8KHzcH1sH+H40HWeJPlN8IR1j73Ts7Mm4P0YY
Df+IfHxU+EE4Rjvx91fa4HEq43ihunBCUfCc9pvwfWHoGI0PXMb+dJwv+wz9
83SMow9Rlm1pzVh4KePYSUVRJ9elmdBPbSKrb0bok4mv/64kVHS9xUvrmxJ6
ia5SFDbatmpF4csriIF9apn/yMrWaqJfKIxx73jydUPOcelKXUYKl1Ona2Rj
e6Gd0MF3+8rbpzDmnb6FMQd4LugP37TnigHw3Dc91x2hH+6HLvP1ibKhDTG1
Hyy7l5gcQaf1DKTMtpRpvm2pDc90c/rOcProCMaKb4mVx4yZzFXuc+57/bH1
Rsqomokxz3NiFdGtZdNlwtXYaR/alz2R9dzo+bYb9e5O2ijscLtpTV7X9XLh
CuEq4cqi8OsVzHlt8PWV8JzWFr7nvavddpSnFTZZ7xbGzZa0068YFy1TxmuJ
bHX68rnCBfTpq9HtufSSROS1ny4vV47tbI8Pnk3H/a/vZzeno020w0bbap7T
fD/p3xo8l47zc+dx3jboaUfMvyM2VxT9XubllOmyq9Kuawo1hLkaN6cKU4Q5
wkHFYHJxjKkeW5cVxRzpuXFhUfSFy4SW9Inl4i1BxrJ+f9RQ48ohfVfo7/XC
WmGNsA6YXimshl6G7pXILofntP28ZzrAG6pnhA2UabntwkvCVmGb8KrwMjyn
XUnfu4x+/IrHQMcZuW3kXYut/yoKmZfL6bLsZnQelh2NZM9X+q7S3zvJ53rt
EC5VGecLpwtNPFbJh3uQmyr6Y/Tatg/Bduyw3CfYYBnLWte5njfQ+Sl85/tI
OCB8VhT8/ZSxE1umUPY2bDS/NbG7lHnDdAtsNm9hOu72fMd3UzrSmmODZapn
Yl3s9XENr421B3pQ8+Ljwg3Z8NFm4mS/tkJvE+aoX8T7CR//C9lNxLQszzPE
1jFx3C7GxpbosR8a5cQ72rOhT82JN7VNkTmbOfUs+I2ZM6urXR8vVBWOE+qL
10A4WfgDMpYdpb43JhG665N2KjDtNzp+q2M9vxZFvaoUR5p11UPGvF+oq2Pb
Lxl6/UbUb0WrFYfMJ8SxLnn95tBvgE4n9vWp53HY7jzVqMu/i8IG8z+jnI9p
E2dg8ynUq4ZkTiCffVFXOFGoJdQRZimmp+jbSJgtuiblfEZbM9/p1nNScbQB
twXvn2pmwo6fibHrXQ+5EynrJPJWh1eHsl1ObXjViU0teE5z2YeKgnccNpnf
Oxtv2b0n9958aDreFvuN8RDRvbLx3t8ylm2ML/y2yjFuTF1tl23tKl5n4Tqh
UyLWlR4LH2Cc7CId00qizbvt/6Y67xD/LcchE3uLO4U72GNMEO4RxgjjSPN3
LDJ+W97Q7xTZ57WRzlbSfalwVTbWeG6TbjNuOz2w689Cd2GidNxLGWVlNaYu
Y0g7A57TXtO41Vx6CoQH5M/RxMVxGOH6p+NcyedL3dLBq0MchmP3aGRHUZcx
8MZC10OneYuFhcIC77WAac8786Gn49u5zEGei+zHR6Dvx2/mzUPGaY8Rl4nU
/X70PAA9hdhNRqaMP6FcLOZmwj/2037RK7HZdq4Ai7B1qbAEG1z2THjz4Tlt
GV+nzRaWl8vntNXFUYb1rhJeVzzOUyyKhClFwVtBnuXoLvOLy/hROCYcFX4Q
fhF+gue0lmo3h/Q9WBxt6Dl9NwjrhWeF54WN8Jz2hso/X2WXCFM9NyLjtC32
ifCx8GFx/OZkm7AVGcten47fKvmup4voN6WvhXQlhWnSl0jH3YplLLtdeV5C
h3W53+yA57T30euy36Pc96H9u5iPkHPevcIn8PZip/U+Qx2fh78Nne8jsxfa
uv1GuAt93n3fdmxGx1b8uJ+6+3c3XwuHKdNlu8+/Ba9CNs4JWtJ/3Y8PU8ft
5HGcvkFPWQz9PVAccTtK2ifw/iQdvxLn60oCvxDra0T/GZ7pa4n9AWy27Tcw
TniM8VjToSTKPERbcb4fsaMDZx0dqIPrcgBbPkZnp5Kw6TrKvhYdZXm9t/K6
slZR7LFWp+Pth/fE3hs39BwiNBZOF45PxTtzv909LhUw7fe81XzfnorfCfkt
fUr0etVhpbBCWAdMzxYWJ+K3Cdewt1qVCB3W9Z/fT4lezrra6/RlQv1U/LbL
b6HrpkKX+TPR6bKWw1uBzg7oML92Kt5e+732KLX5Oql4h22e06zTuv3e+iTR
41JxP+vz4vGiG6Tid2W2wbasoYzllN0/FefkPi/vl4rfKrieixLxzntQJs4R
vPcYlgmY9n7kJq/PMrH38x7wetFjU3Ffahtsy1p85jLXoNO65yXiDfmtifgN
gd/V34IfrmZvYx81SsXv1vz7tYapsM1+m4WeRdBPovMWdLnf9RaGp+K9g3/j
OVp010ycHdhm236PZO5iH3cN9Hj2dOatS8VvQd2G3JbGJqLNu61fzhrO8/xI
1lyjoV2vEeBW7BoubEjF2xz/tnR9Kni3YGvfRPCc5jJd9rhEvDN3mS77f1Nx
j+wxz2PfD6m45/Z9979FP5qJtZHXSI9lYq90mL2E90yrU3FP5fuqVaL/lImz
cZ9R+azqbqm9DR/cha8dh6fws2PsWPvMvLP3ctTLtt8unKJyGnhdSD+8nbQ+
wl+FO/iOKysnFW3V9xcvi341FW/L/b73tVT48ibaiP3YJxllWm/XZOjqg4+s
88+ZOPt3nVy3mbSli6mDY3UzOkdSz7HE8kpsGgfPabbpNe5YXhHdIxNnST5T
6p4J39rH2/3bqKL4+u+D/D6mO28dfV/u31X5N5fvMf/8lAm7vebqToynl8T6
7wFhKniAOxrf1fh3YGcJZ5bGb/78dtBvcP0G028IzybtdH431UxoKpwjnGvb
fP5cGv/nwGnIWLYRv7E6E/6p8M8iz2mkWVcdoTY6z4GujN66wolCLeQeYi3r
Orluc6iH75rGCKOF7l7rCiPg9YA3mnPR6fjBd1LXZoNv2Y7ZODt9CJkF3GN1
Yu7oiu8mChPwYXf411Om+fcw53Tizmsuds4Dc7BrHGlTqYP5M9ibPogd96Oz
U8nvd2rdKNNlN8BXlYjBufiwAX5ujg/r4OuaQrXSeFNaUajh35gJxwvVoVez
1jNvXyb2BV77f5mJNxN+O5Hxb6qyEZfj0GndxzKxjvR68mgmdFpPVeQqU24W
m0+jbfvs5QB6qvDetZR8Xld6LVqFNNMuoxidVeFXoyzb7jzm2wbb4vXvd6K/
ycQ9iuvkutXG7orYdpHwR+GC0vidpH/3599m+v9I8P9BsSwb/rRf12ajD7ov
+g2Lf+O4IRv5rWdjNnRcQLtvgu5mxMn889HVFL51Noe/Lhu/DfI6rxP9ujdz
kXlO+59UvJXzGO6xvA59pSb96CRiXJ1+dEG5fnsWvOr40fnaJGNv11BoK/r5
VLxF8fuUTal4g2y/2//HOFv2efQfvHcWrk/G2tRr1C7JOLP2uqq+cCowfRrj
uvNWhG8dPltNoct3Tv7tnddQXjf5N3jPCJvgOe3mZPxt/i3JWMunhKeLY01f
pyjOXX227LP20mTsH7x/WVccaz+fLdZmDeh2fQH7AetwWh3yWsZ5rWNTcexB
UpRZUo7nv72v8P4kiT6/OZpGvVxPz2snF8W4cS1r0c6MIddDdxGGZOJuwPcd
40UPSca84/mno8/1kvE7Z//e+bDoYclYB3ntMlT0bb7TKo255Mds8Oaxvhmc
jDWg14KveP4SfWsyfltnHda1Ad8vTsRabkwmzq59Xjva651MnG36PGyC6EmZ
OH/0meVk0c8m4zzTdwqvJWPcKluHu54+2z0BH9vXf8vEWaXPLA9kI7Ze560k
5i5jA2dwE0WvT8Z5k8/7NiYD53IGuCkZuqvTBurQpurhe9/bFdEevK+cQowd
a9/FnCMUJ2O/6/OHtcXx9d/eB/s8okIyzid8TnG//m5CPp+xN6VN1YbXhHJP
YS3TkL7QBFn3iUL0We+a4qALy5X9p2Sc9biPua/53rEhexPfaVaizCboboDe
M1lDdUjGWb/vz9uL/jkb7dLt02/jGiF3Fnser218rje4bI2TjLayxWvRZPjw
ZOpiW25CdgBrLMfQsXQbdFu074rpe0XwG7GmnEjfOBW7T8FvjsV5+PT/AJgP
ZhU=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwt1nm0lVUZgPGPO3inc+45JAaotNTCEBSzVUIOaIoWJlxABLwMJciVy6CA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          "],
          VertexColors->None]}]}, 
      {RGBColor[0.6391666666666667, 0.5283333333333333, 0.44333333333333336`],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt1Nlv1FUYxvEj2IXptDYUxYhBiYFAjCQu9B9QJIBsJSBUKu1gFb0QUEQw
aeM2DRa9EBEQEBCjIC4tWrRoArXIlLYUkES8gJAIUhDEgEbpYEn8nIwXT77n
fc+7nfNbRqQWVTw7IITwGg2kNwpDaKSuohBqkiE08FXjAlplncJX6Lz1q7iv
JIR38kNow6q4xz8Pr5Xyq1N/Uwjz2Wn+x5M532o6pn5ecQg9N4Rwmf+odacB
DuF6uX8lQliHD7DTBizHLnG14rvxEfZW/ik4VY99BdbYYO+cXi/jJntVam7E
yfZaxVRiubp3q/8grizMnbnTPGX25okZgkvkf6fOYqyn09Z1uIKOWy/HU/SN
eU5isZxJcktwhn7bzVaFV//vUcc/1B3dlRfCrXhRTkbu78ncfbxNP5rhA/HX
zLYVm+UvNX8Tfk6LrT/DhXLWmCGNbewX+Xfhp7TIeiee1a9uUAi9+Lq4S+I3
xniarO/3eK8eI/W6H58UlzDDM3iiNPcO9OE49mbnKsfZ7FHi78On2Hv5p+Fo
9nD+MTjY2YY6Yxm2sac4015sNVOj2fbgQ3Ka5Y7Hh2mX9QT8x177je4MW9nj
zf81nizN3U8Wn7OXr84SHBvP657vwd1Ux9+DT8spE78QD8iZZYZ2DPSzmrfg
QedPuYdOLGJn+RO43dyl3udVOFN+t9kq8LC6x9Q/gvvlzJDbgaPYFWYYiYPk
/6lOIXazu8V34gL5SfPUYoG9S2Ly8ageGb0O4372bHN24BxKu89HscNes5iD
2MIeKCaDTXE+/i9worq7zTkJd9hLiNmJ8/VuMVt1fHfoI+vpOIQGW9+ML9Ew
c67Ayvjc9Z2Ln8T3IH6reIceP3kuA/A2Gu353onT5GxTZ2o8I/tD/hRW03vW
L+Ay6rNejuNorPVwvErnzX8Ra+lj/ifwijs94m6L1bydPYZ/GL5pjh7zvIX9
9g6Z5zpeZm9wn1fwXTorZm38D8gpUD8d/0/sU/xr4rfAzuNfiV/Jr3f2Fjyh
7xx9M/Hfxe5Q/1/sl9OlfhbX0QV11mOfvYyYLDbH78Kdf4kNdMYdpuN3rMff
emVxj5yJ6pzGIprgeSXjN2evX50iPMNeJuZXXBrfJ7M9j4/F87uHynjH6l5X
fxueY/+ifi82Uon1FmyP/yJ1vo3fVvzGzdaEfzjbD854AWvErVazKj6H2Fvu
b3hczky5B+JZ2b38CeuU/Pf1rcH/AEDv5TI=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJxNmWmQldURhr/Z7izc+32XHUkCGllEgxqt4I8k/kmIyDCWsosgiGgq+RFj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          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwt1udv1VUcgPHTeTvuqEXjwBmx4Ewc6B/gAIooWIZGkBYhjhfiRBw40Cq4
ErECoshy4EYEFbdUShktDlxBSRQoWEREY5Qh+jk5vHhyz/M9+/zOuMeNGX/J
dcUhhLtRht25ENpKQ+hFjseh+RA+qAmhf3UIA/BnVQgz+b/KrVWuEx3Yzxux
RGO1JSH0wC38Ddwc07gJr/NJ2RB+1tcmNGM0v028p/xDcDAm8v8KIayvDOEb
fIug3xvEy+Uv1M/zuJ6fK36ycU1FC0byHeq2qHMXGmIb/DLxh+RPQTMu5a+q
f732bsB4vBLHLH6CufZCHRbF+ar/hXbWYDX28YnG/Y1hfYsPcWM25a/CQdLt
B8puVnaC3zsxCVt4kzZnG8MMTEcjL7bWX1vLr7AeRbxKfLc6f+IPVPKbjLHS
WDMlaS1u5Itr0lj3aqvI71v8b/Hl2mnHSuzhL4tXyc8gh1f4KPEXreVLxen7
jeYjatIa9UYdhvMl4nfp7w5MwlK+01yeNK4ZmIXf+Zvit8qfEL8jFvNOeWvR
I5vWJ65TRU2a0+/YgQz/uiKEdejELuNb77dZnRbrOxVb8QDPWpv95nRY3KOo
5c3IlIdQihfExvG9uTT3VaVpX//DbxF/Sv4s/IMJfArK1CtHFlP51ebSQ/8f
ZkL4CFfxh8Vr5BdQiQf52Hzq73kswJV8Yj61XVKe2r2fX6t+lfYqKlK71/Bx
yEqXoxJj+SfKPqFOC6bjU94qPsQaDUQ9lvMzzWWy73U/mnEWn6NsXp2D0Bvz
+DLxh3yH0WjCe3wgnlZnNubiQl6PZ6RnYTxO4+foZ465z8Oz6Mt/xoADY4n7
ehMfrZ8W851Rlta2kY/Jp/WYiWlo4v3i/tBOxlxL0cQLGCrWgL+MeY9yPXGi
Or3RB0fwdiySvwE/YjPPqttPvf6oR44fJX6KOnVlqY0jea34MPnDMRI9+LH5
1Pbq0nTujuEj8bjYY3gEl+fTfuzAWuysTnuzXv2l2nkfi3AeP1vZc9U5Faeh
L+9Em7GuQCs6+O58mmc3tuHveM7V75L+pTzNp5r/Ir4pzrM85XXzC8WXyX8H
72Ignx/vJ2c0GNsev/P4c9gv/V9VylvAt+dTf1vxU/zlc2tSnXhv7MYc3pVP
+RvxA7bw9wpp3/XH+XiX98cSY3g7k9ZiAJ+J7opULu6RZfxp+2iUfdeIKzA7
7j1neIch/4riIvuO74z3p/QKfIbfeBsulR6OhpjHP8VA6UEYjOXxTsEY6bEY
h9V8JYZIjyhKee28O5vaXo53sJH/kE3py4pSXxv4xYV05j/Ax7iI11mbXQfu
4qOtVR/eIr7RfDdjC57kL+fSW3J7SXr7FvEMurT9OTpQFt8d/bxv/t3YHN9g
fri1PsHeORn77MmqeL+IPyL/UTyMK/lkbJPegu24jzfiAekHcS9G8emFNK6t
Fem7zOBXZNO7OyWk8k08bzxfGNdW1Dr7B/M12bSWrWjDdv5oIZ2FeCa+xGP8
KvEntDMtpHv6an5mfEMPvB8noS9fqc1W69FWkt7c1/g92XSnd4U0n3v5GTXp
zelVld6+av4x6u3vfhiET/iJNek7xHKxr9P569arwZ7tg1os5OcX0hldnEl3
zwXxvonnRnou1sS7hw/KpbvwheL0Hg6J76c2h+lvKIajlXfk0vt3J75EJ1+X
S+mVWIXP+TRtbrBG3+M7PM4H59L/lgWYj4v5arSrswJrIvztQjpn8bt1YSnf
Ef9T+A6dWIddcS/H/w3V6ZzHca7gvdUfpu0GXII63iy+SZm8Mlm8xP8HnYJt
dg==
          "],
          VertexColors->None]}]}, 
      {RGBColor[0.8130555555555555, 0.5894444444444444, 0.34111111111111114`],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwV03loz3Ecx/EPc9//KDliEtvUHJvhL3PfxbK/XOMfJFNy/Tl+xkaJtUnt
YG4zJmtzl1spSrGEkQmNbM2xzVE8vn+8er7f78/7+n6+32/86o0Z2R1DCMsp
jrb2CaGtcwhbsJxGdAnhCJ7qHcJaCSfxDK1nn8aDfUN42S2EApxBFV1DmIf5
anqqzcMYdWQXYDN9ZTfhH/rBbscJakrUTsQP/LfiH6Nd6Dv7F36iBvYX/Ngr
hCsdQqjHXfzfdt6Om6Ke7M1431mmnAe4xa41HjQLJzkbLycJ55pXbe4cnEVV
7JnYWd57tV2xqF8ILT1CKMR6NY/s8BS30S99crDE2U85xbjXvO/ucg+W8VvF
S/GxvHtqn+ArZ7X6v8ZSM5a6z2J8w78q/hnv2GNR9xDu4jPKYN/DLPWHzF0Z
3RvNYKfh9egZ5FzGW7SQfRPHmT3UDomYTMPZY3GwmjFqh2B/fhfxAVEuP0V8
GCZEeeIjcRQNYY/GK/rO1v8aTuAniKdgKiWy0/G3+lbP21dOk+d55LmaMTh7
rvZf9O3wq8Vf4AFqcVwWvVM5DfrEcKq8Su9lGiZTAXsMDtQ/yZ6DsCb6/vSs
jXJpMrsC62gd+ytOobNq07HdjNvmNmJCdI/6DMc8/g877MfjZv+1wwlcpeaC
2tlRD/478VzcIa9Rfg6W89vEj2GM3yS+E1O915hvLwUXUBl7Pi6mcvZCXEHV
7FW4ki6xl+M/vQr9XznmnuNn+04qcZl4mlnT8SJ/nXgF7jbvm7m5uIRfqU9m
9O/yi8TX4ER+vvh0LOHHuYdivMDfpE8VdnAXdZ38t1gU7SpeiEfMazf3aPQv
0D67/cF4eanucAQe5n+TcwPPq9mg9iH+B4U2o8c=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJw1lmto12UUx5/d5/a7RZdXFYQpWebmzA21DHJ4IWm56Zsy1w3ErliUyGhY
i2j5Ii/b1NqclzlckG9C6DKUkSY6h0HkmCLWbETTTacRZtfPl3N88eX3/T/P
Oec55zznnOd/z/Ov176WG0L4DOSDsjSELUUh7Afz4RujEHawvh00w1tZbwPt
4FNwhLXlOSGsAEfh72Uh/FwSwlnQkJmtDvCF2yxGrhDkgQKwgDM+Z/1GYQj/
JiF0RrYvuV3wNZGdLR9egn8Xh/BKXghf4fQ6eBc6D6K7FRvlqfEZoKXI1irx
YRq+3Admw/9D5sdJIZwCf6VmU7YVg2L5GplxZOeBenjivsjXUnCMM1/NMx/k
ywfIDCN7HXTCJ8Cj2PmhNIRG7E/l953sFYI74KuVQ8+nYhvD5kUwCi6B91m7
wt44aIoshhbPeavHuNX5zNTQ6nfxELwIny5gZ0R+x+bL7WCAeG/jO4TMy/A1
YBC+AJlmctkJauHX8XFjcQj9+H8WfjUzPelH8CnkdiqYDh4AexP7Ku9dzqf7
HWjtEOgDx8AR8Dt2yyKzr3N2R5ZX5bcD/i42AnK5oAm+K7Ezb561B5nY70K6
ilPxDoNfcsy2zjiN7Wt8exUDub8MvoH3Yuew+yTfHsbmEwW2fjwx9PreCfjF
zOzJ13PwVWAutqrAM5npLiswm9JTDAVe3+2RnamzVVOqLdk85LkYgOeBIRrv
NMiBdyHzN7ITYJt6iTt6k9yvBedTg7juUHd5zfeHkN+XWQ+pl/4E/8A3ez3L
hy3yBZ9O4NtJcAU+6P2rHlCvH1fc4CdwvtBiVKyVYCW8h/PmcF41OAhfnFmv
6Ayd1Z1Z72sG9GRW2yN+N6px+Tjk80Gym7AxSG7PgM3w0czuUHc3DM8nhjP5
liPlajI+3es1qLrY6WviqpXvE4tBvo8kHnOJ1UBbZrVVCmKvMeVB+TgM+kCK
D394/jL4BCqXvR/Vl6cSq2XVz0ndFz2zmlmwDLTCN6DTUmw9o97Zk5iv8nk3
vDC2XKhe8+FvoLfS9WVnG2vL+daCNvgn4Kk8W9PevsT6SzZl+8XYZqHmUQ/8
t8jiUDy/wp9mfYXry86lxO5Wd3wOXpHafFG/dvN7VmqzRmva+yixXClnzaqt
1OaJ5opmXRlnNuRaT6o3o9hmWh1nbY8Nde7DDnhVam+HztBZ2hvz2aeY5cMM
nyGK9QV0vsy1GBVrvdebelC9OMXro5UeXJvYzOr3GaNaWuf5kY23Na/5bgDv
gCYwk7VGX6uI7avfDS5zIbNZohmgWVAe27r2FftNHdmdDZ8Vm13JSHay97d8
lK/KgXKhe+mAPw52IvshqIztzpUH5aMEPhedJcS2CMyBL07tLdWbWpna3G52
fdl5BJmaAtOR7v26Y3g5mJZYDpSLg+Atjz3LsftTTF2R/W703MjXOq9H1dCz
/l4fAM/B5yc2/3Smzr4ltfkjGcnqHVStqB/UF/tT63X1fDf8LnTK0J0J7k5s
TXvKuXK/yOet7lyzpgqZhcguBfPg9aCtwO5/Fbza55V0pNvg80gzZ73e88ze
fv0HuDUzOzU+wzXLv+X8J9mrBUdTe/MG/P+CdNf7/NLM1WzWGzvib3gpvD22
flZfH4jNx6VuW2+NZCSrmlevPJbZbJXP8r3M76rCc7LQ77LGY1aMilX1pNmo
GaVZpZwr9x9HNq80tzbBq712lrgt3W3i72fsNXbJZ/Mk+N7I9iWnWtDaqM9v
za6r/v4ofr09Y6n9l9B7NJ7aTOzzN7Y/sf9wxX6mbFcm5pN80V02eo2oNm5k
piNd3Ydqa9z/r+hMnf0/mjZzOA==
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlFlsjFEUgG+3KfUv8yIRShWJloSiRV+s1YaQaMOLfXlQQUVje2yp9QGR
VkRraqeMJSZoiVgihFhf7FtGQmqpbky1JL6Tcx++5P/Of+89554586cvWV1U
Em+MKYQkeOsYcznOmHpogPf4P8+YPwFjfkM7dOHvHF0jayPwGv9DvM2ukbWd
+EtH38+GWfACn+Eac5iktRCC6fhj1t5hzz24D0/x88RLE4xZBsvhAh4NkqOH
Mc+7cRbs8Y356mitN+ABNOHf2B/lnB8BrSmGNxN/yPsofIIkzttCrJV7t0EV
FONh4iXkWwGr4Cze5OlZcuZH+I4nunqWnHkLOtj7xdE6GmwPP+N3qLGouzEz
YQbcxDcRbyLfT2iEcvwZZz6w95c+PMFPu3r34gSt6Qx+hf35nJMHuRDGP7P2
g61NavyCH6JXHSnG/IIYHMbLHM3XbvTeW/EjQX3/G/7CUfwqZxbYeqXu2/h1
X13ikv8a3gVPeH4EPTmrE+/wdAbabP9/4pd9rTff7q/Htzna91Zbz3b8pKt9
L7F3PoGPhu3MyVbYDNn4OPafSqY/UAfj8UkQ5vkcnIXJ+ARf359P1ncT8X7U
M4JhL4A8yMHLZMZ57pQ/ATWX49XkmUsNc2Ae1EgdxHsEdI2srcBrYRA+EFzY
iY8mz0HyVUMN5ODZvrrE98IwPJNep9HzvpAKGXgvCFiX+GB8l6M9arQzsxvf
Afvt3Eofd+L9yT1K7gRDoDceIt7C+2Ypm5msxeOJP0+kpiRdn4b38XRPFgyH
VDmL3BnUMCBF6xyBZwXVJZ4J2fjQoNaaZtcOw6vJkxCnOSV3Bb7R075Jr2Ow
Hl8r82Jd4hvwNVDF874kfVeKD/D0XlKv1J0uv1FQ51vmPAoVeCW02FmWmQ7h
gzzdI3d+BQPxTE/vOsT2KwMv8HV+wnZm8uW/6+q3Sr5ZYZiF57g6jzKXO2AM
PsXXPXV2LvPwXE/nTOZtJIzF90K8nRWZmRA+zdc9MtMRmIrPdjXfRYjAAny+
qx629RTix139ryy338pjeCUU2rmV+T2A18FK+02T/9gpfJ2nfW+3vV6E33X0
ex2x3/c3+MGg9jJmvyc1+CL2X7K1SU0L8cWuusTrYSn+Hyqp8cY=
          "],
          VertexColors->None], 
         Polygon3DBox[{{4227, 2786, 4230, 4229, 2785, 4226}, {4055, 2409, 
          4054, 4037, 2386, 4052}, {4160, 2601, 4150, 4163, 2614, 4162}, {
          4010, 2361, 4009, 3986, 2266, 4008}, {4115, 2517, 4096, 4118, 2566, 
          4117}, {4246, 2802, 4248, 4247, 2801, 4245}},
          VertexColors->None]}]}, 
      {RGBColor[0.9138888888888889, 0.6547222222222222, 0.33305555555555555`],
        EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0mloz3EcwPHvGEPOkMkTV+Zo48HY5Zh5YA/UakhJiiF5QI6SFBtqJptj
m7K57XCttBwPxqI88ERaVhvFKPFgjGVmbOL1r9+DT+/P/fl8j2mbd+XvHBRC
yCeDycZRITRwrMX5Y0OYMSKEDNw7OoSfQ0I4gMvHhFCXEEI2pkY5CzCFTKXP
w7mRnoxVeuVpXoEr1NxWm4OnRobwx8wyTNc3V/8MvKSmU20FJpEEeiL2i/0a
GsJfLNDrgT034WX1CXHqsFvsi5yv+E5N5bAQBrCX3c3fg4vNrrXDEvzG7uLv
w0nRrCk4S6xEThIWsjv4D+NKeWvtmR2bQzrVdmEreUF/hVXyeuSfxxN26nXG
EszUq0bPLDwW9azGUmfIdT8ncY/6H/rvxiZ5q4aH8BgbSRa9Ae9E+kNsjnIe
xd7EjAnuoQFb2Hn8T/GgXgN6HsJkkkFPwiLyj16IT6L8Z9hKttPbcF7svuSk
YKVdv9v5XGxnM/qcqxxr7L3N/rVYwe7nP4M32Dv4b+JENfFqx2Mdeyt/Peaw
U/mz8Tp7C/81nG1elrlz8IjYezlHY3+NncY/Ey9E93wRr6opUHsFp4ktkjMd
j9vjp32KcT+7l38fpjjbaW+Rii/Zz71dC5ZFf68Uwzhv6P8UyelQf8/dvsY0
M4r9vYX4id3M/xkz2Cf5M7GP3cYfT19DbvHn42pym74Oy82bbG517M+TRPpZ
jBNrV/s71oM00tvxDblPf4vL7FRv/6W4Xv5dPTfgR7EmOR9i9y+W7h1v4X+p
1o4X
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlclvjWEUxt+r1Wrd77ufIaaVISKkYkgbLTGX3lrQVPwDiEgXlFgYFpSF
Oa3WEGJoohRNSCzYSWMlQSTGVrTakCAqEUINNfyenLN4cp+833nP+Jz3Tli7
uXrToBDCNpALliUhlBaGUAaWw3syIWwtCKEWdMOvRiHU5IRwm0vr4R1DQ1iU
DmEUOD0khEbOj4A6sB904eMpNjP5/hF+gjtV3N8AWuCNnA8Qd3gqhEvwJv++
EjTCJ8fkMziEOWASfAQ+csntL/nE8Cznq8EasALcx6Y9L4S74AF8PqjivBos
gPd6PR342JFYDMXKgqPwkSnLJR8UgNcZq113dLcstpiKNRf+3WtTjSeG2Jm+
KaZid3KnxvsnXxExBwos/wz8GDajyXUsaIIv5KyY3ErAYvhUzubJF5gWW69H
p82Her4An635+AEz4HuxSeWZT/lWDMVSz0bCq6nxGnM5DpbCD4MKau+l1hx4
J78vwHPQAZZENlPZl2veXs9G8Aw+i7PdfBuGbQv5zI5s9jrTt+2J9Vr9k5au
Y5NJmf0N+E6+vyw0G9m2YVOKbQlohX9NrE7Vq95JQ+r3N/r9Bl5AjNcpy78w
sju6Wwze8n1hbPpQ/4rgLzKWu2rQbL4k1lPpeE/GfGumuq8Y0qT0IF1chm/B
x9fBpklps5H7n8i9DxxLDH2+P1nxxPxJG93wXV5vD9ibmAZVu870bRWzqHQ9
Spf7fJ7/iFcX2w7Wev6ahTQirWhntbtd2DzD/iPog+f5TNUj9aoksr3UjDQr
7YR2Qzuj3dHOaHfugUfwk/j8XGg1qtZ39OAOvtrBB/gfbPqx/QH+wmeR0yG0
eADMhD/2fVSMSnhz2vZK+3UhbW9MmfevHn6Ys37eg5vSIbwusV6pP9KKNNrr
9QyCN/j78QvUw1uIMZF448FF+NnYuM7OwXMj07d6ot6cc3vlO5l8+9OmfdX3
Hl7EWb3v13T4wXyrryHfzru930/AK/hB6SdYDapFGpfWtQ+lkWlS2pImpI1m
7ozj7hhwHp5ObL+lSWmzOGOxFFO9neI5KLZymxvZe6sd1a5Kw9Ky3uJ/ic1A
talG9abB9aqZNiXWI/VHOTT77B96PdJAXcZ8aQe1iyf9vZBGT0W2c5qHzvRN
PXjiPp7Gpglpo40cluLrd2K7oPdS/w31vi/KSbnpP0X/LbfAusg0U+3vadbf
yjGer97MrOtH+q9ILCflpj06A18U23+D3gC9BZf9fdAbcwX+M23vnGau2Vf4
/592qlz98fdKmpV2y33f9EYvSezN03xlI9v/Wjr8pQ==
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtk01IVFEUgM8oOkjv3YkIrFYZZVFpm8pRR/oFpxYlmQQhQZYuWhRUEBH0
u9BsKh2nVRH9OGMohkTWIhBp1aZFSaWBSRRRWMZQMw45VN/l3MUH77v3nnfP
OffespZje44WiEgNFMFNI7K4WGQJLIVb+EqoZrIKwlCO3/ZEggGRBZAnrguf
YXyamO8wAz/xsC9yjg0uQAyq8bqQSDIoMgA51uVZ9xvSLs7Gp/Fa1vWyJhXU
9RH8JONZcsjALziOr4U6vmshAmvwbeyTYL84tEOVr3mHXZyNP4FXGo3ZWKQ1
VhjNx+Y1W6w5ZfFB6ltIrSUQgod4Bfl0k1dfUPOswVdAB9+dcBnK8U/z2W+e
yPoSkQ2QYuwV/3zBv8fgDUziY/CS7+cwCq9tHkZ7knb5zOHf2HuUHN7CO8jh
zdQ3RJ1P4Cm04D+M9nLa7fEBj0IDde6EJqjHY8TPcoZZyMFVPEZ8tFBkB9TD
Fbyb8Tnm/4ieeRwfh0fk8BiG4T1+zdM1dm0GOnBDD/5Sex5KcQ9fZrTvEXd2
q4zmbfM/wp6H4T7eBIOMDUA/7MX3+ep23Na9Hz/oa/1DbvwAvjmk96fXndMm
fGtI717S3a0t+HZ3X/rdPo14AUxR0wSMQwCf9LTOZzACX/AE47vJdRc0wA28
D1pdDbaWB3gS2vg+VKhzKbzH055nXL8S+Dp3r65DF1TiX92Zj7i9P+Nx+rWI
cy2FAFzCP3o6P+zOZApf7d5HI0TtG8YnPJ23Z2fP3t6B00bfhX1feTiDLzf6
7qvdGynD2z3NN+fuTCd+nvF/Ls7Gn8Lv+Fprm+tLD37W6Bq71uZ8Eb/na59a
XW/u4v8BQN+wDw==
          "],
          VertexColors->None], 
         Polygon3DBox[{{4028, 2380, 4027, 4023, 2363, 4018}, {4033, 2383, 
          4032, 4029, 2380, 4030}, {4249, 2804, 4252, 4251, 2783, 4224}, {
          4237, 2795, 4254, 4253, 2804, 4250}, {4141, 2592, 4142, 4144, 2595, 
          4143}, {4153, 2595, 4148, 4160, 2612, 4159}, {4013, 2363, 4012, 
          4010, 2360, 4011}, {4116, 2564, 4117, 4120, 2567, 4119}, {4053, 
          2408, 4052, 4036, 2383, 4049}, {4243, 2800, 4245, 4244, 2795, 
          4238}, {4223, 2783, 4228, 4227, 2784, 4225}, {4123, 2567, 4135, 
          4139, 2592, 4138}},
          VertexColors->None]}]}, 
      {RGBColor[0.9416666666666667, 0.7241666666666666, 0.4191666666666666], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0ktszVEQx/G5lVINWolE1EK6QEJvsXJvlZIINixIiMfqhq0urLzpRtKH
hOsRJV5dSpuUnSCxtqFCIuF6xKIk4hmJ0MbnpGcx+c7Mf+Z35sz5t1a6tx+s
i4hONo39nhPxY3rEP7w1O6IieRvLrFdhCd82R1xqiJjAC7MiJvVV8SN7WIgY
x86miKEZEWuwSKurPqIdl7AO/lJclfMrcTlbx2/DI+wv/xhWnbfVDDexn+4f
Z73CPvEm+X48bo7XjepxGWvkL8QP6u6b5x1uprWX5hYc0jPqLpV0l1zzHgtz
Iwbdq8fMY+qe2MNzXECrgWYLHsrzp3vU2Es1X/BonvkwDqr7pH4AR+i20B/G
Mbr7Z0Y8xfPiCXc5h9f0LKJzFUt5b2X8Kf4q/y3tTXxGfjF2sLP8YqIzPjur
infFG+g/wD7xuHxveqv8RpfxkW/b1DzG0769UXOyeeq907uvbZraS9rPPtzB
LvI34h42wt+Fp/TU9F7BZ3oO0HyBd9J8/GHsoTlpJydwhbpW9UW859t6NaM4
kN80ve2N/L9dx535rN34Pe/hF87XX09nHhZ8q9ltHa4Wt8mXsIu188v4HwE3
aFA=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJw1ld1rjnEYxy/mGeZ+7vteRl6GViQZspVpYoYtkh1ITrADkRPsDCm05XXM
sAhxiKQm2an8ASSxB2vbsyUvI44mo8x8vl0/B9+e7/37Xb/r/bqest1NWw+O
N7P9YAL4k5pdm2SWm2KWh1+PzEY5nzrO7B48n5gdmGzWBAbhPcjVcj4D3OTd
j9T5KPdp6hAfA8Wpy84M95LrQkctfC14DO9A5muR2WdwKXWIfwLt8E5kqpBd
AT7yneN7L3wfeJe4jGQrQX3qEK8AdfCNsdmOjNkusAl+Kmu2vsCsn/jG8Ke0
0GweKANzwWXut3C/GbTDr8Uuo7sb8PGc5Xk7CArgtZxtQ/caUBH7ue57x7kN
6ZCuOtAq28hsz/gbvdWZ7uSTfGvjrARb08El+AnwN+NnuhvC5yfofQ1GIod4
DvyGb0ZmZ8ZtyNZ78Ia33WAAfp7iz0G2FLTCrwT/FHNH1mNSDPV8n4dfDv7I
hxb4qqzraAM18PLYY1c8NbFjW7C/Fv6LflkeeX+pzzpij006pVs6pKsD1GUd
4lfBRngDMo0Zj0mxya/BkFvlrC3kTzEoFvWEekM9q969HXttVeNboRekqzH0
hHKi3LwAPfCuyPOjGBXr99RjkO8DqddE/qsn1BtHOXtLr/WDZng1WBb6b3Xq
fSP7ZyaanQTzEv89DebDh0P9VNOPkedK9tTvI/z+ibyXVN+fkSMX6q+398J8
VIMHifeobP63tQhcgF8EixO3Kds6051mPhdq9A0+C0zC9yJQCi8HZfByUJV6
TBVh3tbAD+l9ke+HfvQdDvnQme7OhvnUTJ+D94Z9ohq9TlxHZZh3yT6MvDdn
gc7IZ165UE5Ui/IQj2JYCG8OO0m7yIrNliQeq2Qk+xLs4X0DeApfkHgtVBP1
hnxuCv0i37TztPumgfvw49jM41sfOJb6me5mg0ehV2YHf+X3yqzPlbhiGQz6
lY8jvG8FQ/Av4AK8BGSKfF8m8HWh/zUT1fA7wR/t5Cvwu8G+zu6Emql26pUP
8Gzq+1Z7dzh1m7KtmqhXa0N/LgU1qc+AZuE5+XhW6DuxP+wv9Z5iVHyKsyvo
lG7lXLnvjn12NEN9sc+QvqUvFzvEZUOzrB0sm7L1KvY3eqsdlY99Z6u/5KN8
3ZD1XaCcKDctidda/yX67/kHpQLrpg==
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwt0DFLQlEYh/G/xbWy7N6GFDUIF1sit8o7KaFuDQ0tNkXRVmOLUEMUZbo4
ttdkkN+g2QjMoqFyCiq/QDREPYd7hh/4XM/7Xj3pzb213SFJMTjIedJCRJpH
Gll6zpWOR6QjnCBD5yeldQY2UEGZdjn7Nyb9IjEhRekqXtnzhmfs08tesN+8
Jwuffsf3uLTI7BKueEcLPp/zKKBN37hB+/bcNX3K7Ad7BvhEje7xfIfvt7GF
B7MrKtX5szWcIWeas192zsw36B9++1NIekEfIc7dMr9qd5mdXfqc56VhaQVF
1OkWs0lmUpjGJd3jbjph6Q73eKQPvOBOzN30cUinEOHzKBzE6Sl7p459nqAv
mJ9lzwxiaNL/+U45UA==
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtzztLgnEYxuHbQiMpDVxdnILMMqfSLNpaajAoOkx+gBqcrLAvoIGUnYZO
7kHQFFnfImjpIDk0RGYHiEj6vfgMN9fN+/5PTyi9klpukxQgHjLfLZ3xYQGX
yDl9ESdJiT6Dc7ZmFne7pCb7trFI/uh7WCI/9AJu2ZodXPdJv25pDXOkSd/A
G7803Sld4xWZoF/gF/8aPOwbP8kb/QMHSZy9Gczamau+1ludN5fxlKTbpSMc
4axyhzSKSX/rTOfsGBljbxgHyDh9CKPWI9hrdzl3PjLDpUt6wDub0Zn10O46
wWMyRS9ivkd68UoHuE/u6Tms2yzv+Epu6VUM8s/Lmj6MkBC9H2vcUeHeZ3yy
N1QxzCybzBXHhM04jP8huUaY
          "],
          VertexColors->None]}]}, 
      {RGBColor[0.9694444444444444, 0.793611111111111, 0.5052777777777777], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwt0M0rpnEUxvEzNITHawk1FpQskJfVQzE0piSrWSjZzcKS2CiJldAMUd5W
/AFqUJZTs5vNU+QlGSspe2VslPjcPRan7zm/c13nvrrrvk98G8+JiEaVq/6W
RnwuiDjE/VRE9Qc9VpTZF0bU4npxxBDxLu6pAwdGsUet6Xsxzb+SH9GEO/zh
zjbOl0S8fIyYxS3zq9UmDppHvH/FJf5+9xfxmP+LPH/wme7Snf94Q3eWF3GN
dXYLvlVfms2R5BnBKVlPZZ7ER7oH+iccttuhGcA7t367eZ/K7hJNpzv1PFW8
DTitrvSzOKEy+vGybO4k/y228vbK34a/+LtlPsJ2c5/3DuziaeFNY7Mq0n/C
OXWh/4mrdJUybOAP8733ZZx5v59859zdMfcv8M78j/4Ba+hy6MvxJPkXNBl8
AwRwQY0=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtlMlvjWEUh09bVN3pE1FSGm1jYUwoiUQv1VuNqdFEJNLYWVhJGzGtqomk
VHWyaYs/ALEQ1E5iJ6ELOriNW1JUY8WCkmgVz895F0/u73u/M7zfGW75ieYj
TflmdhQWgCXM/sbNfsO8iMz6F5tlY2aT6BYYXmI2ChfRGWxWgfFcwm/+UrNb
2E9g/573+4k3QII+qENXYjPLu3SR2a+Y+9TG3V5+peG5JMSc4Xcsz2wEvqFn
Qs4c9pdSZg1Js8NwCOrhEWcZYtfCILqOs8aFZscgk3SfXMiVx13f8tyE7SnI
oW8Tu5hcBgPofnz64AbchCl4s8hsHD6gh/A5jm8jvECvh2uFZm2wFt2LzXJs
l0EXupWz8ZjX9A/fspHnrkL3ke9Dcj6AQXgcdx/5znP/VvRXfLbFPYZiZTl7
HWqgWtznbC7mNrJVzVX7XqhOeA1UixrYjr7MWVvouXo/Hnxnwx17OasvMDsI
3Qm/k+5WhU7DXfTKPK+ZaqceqVdPYCrEUc+zIZ5iKNZeaEefCfM0BM3oUihA
F0FZ5DOk2dBM/EBPxz22cnxHvwv9G8P+fORIZ+FC5D7y1Vx9jtxHvpqpn+g7
od/6hnvodaF/6skGdE2ol2aoFn0uxFdOzY52Ihu+8Qt6X6i3Zv4A+qrujP0n
aEeXQzF6BVSgd8NW9BbYFTnSm2EnOop8vzJh9ldDLNSnBL0jxNPZJvSehPda
d9BdlFO5lUO5OiPf3RHoQFekfFb1zfr2lqTPmmauM8y8Zn8N78rgND4vg/9Z
dEfCe6me9iR8tzJhf7VjPaHfmqHrCa+RaqXdn0ZXhe/V/dKRz4vmby78RzxN
+S5rv16hR+Fk2NeJlN9Rd9WOdaMrkz7b/2dc94/7LqvH6vXz8P9QDc9SvsPa
5WHIabeTrnU2mXSktfMfk55TudV/zV469E81voL+ByzMuzo=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwt0T1LQmEYxvErpUTNfBrMXoY8UGPQZpAmpFM1tYlbg1MYaG01mlCLg9hn
aInMT2FC5UtizfoVgqKg/+E8w4/7XPd53s5znJOz45JPUhyzeJyXlmeke2oL
T1g1UjAk+eHDCvloQTpEFnkmHlBv6Pd5/4opbsl/zP/FF4as+0Pdob/F+ziW
kCR/RqXToFREAS/kKf3vsJQip/FA7w15O8Yd2yfXGDexe7p7l8mbxlvf3Wcb
u+QSujyPMMQFOcH8dWygGpAc6rn9jgF6qJBbUe8MGeyjTU5FWBcZ1LnEPeqz
PV/WjuuQF413b8Ia32/IY+6rNyd9UN8xwqXxzta1+16RG/RjjKtTm7hDwv6P
sL0/h1xj75yff0Ct4hr/va88tA==
          "],
          VertexColors->None], 
         Polygon3DBox[{{3299, 444, 3298, 3296, 255, 3225}, {4327, 3101, 2560, 
          2562, 2563, 4114}, {3225, 255, 3222, 3223, 256, 3226}, {4016, 2367, 
          2365, 2364, 3067, 4015}, {3636, 1345, 3633, 3632, 1344, 3635}, {
          3416, 687, 3487, 3486, 844, 3472}, {3882, 1933, 3896, 3897, 1776, 
          3826}, {3635, 1344, 3706, 3708, 1533, 3709}, {3826, 1776, 3827, 
          3824, 1753, 3811}, {3401, 664, 3414, 3417, 687, 3416}},
          VertexColors->None]}]}, 
      {RGBColor[0.9972222222222222, 0.8630555555555555, 0.5913888888888887], 
       EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtkDFLQlEYht9raLeya0aTwdU7tLTWZtzBrXBq0U10LRS0RnEIcouGoBSj
n5D0JyoRcxK5RAQN7Y5B0XO4d/h4zvee93vPx/FqjeN6TFKOWqJeU1J5RRrB
8w36VakOPfqLZXxwz5EKcWkfltelHgGH8JIqENKF15Fu7o/wVfAX4S21nZBu
YDvKMXkt3pjy1hn8og/wLKBLn0LPwjyV4bwDJ+xRZc8AzvC94Z874YyZ3UX3
8G3hz8FPamBLsbR0yvkZ/QQ+2KH+sca+ScmyeB/+cXeH3iGnH+nmfhPdYvYb
PnLns8MQNs1O6F34hM/FP0yGGffUO/k/9AH6L/T5lyv+5wCOmS+R8wL/AQ6p
NhY=
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJw1k8tvzUEcxefqw63+HiMhHpfqxUKsa6Us6opICBGiseHWmhIsxYKwkcZG
Wg2xtZMQ/gTVUqyQmxZNF6xIJGzU5XOcsTiZM9+Z7+vMd+ojo0fOLgsh7AGd
4FkZwrGeEIbBNPxbDGFHFsJ8bwhX2U+vCOE0ZyPgOfwxZ32VEPrBU3gDbAIZ
Z32sG5LtA/53qyHU4Xszn+nOZuKvZl0F6tG+jeRXwTZFzj+9rkG13ACvsNfA
YHQcxfvInftV29eBtWA9eF261lNgFj6Kzwz2N+ACvI3fAP5zrPfwP5F6lwbH
wUzpvewvSt9XLarpKLbOlc6r/AvEa3Gn2WON5kqvzZRfdSylfL9Zd7P/Ed2r
tPkUrbPit1M9iqnY6vFndM+11NvO6FjtVItifo3OodgPS/elO7JNVK11CYqk
ubR8mTRT3P81650vEetitFaz4Hzi0m8q2T5Hv5N6UC/90XEVf2P0uzfSe0un
iQJ7N7O0HBu5toMW+/dgG3yhMJdtEX4tD2Gog7qYr7Z0A62K94Gz29ypdTum
YksjaaU5+6J6SufS+STnY/iMM/B3wC34IWzNLuaE87fwd4W5bIfhV0rrtpS0
VU7lVk3X4YuaU/ZrwPfMf0B/YYz4u3LXrPuq+Rd8a7TW0vwc/AA5TnY5n2o5
E/2vNCua3S3Rsywf+Q7mjq0cTzL/yfk0Kx3M4oPMtaimSfj+3L2q5325NZAW
0mwcfhMMk3sIXIYPFOb/bIU1UG2q8WDhnMqtP/8I/hfJyI3u
          "],
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtkM0ug1EQhl8apE1939mIhoS0XyRugtBQSRMbm4qNny1a3AIJEvlsiFsQ
tZC4CH9tLTW14RaEDRvP5JzFkzczZ+Y9M1PcaqzU+yUVYAD+8lKvT/pFv+EH
JmLpcEgqoiVIYH5YmoMluMKggu45qZWT2vAAO873m88XjOJ7g95CE+7Mm9x9
3uft/Tq8Wc0Mnines+Ev+zMJM0xDd1D6iKR36EEXXsm9oQuwykJnaArnka+1
ns9Qb32TzBgz6wgUICGegrEQW75EvO38Ts/wCLvEp8xzAsdQzkhH6DKe6/xb
RRehEvnb2I3SUG99+87fye7VgQPna62nHGa3HdrsuZGV1qAGrdjvYjtdwDj7
XKIvsa+x2k3oENfxfArz2twN4n9KYkPV
          "],
          VertexColors->None], 
         Polygon3DBox[{{4328, 3105, 2572, 2574, 2575, 4126}, {4040, 2391, 
          2389, 2388, 3071, 4039}, {4125, 2574, 2572, 3103, 2561, 4114}, {
          4016, 2366, 3069, 2388, 2389, 4038}},
          VertexColors->None]}]}, 
      {RGBColor[1, 0.95, 0.75], EdgeForm[None], 
       GraphicsGroup3DBox[{
         Polygon3DBox[{{4039, 2390, 4040}, {4205, 2757, 4203}, {4321, 2208, 
          4356}, {2210, 2208, 3041}, {3727, 1370, 3652}, {3244, 281, 3242}, {
          3652, 1370, 3654}, {3242, 281, 3317}, {3803, 1746, 3808}, {2206, 
          2209, 3040}, {4044, 2397, 4045}, {3465, 657, 3398}, {4204, 2758, 
          4208}, {4131, 2578, 4127}, {4355, 2206, 3971}, {3808, 1746, 3875}, {
          3398, 657, 3393}, {4126, 2573, 4328}},
          VertexColors->None], Polygon3DBox[CompressedData["
1:eJwtUitPA2EQnL7I9XrHFVAYoL0WDJoqBKbFkBAEgvBKPY//AAbVIEhQBIrF
NeEX8FAEgkFgeBgcCkyThhl2xaT77c3OzjdfK+29ld0sgFkiT0xFQJN4LwHn
gf3qXCW6PH+VgTg03i/r5WGgXQCehoAX1nn2F4lpYrMI1Pys/mVg9QxxExpn
iTPbBdOQVsO5ms05VzPSGQntmzgfJdN7SIANcreIx8Q8ydu/d9bzMdDhBSsZ
4Jr9T861XE/zTe5cK5gHeTlxP+p1WPfJm8zY/CCy2bp7qXlWKVEOLaO6c6re
+6YHsF6lv/vEMlJWz8Qr6wP2zgLjiHvofo+Jo9g8a7c89Fjvk3NH3THtZ33q
+cuzvEtnjsj4zjSxXdo5kZivlueg9+z5/caJq8g44kpT2tLKEutF01TGyvqW
+3fK9k2cN+pdBOZJ3kaJlPVCbHfRnfQWP5Ht0s6+v2PDd2g+9Uz1hvqfZf29
c+5Be7RP91RuA89H+sruDyGrTs8=
          "],
          VertexColors->None], 
         Polygon3DBox[{{2579, 2577, 3109, 2576, 2578}, {2399, 2397, 2396, 
          3075, 2398}, {2758, 2756, 3111, 2577, 2579}, {2757, 2399, 2398, 
          3110, 2756}, {2209, 2210, 3043, 2211, 3042}, {4203, 2757, 2756, 
          2758, 4204}},
          VertexColors->None], 
         Polygon3DBox[{{4127, 2578, 2576, 3107, 2573, 4126}, {4040, 2390, 
          3073, 2396, 2397, 4044}},
          VertexColors->None]}]}}, {
      {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwt0s8qhGEUB+DvQySELCRJkyQxzKc0ZKbhFoiSjVhIGpNcgKQhK1mJkpSS
laz8KaQUZecClJ1CjT3lmVg8/Rbn7fSe04nN5EYXwyAI8pRSRjlV1NBMCzHa
GGOcSaaKqoNgTs6TJVd8p2E7nVyod8kkg6TJsECWJZZZYZU8G6yzyRbbHHPC
KWdUlARBJbXU00EnvUTsGGaXAw4555Jb7mg0aBOtxEgySIYRhkmTIiJBnG7C
sr9F/ejzzRfPllWQn3wwwjBpUqypRzJBnG7C0r+l//jvN18U+OSDd9545YUH
7rnmilmmmWSCDCn66eNJ+0fuuOGYI/bZY4gBInpooI4Kwv97+AWzNzk2
        "],
        VertexColors->None]}, 
      {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0ksrBFAYBuBDLqNcfoHETqHYmzISSTKThSRpkiRmGCXENJR/IGqyURaS
JPkBskBWshIlKSUrKSUKjyye3sWp7z232mQ6kSoIIazRURRCOzG6iNNPmgwL
LHHHPU8880NhcQhllDNbEsIcy+TYJM82O3zxTXFpCBFqqKOeBhppopkWWonS
RowpUsyQobpKl8yywurfjIgZNDNpvUW2EqWNGFOkmCHDMllWWCXHIvMkGWGQ
AQoJfOr64JEHbrn525fzTTPBOAn66KaLN/f0ygvPXHPFJedccMYpJxxzxAH7
5MiyyDyTxCv1yTFGOfQuB+yxy3tFCFsyzwbrjJJkmCF66aGz6P8//AJ1KESA

        "],
        VertexColors->None]}, 
      {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwl0ktLVGEcwOG/F3TMQMVVtJJW0UpchYKIELj1E0TuBGdA9wqOaV7ymvdK
TSJCVHKCEGGGsVXfIHAnuJQW4t3UZ3Dx8DvvOZz3fc+l7k2qPVkUEXMcVUZ8
TUR8Y4O3VRGbusseOfIc848TTimqiCihnAoSVFJDLc95QT0NDDPKFDOcWee7
bvCDDE/s5Sl1bFZHPNOXNNJCK4sss8Y6u+yR5zf75MiSYYdttkjTTx+99PDH
Ot2aIlmY45E5yJGl0/WM7rDNFmn66aOXHrpJkaSrcB8dvKaNVzTTxJFnPeSA
v+Q59z6y+ouflD2OGPOe3zPOBJNc2s+UTjPDlfEHvdNFjZqIpcL30WUt1o+6
QqnjVf3CGp8pce6TLnBrjnn9r3N6o7N6raN6oSM6zDvOjYd0sPDfkGYg8fBP
3QMEKlsi
        "],
        VertexColors->None]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
      {GrayLevel[0.2], CapForm["Butt"], 
       Line3DBox[{3163, 3162, 3161, 3157, 3158, 3159, 3160, 3149, 3147, 3148, 
        3145, 3146, 3155, 3156, 3150, 3151, 3152, 3153, 3154, 3181, 3179, 
        3180, 3182, 3183, 3187, 3188, 3189, 3190, 3191, 3358, 3359, 3360, 
        3361, 3362, 3368, 3369, 3370, 3371, 3372, 3429, 3430, 3431, 3432, 
        3433, 3434, 3435, 3436, 3437, 3438, 3439, 3453, 3454, 3455, 3456, 
        3457, 3458, 3459},
        VertexColors->None], 
       Line3DBox[{3256, 3255, 3257, 3258, 3259, 3260, 3261, 3262, 3276, 3277, 
        3278, 3279, 3280, 3281, 3282, 3283, 3284, 3285, 3286, 3343, 3344, 
        3345, 3346, 3347, 3353, 3354, 3355, 3356, 3357, 3515, 3516, 3517, 
        3518, 3519, 3521, 3522, 3523, 3524, 3525, 3549, 3550, 3551, 3545, 
        3546, 3547, 3548, 3552, 3553, 3554, 3539, 3540, 3543, 3544, 3542, 
        3541, 3537, 3538},
        VertexColors->None], 
       Line3DBox[{3573, 3572, 3571, 3567, 3568, 3569, 3570, 3559, 3557, 3558, 
        3555, 3556, 3565, 3566, 3560, 3561, 3562, 3563, 3564, 3591, 3589, 
        3590, 3592, 3593, 3597, 3598, 3599, 3600, 3601, 3768, 3769, 3770, 
        3771, 3772, 3778, 3779, 3780, 3781, 3782, 3839, 3840, 3841, 3842, 
        3843, 3844, 3845, 3846, 3847, 3848, 3849, 3863, 3864, 3865, 3866, 
        3867, 3868, 3869},
        VertexColors->None], 
       Line3DBox[{3665, 3666, 3667, 3668, 3669, 3670, 3671, 3672, 3686, 3687, 
        3688, 3689, 3690, 3691, 3692, 3693, 3694, 3695, 3696, 3753, 3754, 
        3755, 3756, 3757, 3763, 3764, 3765, 3766, 3767, 3925, 3926, 3927, 
        3928, 3929, 3931, 3932, 3933, 3934, 3935, 3959, 3960, 3961, 3955, 
        3956, 3957, 3958, 3962, 3963, 3964, 3949, 3950, 3953, 3954, 3952, 
        3951, 3947, 3948},
        VertexColors->None], 
       Line3DBox[{3973, 3972, 3974, 3975, 3976, 3977, 3978, 3993, 3994, 3995, 
        3996, 3997, 3998, 3999, 4000, 4001, 4002, 4003, 4004, 4005, 4072, 
        4073, 4074, 4075, 4076, 4086},
        VertexColors->None], 
       Line3DBox[{4087, 4088, 4097, 4098, 4099, 4100, 4101, 4169, 4170, 4171, 
        4172, 4173, 4174, 4175, 4176, 4177, 4178, 4179, 4180, 4181, 4197, 
        4198, 4199, 4200, 4201, 4202},
        VertexColors->None], 
       Line3DBox[{4269, 4270, 4277, 4278, 4279, 4280, 4281, 4305, 4306, 4307, 
        4308, 4309, 4303, 4304, 4313, 4314, 4312, 4310, 4311, 4302, 4300, 
        4301, 4299, 4298, 4296, 4297},
        VertexColors->None], 
       Line3DBox[{4343, 3965, 4329, 3979, 3980, 3981, 3982, 3983, 3987, 3988, 
        3989, 3990, 3991, 3992, 4025, 4066, 4067, 4068, 4069, 4070, 4071, 
        4079, 4080, 4081, 4084, 4085, 4263, 4264, 4266, 4267, 4268, 4273, 
        4271, 4272, 4274, 4275, 4276, 4294, 4292, 4293, 4290, 4291, 4295, 
        4289, 4287, 4288, 4286, 4285, 4196, 4195, 4194, 4193, 4192, 4187, 
        4186, 4185, 4184, 4183, 4182, 4146, 4107, 4106, 4105, 4104, 4103, 
        4102, 4094, 4093, 4092, 4089, 4326, 4336, 4316, 4345},
        VertexColors->None], 
       Line3DBox[{4344, 4315, 4330, 4322, 3984, 3985, 3986, 4009, 4021, 4022, 
        4024, 4026, 4034, 4035, 4037, 4054, 4077, 4078, 4082, 4083, 4261, 
        4262, 4265, 4229, 4230, 4255, 4256, 4257, 4258, 4259, 4260, 4247, 
        4248, 4284, 4283, 4282, 4191, 4190, 4189, 4188, 4163, 4150, 4149, 
        4147, 4145, 4137, 4136, 4134, 4118, 4096, 4095, 4091, 4090, 4337, 
        3966, 4346},
        VertexColors->None], 
       Line3DBox[{4347, 4317, 4331, 4323, 4006, 4008, 4010, 4012, 4023, 4027, 
        4029, 4032, 4036, 4052, 4055, 4057, 4063, 4065, 4217, 4219, 4226, 
        4227, 4228, 4251, 4252, 4253, 4254, 4244, 4245, 4246, 4242, 4241, 
        4168, 4167, 4164, 4162, 4160, 4148, 4144, 4142, 4139, 4135, 4120, 
        4117, 4115, 4110, 4108, 4338, 3968, 4351},
        VertexColors->None], 
       Line3DBox[{4348, 4318, 4332, 4324, 4007, 4011, 4013, 4018, 4028, 4030, 
        4033, 4049, 4053, 4056, 4062, 4064, 4216, 4218, 4225, 4223, 4224, 
        4249, 4250, 4237, 4238, 4243, 4240, 4239, 4166, 4165, 4161, 4159, 
        4153, 4143, 4141, 4138, 4123, 4119, 4116, 4111, 4109, 4339, 3969, 
        4352},
        VertexColors->None], 
       Line3DBox[{4349, 4319, 4333, 4325, 4014, 4017, 4019, 4020, 4031, 4048, 
        4050, 4051, 4059, 4061, 4214, 4215, 4220, 4221, 4222, 4236, 4234, 
        4235, 4233, 4232, 4158, 4157, 4154, 4152, 4151, 4140, 4124, 4122, 
        4121, 4113, 4112, 4340, 3970, 4353},
        VertexColors->None], 
       Line3DBox[{4350, 3967, 4334, 4015, 4016, 4038, 4041, 4042, 4043, 4046, 
        4058, 4060, 4213, 4206, 4207, 4211, 4212, 4209, 4210, 4231, 4156, 
        4155, 4133, 4130, 4129, 4128, 4125, 4114, 4327, 4341, 4320, 4354},
        VertexColors->None], 
       Line3DBox[{4355, 3971, 4335, 4039, 4040, 4044, 4045, 4047, 4205, 4203, 
        4204, 4208, 4132, 4131, 4127, 4126, 4328, 4342, 4321, 4356},
        VertexColors->None], Line3DBox[CompressedData["
1:eJwl0Ls2AnAAwOG/vUzE2imZeJAGOZ3TVujCmEpDNzwTym2pGLqK98DQG/jO
MXwP8PvFS5fZ6kYIIUc+EkKBM4qccMo1N9xSo06DFm06dOmRiIaQZI8U+xxw
SJojMhxTo06DK5q0aNOhS48pMxbMWfLFJys+GNDngXvuGPHKC8888cguO8TY
ZotNoqw1/PLDNwvmzJgy4Z03xowYcsE5JcpUIv8//wARvTHF
        "],
        VertexColors->None], 
       Line3DBox[{3175, 3176, 3205, 3206, 3200, 3201, 3202, 3203, 3204, 3227, 
        3228, 3229, 3233, 3234, 3375, 3376, 3379, 3380, 3382, 3403, 3404, 
        3405, 3409, 3421, 3423, 3424, 3445, 3446, 3447, 3526, 3527, 3501, 
        3500, 3499, 3498, 3504, 3503, 3502, 3484, 3483, 3485, 3481, 3480, 
        3340, 3339, 3336, 3335, 3333, 3312, 3311, 3310, 3306, 3294, 3292, 
        3291, 3270, 3269, 3268, 3178, 3177, 3175},
        VertexColors->None], 
       Line3DBox[{3207, 3208, 3214, 3215, 3216, 3230, 3231, 3232, 3235, 3236, 
        3377, 3378, 3381, 3383, 3395, 3410, 3412, 3413, 3422, 3425, 3427, 
        3428, 3497, 3496, 3495, 3494, 3493, 3492, 3477, 3476, 3482, 3479, 
        3478, 3338, 3337, 3334, 3332, 3320, 3305, 3303, 3302, 3293, 3290, 
        3288, 3287, 3211, 3209, 3210, 3207},
        VertexColors->None], 
       Line3DBox[{3212, 3213, 3219, 3220, 3217, 3218, 3237, 3238, 3245, 3246, 
        3247, 3384, 3385, 3386, 3394, 3396, 3411, 3415, 3418, 3420, 3426, 
        3491, 3490, 3489, 3488, 3475, 3474, 3469, 3468, 3467, 3331, 3330, 
        3329, 3321, 3319, 3304, 3300, 3297, 3295, 3289, 3212},
        VertexColors->None], 
       Line3DBox[{3222, 3221, 3296, 3298, 3301, 3315, 3318, 3324, 3327, 3461, 
        3466, 3471, 3473, 3486, 3487, 3419, 3417, 3414, 3400, 3397, 3391, 
        3387, 3252, 3249, 3241, 3239, 3224, 3223, 3222},
        VertexColors->None], 
       Line3DBox[{3226, 3225, 3299, 3314, 3316, 3322, 3325, 3328, 3462, 3463, 
        3464, 3470, 3472, 3416, 3401, 3399, 3392, 3390, 3388, 3253, 3250, 
        3248, 3243, 3240, 3226},
        VertexColors->None], 
       Line3DBox[{3244, 3242, 3317, 3323, 3326, 3460, 3465, 3398, 3393, 3389, 
        3254, 3251, 3244},
        VertexColors->None], Line3DBox[CompressedData["
1:eJwl0DdSQmEAhdHfFnkwQ1JK1qOIghYSCh8gYAGrQAsWopWpN1DBQijUBShm
j0Nx2u/O3FI8qg7XQggHvEYhvPHBJ0ve2UiFsEmRBOskyZAlR54Cd9zzwCNT
ZsxZ8MQzL/+ttBZJIlJkyJIjT4GYNl06HHPCgD49KuxQZpst6uxTo8oeu9za
vuGaKy654JwJZ5wypkuHNjFHtGjSoM4hgV9fffHNT7T68w8YxS10
        "],
        VertexColors->None], 
       Line3DBox[{3585, 3586, 3615, 3616, 3610, 3611, 3612, 3613, 3614, 3637, 
        3638, 3639, 3643, 3644, 3785, 3786, 3789, 3790, 3792, 3813, 3814, 
        3815, 3819, 3831, 3833, 3834, 3855, 3856, 3857, 3936, 3937, 3911, 
        3910, 3909, 3908, 3914, 3913, 3912, 3894, 3893, 3895, 3891, 3890, 
        3750, 3749, 3746, 3745, 3743, 3722, 3721, 3720, 3716, 3704, 3702, 
        3701, 3680, 3679, 3678, 3588, 3587, 3585},
        VertexColors->None], 
       Line3DBox[{3617, 3618, 3624, 3625, 3626, 3640, 3641, 3642, 3645, 3646, 
        3787, 3788, 3791, 3793, 3805, 3820, 3822, 3823, 3832, 3835, 3837, 
        3838, 3907, 3906, 3905, 3904, 3903, 3902, 3887, 3886, 3892, 3889, 
        3888, 3748, 3747, 3744, 3742, 3730, 3715, 3713, 3712, 3703, 3700, 
        3698, 3697, 3621, 3619, 3620, 3617},
        VertexColors->None], 
       Line3DBox[{3622, 3623, 3629, 3630, 3627, 3628, 3647, 3648, 3655, 3656, 
        3657, 3794, 3795, 3796, 3804, 3806, 3821, 3825, 3828, 3830, 3836, 
        3901, 3900, 3899, 3898, 3885, 3884, 3879, 3878, 3877, 3741, 3740, 
        3739, 3731, 3729, 3714, 3710, 3707, 3705, 3699, 3622},
        VertexColors->None], 
       Line3DBox[{3631, 3632, 3633, 3634, 3649, 3651, 3659, 3662, 3797, 3801, 
        3807, 3810, 3824, 3827, 3829, 3897, 3896, 3883, 3881, 3876, 3871, 
        3737, 3734, 3728, 3725, 3711, 3708, 3706, 3631},
        VertexColors->None], 
       Line3DBox[{3635, 3636, 3650, 3653, 3658, 3660, 3663, 3798, 3800, 3802, 
        3809, 3811, 3826, 3882, 3880, 3874, 3873, 3872, 3738, 3735, 3732, 
        3726, 3724, 3709, 3635},
        VertexColors->None], 
       Line3DBox[{3652, 3654, 3661, 3664, 3799, 3803, 3808, 3875, 3870, 3736, 
        3733, 3727, 3652},
        VertexColors->None]}}},
    VertexColors->CompressedData["
1:eJx0unk0le8b9q1EJCVUREUjopDQeDTIFGlUUSoUkqGUiIRoUpFSpImiSKaM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     "]], GraphicsComplex3DBox[CompressedData["
1:eJxM3Gc419//wHEjK5E9iyRFO6slx5aMooyUlYxIg6JUiMrMTrJHqOy9HSt7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    "], {
     {RGBColor[0.880722, 0.611041, 0.142051], Opacity[0.5], EdgeForm[None], 
      Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[Polygon3DBox[CompressedData["
1:eJxVnXXYldXzd0+H3S12t4JISAlIiKiIghgoNiIiWJggiKAYKCgiiIWCiAEq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         "]]],
       Lighting->"Neutral"]}, {}, {}, {}, {}},
    VertexColors->{
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143381, 0.4523915157143381, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977495`, 0.20933181110977495`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953374`, 0.025523560300953374`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826985, 0.5599212519826985, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.1655082326424132, 0.1655082326424132, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063408`, 0.24269488509063408`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.300145787776235, 0.300145787776235, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041647, 0.7990029020041647, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328712, 0.3216012188328712, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476479, 0.6042710320476479, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228795`, 0.48492124636228795`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.3443927181955512, 0.3443927181955512, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697425, 0.3945960418697425, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.7172161946826352, 0.7172161946826352, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266786`, 0.10645798861266786`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104005, 0.1523853201104005, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041658, 0.7990029020041658, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.030451141206554788`, 0.030451141206554788`, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338298, 0.06211222097338298, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063375`, 0.24269488509063375`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908774`, 0.27990698920908774`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555084`, 0.34439271819555084`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697422, 0.3945960418697422, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.4523915157143378, 0.4523915157143378, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134403, 0.5205167296134403, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804033`, 0.36866496741804033`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826988, 0.5599212519826988, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.2607848866826602, 0.2607848866826602, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476483, 0.6042710320476483, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.1281628831308641, 0.1281628831308641, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780695756, 0.0008333334780695756, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.0964920970947486, 0.0964920970947486, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241343`, 0.16550823264241343`, 1.], 
      RGBColor[0.17934819335171004`, 0.17934819335171004`, 1.], 
      RGBColor[0.1939421364027959, 0.1939421364027959, 1.], 
      RGBColor[0.20933181110977472`, 0.20933181110977472`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328713, 0.3216012188328713, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999817498793, 0.9999999817498793, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264175`, 0.22556465465264175`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804067`, 0.36866496741804067`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911418, 0.6554705506911418, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132931, 0.07823756811132931, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677801`, 0.11700785090677801`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018457`, 0.13994663242018457`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171015`, 0.17934819335171015`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.27990698920908796`, 0.27990698920908796`, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.42240931844551466`, 0.42240931844551466`, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.48492124636228817`, 0.48492124636228817`, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.655470550691142, 0.655470550691142, 1.], 
      RGBColor[0.7172161946826345, 0.7172161946826345, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.00020826825176400998`, 0.00020826825176400998`, 1.], 
      RGBColor[0.0008333334780696866, 0.0008333334780696866, 1.], 
      RGBColor[0.0018759787234706726`, 0.0018759787234706726`, 1.], 
      RGBColor[0.003337514524507812, 0.003337514524507812, 1.], 
      RGBColor[0.005219787187433433, 0.005219787187433433, 1.], 
      RGBColor[0.0075251905479323256`, 0.0075251905479323256`, 1.], 
      RGBColor[0.010256681389212985`, 0.010256681389212985`, 1.], 
      RGBColor[0.013417798753320831`, 0.013417798753320831`, 1.], 
      RGBColor[0.017012687445526864`, 0.017012687445526864`, 1.], 
      RGBColor[0.02104612610518719, 0.02104612610518719, 1.], 
      RGBColor[0.025523560300953263`, 0.025523560300953263`, 1.], 
      RGBColor[0.0304511412065549, 0.0304511412065549, 1.], 
      RGBColor[0.03583577052916598, 0.03583577052916598, 1.], 
      RGBColor[0.041685152500090084`, 0.041685152500090084`, 1.], 
      RGBColor[0.04800785390280804, 0.04800785390280804, 1.], 
      RGBColor[0.05481337331351743, 0.05481337331351743, 1.], 
      RGBColor[0.06211222097338309, 0.06211222097338309, 1.], 
      RGBColor[0.06991601101176803, 0.06991601101176803, 1.], 
      RGBColor[0.07823756811132943, 0.07823756811132943, 1.], 
      RGBColor[0.08709105116959004, 0.08709105116959004, 1.], 
      RGBColor[0.09649209709474871, 0.09649209709474871, 1.], 
      RGBColor[0.10645798861266775`, 0.10645798861266775`, 1.], 
      RGBColor[0.11700785090677812`, 0.11700785090677812`, 1.], 
      RGBColor[0.128162883130864, 0.128162883130864, 1.], 
      RGBColor[0.13994663242018435`, 0.13994663242018435`, 1.], 
      RGBColor[0.1523853201104004, 0.1523853201104004, 1.], 
      RGBColor[0.16550823264241332`, 0.16550823264241332`, 1.], 
      RGBColor[0.17934819335171026`, 0.17934819335171026`, 1.], 
      RGBColor[0.193942136402796, 0.193942136402796, 1.], 
      RGBColor[0.20933181110977483`, 0.20933181110977483`, 1.], 
      RGBColor[0.22556465465264186`, 0.22556465465264186`, 1.], 
      RGBColor[0.24269488509063386`, 0.24269488509063386`, 1.], 
      RGBColor[0.26078488668266, 0.26078488668266, 1.], 
      RGBColor[0.2799069892090881, 0.2799069892090881, 1.], 
      RGBColor[0.30014578777623513`, 0.30014578777623513`, 1.], 
      RGBColor[0.3216012188328714, 0.3216012188328714, 1.], 
      RGBColor[0.34439271819555095`, 0.34439271819555095`, 1.], 
      RGBColor[0.36866496741804056`, 0.36866496741804056`, 1.], 
      RGBColor[0.3945960418697424, 0.3945960418697424, 1.], 
      RGBColor[0.4224093184455149, 0.4224093184455149, 1.], 
      RGBColor[0.452391515714338, 0.452391515714338, 1.], 
      RGBColor[0.4849212463622883, 0.4849212463622883, 1.], 
      RGBColor[0.5205167296134406, 0.5205167296134406, 1.], 
      RGBColor[0.5599212519826986, 0.5599212519826986, 1.], 
      RGBColor[0.6042710320476481, 0.6042710320476481, 1.], 
      RGBColor[0.6554705506911425, 0.6554705506911425, 1.], 
      RGBColor[0.717216194682635, 0.717216194682635, 1.], 
      RGBColor[0.7990029020041651, 0.7990029020041651, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.8575077546554213, 0.8575077546554213, 1.], 
      RGBColor[0.00005206299626070443, 0.00005206299626070443, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.899113673809771, 0.899113673809771, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[0.9999999894632878, 0.9999999894632878, 1.], 
      RGBColor[0.000013015494947254957`, 0.000013015494947254957`, 1.], 
      RGBColor[1., 1., 1.], 
      RGBColor[0., 0., 1.], 
      RGBColor[0.8991136738097699, 0.8991136738097699, 1.]},
    VertexNormals->CompressedData["
1:eJztzrsJgEAQBNBBI8uwEnuwBMHYFizUIizBwEjksvMTvEkG3sIy/bSMc5Nk
65I2t6xn7QPnnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeec
v+zhnHPOOeecc84555xzzjnnnHPOOeecc84555xzzjnnnHPOOeecc84555xz
zjnnnHPOOeecc84555xzzjnnnHPOOeecc875b33lnHPOOeecc84555xzzjnn
nHPOOeecc84555xzzjnnnHPOOeec848813t1r7Wz5E/v8b/gB/iCRMo=
     "],
    VertexTextureCoordinates->CompressedData["
1:eJxl3UHILeddx/FBcKGIoZCFuClCNy7ERaVYWnrBrrpx0W5cSWloMaAIkoUb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     "]]},
  Axes->False,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 1},
  DisplayFunction->Identity,
  ImageSize->{360., 360.},
  Lighting->{{"Ambient", 
     GrayLevel[0.6]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.25], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]]},
  PlotRange->{{-2, 2}, {-2, 2}, {-2, 2}},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, Automatic, Automatic},
  ViewAngle->0.4703007239436897,
  ViewPoint->{1.249656434362891, -2.2646079196992215`, 2.1817217435069467`},
  ViewVertical->{-0.041972763995151756`, 0.05478565957939029, 
   0.9976155665320477}]], "Output",
 CellChangeTimes->{3.6509321228869123`*^9},
 CellID->1914332537,ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Editable->True,
ScreenStyleEnvironment->"Working",
WindowSize->{1083, 892},
WindowMargins->{{12, Automatic}, {Automatic, 0}},
WindowTitle->Automatic,
Visible->True,
DockedCells->{},
TaggingRules:>{
 "WorkLifeNotebookCreationVersion" -> "3.0.0:76", "Notebook", 
  "CreatedOn[{2015, 9, 7, 23, 26, 54.018245}]", 
  "OpenedDate[{2015, 9, 7, 23, 26, 54.937703}]", Diary`Diary`Organization :> 
  None, "ToolbarCellVersion" -> "3.0.0:76", "SaveBackupToolbarDockedCell", 
  "OpenedDate[{2015, 9, 8, 19, 33, 36.055638}]", 
  "OpenedDate[{2015, 9, 10, 17, 7, 19.116965}]", 
  "OpenedDate[{2015, 9, 11, 1, 56, 0.932181}]", 
  "LastOpened[{2015, 9, 11, 14, 19, 23.381686}]", 
  "OpenedDate[{2015, 9, 11, 14, 19, 23.548567}]", 
  "GUIDTag[192790197709260812603464389990507826759]"},
CreateCellID->True,
DefaultNewCellStyle->"Input",
FrontEndVersion->"10.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 6, \
2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Section"], ShowGroupOpener -> True], 
   Cell[
    StyleData["Subsection"], ShowGroupOpener -> True], 
   Cell[
    StyleData["Subsubsection"], ShowGroupOpener -> True]}, 
  WindowMargins -> {{295, Automatic}, {Automatic, 12}}, Visible -> False, 
  FrontEndVersion -> 
  "10.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (July 6, 2015)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "DiaryDate[{2015, 9, 7, 23, 26, 54.229558}]"->{
  Cell[603, 23, 305, 8, 92, "Title",
   CellOpen->True,
   CellTags->{
    "DiaryDate[{2015, 9, 7, 23, 26, 54.229558}]", 
     "CellGUID[158075531113598598368791436607253277117]"},
   CellID->1490466418]},
 "CellGUID[158075531113598598368791436607253277117]"->{
  Cell[603, 23, 305, 8, 92, "Title",
   CellOpen->True,
   CellTags->{
    "DiaryDate[{2015, 9, 7, 23, 26, 54.229558}]", 
     "CellGUID[158075531113598598368791436607253277117]"},
   CellID->1490466418]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"DiaryDate[{2015, 9, 7, 23, 26, 54.229558}]", 4550141, 79971},
 {"CellGUID[158075531113598598368791436607253277117]", 4550403, 79978}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[603, 23, 305, 8, 92, "Title",
 CellOpen->True,
 CellTags->{
  "DiaryDate[{2015, 9, 7, 23, 26, 54.229558}]", 
   "CellGUID[158075531113598598368791436607253277117]"},
 CellID->1490466418],
Cell[CellGroupData[{
Cell[933, 35, 206, 4, 64, "Section",
 CellID->53137184],
Cell[CellGroupData[{
Cell[1164, 43, 122, 2, 44, "Subsection",
 CellID->839477994],
Cell[1289, 47, 263, 5, 30, "Text",
 CellID->1440129765],
Cell[1555, 54, 427, 10, 30, "Text",
 CellID->1242176565],
Cell[1985, 66, 211, 5, 30, "Text",
 CellID->1811136106],
Cell[2199, 73, 275, 6, 30, "Text",
 CellID->1331320964],
Cell[2477, 81, 991, 18, 106, "Text",
 CellID->1665790189],
Cell[3471, 101, 468, 13, 44, "Text",
 CellID->746921763]
}, Open  ]],
Cell[CellGroupData[{
Cell[3976, 119, 204, 3, 44, "Subsection",
 CellID->1859160167],
Cell[4183, 124, 175, 4, 30, "Text",
 CellID->1584707174],
Cell[4361, 130, 35126, 585, 200, "Text",
 CellID->1879126508],
Cell[39490, 717, 317, 6, 30, "Text",
 CellID->707936593],
Cell[39810, 725, 800, 25, 59, "DisplayFormula",
 CellID->805650956],
Cell[40613, 752, 301, 7, 49, "Text",
 CellID->614425537],
Cell[40917, 761, 64924, 1073, 413, "Text",
 CellID->901763965],
Cell[105844, 1836, 9568, 165, 234, "Text",
 CellID->1937722837]
}, Open  ]],
Cell[CellGroupData[{
Cell[115449, 2006, 189, 3, 44, "Subsection",
 CellID->139084368],
Cell[115641, 2011, 1040, 20, 89, "Text",
 CellID->307386776],
Cell[116684, 2033, 855, 17, 82, "Text",
 CellID->1128765040],
Cell[117542, 2052, 1510, 37, 64, "Text",
 CellID->632671142],
Cell[119055, 2091, 503, 12, 50, "Input",
 CellID->858673513],
Cell[119561, 2105, 538, 15, 50, "Text",
 CellID->732743175],
Cell[120102, 2122, 150, 6, 31, "Text",
 CellID->1577158026],
Cell[CellGroupData[{
Cell[120277, 2132, 589, 19, 53, "Input",
 CellID->1543310327],
Cell[120869, 2153, 526, 17, 61, "Output",
 CellID->1099153206]
}, Open  ]],
Cell[121410, 2173, 204, 7, 31, "Text",
 CellID->1786892401],
Cell[CellGroupData[{
Cell[121639, 2184, 628, 20, 52, "Input",
 CellID->1109177423],
Cell[122270, 2206, 831, 27, 61, "Output",
 CellID->813601748]
}, Open  ]],
Cell[123116, 2236, 198, 8, 31, "Text",
 CellID->72086914],
Cell[123317, 2246, 649, 20, 64, "Input",
 CellID->259879548],
Cell[123969, 2268, 982, 30, 64, "Input",
 CellID->312793153],
Cell[124954, 2300, 544, 17, 49, "Text",
 CellID->1986570322],
Cell[CellGroupData[{
Cell[125523, 2321, 454, 12, 52, "Input",
 CellID->2052067146],
Cell[125980, 2335, 554, 13, 50, "Output",
 CellID->1176198187]
}, Open  ]],
Cell[126549, 2351, 247, 6, 30, "Text",
 CellID->1153083017],
Cell[126799, 2359, 314, 7, 30, "Text",
 CellID->467938630],
Cell[CellGroupData[{
Cell[127138, 2370, 458, 14, 58, "Input",
 CellID->97972188],
Cell[127599, 2386, 591, 16, 63, "Output",
 CellID->775958274]
}, Open  ]],
Cell[128205, 2405, 346, 9, 31, "Text",
 CellID->394138863],
Cell[CellGroupData[{
Cell[128576, 2418, 488, 14, 58, "Input",
 CellID->819432782],
Cell[129067, 2434, 504, 14, 63, "Output",
 CellID->2010006534]
}, Open  ]],
Cell[129586, 2451, 349, 9, 31, "Text",
 CellID->558952249],
Cell[CellGroupData[{
Cell[129960, 2464, 460, 14, 58, "Input",
 CellID->1097596727],
Cell[130423, 2480, 565, 16, 63, "Output",
 CellID->114565981]
}, Open  ]],
Cell[131003, 2499, 156, 2, 30, "Text",
 CellID->1394744027],
Cell[CellGroupData[{
Cell[131184, 2505, 465, 14, 58, "Input",
 CellID->1415107266],
Cell[131652, 2521, 509, 15, 63, "Output",
 CellID->1365094955]
}, Open  ]],
Cell[132176, 2539, 226, 7, 31, "Text",
 CellID->1431217511],
Cell[132405, 2548, 549, 14, 51, "Input",
 CellID->1171745599],
Cell[132957, 2564, 348, 10, 31, "Text",
 CellID->1012304277],
Cell[133308, 2576, 1750, 47, 76, "Input",
 CellID->17249391],
Cell[135061, 2625, 1079, 30, 76, "Input",
 CellID->1455839901],
Cell[136143, 2657, 667, 16, 70, "Text",
 CellID->1775296751]
}, Open  ]],
Cell[CellGroupData[{
Cell[136847, 2678, 219, 4, 44, "Subsection",
 CellID->350418199],
Cell[CellGroupData[{
Cell[137091, 2686, 352, 8, 28, "Input",
 CellID->428911551],
Cell[137446, 2696, 2279, 65, 120, "Output",
 CellID->143693563]
}, Open  ]],
Cell[CellGroupData[{
Cell[139762, 2766, 322, 7, 28, "Input",
 CellID->1176127223],
Cell[140087, 2775, 189, 3, 28, "Output",
 CellID->1286094113]
}, Open  ]],
Cell[CellGroupData[{
Cell[140313, 2783, 298, 6, 28, "Input",
 CellID->1239296472],
Cell[140614, 2791, 161, 3, 28, "Output",
 CellID->960850136]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[140836, 2801, 118, 2, 64, "Section",
 CellID->1184817857],
Cell[140957, 2805, 327, 7, 49, "Text",
 CellID->1765347615],
Cell[141287, 2814, 254, 5, 30, "Text",
 CellID->1149328518],
Cell[141544, 2821, 281, 6, 49, "Text",
 CellID->833680192]
}, Open  ]],
Cell[CellGroupData[{
Cell[141862, 2832, 190, 3, 64, "Section",
 CellID->1007106498],
Cell[CellGroupData[{
Cell[142077, 2839, 115, 2, 44, "Subsection",
 CellID->1499011559],
Cell[142195, 2843, 660, 16, 61, "Text",
 CellID->1242625867],
Cell[CellGroupData[{
Cell[142880, 2863, 514, 12, 51, "Input",
 CellID->1945623591],
Cell[143397, 2877, 2305, 65, 90, "Output",
 CellID->557359578]
}, Open  ]],
Cell[CellGroupData[{
Cell[145739, 2947, 419, 11, 51, "Input",
 CellID->1070117033],
Cell[146161, 2960, 1208, 36, 90, "Output",
 CellID->2010485893]
}, Open  ]],
Cell[147384, 2999, 288, 6, 49, "Text",
 CellID->204579048],
Cell[147675, 3007, 2942, 77, 187, "Input",
 CellID->805446546],
Cell[150620, 3086, 1735, 47, 91, "Input",
 CellID->814147825],
Cell[152358, 3135, 360, 7, 30, "Text",
 CellID->154342588],
Cell[152721, 3144, 284, 8, 31, "Input",
 CellID->1323435006],
Cell[153008, 3154, 393, 10, 31, "Input",
 CellID->1704025153]
}, Open  ]],
Cell[CellGroupData[{
Cell[153438, 3169, 140, 2, 44, "Subsection",
 CellID->502867073],
Cell[153581, 3173, 324, 7, 49, "Text",
 CellID->1715162838],
Cell[CellGroupData[{
Cell[153930, 3184, 316, 8, 51, "Input",
 CellID->1338744966],
Cell[154249, 3194, 454, 15, 63, "Output",
 CellID->1600530724]
}, Open  ]],
Cell[CellGroupData[{
Cell[154740, 3214, 763, 24, 64, "Input",
 CellID->680055749],
Cell[155506, 3240, 637, 20, 74, "Output",
 CellID->623071939]
}, Open  ]],
Cell[CellGroupData[{
Cell[156180, 3265, 726, 22, 77, "Input",
 CellID->685184104],
Cell[156909, 3289, 325, 11, 67, "Output",
 CellID->1525000723]
}, Open  ]],
Cell[157249, 3303, 457, 13, 42, "Text",
 CellID->1642036448],
Cell[CellGroupData[{
Cell[157731, 3320, 468, 15, 69, "Input",
 CellID->1952844528],
Cell[158202, 3337, 669, 22, 52, "Output",
 CellID->1756564992]
}, Open  ]],
Cell[158886, 3362, 392, 11, 42, "Text",
 CellID->1942274173]
}, Open  ]],
Cell[CellGroupData[{
Cell[159315, 3378, 189, 3, 44, "Subsection",
 CellID->262142437],
Cell[159507, 3383, 296, 7, 30, "Text",
 CellID->1760371544],
Cell[159806, 3392, 291, 6, 30, "Text",
 CellID->671699585],
Cell[CellGroupData[{
Cell[160122, 3402, 1188, 35, 74, "Input",
 CellID->160957774],
Cell[161313, 3439, 37181, 707, 376, "Output",
 CellID->134014425]
}, Open  ]],
Cell[198509, 4149, 473, 9, 49, "Text",
 CellID->1427656527],
Cell[CellGroupData[{
Cell[199007, 4162, 4345, 109, 295, "Input",
 CellID->1907003143],
Cell[203355, 4273, 33297, 665, 375, "Output",
 CellID->693348500]
}, Open  ]],
Cell[236667, 4941, 1051, 21, 107, "Text",
 CellID->1476542942]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[237767, 4968, 400, 12, 114, "Section",
 CellID->252724095],
Cell[CellGroupData[{
Cell[238192, 4984, 115, 2, 44, "Subsection",
 CellID->1977060651],
Cell[238310, 4988, 740, 23, 77, "Text",
 CellID->867775769],
Cell[239053, 5013, 242, 6, 30, "Text",
 CellID->993769986],
Cell[CellGroupData[{
Cell[239320, 5023, 618, 17, 70, "Input",
 CellID->443891326],
Cell[239941, 5042, 2502, 70, 103, "Output",
 CellID->1304341000]
}, Open  ]],
Cell[CellGroupData[{
Cell[242480, 5117, 618, 17, 70, "Input",
 CellID->425152673],
Cell[243101, 5136, 1448, 42, 103, "Output",
 CellID->546118424]
}, Open  ]],
Cell[244564, 5181, 226, 8, 31, "Text",
 CellID->665150686],
Cell[244793, 5191, 3314, 84, 245, "Input",
 CellID->493008203],
Cell[248110, 5277, 1951, 53, 104, "Input",
 CellID->996957695],
Cell[250064, 5332, 308, 9, 31, "Input",
 CellID->861970878],
Cell[250375, 5343, 415, 11, 31, "Input",
 CellID->219863884]
}, Open  ]],
Cell[CellGroupData[{
Cell[250827, 5359, 140, 2, 44, "Subsection",
 CellID->307849756],
Cell[CellGroupData[{
Cell[250992, 5365, 544, 15, 70, "Input",
 CellID->742743469],
Cell[251539, 5382, 656, 21, 89, "Output",
 CellID->310263991]
}, Open  ]],
Cell[CellGroupData[{
Cell[252232, 5408, 974, 30, 90, "Input",
 CellID->150414830],
Cell[253209, 5440, 709, 20, 62, "Output",
 CellID->1900677409]
}, Open  ]],
Cell[CellGroupData[{
Cell[253955, 5465, 922, 25, 62, "Input",
 CellID->90474272],
Cell[254880, 5492, 466, 13, 61, "Output",
 CellID->865963938]
}, Open  ]],
Cell[255361, 5508, 148, 2, 30, "Text",
 CellID->951398009]
}, Open  ]],
Cell[CellGroupData[{
Cell[255546, 5515, 134, 2, 44, "Subsection",
 CellID->652444475],
Cell[255683, 5519, 177, 3, 30, "Text",
 CellID->582789743],
Cell[CellGroupData[{
Cell[255885, 5526, 1180, 35, 74, "Input",
 CellID->274296634],
Cell[257068, 5563, 37332, 710, 376, "Output",
 CellID->308322049]
}, Open  ]],
Cell[294415, 6276, 137, 2, 30, "Text",
 CellID->1516498751],
Cell[CellGroupData[{
Cell[294577, 6282, 4679, 113, 260, "Input",
 CellID->1943859137],
Cell[299259, 6397, 27669, 453, 375, "Output",
 CellID->1356066043]
}, Open  ]],
Cell[326943, 6853, 627, 12, 68, "Text",
 CellID->1389638980],
Cell[327573, 6867, 195, 5, 30, "Text",
 CellID->1366025182],
Cell[CellGroupData[{
Cell[327793, 6876, 2611, 65, 131, "Input",
 CellID->1193845310],
Cell[330407, 6943, 12594, 211, 376, "Output",
 CellID->1114243051]
}, Open  ]],
Cell[343016, 7157, 230, 5, 30, "Text",
 CellID->2122027608],
Cell[343249, 7164, 280, 7, 28, "Input",
 CellID->768198854],
Cell[343532, 7173, 214, 5, 28, "Input",
 CellID->174626081],
Cell[343749, 7180, 482, 13, 28, "Input",
 CellID->1819804432],
Cell[344234, 7195, 158, 2, 30, "Text",
 CellID->430491815],
Cell[CellGroupData[{
Cell[344417, 7201, 217, 4, 28, "Input",
 CellID->1304431384],
Cell[344637, 7207, 54935, 1007, 414, "Output",
 CellID->1025556317]
}, Open  ]],
Cell[399587, 8217, 200, 5, 30, "Text",
 CellID->472774026],
Cell[CellGroupData[{
Cell[399812, 8226, 1134, 27, 135, "Input",
 CellID->1838132122],
Cell[400949, 8255, 569890, 10135, 406, "Output",
 CellID->1190633310]
}, Open  ]],
Cell[970854, 18393, 200, 3, 30, "Text",
 CellID->651085393],
Cell[971057, 18398, 1754, 43, 120, "Input",
 CellID->1495100134],
Cell[972814, 18443, 287, 7, 28, "Input",
 CellID->2003832896],
Cell[CellGroupData[{
Cell[973126, 18454, 83, 2, 28, "Input",
 CellID->1569375231],
Cell[973212, 18458, 244258, 3988, 291, "Output",
 CellID->1007470130]
}, Open  ]],
Cell[1217485, 22449, 154, 2, 30, "Text",
 CellID->331238253],
Cell[CellGroupData[{
Cell[1217664, 22455, 506, 10, 28, "Input",
 CellID->187545162],
Cell[1218173, 22467, 826498, 14141, 515, "Output",
 CellID->1659405620]
}, Open  ]],
Cell[2044686, 36611, 188, 4, 30, "Text",
 CellID->118059209],
Cell[CellGroupData[{
Cell[2044899, 36619, 2457, 67, 149, "Input",
 CellID->1496579925],
Cell[2047359, 36688, 177906, 3139, 377, "Output",
 CellID->601690876]
}, Open  ]],
Cell[2225280, 39830, 258, 5, 30, "Text",
 CellID->781908485],
Cell[CellGroupData[{
Cell[2225563, 39839, 2507, 68, 149, "Input",
 CellID->1435267006],
Cell[2228073, 39909, 281556, 4915, 377, "Output",
 CellID->1215003148]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2509678, 44830, 172, 3, 44, "Subsection",
 CellID->429072009],
Cell[2509853, 44835, 222, 5, 30, "Text",
 CellID->135909113],
Cell[2510078, 44842, 6040, 150, 609, "Input",
 CellID->2076185169],
Cell[2516121, 44994, 247, 5, 30, "Text",
 CellID->131289048],
Cell[CellGroupData[{
Cell[2516393, 45003, 356, 8, 28, "Input",
 CellID->3471281],
Cell[2516752, 45013, 924008, 16065, 558, "Output",
 CellID->465618857]
}, Open  ]],
Cell[3440775, 61081, 323, 7, 30, "Text",
 CellID->2005123308]
}, Open  ]],
Cell[CellGroupData[{
Cell[3441135, 61093, 196, 3, 44, "Subsection",
 CellID->2101273939],
Cell[3441334, 61098, 384, 7, 30, "Text",
 CellID->470166689],
Cell[3441721, 61107, 1787, 54, 142, "Input",
 CellID->707930719],
Cell[CellGroupData[{
Cell[3443533, 61165, 832, 21, 46, "Input",
 CellID->105700983],
Cell[3444368, 61188, 28837, 472, 406, "Output",
 CellID->1070057912]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3473266, 61667, 196, 3, 64, "Section",
 CellID->19044002],
Cell[CellGroupData[{
Cell[3473487, 61674, 120, 2, 44, "Subsection",
 CellID->97478211],
Cell[3473610, 61678, 469, 12, 32, "Text",
 CellID->1083191080],
Cell[CellGroupData[{
Cell[3474104, 61694, 513, 15, 55, "Input",
 CellID->1933753263],
Cell[3474620, 61711, 436, 13, 72, "Output",
 CellID->1143599798]
}, Open  ]],
Cell[3475071, 61727, 204, 5, 30, "Text",
 CellID->1184459662],
Cell[3475278, 61734, 149, 3, 30, "Text",
 CellID->690800992],
Cell[CellGroupData[{
Cell[3475452, 61741, 772, 25, 112, "Input",
 CellID->1133530922],
Cell[3476227, 61768, 562, 18, 74, "Output",
 CellID->2039876913]
}, Open  ]],
Cell[3476804, 61789, 420, 10, 50, "Text",
 CellID->1905330897],
Cell[CellGroupData[{
Cell[3477249, 61803, 1192, 35, 77, "Input",
 CellID->1322339561],
Cell[3478444, 61840, 872, 27, 90, "Output",
 CellID->473154978]
}, Open  ]],
Cell[3479331, 61870, 151, 2, 30, "Text",
 CellID->610290968],
Cell[3479485, 61874, 1239, 36, 91, "Input",
 CellID->116977404],
Cell[3480727, 61912, 221, 6, 30, "Text",
 CellID->493377353]
}, Open  ]],
Cell[CellGroupData[{
Cell[3480985, 61923, 140, 2, 44, "Subsection",
 CellID->1197875539],
Cell[CellGroupData[{
Cell[3481150, 61929, 298, 9, 51, "Input",
 CellID->183153390],
Cell[3481451, 61940, 963, 30, 90, "Output",
 CellID->533729327]
}, Open  ]],
Cell[3482429, 61973, 162, 3, 30, "Text",
 CellID->1043090698],
Cell[3482594, 61978, 1378, 39, 91, "Input",
 CellID->1316350825],
Cell[3483975, 62019, 412, 11, 31, "Text",
 CellID->1029497776],
Cell[3484390, 62032, 677, 21, 45, "Input",
 CellID->1562829634]
}, Open  ]],
Cell[CellGroupData[{
Cell[3485104, 62058, 183, 3, 44, "Subsection",
 CellID->290970972],
Cell[3485290, 62063, 151, 2, 30, "Text",
 CellID->1059647592],
Cell[CellGroupData[{
Cell[3485466, 62069, 504, 13, 28, "Input",
 CellID->413977081],
Cell[3485973, 62084, 5398, 101, 243, "Output",
 CellID->2068177289]
}, Open  ]],
Cell[3491386, 62188, 208, 5, 30, "Text",
 CellID->1853633507],
Cell[CellGroupData[{
Cell[3491619, 62197, 318, 9, 51, "Input",
 CellID->1489697098],
Cell[3491940, 62208, 298, 10, 75, "Output",
 CellID->93232348]
}, Open  ]],
Cell[CellGroupData[{
Cell[3492275, 62223, 643, 21, 77, "Input",
 CellID->980608506],
Cell[3492921, 62246, 354, 12, 68, "Output",
 CellID->1802412980]
}, Open  ]],
Cell[3493290, 62261, 144, 2, 30, "Text",
 CellID->750630278]
}, Open  ]],
Cell[CellGroupData[{
Cell[3493471, 62268, 204, 3, 44, "Subsection",
 CellID->1033820060],
Cell[3493678, 62273, 122, 2, 30, "Text",
 CellID->123560543],
Cell[CellGroupData[{
Cell[3493825, 62279, 407, 11, 28, "Input",
 CellID->815671893],
Cell[3494235, 62292, 5355, 100, 243, "Output",
 CellID->178219459]
}, Open  ]],
Cell[3499605, 62395, 209, 3, 30, "Text",
 CellID->657213787],
Cell[3499817, 62400, 1287, 36, 46, "Input",
 CellID->266775360],
Cell[3501107, 62438, 362229, 6010, 406, "Output",
 CellID->211963738],
Cell[CellGroupData[{
Cell[3863361, 68452, 1039, 28, 46, "Input",
 CellID->2037630118],
Cell[3864403, 68482, 131616, 2206, 404, "Output",
 CellID->1778441594]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3996068, 70694, 136, 2, 44, "Subsection",
 CellID->341284266],
Cell[CellGroupData[{
Cell[3996229, 70700, 455, 15, 70, "Input",
 CellID->35837525],
Cell[3996687, 70717, 1040, 33, 103, "Output",
 CellID->199229031]
}, Open  ]],
Cell[3997742, 70753, 115, 2, 30, "Text",
 CellID->515318344],
Cell[3997860, 70757, 1578, 45, 104, "Input",
 CellID->342221411],
Cell[3999441, 70804, 411, 11, 31, "Text",
 CellID->754048011],
Cell[3999855, 70817, 723, 22, 45, "Input",
 CellID->983919930]
}, Open  ]],
Cell[CellGroupData[{
Cell[4000615, 70844, 130, 2, 44, "Subsection",
 CellID->759531565],
Cell[4000748, 70848, 125, 2, 30, "Text",
 CellID->1549977545],
Cell[CellGroupData[{
Cell[4000898, 70854, 379, 11, 28, "Input",
 CellID->1504411512],
Cell[4001280, 70867, 6535, 120, 243, "Output",
 CellID->1601156074]
}, Open  ]],
Cell[4007830, 70990, 159, 3, 30, "Text",
 CellID->512555161],
Cell[CellGroupData[{
Cell[4008014, 70997, 571, 16, 28, "Input",
 CellID->957682810],
Cell[4008588, 71015, 11018, 195, 243, "Output",
 CellID->1417996537]
}, Open  ]],
Cell[4019621, 71213, 193, 5, 30, "Text",
 CellID->753462768],
Cell[4019817, 71220, 237, 5, 30, "Text",
 CellID->1121960919],
Cell[CellGroupData[{
Cell[4020079, 71229, 685, 19, 51, "Input",
 CellID->1435236552],
Cell[4020767, 71250, 9158, 163, 243, "Output",
 CellID->1100165321]
}, Open  ]],
Cell[4029940, 71416, 371, 7, 49, "Text",
 CellID->846380207],
Cell[CellGroupData[{
Cell[4030336, 71427, 2000, 46, 182, "Input",
 CellID->766512483],
Cell[4032339, 71475, 516194, 8449, 375, "Output",
 CellID->1914332537]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
